(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)




(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2279095,      95465]*)
(*NotebookOutlinePosition[   2280097,      95498]*)
(*  CellTagsIndexPosition[   2279959,      95491]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "3D XplorMath surface data conversion\n",
  StyleBox["by Xah Lee. 2002 November",
    FontSize->14]
}], "Title"],

Cell[CellGroupData[{

Cell["copyright & author info", "Subsubsection"],

Cell[TextData[{
  "XplorMathConvert.m is a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package, which read 3D XplorMath surface data files and display the \
surface in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".\n\nThis package is written by Xah Lee\nemail: xah@xahlee.org\nwebsite: \
",
  ButtonBox["http://xahlee.org/PageTwo_dir/more.html",
    ButtonData:>{
      URL[ "http://xahlee.org/PageTwo_dir/more.html"], None},
    ButtonStyle->"Hyperlink"],
  "\n3D-",
  "Xplor",
  "Math is a mathematics visualization software by Richard Palais, available \
at\n",
  ButtonBox["http://rsp.math.brandeis.edu/3D-Filmstrip_html/3D-\
FilmstripHomePage.html",
    ButtonData:>{
      URL[ 
      "http://rsp.math.brandeis.edu/3D-Filmstrip_html/3D-FilmstripHomePage.\
html"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell["\<\
This software is copyright \[Copyright] 2002 by Xah Lee. Personal \
use is granted.\
\>", "Text"],

Cell["\<\
The author is not responsible for any damage resulting from this \
software. Use at your own risk.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Loading the package", "Subtitle"],

Cell["\<\
Run the following to load the package. See Troubleshooting below if \
you get any errors. If Mathematica asks you whether you want to run all the \
initialization cells, answer Yes. Answer No is ok too.\
\>", "Text"],

Cell[BoxData[
    \(Get["\<XplorMathConvert.m\>", 
      Path \[Rule] {ToFileName[\(("\<FileName\>" /. 
                  NotebookInformation[
                    EvaluationNotebook[]])\)[\([{1}]\)]]}]\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Troubleshooting", "Subsubtitle",
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
  "The command above should have loaded the package for you. It does this \
specifying the full path to this notebook's directory. If you want to use \
this package often, you should place the file XplorMathConvert.m in a \
standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package despositiory location at\n",
  StyleBox["Applications/Mathematica 4.1.app/AddOns/ExtraPackages\n\n",
    FontFamily->"Osaka",
    FontSize->16],
  "On Mac OS X, go to the Application directory, hold down the control key \
and click on the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " application icon, then choose \"Show Package Contents\". That will allow \
you to open it as a directory. Then you can copy the XplorMathConvert.m into \
the designated directory.\n\nFor Windows, the steps are simular.\n\nOnce you \
have copied the file to the right directory, quit ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and restart again."
}], "Text"],

Cell[TextData[{
  "The following command will load the package.\n",
  StyleBox["(*before you can evaluate the following cell,  you need to make \
it active by going to the menu Cell\[Rule]Cell Properties\[Rule]Cell \
Evaluable*)",
    Background->RGBColor[0, 1, 0]]
}], "Text"],

Cell[BoxData[
    \(Needs["\<XplorMathConvert`\>"]\)], "Input",
  Evaluatable->False,
  Background->RGBColor[0, 1, 0]],

Cell[TextData[{
  "If you get the error\n",
  Cell[BoxData[
      \(Get::"noopen" \(\(:\)\(\ \)\) 
        "Cannot open \!\(\"XplorMathConvert`\"\)."\)], "Message",
    GeneratedCell->False,
    CellAutoOverwrite->False],
  "\nthen that means ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " cannot locate the package. Make sure you followed the instructions above \
precisely."
}], "Text"],

Cell["\<\
Alternatively, you can specify the full path to the file as the \
second argument to Needs.\
\>", "Text"],

Cell[BoxData[
    \(Needs["\<XplorMathConvert`\>", \
"\<~/Documents/3dxm/XplorMathConvert.m\>"]\)], "Input",
  Evaluatable->False,
  Background->RGBColor[0, 1, 0]],

Cell[TextData[{
  "Or, you can append a path to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s search path stored in $Path"
}], "Text"],

Cell[BoxData[
    \(Append[$Path, "\<~/Documents/3dxm\>"] // InputForm\)], "Input",
  Evaluatable->False,
  Background->RGBColor[0, 1, 0]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Converting a Surface", "Subtitle"],

Cell[CellGroupData[{

Cell["Showing 3D XplorMath surfaces", "Section"],

Cell[CellGroupData[{

Cell["ShowSurface", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ShowSurface\)\)], "Input"],

Cell[BoxData[
    \("ShowSurface[\"3dfs_surface_file\"] returns a Graphics3D object that \
represents the 3D XplorMath's surface date file. Example: \
ShowSurface[\"~/Documents/3dxm/Costa.surf\"]"\)], "Print",
  CellTags->"Info3247255160-7945342"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mySurface = ShowSurface["\<Costa.surf\>"]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .97101 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00692488 1.0652 -1.66533e-16 1.0652 [
[ 0 0 0 0 ]
[ 1 .97101 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06678 .25008 m
0 .67149 L
s
0 .67149 m
.39925 .97101 L
s
.39925 .97101 m
.41257 .59009 L
s
.41257 .59009 m
.06678 .25008 L
s
.67926 0 m
.94495 .42182 L
s
.94495 .42182 m
1 .82462 L
s
1 .82462 m
.70489 .4415 L
s
.70489 .4415 m
.67926 0 L
s
.06678 .25008 m
0 .67149 L
s
0 .67149 m
.70489 .4415 L
s
.70489 .4415 m
.67926 0 L
s
.67926 0 m
.06678 .25008 L
s
.41257 .59009 m
.94495 .42182 L
s
.94495 .42182 m
1 .82462 L
s
1 .82462 m
.39925 .97101 L
s
.39925 .97101 m
.41257 .59009 L
s
0 0 m
1 0 L
1 .97101 L
0 .97101 L
closepath
clip
newpath
.5 Mabswid
.46067 .49984 m .50762 .50444 L .5048 .52827 L p .529 .79 .993 r
F P
0 g
s
.5048 .52827 m .44339 .52215 L .46067 .49984 L p .529 .79 .993 r
F P
0 g
s
.55849 .527 m .5048 .52827 L .50762 .50444 L p .558 .816 .994 r
F P
0 g
s
.50762 .50444 m .54891 .50335 L .55849 .527 L p .558 .816 .994 r
F P
0 g
s
.60155 .52151 m .55849 .527 L .54891 .50335 L p .588 .835 .992 r
F P
0 g
s
.41191 .48764 m .46067 .49984 L .44339 .52215 L p .507 .758 .986 r
F P
0 g
s
.44339 .52215 m .3792 .50604 L .41191 .48764 L p .507 .758 .986 r
F P
0 g
s
.54891 .50335 m .582 .49895 L .60155 .52151 L p .588 .835 .992 r
F P
0 g
s
.63247 .51488 m .60155 .52151 L .582 .49895 L p .613 .847 .988 r
F P
0 g
s
.582 .49895 m .60578 .49381 L .63247 .51488 L p .613 .847 .988 r
F P
0 g
s
.65095 .5098 m .63247 .51488 L .60578 .49381 L p .63 .853 .984 r
F P
0 g
s
.60578 .49381 m .61995 .48983 L .65095 .5098 L p .63 .853 .984 r
F P
0 g
s
.65711 .5079 m .65095 .5098 L .61995 .48983 L p .638 .856 .982 r
F P
0 g
s
.61995 .48983 m .62465 .48832 L .65711 .5079 L p .638 .856 .982 r
F P
0 g
s
.62935 .4868 m .62465 .48832 L .65711 .5079 L p .643 .857 .981 r
F P
0 g
s
.65711 .5079 m .66321 .50591 L .62935 .4868 L p .643 .857 .981 r
F P
0 g
s
.36639 .46695 m .41191 .48764 L .3792 .50604 L p .498 .725 .973 r
F P
0 g
s
.3792 .50604 m .31844 .47866 L .36639 .46695 L p .498 .725 .973 r
F P
0 g
s
.64286 .48185 m .62935 .4868 L .66321 .50591 L p .651 .859 .979 r
F P
0 g
s
.66321 .50591 m .68088 .49953 L .64286 .48185 L p .651 .859 .979 r
F P
0 g
s
.66384 .47251 m .64286 .48185 L .68088 .49953 L p .667 .862 .974 r
F P
0 g
s
.68088 .49953 m .70843 .48756 L .66384 .47251 L p .667 .862 .974 r
F P
0 g
s
.68983 .45766 m .66384 .47251 L .70843 .48756 L p .689 .864 .965 r
F P
0 g
s
.70843 .48756 m .74272 .46819 L .68983 .45766 L p .689 .864 .965 r
F P
0 g
s
.32923 .43835 m .36639 .46695 L .31844 .47866 L p .504 .694 .954 r
F P
0 g
s
.31844 .47866 m .26772 .44047 L .32923 .43835 L p .504 .694 .954 r
F P
0 g
s
.47164 .48963 m .50879 .49308 L .50762 .50444 L p .4 .777 .992 r
F P
0 g
s
.50762 .50444 m .46067 .49984 L .47164 .48963 L p .4 .777 .992 r
F P
0 g
s
.54891 .50335 m .50762 .50444 L .50879 .49308 L p .449 .819 .993 r
F P
0 g
s
.50879 .49308 m .54157 .49214 L .54891 .50335 L p .449 .819 .993 r
F P
0 g
s
.582 .49895 m .54891 .50335 L .54157 .49214 L p .501 .852 .993 r
F P
0 g
s
.43341 .48013 m .47164 .48963 L .46067 .49984 L p .372 .733 .99 r
F P
0 g
s
.46067 .49984 m .41191 .48764 L .43341 .48013 L p .372 .733 .99 r
F P
0 g
s
.71708 .43604 m .68983 .45766 L .74272 .46819 L p .714 .861 .952 r
F P
0 g
s
.74272 .46819 m .77897 .43992 L .71708 .43604 L p .714 .861 .952 r
F P
0 g
s
.54157 .49214 m .56795 .48849 L .582 .49895 L p .501 .852 .993 r
F P
0 g
s
.60578 .49381 m .582 .49895 L .56795 .48849 L p .544 .874 .992 r
F P
0 g
s
.56795 .48849 m .58691 .48434 L .60578 .49381 L p .544 .874 .992 r
F P
0 g
s
.61995 .48983 m .60578 .49381 L .58691 .48434 L p .576 .887 .99 r
F P
0 g
s
.58691 .48434 m .59825 .48115 L .61995 .48983 L p .576 .887 .99 r
F P
0 g
s
.62465 .48832 m .61995 .48983 L .59825 .48115 L p .595 .894 .989 r
F P
0 g
s
.39814 .46417 m .43341 .48013 L .41191 .48764 L p .37 .689 .981 r
F P
0 g
s
.41191 .48764 m .36639 .46695 L .39814 .46417 L p .37 .689 .981 r
F P
0 g
s
.60575 .47871 m .602 .47993 L .62465 .48832 L p .595 .894 .989 r
F P
0 g
s
.62465 .48832 m .62935 .4868 L .60575 .47871 L p .595 .894 .989 r
F P
0 g
s
.59825 .48115 m .602 .47993 L .62465 .48832 L p .595 .894 .989 r
F P
0 g
s
.61651 .4747 m .60575 .47871 L .62935 .4868 L p .613 .9 .987 r
F P
0 g
s
.62935 .4868 m .64286 .48185 L .61651 .4747 L p .613 .9 .987 r
F P
0 g
s
.63326 .46721 m .61651 .4747 L .64286 .48185 L p .644 .907 .982 r
F P
0 g
s
.64286 .48185 m .66384 .47251 L .63326 .46721 L p .644 .907 .982 r
F P
0 g
s
.30504 .40386 m .32923 .43835 L .26772 .44047 L p .521 .67 .93 r
F P
0 g
s
.26772 .44047 m .23321 .39395 L .30504 .40386 L p .521 .67 .93 r
F P
0 g
s
.65395 .45542 m .63326 .46721 L .66384 .47251 L p .68 .913 .974 r
F P
0 g
s
.66384 .47251 m .68983 .45766 L .65395 .45542 L p .68 .913 .974 r
F P
0 g
s
.7407 .40734 m .71708 .43604 L .77897 .43992 L p .737 .851 .934 r
F P
0 g
s
.77897 .43992 m .81108 .40185 L .7407 .40734 L p .737 .851 .934 r
F P
0 g
s
.36997 .44221 m .39814 .46417 L .36639 .46695 L p .398 .654 .961 r
F P
0 g
s
.36639 .46695 m .32923 .43835 L .36997 .44221 L p .398 .654 .961 r
F P
0 g
s
.50849 .49 m .50879 .49308 L p .49093 .48968 L .134 .663 .87 r
F P
0 g
s
.54157 .49214 m .50879 .49308 L .50849 .49 L p .21 .726 .873 r
F P
0 g
s
.53565 .48904 m .54157 .49214 L p .51921 .49069 L .21 .726 .873 r
F P
0 g
s
.50849 .49 m .53565 .48904 L p .51921 .49069 L .21 .726 .873 r
F P
0 g
s
.56795 .48849 m .54157 .49214 L .53565 .48904 L p .311 .795 .894 r
F P
0 g
s
.55766 .48609 m .56795 .48849 L p .54413 .4889 L .311 .795 .894 r
F P
0 g
s
.53565 .48904 m .55766 .48609 L p .54413 .4889 L .311 .795 .894 r
F P
0 g
s
.58691 .48434 m .56795 .48849 L .55766 .48609 L p .379 .838 .905 r
F P
0 g
s
.57351 .48252 m .58691 .48434 L p .56164 .48585 L .379 .838 .905 r
F P
0 g
s
.55766 .48609 m .57351 .48252 L p .56164 .48585 L .379 .838 .905 r
F P
0 g
s
.59825 .48115 m .58691 .48434 L .57351 .48252 L p .439 .87 .919 r
F P
0 g
s
.58302 .47981 m .59825 .48115 L p .57501 .48243 L .439 .87 .919 r
F P
0 g
s
.57351 .48252 m .58302 .47981 L p .57501 .48243 L .439 .87 .919 r
F P
0 g
s
.58302 .47981 m .57351 .48252 L p .58117 .48037 L 0 0 0 r
F P
0 g
s
.57224 .48319 m .58302 .47981 L p .56528 .48515 L 0 0 0 r
F P
0 g
s
.56382 .48559 m .57224 .48319 L p .56528 .48515 L 0 0 0 r
F P
0 g
s
.57224 .48319 m .56449 .48947 L p .57472 .4825 L .062 0 0 r
F P
0 g
s
.57503 .48228 m .57224 .48319 L p .57472 .4825 L .062 0 0 r
F P
0 g
s
.58302 .47981 m .57224 .48319 L p .58586 .47888 L .228 .735 .682 r
F P
0 g
s
.58617 .47878 m .58302 .47981 L p .58586 .47888 L .228 .735 .682 r
F P
0 g
s
.57351 .48252 m .56382 .48559 L p .58117 .48037 L 0 0 0 r
F P
0 g
s
.55766 .48609 m .5498 .48869 L p .56819 .4839 L 0 0 0 r
F P
0 g
s
.57351 .48252 m .55766 .48609 L p .56819 .4839 L 0 0 0 r
F P
0 g
s
.53565 .48904 m .53058 .49134 L p .54969 .48764 L .028 0 0 r
F P
0 g
s
.55766 .48609 m .53565 .48904 L p .54969 .48764 L .028 0 0 r
F P
0 g
s
.50849 .49 m .50709 .49207 L p .52401 .49028 L .14 0 0 r
F P
0 g
s
.53565 .48904 m .50849 .49 L p .52401 .49028 L .14 0 0 r
F P
0 g
s
.47801 .48723 m .50849 .49 L p .49093 .48968 L .134 .663 .87 r
F P
0 g
s
.50879 .49308 m .47164 .48963 L .47801 .48723 L p .134 .663 .87 r
F P
0 g
s
.44697 .47958 m .47801 .48723 L .47164 .48963 L p .095 .609 .888 r
F P
0 g
s
.47164 .48963 m .43341 .48013 L .4469 .47958 L p .095 .609 .888 r
F P
0 g
s
.47164 .48963 m .4469 .47958 L .4471 .47963 L .095 .609 .888 r
F
.45492 .48315 m .48106 .48962 L .47801 .48723 L p .314 0 0 r
F P
0 g
s
.47801 .48723 m .47801 .48723 L p .478 .48723 L .314 0 0 r
F P
0 g
s
.478 .48723 m .45492 .48315 L .47801 .48723 L .314 0 0 r
F
.4469 .47958 m .44697 .47958 L p .4471 .47963 L .095 .609 .888 r
F P
0 g
s
.49651 .70167 m .52403 .70358 L .52454 .67805 L p .624 .733 .925 r
F P
0 g
s
.52403 .70358 m .55589 .70386 L .55126 .67903 L p .623 .741 .932 r
F P
0 g
s
.55126 .67903 m .52454 .67805 L .52403 .70358 L p .623 .741 .932 r
F P
0 g
s
.47441 .699 m .49651 .70167 L .50141 .67569 L p .626 .727 .92 r
F P
0 g
s
.52454 .67805 m .50141 .67569 L .49651 .70167 L p .624 .733 .925 r
F P
0 g
s
.55589 .70386 m .59089 .70176 L .5806 .67783 L p .626 .752 .938 r
F P
0 g
s
.5806 .67783 m .55126 .67903 L .55589 .70386 L p .626 .752 .938 r
F P
0 g
s
.45814 .69643 m .47441 .699 L .48284 .67284 L p .629 .724 .915 r
F P
0 g
s
.50141 .67569 m .48284 .67284 L .47441 .699 L p .626 .727 .92 r
F P
0 g
s
.67549 .4383 m .65395 .45542 L .68983 .45766 L p .723 .91 .959 r
F P
0 g
s
.68983 .45766 m .71708 .43604 L .67549 .4383 L p .723 .91 .959 r
F P
0 g
s
.44826 .69459 m .45814 .69643 L .46925 .67016 L p .631 .723 .913 r
F P
0 g
s
.48284 .67284 m .46925 .67016 L .45814 .69643 L p .629 .724 .915 r
F P
0 g
s
.44154 .69376 m .44426 .69447 L .45747 .66821 L p .628 .715 .909 r
F P
0 g
s
.44542 .69412 m .44826 .69459 L .46097 .66831 L p .627 .715 .91 r
F P
0 g
s
.46925 .67016 m .46097 .66831 L .44826 .69459 L p .631 .723 .913 r
F P
0 g
s
.46097 .66831 m .45865 .66785 L .44542 .69412 L p .627 .715 .91 r
F P
0 g
s
.59089 .70176 m .62736 .6966 L .61118 .6739 L p .633 .764 .941 r
F P
0 g
s
.61118 .6739 m .5806 .67783 L .59089 .70176 L p .633 .764 .941 r
F P
0 g
s
.43178 .69163 m .44154 .69376 L .45527 .6675 L p .636 .721 .909 r
F P
0 g
s
.45747 .66821 m .45527 .6675 L .44154 .69376 L p .628 .715 .909 r
F P
0 g
s
.41605 .68773 m .43178 .69163 L .4471 .6654 L p .64 .72 .906 r
F P
0 g
s
.45527 .6675 m .4471 .6654 L .43178 .69163 L p .636 .721 .909 r
F P
0 g
s
.41866 .4668 m .44697 .47958 L .43341 .48013 L p .123 .578 .921 r
F P
0 g
s
.43341 .48013 m .39814 .46417 L .41866 .4668 L p .123 .578 .921 r
F P
0 g
s
.602 .47993 m .59825 .48115 L .58302 .47981 L p .477 .889 .926 r
F P
0 g
s
.39529 .68176 m .41605 .68773 L .43396 .66168 L p .646 .719 .902 r
F P
0 g
s
.4471 .6654 m .43396 .66168 L .41605 .68773 L p .64 .72 .906 r
F P
0 g
s
.58932 .47775 m .58617 .47878 L .602 .47993 L p .477 .889 .926 r
F P
0 g
s
.602 .47993 m .60575 .47871 L .58932 .47775 L p .477 .889 .926 r
F P
0 g
s
.58302 .47981 m .58617 .47878 L .602 .47993 L p .477 .889 .926 r
F P
0 g
s
.62736 .6966 m .66357 .68811 L .64144 .66685 L p .645 .773 .942 r
F P
0 g
s
.64144 .66685 m .61118 .6739 L .62736 .6966 L p .645 .773 .942 r
F P
0 g
s
.59836 .4744 m .58932 .47775 L .60575 .47871 L p .513 .906 .932 r
F P
0 g
s
.60575 .47871 m .61651 .4747 L .59836 .4744 L p .513 .906 .932 r
F P
0 g
s
.37046 .67321 m .39529 .68176 L .41662 .65597 L p .654 .721 .898 r
F P
0 g
s
.43396 .66168 m .41662 .65597 L .39529 .68176 L p .646 .719 .902 r
F P
0 g
s
.61245 .46818 m .59836 .4744 L .61651 .4747 L p .565 .928 .938 r
F P
0 g
s
.61651 .4747 m .63326 .46721 L .61245 .46818 L p .565 .928 .938 r
F P
0 g
s
.35226 .41601 m .36997 .44221 L .32923 .43835 L p .442 .627 .932 r
F P
0 g
s
.32923 .43835 m .30504 .40386 L .35226 .41601 L p .442 .627 .932 r
F P
0 g
s
.66357 .68811 m .69794 .67655 L .67001 .65689 L p .659 .779 .938 r
F P
0 g
s
.67001 .65689 m .64144 .66685 L .66357 .68811 L p .659 .779 .938 r
F P
0 g
s
.34312 .66182 m .37046 .67321 L .39587 .64807 L p .663 .724 .895 r
F P
0 g
s
.41662 .65597 m .39587 .64807 L .37046 .67321 L p .654 .721 .898 r
F P
0 g
s
.6298 .45819 m .61245 .46818 L .63326 .46721 L p .636 .949 .946 r
F P
0 g
s
.63326 .46721 m .65395 .45542 L .6298 .45819 L p .636 .949 .946 r
F P
0 g
s
.3964 .44941 m .41866 .4668 L .39814 .46417 L p .209 .562 .936 r
F P
0 g
s
.39814 .46417 m .36997 .44221 L .3964 .44941 L p .209 .562 .936 r
F P
0 g
s
.69402 .41589 m .67549 .4383 L .71708 .43604 L p .76 .897 .938 r
F P
0 g
s
.71708 .43604 m .7407 .40734 L .69402 .41589 L p .76 .897 .938 r
F P
0 g
s
.75518 .37238 m .7407 .40734 L .81108 .40185 L p .753 .833 .913 r
F P
0 g
s
.81108 .40185 m .83157 .35481 L .75518 .37238 L p .753 .833 .913 r
F P
0 g
s
.48106 .48962 m .50709 .49207 L .50849 .49 L p .247 0 0 r
F P
0 g
s
.50849 .49 m .47801 .48723 L .48106 .48962 L p .247 0 0 r
F P
0 g
s
.47801 .48723 m .44697 .47958 L .45492 .48315 L p .314 0 0 r
F P
0 g
s
.50709 .49207 m .53058 .49134 L .53565 .48904 L p .14 0 0 r
F P
0 g
s
.50141 .67569 m .52454 .67805 L .52492 .65892 L p .6 .719 .928 r
F P
0 g
s
.52454 .67805 m .55126 .67903 L .54768 .66075 L p .597 .733 .939 r
F P
0 g
s
.54768 .66075 m .52492 .65892 L .52454 .67805 L p .597 .733 .939 r
F P
0 g
s
.48284 .67284 m .50141 .67569 L .50526 .65592 L p .605 .71 .918 r
F P
0 g
s
.52492 .65892 m .50526 .65592 L .50141 .67569 L p .6 .719 .928 r
F P
0 g
s
.29616 .36679 m .30504 .40386 L .23321 .39395 L p .545 .653 .906 r
F P
0 g
s
.23321 .39395 m .21859 .3433 L .29616 .36679 L p .545 .653 .906 r
F P
0 g
s
.46925 .67016 m .48284 .67284 L .48948 .65261 L p .61 .704 .911 r
F P
0 g
s
.50526 .65592 m .48948 .65261 L .48284 .67284 L p .605 .71 .918 r
F P
0 g
s
.53058 .49134 m .5498 .48869 L .55766 .48609 L p .028 0 0 r
F P
0 g
s
.55126 .67903 m .5806 .67783 L .57266 .66063 L p .601 .751 .949 r
F P
0 g
s
.57266 .66063 m .54768 .66075 L .55126 .67903 L p .601 .751 .949 r
F P
0 g
s
.46097 .66831 m .46925 .67016 L .47799 .64969 L p .614 .703 .907 r
F P
0 g
s
.48948 .65261 m .47799 .64969 L .46925 .67016 L p .61 .704 .911 r
F P
0 g
s
.31483 .64752 m .34312 .66182 L .37315 .63779 L p .671 .731 .895 r
F P
0 g
s
.39587 .64807 m .37315 .63779 L .34312 .66182 L p .663 .724 .895 r
F P
0 g
s
.45527 .6675 m .45747 .66821 L .46784 .64757 L p .606 .687 .9 r
F P
0 g
s
.45865 .66785 m .46097 .66831 L .47094 .6477 L p .604 .687 .901 r
F P
0 g
s
.47799 .64969 m .47094 .6477 L .46097 .66831 L p .614 .703 .907 r
F P
0 g
s
.47094 .6477 m .46905 .64721 L .45865 .66785 L p .604 .687 .901 r
F P
0 g
s
.4471 .6654 m .45527 .6675 L .46608 .64683 L p .622 .7 .901 r
F P
0 g
s
.46784 .64757 m .46608 .64683 L .45527 .6675 L p .606 .687 .9 r
F P
0 g
s
.69794 .67655 m .72892 .66243 L .69559 .64449 L p .672 .78 .931 r
F P
0 g
s
.69559 .64449 m .67001 .65689 L .69794 .67655 L p .672 .78 .931 r
F P
0 g
s
.6479 .4441 m .6298 .45819 L .65395 .45542 L p .717 .962 .943 r
F P
0 g
s
.65395 .45542 m .67549 .4383 L .6479 .4441 L p .717 .962 .943 r
F P
0 g
s
.43132 .47246 m .45492 .48315 L .44697 .47958 L p 0 .293 .649 r
F P
0 g
s
.41309 .45823 m .43132 .47246 L .41866 .4668 L p 0 .347 .793 r
F P
0 g
s
.42305 .46744 m .42681 .47037 L p .43132 .47246 L .563 .023 0 r
F P
0 g
s
.43645 .47483 m .41866 .4668 L .43132 .47246 L p 0 .293 .649 r
F P
0 g
s
.42681 .47037 m .43856 .47953 L .43132 .47246 L p .563 .023 0 r
F P
0 g
s
.44697 .47958 m .43645 .47483 L p .43132 .47246 L 0 .293 .649 r
F P
0 g
s
.43396 .66168 m .4471 .6654 L .45912 .64465 L p .629 .698 .895 r
F P
0 g
s
.46608 .64683 m .45912 .64465 L .4471 .6654 L p .622 .7 .901 r
F P
0 g
s
.5498 .48869 m .56382 .48559 L .57351 .48252 L p 0 0 0 r
F P
0 g
s
.5806 .67783 m .61118 .6739 L .59863 .6578 L p .614 .772 .956 r
F P
0 g
s
.59863 .6578 m .57266 .66063 L .5806 .67783 L p .614 .772 .956 r
F P
0 g
s
.41662 .65597 m .43396 .66168 L .44803 .64085 L p .639 .698 .888 r
F P
0 g
s
.45912 .64465 m .44803 .64085 L .43396 .66168 L p .629 .698 .895 r
F P
0 g
s
.5859 .47837 m .57783 .48136 L .57931 .4809 L p .284 .774 .707 r
F P
0 g
s
.57931 .4809 m .58932 .47775 L p .5859 .47837 L .284 .774 .707 r
F P
0 g
s
.59846 .47279 m .5859 .47837 L .59836 .4744 L p .371 .83 .747 r
F P
0 g
s
.5859 .47837 m .59846 .47279 L .59638 .47436 L p 0 0 0 r
F P
0 g
s
.58617 .47878 m .58932 .47775 L .57783 .48136 L p .228 .735 .682 r
F P
0 g
s
.58932 .47775 m .59836 .4744 L .5859 .47837 L p .284 .774 .707 r
F P
0 g
s
.59638 .47436 m .58939 .47965 L p .5859 .47837 L 0 0 0 r
F P
0 g
s
.57783 .48136 m .5859 .47837 L .58514 .47897 L p .009 0 0 r
F P
0 g
s
.57534 .48218 m .58617 .47878 L p .57783 .48136 L .228 .735 .682 r
F P
0 g
s
.57224 .48319 m .57503 .48228 L .58617 .47878 L p .228 .735 .682 r
F P
0 g
s
.58514 .47897 m .57744 .48494 L p .57783 .48136 L .009 0 0 r
F P
0 g
s
.57783 .48136 m .57503 .48228 L .57534 .48218 L p .228 .735 .682 r
F P
0 g
s
.61118 .6739 m .64144 .66685 L .62431 .65199 L p .635 .79 .956 r
F P
0 g
s
.62431 .65199 m .59863 .6578 L .61118 .6739 L p .635 .79 .956 r
F P
0 g
s
.39587 .64807 m .41662 .65597 L .43332 .63519 L p .652 .701 .882 r
F P
0 g
s
.44803 .64085 m .43332 .63519 L .41662 .65597 L p .639 .698 .888 r
F P
0 g
s
.59836 .4744 m .61245 .46818 L .59846 .47279 L p .371 .83 .747 r
F P
0 g
s
.38298 .42896 m .3964 .44941 L .36997 .44221 L p .314 .553 .919 r
F P
0 g
s
.36997 .44221 m .35226 .41601 L .38298 .42896 L p .314 .553 .919 r
F P
0 g
s
.41866 .4668 m .3964 .44941 L .41309 .45823 L p 0 .347 .793 r
F P
0 g
s
.28755 .63045 m .31483 .64752 L .3498 .62512 L p .678 .74 .898 r
F P
0 g
s
.37315 .63779 m .3498 .62512 L .31483 .64752 L p .671 .731 .895 r
F P
0 g
s
.37315 .63779 m .39587 .64807 L .41575 .62754 L p .666 .707 .879 r
F P
0 g
s
.43332 .63519 m .41575 .62754 L .39587 .64807 L p .652 .701 .882 r
F P
0 g
s
.72892 .66243 m .75546 .64671 L .7174 .63063 L p .681 .776 .922 r
F P
0 g
s
.7174 .63063 m .69559 .64449 L .72892 .66243 L p .681 .776 .922 r
F P
0 g
s
.48172 .49486 m .50471 .49734 L .50709 .49207 L p .518 0 0 r
F P
0 g
s
.50709 .49207 m .48106 .48962 L .48172 .49486 L p .518 0 0 r
F P
0 g
s
.53058 .49134 m .50709 .49207 L .50471 .49734 L p .413 0 0 r
F P
0 g
s
.61397 .46402 m .59846 .47279 L .61245 .46818 L p .502 .905 .797 r
F P
0 g
s
.61245 .46818 m .6298 .45819 L .61397 .46402 L p .502 .905 .797 r
F P
0 g
s
.45889 .48891 m .48172 .49486 L .48106 .48962 L p .604 .064 0 r
F P
0 g
s
.48106 .48962 m .45492 .48315 L .45889 .48891 L p .604 .064 0 r
F P
0 g
s
.64144 .66685 m .67001 .65689 L .64839 .64324 L p .66 .8 .95 r
F P
0 g
s
.64839 .64324 m .62431 .65199 L .64144 .66685 L p .66 .8 .95 r
F P
0 g
s
.66345 .42573 m .6479 .4441 L .67549 .4383 L p .781 .952 .928 r
F P
0 g
s
.67549 .4383 m .69402 .41589 L .66345 .42573 L p .781 .952 .928 r
F P
0 g
s
.70519 .38886 m .69402 .41589 L .7407 .40734 L p .785 .871 .911 r
F P
0 g
s
.7407 .40734 m .75518 .37238 L .70519 .38886 L p .785 .871 .911 r
F P
0 g
s
.50471 .49734 m .52585 .49695 L .53058 .49134 L p .413 0 0 r
F P
0 g
s
.5498 .48869 m .53058 .49134 L .52585 .49695 L p .303 0 0 r
F P
0 g
s
.34677 .3881 m .35226 .41601 L .30504 .40386 L p .488 .612 .901 r
F P
0 g
s
.30504 .40386 m .29616 .36679 L .34677 .3881 L p .488 .612 .901 r
F P
0 g
s
.43856 .47953 m .45889 .48891 L .45492 .48315 L p .647 .089 0 r
F P
0 g
s
.45492 .48315 m .43132 .47246 L .43856 .47953 L p .647 .089 0 r
F P
0 g
s
.48948 .65261 m .50526 .65592 L .50838 .64104 L p .571 .682 .915 r
F P
0 g
s
.50526 .65592 m .52492 .65892 L .52521 .64495 L p .56 .695 .931 r
F P
0 g
s
.52521 .64495 m .50838 .64104 L .50526 .65592 L p .56 .695 .931 r
F P
0 g
s
.52585 .49695 m .54351 .49462 L .5498 .48869 L p .303 0 0 r
F P
0 g
s
.56382 .48559 m .5498 .48869 L .54351 .49462 L p .201 0 0 r
F P
0 g
s
.52492 .65892 m .54768 .66075 L .54485 .64787 L p .553 .718 .949 r
F P
0 g
s
.54485 .64787 m .52521 .64495 L .52492 .65892 L p .553 .718 .949 r
F P
0 g
s
.47799 .64969 m .48948 .65261 L .49475 .63702 L p .581 .674 .904 r
F P
0 g
s
.50838 .64104 m .49475 .63702 L .48948 .65261 L p .571 .682 .915 r
F P
0 g
s
.47094 .6477 m .47799 .64969 L .48487 .63364 L p .588 .671 .897 r
F P
0 g
s
.49475 .63702 m .48487 .63364 L .47799 .64969 L p .581 .674 .904 r
F P
0 g
s
.46608 .64683 m .46784 .64757 L .47608 .6312 L p .571 .643 .882 r
F P
0 g
s
.3498 .62512 m .37315 .63779 L .39652 .6179 L p .679 .718 .879 r
F P
0 g
s
.41575 .62754 m .39652 .6179 L .37315 .63779 L p .666 .707 .879 r
F P
0 g
s
.45912 .64465 m .46608 .64683 L .47465 .63037 L p .601 .668 .887 r
F P
0 g
s
.47608 .6312 m .47465 .63037 L .46608 .64683 L p .571 .643 .882 r
F P
0 g
s
.46905 .64721 m .47094 .6477 L .47886 .63139 L p .568 .643 .884 r
F P
0 g
s
.48487 .63364 m .47886 .63139 L .47094 .6477 L p .588 .671 .897 r
F P
0 g
s
.47886 .63139 m .4773 .63083 L .46905 .64721 L p .568 .643 .884 r
F P
0 g
s
.54768 .66075 m .57266 .66063 L .56647 .64891 L p .557 .748 .966 r
F P
0 g
s
.56647 .64891 m .54485 .64787 L .54768 .66075 L p .557 .748 .966 r
F P
0 g
s
.44803 .64085 m .45912 .64465 L .46871 .628 L p .613 .667 .878 r
F P
0 g
s
.47465 .63037 m .46871 .628 L .45912 .64465 L p .601 .668 .887 r
F P
0 g
s
.54351 .49462 m .55656 .49175 L .56382 .48559 L p .201 0 0 r
F P
0 g
s
.57224 .48319 m .56382 .48559 L .55656 .49175 L p .119 0 0 r
F P
0 g
s
.63008 .45162 m .61397 .46402 L .6298 .45819 L p .645 .968 .846 r
F P
0 g
s
.6298 .45819 m .6479 .4441 L .63008 .45162 L p .645 .968 .846 r
F P
0 g
s
.43332 .63519 m .44803 .64085 L .45916 .62391 L p .629 .669 .869 r
F P
0 g
s
.46871 .628 m .45916 .62391 L .44803 .64085 L p .613 .667 .878 r
F P
0 g
s
.57266 .66063 m .59863 .6578 L .58893 .6472 L p .577 .783 .977 r
F P
0 g
s
.58893 .6472 m .56647 .64891 L .57266 .66063 L p .577 .783 .977 r
F P
0 g
s
.67001 .65689 m .69559 .64449 L .66985 .6321 L p .683 .801 .938 r
F P
0 g
s
.66985 .6321 m .64839 .64324 L .67001 .65689 L p .683 .801 .938 r
F P
0 g
s
.55656 .49175 m .56449 .48947 L .57224 .48319 L p .119 0 0 r
F P
0 g
s
.56979 .48774 m .56718 .48872 L .57503 .48228 L p .062 0 0 r
F P
0 g
s
.57503 .48228 m .57783 .48136 L .56979 .48774 L p .062 0 0 r
F P
0 g
s
.56449 .48947 m .56718 .48872 L .57503 .48228 L p .062 0 0 r
F P
0 g
s
.41575 .62754 m .43332 .63519 L .44642 .61802 L p .648 .673 .86 r
F P
0 g
s
.45916 .62391 m .44642 .61802 L .43332 .63519 L p .629 .669 .869 r
F P
0 g
s
.40247 .44172 m .41309 .45823 L .3964 .44941 L p .103 .413 .862 r
F P
0 g
s
.3964 .44941 m .38298 .42896 L .40247 .44172 L p .103 .413 .862 r
F P
0 g
s
.57744 .48494 m .56979 .48774 L .57783 .48136 L p .009 0 0 r
F P
0 g
s
.42139 .46471 m .41309 .45823 L .42305 .46744 L p .563 .023 0 r
F P
0 g
s
.41425 .45362 m .42305 .46744 L .41309 .45823 L p 0 .16 .694 r
F P
0 g
s
.42089 .46423 m .4245 .46983 L p .42305 .46744 L .609 .19 0 r
F P
0 g
s
.4245 .46983 m .42853 .47608 L .42305 .46744 L p .609 .19 0 r
F P
0 g
s
.43132 .47246 m .42139 .46471 L p .42305 .46744 L .563 .023 0 r
F P
0 g
s
.75546 .64671 m .77705 .63067 L .73496 .61642 L p .686 .768 .914 r
F P
0 g
s
.73496 .61642 m .7174 .63063 L .75546 .64671 L p .686 .768 .914 r
F P
0 g
s
.26301 .61107 m .28755 .63045 L .32732 .61036 L p .681 .751 .904 r
F P
0 g
s
.3498 .62512 m .32732 .61036 L .28755 .63045 L p .678 .74 .898 r
F P
0 g
s
.59863 .6578 m .62431 .65199 L .61108 .64239 L p .614 .815 .977 r
F P
0 g
s
.61108 .64239 m .58893 .6472 L .59863 .6578 L p .614 .815 .977 r
F P
0 g
s
.58939 .47965 m .57744 .48494 L .5859 .47837 L p 0 0 0 r
F P
0 g
s
.46026 .49556 m .4807 .50147 L .48172 .49486 L p .713 .277 .211 r
F P
0 g
s
.48172 .49486 m .45889 .48891 L .46026 .49556 L p .713 .277 .211 r
F P
0 g
s
.50471 .49734 m .48172 .49486 L .4807 .50147 L p .628 .199 .207 r
F P
0 g
s
.4807 .50147 m .50155 .50428 L .50471 .49734 L p .628 .199 .207 r
F P
0 g
s
.52585 .49695 m .50471 .49734 L .50155 .50428 L p .538 .105 .167 r
F P
0 g
s
.39652 .6179 m .41575 .62754 L .43138 .61035 L p .669 .684 .855 r
F P
0 g
s
.44642 .61802 m .43138 .61035 L .41575 .62754 L p .648 .673 .86 r
F P
0 g
s
.32732 .61036 m .3498 .62512 L .37676 .60641 L p .691 .733 .883 r
F P
0 g
s
.39652 .6179 m .37676 .60641 L .3498 .62512 L p .679 .718 .879 r
F P
0 g
s
.75543 .33362 m .75518 .37238 L .83157 .35481 L p .761 .809 .891 r
F P
0 g
s
.83157 .35481 m .83345 .30168 L .75543 .33362 L p .761 .809 .891 r
F P
0 g
s
.44222 .48692 m .46026 .49556 L .45889 .48891 L p .79 .335 .162 r
F P
0 g
s
.45889 .48891 m .43856 .47953 L .44222 .48692 L p .79 .335 .162 r
F P
0 g
s
.50155 .50428 m .52114 .5044 L .52585 .49695 L p .538 .105 .167 r
F P
0 g
s
.54351 .49462 m .52585 .49695 L .52114 .5044 L p .444 .007 .11 r
F P
0 g
s
.37958 .4074 m .38298 .42896 L .35226 .41601 L p .408 .55 .886 r
F P
0 g
s
.35226 .41601 m .34677 .3881 L .37958 .4074 L p .408 .55 .886 r
F P
0 g
s
.6041 .47138 m .58939 .47965 L .59846 .47279 L p 0 0 0 r
F P
0 g
s
.59846 .47279 m .61397 .46402 L .6041 .47138 L p 0 0 0 r
F P
0 g
s
.67272 .40394 m .66345 .42573 L .69402 .41589 L p .823 .916 .9 r
F P
0 g
s
.69402 .41589 m .70519 .38886 L .67272 .40394 L p .823 .916 .9 r
F P
0 g
s
.64384 .43574 m .63008 .45162 L .6479 .4441 L p .78 .994 .874 r
F P
0 g
s
.6479 .4441 m .66345 .42573 L .64384 .43574 L p .78 .994 .874 r
F P
0 g
s
.69559 .64449 m .7174 .63063 L .68792 .61939 L p .699 .793 .923 r
F P
0 g
s
.68792 .61939 m .66985 .6321 L .69559 .64449 L p .699 .793 .923 r
F P
0 g
s
.62431 .65199 m .64839 .64324 L .63175 .63456 L p .659 .833 .966 r
F P
0 g
s
.63175 .63456 m .61108 .64239 L .62431 .65199 L p .659 .833 .966 r
F P
0 g
s
.52114 .5044 m .538 .5025 L .54351 .49462 L p .444 .007 .11 r
F P
0 g
s
.55656 .49175 m .54351 .49462 L .538 .5025 L p .362 0 .058 r
F P
0 g
s
.37676 .60641 m .39652 .6179 L .41474 .60102 L p .689 .701 .856 r
F P
0 g
s
.43138 .61035 m .41474 .60102 L .39652 .6179 L p .669 .684 .855 r
F P
0 g
s
.48487 .63364 m .49475 .63702 L .49896 .62505 L p .536 .628 .89 r
F P
0 g
s
.49475 .63702 m .50838 .64104 L .5107 .6301 L p .518 .638 .907 r
F P
0 g
s
.5107 .6301 m .49896 .62505 L .49475 .63702 L p .518 .638 .907 r
F P
0 g
s
.47465 .63037 m .47608 .6312 L .48269 .61806 L p .523 .582 .856 r
F P
0 g
s
.50838 .64104 m .52521 .64495 L .52537 .63525 L p .495 .656 .932 r
F P
0 g
s
.52537 .63525 m .5107 .6301 L .50838 .64104 L p .495 .656 .932 r
F P
0 g
s
.46871 .628 m .47465 .63037 L .48149 .6171 L p .57 .623 .866 r
F P
0 g
s
.48269 .61806 m .48149 .6171 L .47465 .63037 L p .523 .582 .856 r
F P
0 g
s
.47886 .63139 m .48487 .63364 L .49042 .62102 L p .549 .625 .88 r
F P
0 g
s
.49896 .62505 m .49042 .62102 L .48487 .63364 L p .536 .628 .89 r
F P
0 g
s
.4773 .63083 m .47886 .63139 L .48526 .61838 L p .517 .581 .858 r
F P
0 g
s
.48526 .61838 m .48392 .61768 L .4773 .63083 L p .517 .581 .858 r
F P
0 g
s
.49042 .62102 m .48526 .61838 L .47886 .63139 L p .549 .625 .88 r
F P
0 g
s
.45916 .62391 m .46871 .628 L .47636 .61439 L p .59 .624 .854 r
F P
0 g
s
.48149 .6171 m .47636 .61439 L .46871 .628 L p .57 .623 .866 r
F P
0 g
s
.52521 .64495 m .54485 .64787 L .54258 .63951 L p .475 .689 .96 r
F P
0 g
s
.54258 .63951 m .52537 .63525 L .52521 .64495 L p .475 .689 .96 r
F P
0 g
s
.44642 .61802 m .45916 .62391 L .46812 .60979 L p .615 .628 .841 r
F P
0 g
s
.47636 .61439 m .46812 .60979 L .45916 .62391 L p .59 .624 .854 r
F P
0 g
s
.42853 .47608 m .44222 .48692 L .43856 .47953 L p .82 .339 0 r
F P
0 g
s
.43856 .47953 m .42305 .46744 L .42853 .47608 L p .82 .339 0 r
F P
0 g
s
.538 .5025 m .55086 .4998 L .55656 .49175 L p .362 0 .058 r
F P
0 g
s
.56449 .48947 m .55656 .49175 L .55086 .4998 L p .3 0 .02 r
F P
0 g
s
.41309 .45823 m .40247 .44172 L .41425 .45362 L p 0 .16 .694 r
F P
0 g
s
.54485 .64787 m .56647 .64891 L .56158 .64174 L p .472 .736 .985 r
F P
0 g
s
.56158 .64174 m .54258 .63951 L .54485 .64787 L p .472 .736 .985 r
F P
0 g
s
.45996 .50223 m .4787 .50826 L .4807 .50147 L p .747 .39 .376 r
F P
0 g
s
.4807 .50147 m .46026 .49556 L .45996 .50223 L p .747 .39 .376 r
F P
0 g
s
.50155 .50428 m .4807 .50147 L .4787 .50826 L p .667 .309 .356 r
F P
0 g
s
.43138 .61035 m .44642 .61802 L .45701 .60349 L p .643 .638 .83 r
F P
0 g
s
.46812 .60979 m .45701 .60349 L .44642 .61802 L p .615 .628 .841 r
F P
0 g
s
.61923 .45977 m .6041 .47138 L .61397 .46402 L p .443 .821 .576 r
F P
0 g
s
.63198 .44528 m .61923 .45977 L .63008 .45162 L p .693 .957 .701 r
F P
0 g
s
.62557 .45384 m .62319 .45657 L p .61923 .45977 L 0 0 0 r
F P
0 g
s
.61421 .46384 m .63008 .45162 L .61923 .45977 L p .443 .821 .576 r
F P
0 g
s
.62319 .45657 m .61344 .4677 L .61923 .45977 L p 0 0 0 r
F P
0 g
s
.61397 .46402 m .61421 .46384 L p .61923 .45977 L .443 .821 .576 r
F P
0 g
s
.30235 .3308 m .29616 .36679 L .21859 .3433 L p .57 .644 .884 r
F P
0 g
s
.21859 .3433 m .22411 .29344 L .30235 .3308 L p .57 .644 .884 r
F P
0 g
s
.4787 .50826 m .4979 .51174 L .50155 .50428 L p .667 .309 .356 r
F P
0 g
s
.52114 .5044 m .50155 .50428 L .4979 .51174 L p .587 .224 .32 r
F P
0 g
s
.55086 .4998 m .5588 .49758 L .56449 .48947 L p .3 0 .02 r
F P
0 g
s
.56718 .48872 m .56449 .48947 L .5588 .49758 L p .302 0 .02 r
F P
0 g
s
.44354 .49382 m .45996 .50223 L .46026 .49556 L p .828 .458 .355 r
F P
0 g
s
.46026 .49556 m .44222 .48692 L .44354 .49382 L p .828 .458 .355 r
F P
0 g
s
.56414 .49584 m .56148 .49672 L .56718 .48872 L p .222 0 0 r
F P
0 g
s
.56718 .48872 m .56979 .48774 L .56414 .49584 L p .222 0 0 r
F P
0 g
s
.5588 .49758 m .56148 .49672 L .56718 .48872 L p .302 0 .02 r
F P
0 g
s
.56647 .64891 m .58893 .6472 L .58149 .64116 L p .5 .791 .997 r
F P
0 g
s
.58149 .64116 m .56158 .64174 L .56647 .64891 L p .5 .791 .997 r
F P
0 g
s
.77705 .63067 m .79362 .6155 L .74833 .60293 L p .687 .76 .907 r
F P
0 g
s
.74833 .60293 m .73496 .61642 L .77705 .63067 L p .687 .76 .907 r
F P
0 g
s
.41474 .60102 m .43138 .61035 L .44374 .59555 L p .672 .655 .825 r
F P
0 g
s
.45701 .60349 m .44374 .59555 L .43138 .61035 L p .643 .638 .83 r
F P
0 g
s
.57191 .49297 m .56414 .49584 L .56979 .48774 L p .224 0 0 r
F P
0 g
s
.56979 .48774 m .57744 .48494 L .57191 .49297 L p .224 0 0 r
F P
0 g
s
.64839 .64324 m .66985 .6321 L .64996 .62419 L p .7 .833 .947 r
F P
0 g
s
.64996 .62419 m .63175 .63456 L .64839 .64324 L p .7 .833 .947 r
F P
0 g
s
.32732 .61036 m .30731 .59395 L .26301 .61107 L p .681 .751 .904 r
F P
0 g
s
.30731 .59395 m .32732 .61036 L .35796 .59333 L p .697 .751 .893 r
F P
0 g
s
.37676 .60641 m .35796 .59333 L .32732 .61036 L p .691 .733 .883 r
F P
0 g
s
.35796 .59333 m .37676 .60641 L .39767 .59028 L p .707 .724 .863 r
F P
0 g
s
.41474 .60102 m .39767 .59028 L .37676 .60641 L p .689 .701 .856 r
F P
0 g
s
.4979 .51174 m .51627 .51267 L .52114 .5044 L p .587 .224 .32 r
F P
0 g
s
.538 .5025 m .52114 .5044 L .51627 .51267 L p .509 .136 .268 r
F P
0 g
s
.70516 .35942 m .70519 .38886 L .75518 .37238 L p .795 .835 .882 r
F P
0 g
s
.75518 .37238 m .75543 .33362 L .70516 .35942 L p .795 .835 .882 r
F P
0 g
s
.40042 .4246 m .40247 .44172 L .38298 .42896 L p .292 .456 .852 r
F P
0 g
s
.38298 .42896 m .37958 .4074 L .40042 .4246 L p .292 .456 .852 r
F P
0 g
s
.58401 .48755 m .57191 .49297 L .57744 .48494 L p .157 0 0 r
F P
0 g
s
.57744 .48494 m .58939 .47965 L .58401 .48755 L p .157 0 0 r
F P
0 g
s
.58893 .6472 m .61108 .64239 L .60102 .63721 L p .565 .845 .997 r
F P
0 g
s
.60102 .63721 m .58149 .64116 L .58893 .6472 L p .565 .845 .997 r
F P
0 g
s
.7174 .63063 m .73496 .61642 L .70241 .60629 L p .706 .78 .909 r
F P
0 g
s
.70241 .60629 m .68792 .61939 L .7174 .63063 L p .706 .78 .909 r
F P
0 g
s
.43108 .48385 m .44354 .49382 L .44222 .48692 L p .905 .517 .272 r
F P
0 g
s
.44222 .48692 m .42853 .47608 L .43108 .48385 L p .905 .517 .272 r
F P
0 g
s
.24243 .59018 m .26301 .61107 L .30731 .59395 L p .68 .762 .913 r
F P
0 g
s
.45884 .50816 m .4763 .51455 L .4787 .50826 L p .755 .449 .466 r
F P
0 g
s
.4787 .50826 m .45996 .50223 L .45884 .50816 L p .755 .449 .466 r
F P
0 g
s
.4979 .51174 m .4787 .50826 L .4763 .51455 L p .681 .373 .447 r
F P
0 g
s
.39767 .59028 m .41474 .60102 L .42898 .5863 L p .7 .68 .827 r
F P
0 g
s
.44374 .59555 m .42898 .5863 L .41474 .60102 L p .672 .655 .825 r
F P
0 g
s
.4435 .49991 m .45884 .50816 L .45996 .50223 L p .834 .525 .466 r
F P
0 g
s
.45996 .50223 m .44354 .49382 L .4435 .49991 L p .834 .525 .466 r
F P
0 g
s
.42305 .46744 m .4176 .45889 L p .42089 .46423 L .609 .19 0 r
F P
0 g
s
.42853 .47608 m .42307 .46761 L p .42411 .47323 L .872 .493 .013 r
F P
0 g
s
.42307 .46761 m .42089 .46423 L .42411 .47323 L p .872 .493 .013 r
F P
0 g
s
.42411 .47323 m .43108 .48385 L .42853 .47608 L p .872 .493 .013 r
F P
0 g
s
.43108 .48385 m .42411 .47323 L .42524 .48062 L p .97 .661 .284 r
F P
0 g
s
.42444 .47165 m .42501 .47804 L p .42411 .47323 L 0 0 .141 r
F P
0 g
s
.42501 .47804 m .42524 .48062 L .42411 .47323 L p 0 0 .141 r
F P
0 g
s
.42336 .46322 m .42379 .46896 L p .42089 .46423 L 0 0 .42 r
F P
0 g
s
.42379 .46896 m .42411 .47323 L .42089 .46423 L p 0 0 .42 r
F P
0 g
s
.4176 .45889 m .41425 .45362 L .42089 .46423 L p .609 .19 0 r
F P
0 g
s
.51627 .51267 m .53271 .51137 L .538 .5025 L p .509 .136 .268 r
F P
0 g
s
.55086 .4998 m .538 .5025 L .53271 .51137 L p .44 .058 .217 r
F P
0 g
s
.5987 .47914 m .58401 .48755 L .58939 .47965 L p .046 0 0 r
F P
0 g
s
.58939 .47965 m .6041 .47138 L .5987 .47914 L p .046 0 0 r
F P
0 g
s
.35298 .36132 m .34677 .3881 L .29616 .36679 L p .53 .605 .873 r
F P
0 g
s
.29616 .36679 m .30235 .3308 L .35298 .36132 L p .53 .605 .873 r
F P
0 g
s
.4763 .51455 m .49419 .51881 L .4979 .51174 L p .681 .373 .447 r
F P
0 g
s
.51627 .51267 m .4979 .51174 L .49419 .51881 L p .606 .292 .411 r
F P
0 g
s
.65212 .41731 m .64384 .43574 L .66345 .42573 L p .861 .964 .867 r
F P
0 g
s
.66345 .42573 m .67272 .40394 L .65212 .41731 L p .861 .964 .867 r
F P
0 g
s
.48149 .6171 m .48269 .61806 L .48811 .60728 L p .444 .482 .804 r
F P
0 g
s
.46812 .60979 m .47636 .61439 L .4828 .60292 L p .56 .569 .819 r
F P
0 g
s
.47636 .61439 m .48149 .6171 L .48721 .60611 L p .528 .561 .833 r
F P
0 g
s
.48721 .60611 m .4828 .60292 L .47636 .61439 L p .528 .561 .833 r
F P
0 g
s
.48811 .60728 m .48721 .60611 L .48149 .6171 L p .444 .482 .804 r
F P
0 g
s
.45701 .60349 m .46812 .60979 L .47558 .59767 L p .597 .579 .804 r
F P
0 g
s
.4828 .60292 m .47558 .59767 L .46812 .60979 L p .56 .569 .819 r
F P
0 g
s
.48392 .61768 m .48526 .61838 L .49042 .60773 L p .432 .477 .806 r
F P
0 g
s
.49042 .60773 m .48936 .60689 L .48392 .61768 L p .432 .477 .806 r
F P
0 g
s
.48526 .61838 m .49042 .62102 L .49484 .61092 L p .491 .558 .852 r
F P
0 g
s
.49484 .61092 m .49042 .60773 L .48526 .61838 L p .491 .558 .852 r
F P
0 g
s
.49042 .62102 m .49896 .62505 L .50221 .61595 L p .47 .561 .866 r
F P
0 g
s
.50221 .61595 m .49484 .61092 L .49042 .62102 L p .47 .561 .866 r
F P
0 g
s
.63008 .45162 m .64384 .43574 L .63198 .44528 L p .693 .957 .701 r
F P
0 g
s
.44374 .59555 m .45701 .60349 L .46579 .59071 L p .636 .597 .794 r
F P
0 g
s
.47558 .59767 m .46579 .59071 L .45701 .60349 L p .597 .579 .804 r
F P
0 g
s
.49896 .62505 m .5107 .6301 L .51235 .62232 L p .435 .569 .89 r
F P
0 g
s
.51235 .62232 m .50221 .61595 L .49896 .62505 L p .435 .569 .89 r
F P
0 g
s
.5107 .6301 m .52537 .63525 L .5252 .62902 L p .385 .589 .925 r
F P
0 g
s
.5252 .62902 m .51235 .62232 L .5107 .6301 L p .385 .589 .925 r
F P
0 g
s
.46558 .83315 m .52189 .83867 L .51742 .90109 L p .705 .701 .843 r
F P
0 g
s
.51742 .90109 m .44236 .89471 L .46558 .83315 L p .705 .701 .843 r
F P
0 g
s
.5976 .89818 m .51742 .90109 L .52189 .83867 L p .683 .682 .842 r
F P
0 g
s
.61108 .64239 m .63175 .63456 L .61909 .63 L p .649 .879 .983 r
F P
0 g
s
.61909 .63 m .60102 .63721 L .61108 .64239 L p .649 .879 .983 r
F P
0 g
s
.42898 .5863 m .44374 .59555 L .45383 .58241 L p .674 .623 .789 r
F P
0 g
s
.46579 .59071 m .45383 .58241 L .44374 .59555 L p .636 .597 .794 r
F P
0 g
s
.52537 .63525 m .54258 .63951 L .54052 .63482 L p .331 .627 .959 r
F P
0 g
s
.54052 .63482 m .5252 .62902 L .52537 .63525 L p .331 .627 .959 r
F P
0 g
s
.66985 .6321 m .68792 .61939 L .6651 .6121 L p .725 .818 .923 r
F P
0 g
s
.6651 .6121 m .64996 .62419 L .66985 .6321 L p .725 .818 .923 r
F P
0 g
s
.45748 .51303 m .47402 .51978 L .4763 .51455 L p .756 .484 .521 r
F P
0 g
s
.4763 .51455 m .45884 .50816 L .45748 .51303 L p .756 .484 .521 r
F P
0 g
s
.49419 .51881 m .4763 .51455 L .47402 .51978 L p .685 .411 .503 r
F P
0 g
s
.53271 .51137 m .54588 .50884 L .55086 .4998 L p .44 .058 .217 r
F P
0 g
s
.5588 .49758 m .55086 .4998 L .54588 .50884 L p .389 .002 .179 r
F P
0 g
s
.4428 .50475 m .45748 .51303 L .45884 .50816 L p .83 .562 .533 r
F P
0 g
s
.45884 .50816 m .4435 .49991 L .4428 .50475 L p .83 .562 .533 r
F P
0 g
s
.43177 .49039 m .4435 .49991 L .44354 .49382 L p .918 .605 .435 r
F P
0 g
s
.44354 .49382 m .43108 .48385 L .43177 .49039 L p .918 .605 .435 r
F P
0 g
s
.39767 .59028 m .38152 .57845 L .35796 .59333 L p .707 .724 .863 r
F P
0 g
s
.38152 .57845 m .39767 .59028 L .4139 .57601 L p .725 .711 .837 r
F P
0 g
s
.42898 .5863 m .4139 .57601 L .39767 .59028 L p .7 .68 .827 r
F P
0 g
s
.49419 .51881 m .51136 .52079 L .51627 .51267 L p .606 .292 .411 r
F P
0 g
s
.53271 .51137 m .51627 .51267 L .51136 .52079 L p .533 .207 .361 r
F P
0 g
s
.54258 .63951 m .56158 .64174 L .55772 .63841 L p .296 .683 .975 r
F P
0 g
s
.55772 .63841 m .54052 .63482 L .54258 .63951 L p .296 .683 .975 r
F P
0 g
s
.41301 .43966 m .41425 .45362 L .40247 .44172 L p .127 .313 .781 r
F P
0 g
s
.40247 .44172 m .40042 .4246 L .41301 .43966 L p .127 .313 .781 r
F P
0 g
s
.54588 .50884 m .55433 .50654 L .5588 .49758 L p .389 .002 .179 r
F P
0 g
s
.56148 .49672 m .5588 .49758 L .55433 .50654 L p .364 0 .164 r
F P
0 g
s
.47402 .51978 m .49085 .52478 L .49419 .51881 L p .685 .411 .503 r
F P
0 g
s
.51136 .52079 m .49419 .51881 L .49085 .52478 L p .61 .331 .469 r
F P
0 g
s
.4139 .57601 m .42898 .5863 L .44032 .57317 L p .711 .655 .793 r
F P
0 g
s
.45383 .58241 m .44032 .57317 L .42898 .5863 L p .674 .623 .789 r
F P
0 g
s
.35796 .59333 m .34127 .57922 L .30731 .59395 L p .697 .751 .893 r
F P
0 g
s
.34127 .57922 m .35796 .59333 L .38152 .57845 L p .718 .751 .878 r
F P
0 g
s
.61344 .4677 m .5987 .47914 L .6041 .47138 L p 0 0 0 r
F P
0 g
s
.6041 .47138 m .61923 .45977 L .61344 .4677 L p 0 0 0 r
F P
0 g
s
.79362 .6155 m .80545 .60243 L .75789 .59136 L p .685 .752 .902 r
F P
0 g
s
.75789 .59136 m .74833 .60293 L .79362 .6155 L p .685 .752 .902 r
F P
0 g
s
.56012 .50467 m .55722 .50563 L .56148 .49672 L p .356 0 .161 r
F P
0 g
s
.56148 .49672 m .56414 .49584 L .56012 .50467 L p .356 0 .161 r
F P
0 g
s
.55433 .50654 m .55722 .50563 L .56148 .49672 L p .364 0 .164 r
F P
0 g
s
.52189 .83867 m .58193 .83672 L .5976 .89818 L p .683 .682 .842 r
F P
0 g
s
.67666 .88472 m .5976 .89818 L .58193 .83672 L p .658 .665 .846 r
F P
0 g
s
.45624 .51661 m .47217 .52366 L .47402 .51978 L p .755 .508 .558 r
F P
0 g
s
.47402 .51978 m .45748 .51303 L .45624 .51661 L p .755 .508 .558 r
F P
0 g
s
.49085 .52478 m .47402 .51978 L .47217 .52366 L p .686 .436 .539 r
F P
0 g
s
.44199 .50828 m .45624 .51661 L .45748 .51303 L p .825 .581 .569 r
F P
0 g
s
.45748 .51303 m .4428 .50475 L .44199 .50828 L p .825 .581 .569 r
F P
0 g
s
.56855 .50151 m .56012 .50467 L .56414 .49584 L p .334 0 .153 r
F P
0 g
s
.56414 .49584 m .57191 .49297 L .56855 .50151 L p .334 0 .153 r
F P
0 g
s
.67287 .38054 m .67272 .40394 L .70519 .38886 L p .835 .864 .866 r
F P
0 g
s
.70519 .38886 m .70516 .35942 L .67287 .38054 L p .835 .864 .866 r
F P
0 g
s
.56158 .64174 m .58149 .64116 L .57579 .63881 L p .323 .756 .969 r
F P
0 g
s
.57579 .63881 m .55772 .63841 L .56158 .64174 L p .323 .756 .969 r
F P
0 g
s
.38563 .38681 m .37958 .4074 L .34677 .3881 L p .479 .554 .854 r
F P
0 g
s
.34677 .3881 m .35298 .36132 L .38563 .38681 L p .479 .554 .854 r
F P
0 g
s
.43161 .49551 m .4428 .50475 L .4435 .49991 L p .913 .642 .514 r
F P
0 g
s
.4435 .49991 m .43177 .49039 L .43161 .49551 L p .913 .642 .514 r
F P
0 g
s
.45535 .51881 m .47099 .52604 L .47217 .52366 L p .754 .523 .582 r
F P
0 g
s
.47217 .52366 m .45624 .51661 L .45535 .51881 L p .754 .523 .582 r
F P
0 g
s
.48827 .52924 m .47217 .52366 L .47099 .52604 L p .686 .451 .561 r
F P
0 g
s
.47217 .52366 m .48827 .52924 L .49085 .52478 L p .686 .436 .539 r
F P
0 g
s
.44139 .51042 m .45535 .51881 L .45624 .51661 L p .822 .593 .591 r
F P
0 g
s
.45624 .51661 m .44199 .50828 L .44139 .51042 L p .822 .593 .591 r
F P
0 g
s
.45383 .58241 m .46579 .59071 L .4733 .57912 L p .627 .552 .751 r
F P
0 g
s
.46579 .59071 m .47558 .59767 L .48208 .58676 L p .575 .522 .759 r
F P
0 g
s
.48208 .58676 m .4733 .57912 L .46579 .59071 L p .575 .522 .759 r
F P
0 g
s
.73496 .61642 m .74833 .60293 L .71338 .59386 L p .707 .765 .897 r
F P
0 g
s
.71338 .59386 m .70241 .60629 L .73496 .61642 L p .707 .765 .897 r
F P
0 g
s
.44032 .57317 m .45383 .58241 L .46219 .57054 L p .676 .589 .751 r
F P
0 g
s
.4733 .57912 m .46219 .57054 L .45383 .58241 L p .627 .552 .751 r
F P
0 g
s
.58153 .49557 m .56855 .50151 L .57191 .49297 L p .295 0 .15 r
F P
0 g
s
.57191 .49297 m .58401 .48755 L .58153 .49557 L p .295 0 .15 r
F P
0 g
s
.50685 .52792 m .49085 .52478 L .48827 .52924 L p .611 .355 .506 r
F P
0 g
s
.49085 .52478 m .50685 .52792 L .51136 .52079 L p .61 .331 .469 r
F P
0 g
s
.45507 .51954 m .47059 .52683 L .47099 .52604 L p .754 .527 .588 r
F P
0 g
s
.47099 .52604 m .45535 .51881 L .45507 .51954 L p .754 .527 .588 r
F P
0 g
s
.48666 .53196 m .47099 .52604 L .47059 .52683 L p .687 .458 .57 r
F P
0 g
s
.47099 .52604 m .48666 .53196 L .48827 .52924 L p .686 .451 .561 r
F P
0 g
s
.63175 .63456 m .64996 .62419 L .63472 .61997 L p .721 .881 .955 r
F P
0 g
s
.63472 .61997 m .61909 .63 L .63175 .63456 L p .721 .881 .955 r
F P
0 g
s
.47558 .59767 m .4828 .60292 L .48834 .59281 L p .521 .498 .772 r
F P
0 g
s
.48834 .59281 m .48208 .58676 L .47558 .59767 L p .521 .498 .772 r
F P
0 g
s
.51136 .52079 m .52721 .52049 L .53271 .51137 L p .533 .207 .361 r
F P
0 g
s
.54588 .50884 m .53271 .51137 L .52721 .52049 L p .471 .13 .306 r
F P
0 g
s
.4547 .52043 m .47012 .52779 L .47059 .52683 L p .753 .532 .595 r
F P
0 g
s
.47059 .52683 m .45507 .51954 L .4547 .52043 L p .753 .532 .595 r
F P
0 g
s
.48611 .53287 m .47059 .52683 L .47012 .52779 L p .687 .461 .574 r
F P
0 g
s
.47059 .52683 m .48611 .53287 L .48666 .53196 L p .687 .458 .57 r
F P
0 g
s
.41702 .82223 m .46558 .83315 L .44236 .89471 L p .723 .721 .848 r
F P
0 g
s
.44236 .89471 m .37737 .88141 L .41702 .82223 L p .723 .721 .848 r
F P
0 g
s
.4412 .51112 m .45507 .51954 L .45535 .51881 L p .824 .595 .592 r
F P
0 g
s
.45535 .51881 m .44139 .51042 L .4412 .51112 L p .824 .595 .592 r
F P
0 g
s
.4828 .60292 m .48721 .60611 L .49208 .59667 L p .472 .481 .786 r
F P
0 g
s
.49208 .59667 m .48834 .59281 L .4828 .60292 L p .472 .481 .786 r
F P
0 g
s
.30731 .59395 m .29079 .5766 L .24243 .59018 L p .68 .762 .913 r
F P
0 g
s
.29079 .5766 m .30731 .59395 L .34127 .57922 L p .697 .769 .907 r
F P
0 g
s
.45354 .52311 m .46858 .5307 L .47012 .52779 L p .752 .536 .604 r
F P
0 g
s
.47012 .52779 m .4547 .52043 L .45354 .52311 L p .752 .536 .604 r
F P
0 g
s
.48545 .53398 m .47012 .52779 L .46858 .5307 L p .686 .469 .587 r
F P
0 g
s
.47012 .52779 m .48545 .53398 L .48611 .53287 L p .687 .461 .574 r
F P
0 g
s
.44092 .51199 m .4547 .52043 L .45507 .51954 L p .821 .602 .607 r
F P
0 g
s
.45507 .51954 m .4412 .51112 L .44092 .51199 L p .821 .602 .607 r
F P
0 g
s
.48721 .60611 m .48811 .60728 L .49276 .59804 L p .335 .347 .724 r
F P
0 g
s
.49276 .59804 m .49208 .59667 L .48721 .60611 L p .335 .347 .724 r
F P
0 g
s
.43996 .51461 m .45354 .52311 L .4547 .52043 L p .816 .61 .623 r
F P
0 g
s
.4547 .52043 m .44092 .51199 L .43996 .51461 L p .816 .61 .623 r
F P
0 g
s
.4139 .57601 m .3995 .56511 L .38152 .57845 L p .725 .711 .837 r
F P
0 g
s
.3995 .56511 m .4139 .57601 L .42631 .56329 L p .743 .696 .806 r
F P
0 g
s
.44032 .57317 m .42631 .56329 L .4139 .57601 L p .711 .655 .793 r
F P
0 g
s
.42631 .56329 m .44032 .57317 L .44931 .56144 L p .72 .631 .757 r
F P
0 g
s
.46219 .57054 m .44931 .56144 L .44032 .57317 L p .676 .589 .751 r
F P
0 g
s
.43106 .49919 m .44199 .50828 L .4428 .50475 L p .904 .669 .572 r
F P
0 g
s
.4428 .50475 m .43161 .49551 L .43106 .49919 L p .904 .669 .572 r
F P
0 g
s
.48936 .60689 m .49042 .60773 L .49482 .59877 L p .317 .337 .724 r
F P
0 g
s
.49482 .59877 m .49401 .59765 L .48936 .60689 L p .317 .337 .724 r
F P
0 g
s
.52721 .52049 m .51136 .52079 L .50685 .52792 L p .536 .245 .419 r
F P
0 g
s
.45132 .52764 m .46588 .53559 L .46858 .5307 L p .748 .55 .628 r
F P
0 g
s
.46858 .5307 m .45354 .52311 L .45132 .52764 L p .748 .55 .628 r
F P
0 g
s
.48343 .53732 m .46858 .5307 L .46588 .53559 L p .684 .484 .609 r
F P
0 g
s
.46858 .5307 m .48343 .53732 L .48545 .53398 L p .686 .469 .587 r
F P
0 g
s
.58149 .64116 m .60102 .63721 L .59354 .63558 L p .437 .847 .968 r
F P
0 g
s
.59354 .63558 m .57579 .63881 L .58149 .64116 L p .437 .847 .968 r
F P
0 g
s
.49042 .60773 m .49484 .61092 L .49853 .60271 L p .411 .464 .805 r
F P
0 g
s
.49853 .60271 m .49482 .59877 L .49042 .60773 L p .411 .464 .805 r
F P
0 g
s
.50328 .53332 m .48827 .52924 L .48666 .53196 L p .611 .371 .528 r
F P
0 g
s
.48827 .52924 m .50328 .53332 L .50685 .52792 L p .611 .355 .506 r
F P
0 g
s
.43814 .51898 m .45132 .52764 L .45354 .52311 L p .811 .618 .642 r
F P
0 g
s
.45354 .52311 m .43996 .51461 L .43814 .51898 L p .811 .618 .642 r
F P
0 g
s
.42524 .48062 m .43177 .49039 L .43108 .48385 L p .97 .661 .284 r
F P
0 g
s
.49484 .61092 m .50221 .61595 L .50467 .6091 L p .374 .461 .821 r
F P
0 g
s
.50467 .6091 m .49853 .60271 L .49484 .61092 L p .374 .461 .821 r
F P
0 g
s
.42005 .45253 m .42089 .46423 L .41425 .45362 L p 0 .104 .648 r
F P
0 g
s
.41425 .45362 m .41301 .43966 L .42005 .45253 L p 0 .104 .648 r
F P
0 g
s
.50106 .53665 m .48666 .53196 L .48611 .53287 L p .612 .379 .54 r
F P
0 g
s
.48666 .53196 m .50106 .53665 L .50328 .53332 L p .611 .371 .528 r
F P
0 g
s
.68792 .61939 m .70241 .60629 L .67709 .59952 L p .735 .795 .9 r
F P
0 g
s
.67709 .59952 m .6651 .6121 L .68792 .61939 L p .735 .795 .9 r
F P
0 g
s
.44788 .53399 m .46185 .54245 L .46588 .53559 L p .743 .565 .653 r
F P
0 g
s
.46588 .53559 m .45132 .52764 L .44788 .53399 L p .743 .565 .653 r
F P
0 g
s
.48002 .54286 m .46588 .53559 L .46185 .54245 L p .682 .503 .638 r
F P
0 g
s
.46588 .53559 m .48002 .54286 L .48343 .53732 L p .684 .484 .609 r
F P
0 g
s
.50221 .61595 m .51235 .62232 L .51332 .61724 L p .303 .46 .851 r
F P
0 g
s
.51332 .61724 m .50467 .6091 L .50221 .61595 L p .303 .46 .851 r
F P
0 g
s
.43062 .50138 m .44139 .51042 L .44199 .50828 L p .899 .677 .592 r
F P
0 g
s
.44199 .50828 m .43106 .49919 L .43062 .50138 L p .899 .677 .592 r
F P
0 g
s
.50031 .53776 m .48611 .53287 L .48545 .53398 L p .612 .384 .547 r
F P
0 g
s
.48611 .53287 m .50031 .53776 L .50106 .53665 L p .612 .379 .54 r
F P
0 g
s
.59672 .48656 m .58153 .49557 L .58401 .48755 L p .232 0 .147 r
F P
0 g
s
.58401 .48755 m .5987 .47914 L .59672 .48656 L p .232 0 .147 r
F P
0 g
s
.63971 .42878 m .63198 .44528 L .64384 .43574 L p .877 .994 .777 r
F P
0 g
s
.64384 .43574 m .65212 .41731 L .63971 .42878 L p .877 .994 .777 r
F P
0 g
s
.43507 .52508 m .44788 .53399 L .45132 .52764 L p .803 .632 .67 r
F P
0 g
s
.45132 .52764 m .43814 .51898 L .43507 .52508 L p .803 .632 .67 r
F P
0 g
s
.4994 .53911 m .48545 .53398 L .48343 .53732 L p .611 .392 .559 r
F P
0 g
s
.48545 .53398 m .4994 .53911 L .50031 .53776 L p .612 .384 .547 r
F P
0 g
s
.38152 .57845 m .36736 .56605 L .34127 .57922 L p .718 .751 .878 r
F P
0 g
s
.36736 .56605 m .38152 .57845 L .3995 .56511 L p .743 .749 .857 r
F P
0 g
s
.44931 .56144 m .46219 .57054 L .46925 .55985 L p .677 .557 .711 r
F P
0 g
s
.46219 .57054 m .4733 .57912 L .48019 .56833 L p .619 .508 .705 r
F P
0 g
s
.48019 .56833 m .46925 .55985 L .46219 .57054 L p .619 .508 .705 r
F P
0 g
s
.44931 .56144 m .43579 .55196 L .42631 .56329 L p .72 .631 .757 r
F P
0 g
s
.43579 .55196 m .44931 .56144 L .45638 .55114 L p .729 .607 .722 r
F P
0 g
s
.46925 .55985 m .45638 .55114 L .44931 .56144 L p .677 .557 .711 r
F P
0 g
s
.43045 .50211 m .4412 .51112 L .44139 .51042 L p .896 .683 .606 r
F P
0 g
s
.44139 .51042 m .43062 .50138 L .43045 .50211 L p .896 .683 .606 r
F P
0 g
s
.51235 .62232 m .5252 .62902 L .5246 .62581 L p .192 .466 .886 r
F P
0 g
s
.5246 .62581 m .51332 .61724 L .51235 .62232 L p .192 .466 .886 r
F P
0 g
s
.44287 .54214 m .45638 .55114 L .46185 .54245 L p .737 .585 .685 r
F P
0 g
s
.46185 .54245 m .44788 .53399 L .44287 .54214 L p .737 .585 .685 r
F P
0 g
s
.47526 .55049 m .46185 .54245 L .45638 .55114 L p .679 .528 .673 r
F P
0 g
s
.46185 .54245 m .47526 .55049 L .48002 .54286 L p .682 .503 .638 r
F P
0 g
s
.62523 .45295 m .63198 .44528 L .62557 .45384 L p 0 0 0 r
F P
0 g
s
.63283 .43841 m .62557 .45384 L .63198 .44528 L p .805 .934 .568 r
F P
0 g
s
.62966 .44624 m .62584 .45454 L p .62557 .45384 L 0 0 0 r
F P
0 g
s
.62584 .45454 m .62284 .46104 L .62557 .45384 L p 0 0 0 r
F P
0 g
s
.61923 .45977 m .62523 .45295 L p .62557 .45384 L 0 0 0 r
F P
0 g
s
.4302 .50301 m .44092 .51199 L .4412 .51112 L p .89 .689 .623 r
F P
0 g
s
.4412 .51112 m .43045 .50211 L .4302 .50301 L p .89 .689 .623 r
F P
0 g
s
.49668 .54315 m .48343 .53732 L .48002 .54286 L p .61 .408 .583 r
F P
0 g
s
.48343 .53732 m .49668 .54315 L .4994 .53911 L p .611 .392 .559 r
F P
0 g
s
.52721 .52049 m .54091 .51832 L .54588 .50884 L p .471 .13 .306 r
F P
0 g
s
.55433 .50654 m .54588 .50884 L .54091 .51832 L p .428 .075 .262 r
F P
0 g
s
.42631 .56329 m .41308 .55306 L .3995 .56511 L p .743 .696 .806 r
F P
0 g
s
.41308 .55306 m .42631 .56329 L .43579 .55196 L p .761 .68 .773 r
F P
0 g
s
.45638 .55114 m .44287 .54214 L .43579 .55196 L p .729 .607 .722 r
F P
0 g
s
.45638 .55114 m .46925 .55985 L .47526 .55049 L p .679 .528 .673 r
F P
0 g
s
.42946 .50564 m .43996 .51461 L .44092 .51199 L p .89 .689 .625 r
F P
0 g
s
.44092 .51199 m .4302 .50301 L .42946 .50564 L p .89 .689 .625 r
F P
0 g
s
.4733 .57912 m .48208 .58676 L .48828 .57644 L p .551 .459 .704 r
F P
0 g
s
.48828 .57644 m .48019 .56833 L .4733 .57912 L p .551 .459 .704 r
F P
0 g
s
.4302 .5329 m .44287 .54214 L .44788 .53399 L p .791 .648 .704 r
F P
0 g
s
.44788 .53399 m .43507 .52508 L .4302 .5329 L p .791 .648 .704 r
F P
0 g
s
.40641 .40842 m .40042 .4246 L .37958 .4074 L p .416 .486 .824 r
F P
0 g
s
.37958 .4074 m .38563 .38681 L .40641 .40842 L p .416 .486 .824 r
F P
0 g
s
.52156 .529 m .50685 .52792 L .50328 .53332 L p .528 .26 .453 r
F P
0 g
s
.50685 .52792 m .52156 .529 L .52721 .52049 L p .536 .245 .419 r
F P
0 g
s
.53853 .63322 m .5246 .62581 L .5252 .62902 L p .047 .476 .885 r
F P
0 g
s
.52344 .62512 m .5246 .62581 L p .53031 .62977 L .415 0 0 r
F P
0 g
s
.5252 .62902 m .53475 .63264 L p .53292 .63145 L .047 .476 .885 r
F P
0 g
s
.5365 .63406 m .52888 .62884 L p .53031 .62977 L .415 0 0 r
F P
0 g
s
.52888 .62884 m .52344 .62512 L p .53031 .62977 L .415 0 0 r
F P
0 g
s
.54052 .63482 m .53853 .63322 L p .53292 .63145 L .047 .476 .885 r
F P
0 g
s
.53475 .63264 m .54052 .63482 L p .53292 .63145 L .047 .476 .885 r
F P
0 g
s
.49226 .54973 m .48002 .54286 L .47526 .55049 L p .61 .433 .617 r
F P
0 g
s
.48002 .54286 m .49226 .54973 L .49668 .54315 L p .61 .408 .583 r
F P
0 g
s
.46925 .55985 m .48019 .56833 L .48658 .55837 L p .613 .467 .659 r
F P
0 g
s
.48658 .55837 m .47526 .55049 L .46925 .55985 L p .613 .467 .659 r
F P
0 g
s
.42777 .51004 m .43814 .51898 L .43996 .51461 L p .879 .703 .66 r
F P
0 g
s
.43996 .51461 m .42946 .50564 L .42777 .51004 L p .879 .703 .66 r
F P
0 g
s
.42521 .48622 m .43161 .49551 L .43177 .49039 L p .991 .74 .443 r
F P
0 g
s
.43177 .49039 m .42524 .48062 L .42521 .48622 L p .991 .74 .443 r
F P
0 g
s
.42308 .54228 m .43579 .55196 L .44287 .54214 L p .777 .663 .737 r
F P
0 g
s
.44287 .54214 m .4302 .5329 L .42308 .54228 L p .777 .663 .737 r
F P
0 g
s
.43579 .55196 m .42308 .54228 L .41308 .55306 L p .761 .68 .773 r
F P
0 g
s
.47526 .55049 m .48658 .55837 L .49226 .54973 L p .61 .433 .617 r
F P
0 g
s
.60102 .63721 m .61909 .63 L .6097 .62872 L p .603 .924 .969 r
F P
0 g
s
.6097 .62872 m .59354 .63558 L .60102 .63721 L p .603 .924 .969 r
F P
0 g
s
.48208 .58676 m .48834 .59281 L .49356 .5834 L p .474 .412 .707 r
F P
0 g
s
.49356 .5834 m .48828 .57644 L .48208 .58676 L p .474 .412 .707 r
F P
0 g
s
.54091 .51832 m .55041 .51585 L .55433 .50654 L p .428 .075 .262 r
F P
0 g
s
.55722 .50563 m .55433 .50654 L .55041 .51585 L p .407 .05 .243 r
F P
0 g
s
.42484 .5161 m .43507 .52508 L .43814 .51898 L p .866 .712 .689 r
F P
0 g
s
.43814 .51898 m .42777 .51004 L .42484 .5161 L p .866 .712 .689 r
F P
0 g
s
.54052 .63482 m .55607 .63806 L p .55002 .63702 L 0 .489 .807 r
F P
0 g
s
.55772 .63841 m .55453 .63806 L p .55002 .63702 L 0 .489 .807 r
F P
0 g
s
.55607 .63806 m .55772 .63841 L p .55002 .63702 L 0 .489 .807 r
F P
0 g
s
.55453 .63806 m .53853 .63322 L .54052 .63482 L p 0 .489 .807 r
F P
0 g
s
.5365 .63406 m .53853 .63322 L p .54407 .636 L .491 0 0 r
F P
0 g
s
.55186 .63991 m .53955 .63522 L p .54407 .636 L .491 0 0 r
F P
0 g
s
.53955 .63522 m .5365 .63406 L p .54407 .636 L .491 0 0 r
F P
0 g
s
.64996 .62419 m .6651 .6121 L .6475 .60812 L p .761 .854 .919 r
F P
0 g
s
.6475 .60812 m .63472 .61997 L .64996 .62419 L p .761 .854 .919 r
F P
0 g
s
.80545 .60243 m .81331 .59232 L .76409 .58245 L p .683 .746 .899 r
F P
0 g
s
.76409 .58245 m .75789 .59136 L .80545 .60243 L p .683 .746 .899 r
F P
0 g
s
.5166 .53586 m .50328 .53332 L .50106 .53665 L p .519 .268 .474 r
F P
0 g
s
.50328 .53332 m .5166 .53586 L .52156 .529 L p .528 .26 .453 r
F P
0 g
s
.54091 .51832 m .52721 .52049 L .52156 .529 L p .475 .163 .357 r
F P
0 g
s
.55715 .51368 m .55377 .51481 L .55722 .50563 L p .401 .044 .241 r
F P
0 g
s
.55722 .50563 m .56012 .50467 L .55715 .51368 L p .401 .044 .241 r
F P
0 g
s
.55041 .51585 m .55377 .51481 L .55722 .50563 L p .407 .05 .243 r
F P
0 g
s
.65259 .3978 m .65212 .41731 L .67272 .40394 L p .881 .896 .837 r
F P
0 g
s
.67272 .40394 m .67287 .38054 L .65259 .3978 L p .881 .896 .837 r
F P
0 g
s
.3995 .56511 m .38711 .55401 L .36736 .56605 L p .743 .749 .857 r
F P
0 g
s
.38711 .55401 m .3995 .56511 L .41308 .55306 L p .771 .745 .83 r
F P
0 g
s
.42089 .46423 m .42005 .45253 L .42336 .46322 L p 0 0 .42 r
F P
0 g
s
.61127 .47481 m .59672 .48656 L .5987 .47914 L p .109 0 .118 r
F P
0 g
s
.5987 .47914 m .61344 .4677 L .61127 .47481 L p .109 0 .118 r
F P
0 g
s
.42477 .49019 m .43106 .49919 L .43161 .49551 L p .987 .772 .527 r
F P
0 g
s
.43161 .49551 m .42521 .48622 L .42477 .49019 L p .987 .772 .527 r
F P
0 g
s
.48834 .59281 m .49208 .59667 L .49653 .58808 L p .396 .371 .713 r
F P
0 g
s
.49653 .58808 m .49356 .5834 L .48834 .59281 L p .396 .371 .713 r
F P
0 g
s
.22691 .56868 m .24243 .59018 L .29079 .5766 L p .675 .77 .922 r
F P
0 g
s
.48019 .56833 m .48828 .57644 L .49457 .56637 L p .528 .394 .642 r
F P
0 g
s
.49457 .56637 m .48658 .55837 L .48019 .56833 L p .528 .394 .642 r
F P
0 g
s
.56702 .50992 m .55715 .51368 L .56012 .50467 L p .393 .042 .247 r
F P
0 g
s
.56012 .50467 m .56855 .50151 L .56702 .50992 L p .393 .042 .247 r
F P
0 g
s
.34127 .57922 m .32778 .56465 L .29079 .5766 L p .697 .769 .907 r
F P
0 g
s
.32778 .56465 m .34127 .57922 L .36736 .56605 L p .72 .779 .899 r
F P
0 g
s
.51332 .54019 m .50106 .53665 L .50031 .53776 L p .516 .272 .484 r
F P
0 g
s
.50106 .53665 m .51332 .54019 L .5166 .53586 L p .519 .268 .474 r
F P
0 g
s
.41993 .52375 m .4302 .5329 L .43507 .52508 L p .846 .723 .728 r
F P
0 g
s
.43507 .52508 m .42484 .5161 L .41993 .52375 L p .846 .723 .728 r
F P
0 g
s
.51221 .54165 m .50031 .53776 L .4994 .53911 L p .515 .277 .492 r
F P
0 g
s
.50031 .53776 m .51221 .54165 L .51332 .54019 L p .516 .272 .484 r
F P
0 g
s
.49208 .59667 m .49276 .59804 L .49692 .58977 L p .184 .161 .596 r
F P
0 g
s
.49692 .58977 m .49653 .58808 L .49208 .59667 L p .184 .161 .596 r
F P
0 g
s
.51086 .54342 m .4994 .53911 L .49668 .54315 L p .512 .285 .507 r
F P
0 g
s
.4994 .53911 m .51086 .54342 L .51221 .54165 L p .515 .277 .492 r
F P
0 g
s
.55772 .63841 m .57579 .63881 L .57151 .63933 L p 0 .545 .721 r
F P
0 g
s
.57151 .63933 m .55453 .63806 L .55772 .63841 L p 0 .545 .721 r
F P
0 g
s
.74833 .60293 m .75789 .59136 L .72114 .58319 L p .704 .752 .889 r
F P
0 g
s
.72114 .58319 m .71338 .59386 L .74833 .60293 L p .704 .752 .889 r
F P
0 g
s
.42434 .49253 m .43062 .50138 L .43106 .49919 L p .981 .787 .571 r
F P
0 g
s
.43106 .49919 m .42477 .49019 L .42434 .49253 L p .981 .787 .571 r
F P
0 g
s
.49401 .59765 m .49482 .59877 L .49868 .59083 L p .152 .139 .589 r
F P
0 g
s
.49868 .59083 m .49818 .58938 L .49401 .59765 L p .152 .139 .589 r
F P
0 g
s
.41253 .53274 m .42308 .54228 L .4302 .5329 L p .824 .733 .764 r
F P
0 g
s
.4302 .5329 m .41993 .52375 L .41253 .53274 L p .824 .733 .764 r
F P
0 g
s
.50691 .54865 m .49668 .54315 L .49226 .54973 L p .509 .303 .536 r
F P
0 g
s
.49668 .54315 m .50691 .54865 L .51086 .54342 L p .512 .285 .507 r
F P
0 g
s
.41308 .55306 m .40182 .5429 L .38711 .55401 L p .771 .745 .83 r
F P
0 g
s
.40182 .5429 m .41308 .55306 L .42308 .54228 L p .798 .74 .799 r
F P
0 g
s
.48658 .55837 m .49457 .56637 L .50104 .55674 L p .513 .339 .583 r
F P
0 g
s
.50104 .55674 m .49226 .54973 L .48658 .55837 L p .513 .339 .583 r
F P
0 g
s
.49482 .59877 m .49853 .60271 L .5015 .59586 L p .288 .322 .724 r
F P
0 g
s
.5015 .59586 m .49868 .59083 L .49482 .59877 L p .288 .322 .724 r
F P
0 g
s
.4242 .49331 m .43045 .50211 L .43062 .50138 L p .98 .786 .573 r
F P
0 g
s
.43062 .50138 m .42434 .49253 L .4242 .49331 L p .98 .786 .573 r
F P
0 g
s
.49226 .54973 m .50104 .55674 L .50691 .54865 L p .509 .303 .536 r
F P
0 g
s
.42308 .54228 m .41253 .53274 L .40182 .5429 L p .798 .74 .799 r
F P
0 g
s
.58156 .50297 m .56702 .50992 L .56855 .50151 L p .383 .05 .272 r
F P
0 g
s
.56855 .50151 m .58153 .49557 L .58156 .50297 L p .383 .05 .272 r
F P
0 g
s
.42398 .49424 m .4302 .50301 L .43045 .50211 L p .974 .796 .603 r
F P
0 g
s
.43045 .50211 m .4242 .49331 L .42398 .49424 L p .974 .796 .603 r
F P
0 g
s
.41896 .42677 m .41301 .43966 L .40042 .4246 L p .338 .398 .777 r
F P
0 g
s
.40042 .4246 m .40641 .40842 L .41896 .42677 L p .338 .398 .777 r
F P
0 g
s
.42315 .49703 m .42946 .50564 L .4302 .50301 L p .965 .805 .633 r
F P
0 g
s
.4302 .50301 m .42398 .49424 L .42315 .49703 L p .965 .805 .633 r
F P
0 g
s
.49853 .60271 m .50467 .6091 L .50622 .60408 L p .217 .303 .738 r
F P
0 g
s
.50622 .60408 m .5015 .59586 L .49853 .60271 L p .217 .303 .738 r
F P
0 g
s
.70241 .60629 m .71338 .59386 L .68605 .5876 L p .735 .771 .882 r
F P
0 g
s
.68605 .5876 m .67709 .59952 L .70241 .60629 L p .735 .771 .882 r
F P
0 g
s
.58193 .83672 m .6407 .82635 L .67666 .88472 L p .658 .665 .846 r
F P
0 g
s
.74768 .86092 m .67666 .88472 L .6407 .82635 L p .63 .653 .855 r
F P
0 g
s
.48828 .57644 m .49356 .5834 L .49897 .57406 L p .418 .307 .62 r
F P
0 g
s
.49897 .57406 m .49457 .56637 L .48828 .57644 L p .418 .307 .62 r
F P
0 g
s
.61909 .63 m .63472 .61997 L .62336 .61881 L p .74 .94 .95 r
F P
0 g
s
.62336 .61881 m .6097 .62872 L .61909 .63 L p .74 .94 .95 r
F P
0 g
s
.42411 .47323 m .42336 .46322 L .42444 .47165 L p 0 0 .141 r
F P
0 g
s
.42145 .50159 m .42777 .51004 L .42946 .50564 L p .952 .811 .667 r
F P
0 g
s
.42946 .50564 m .42315 .49703 L .42145 .50159 L p .952 .811 .667 r
F P
0 g
s
.50467 .6091 m .51332 .61724 L .51335 .61446 L p .077 .274 .761 r
F P
0 g
s
.51335 .61446 m .50622 .60408 L .50467 .6091 L p .077 .274 .761 r
F P
0 g
s
.58367 .63737 m .59354 .63558 L .58812 .6366 L p .14 .684 .725 r
F P
0 g
s
.59354 .63558 m .60257 .63175 L p .60302 .62996 L .444 .878 .821 r
F P
0 g
s
.60257 .63175 m .6097 .62872 L .60302 .62996 L p .444 .878 .821 r
F P
0 g
s
.60969 .62264 m .6034 .62841 L p .60302 .62996 L .604 .921 .679 r
F P
0 g
s
.60302 .62996 m .58812 .6366 L .59354 .63558 L p .444 .878 .821 r
F P
0 g
s
.58812 .6366 m .59801 .63219 L p .59857 .63285 L 0 0 0 r
F P
0 g
s
.59801 .63219 m .60302 .62996 L .59857 .63285 L p 0 0 0 r
F P
0 g
s
.6034 .62841 m .59857 .63285 L .60302 .62996 L p .604 .921 .679 r
F P
0 g
s
.60639 .6262 m .59904 .63341 L p .59857 .63285 L 0 0 0 r
F P
0 g
s
.59904 .63341 m .59583 .63655 L .59857 .63285 L p 0 0 0 r
F P
0 g
s
.59857 .63285 m .59193 .63593 L p .58812 .6366 L 0 0 0 r
F P
0 g
s
.59193 .63593 m .5844 .63943 L .58812 .6366 L p 0 0 0 r
F P
0 g
s
.57579 .63881 m .58367 .63737 L p .58812 .6366 L .14 .684 .725 r
F P
0 g
s
.58812 .6366 m .57151 .63933 L .57579 .63881 L p .14 .684 .725 r
F P
0 g
s
.53519 .52773 m .52156 .529 L .5166 .53586 L p .453 .164 .382 r
F P
0 g
s
.52156 .529 m .53519 .52773 L .54091 .51832 L p .475 .163 .357 r
F P
0 g
s
.55041 .51585 m .54091 .51832 L .53519 .52773 L p .433 .096 .292 r
F P
0 g
s
.41835 .50776 m .42484 .5161 L .42777 .51004 L p .932 .819 .712 r
F P
0 g
s
.42777 .51004 m .42145 .50159 L .41835 .50776 L p .932 .819 .712 r
F P
0 g
s
.63198 .44528 m .63971 .42878 L .63283 .43841 L p .805 .934 .568 r
F P
0 g
s
.36736 .56605 m .35605 .55368 L .32778 .56465 L p .72 .779 .899 r
F P
0 g
s
.35605 .55368 m .36736 .56605 L .38711 .55401 L p .751 .79 .885 r
F P
0 g
s
.59729 .49302 m .58156 .50297 L .58153 .49557 L p .352 .046 .298 r
F P
0 g
s
.58153 .49557 m .59672 .48656 L .59729 .49302 L p .352 .046 .298 r
F P
0 g
s
.51332 .61724 m .5194 .62186 L p .51888 .62157 L 0 .219 .737 r
F P
0 g
s
.5246 .62581 m .52344 .62512 L p .51888 .62157 L 0 .219 .737 r
F P
0 g
s
.5194 .62186 m .5246 .62581 L p .51888 .62157 L 0 .219 .737 r
F P
0 g
s
.52344 .62512 m .51335 .61446 L .51332 .61724 L p 0 .219 .737 r
F P
0 g
s
.51237 .61385 m .51335 .61446 L p .51799 .62108 L .644 .182 0 r
F P
0 g
s
.52171 .62636 m .5176 .62086 L p .51799 .62108 L .644 .182 0 r
F P
0 g
s
.5176 .62086 m .51237 .61385 L p .51799 .62108 L .644 .182 0 r
F P
0 g
s
.62284 .46104 m .61127 .47481 L .61344 .4677 L p 0 0 .015 r
F P
0 g
s
.61344 .4677 m .62557 .45384 L .62284 .46104 L p 0 0 .015 r
F P
0 g
s
.6651 .6121 m .67709 .59952 L .65734 .59554 L p .774 .816 .886 r
F P
0 g
s
.65734 .59554 m .6475 .60812 L .6651 .6121 L p .774 .816 .886 r
F P
0 g
s
.37837 .80855 m .41702 .82223 L .37737 .88141 L p .737 .741 .855 r
F P
0 g
s
.37737 .88141 m .32545 .86453 L .37837 .80855 L p .737 .741 .855 r
F P
0 g
s
.49356 .5834 m .49653 .58808 L .50091 .57976 L p .29 .216 .598 r
F P
0 g
s
.50091 .57976 m .49897 .57406 L .49356 .5834 L p .29 .216 .598 r
F P
0 g
s
.42434 .47797 m .42521 .48622 L .42524 .48062 L p .81 .659 .108 r
F P
0 g
s
.42524 .48062 m .42454 .4728 L p .42434 .47797 L .81 .659 .108 r
F P
0 g
s
.42521 .48622 m .4244 .47853 L p .42375 .48236 L .897 .782 .292 r
F P
0 g
s
.4244 .47853 m .42434 .47797 L .42375 .48236 L p .897 .782 .292 r
F P
0 g
s
.42375 .48236 m .42477 .49019 L .42521 .48622 L p .897 .782 .292 r
F P
0 g
s
.42477 .49019 m .42376 .48242 L p .42318 .48494 L .939 .85 .416 r
F P
0 g
s
.42376 .48242 m .42375 .48236 L .42318 .48494 L p .939 .85 .416 r
F P
0 g
s
.42318 .48494 m .42434 .49253 L .42477 .49019 L p .939 .85 .416 r
F P
0 g
s
.42434 .49253 m .42318 .48498 L p .42298 .48578 L .949 .861 .442 r
F P
0 g
s
.42318 .48498 m .42318 .48494 L .42298 .48578 L p .949 .861 .442 r
F P
0 g
s
.42298 .48578 m .4242 .49331 L .42434 .49253 L p .949 .861 .442 r
F P
0 g
s
.4242 .49331 m .42298 .48583 L p .4227 .48679 L .957 .879 .48 r
F P
0 g
s
.42298 .48583 m .42298 .48578 L .4227 .48679 L p .957 .879 .48 r
F P
0 g
s
.4227 .48679 m .42398 .49424 L .4242 .49331 L p .957 .879 .48 r
F P
0 g
s
.42398 .49424 m .42278 .48727 L p .42177 .48979 L .963 .895 .518 r
F P
0 g
s
.42278 .48727 m .4227 .48679 L .42177 .48979 L p .963 .895 .518 r
F P
0 g
s
.42177 .48979 m .42315 .49703 L .42398 .49424 L p .963 .895 .518 r
F P
0 g
s
.42315 .49703 m .42177 .48979 L .41971 .49462 L p .966 .93 .615 r
F P
0 g
s
.42253 .49011 m .42005 .49408 L p .42177 .48979 L 0 0 0 r
F P
0 g
s
.42005 .49408 m .41971 .49462 L .42177 .48979 L p 0 0 0 r
F P
0 g
s
.42517 .48495 m .42185 .48968 L p .4227 .48679 L 0 0 0 r
F P
0 g
s
.42185 .48968 m .42177 .48979 L .4227 .48679 L p 0 0 0 r
F P
0 g
s
.42648 .48167 m .42272 .48676 L p .42298 .48578 L 0 0 .026 r
F P
0 g
s
.42272 .48676 m .4227 .48679 L .42298 .48578 L p 0 0 .026 r
F P
0 g
s
.42684 .48056 m .42299 .48577 L p .42318 .48494 L 0 0 .045 r
F P
0 g
s
.42299 .48577 m .42298 .48578 L .42318 .48494 L p 0 0 .045 r
F P
0 g
s
.42714 .47962 m .42336 .4847 L p .42375 .48236 L 0 0 .1 r
F P
0 g
s
.42336 .4847 m .42318 .48494 L .42375 .48236 L p 0 0 .1 r
F P
0 g
s
.42794 .47675 m .42419 .48177 L p .42434 .47797 L 0 0 .213 r
F P
0 g
s
.42419 .48177 m .42375 .48236 L .42434 .47797 L p 0 0 .213 r
F P
0 g
s
.42454 .4728 m .42444 .47165 L .42434 .47797 L p .81 .659 .108 r
F P
0 g
s
.4131 .51532 m .41993 .52375 L .42484 .5161 L p .9 .823 .762 r
F P
0 g
s
.42484 .5161 m .41835 .50776 L .4131 .51532 L p .9 .823 .762 r
F P
0 g
s
.5246 .62581 m .53853 .63322 L .5365 .63406 L p .415 0 0 r
F P
0 g
s
.73847 .29481 m .75543 .33362 L .83345 .30168 L p .76 .781 .87 r
F P
0 g
s
.83345 .30168 m .81201 .24746 L .73847 .29481 L p .76 .781 .87 r
F P
0 g
s
.81331 .59232 m .8177 .58596 L .76756 .57685 L p .68 .741 .897 r
F P
0 g
s
.76756 .57685 m .76409 .58245 L .81331 .59232 L p .68 .741 .897 r
F P
0 g
s
.49457 .56637 m .49897 .57406 L .50515 .56433 L p .361 .194 .515 r
F P
0 g
s
.50515 .56433 m .50104 .55674 L .49457 .56637 L p .361 .194 .515 r
F P
0 g
s
.52859 .53626 m .5166 .53586 L .51332 .54019 L p .407 .132 .38 r
F P
0 g
s
.5166 .53586 m .52859 .53626 L .53519 .52773 L p .453 .164 .382 r
F P
0 g
s
.42582 .44219 m .42005 .45253 L .41301 .43966 L p .243 .286 .708 r
F P
0 g
s
.41301 .43966 m .41896 .42677 L .42582 .44219 L p .243 .286 .708 r
F P
0 g
s
.53519 .52773 m .54625 .52505 L .55041 .51585 L p .433 .096 .292 r
F P
0 g
s
.55377 .51481 m .55041 .51585 L .54625 .52505 L p .413 .061 .257 r
F P
0 g
s
.49653 .58808 m .49692 .58977 L .50088 .5819 L p 0 0 .39 r
F P
0 g
s
.50088 .5819 m .50091 .57976 L .49653 .58808 L p 0 0 .39 r
F P
0 g
s
.29079 .5766 m .2786 .55906 L .22691 .56868 L p .675 .77 .922 r
F P
0 g
s
.2786 .55906 m .29079 .5766 L .32778 .56465 L p .689 .784 .923 r
F P
0 g
s
.4051 .52397 m .41253 .53274 L .41993 .52375 L p .865 .821 .803 r
F P
0 g
s
.41993 .52375 m .4131 .51532 L .4051 .52397 L p .865 .821 .803 r
F P
0 g
s
.38711 .55401 m .37749 .54331 L .35605 .55368 L p .751 .79 .885 r
F P
0 g
s
.37749 .54331 m .38711 .55401 L .40182 .5429 L p .787 .803 .866 r
F P
0 g
s
.53853 .63322 m .55453 .63806 L .55186 .63991 L p .491 0 0 r
F P
0 g
s
.69176 .33046 m .70516 .35942 L .75543 .33362 L p .79 .795 .856 r
F P
0 g
s
.75543 .33362 m .73847 .29481 L .69176 .33046 L p .79 .795 .856 r
F P
0 g
s
.64041 .41179 m .63971 .42878 L .65212 .41731 L p .931 .926 .782 r
F P
0 g
s
.65212 .41731 m .65259 .3978 L .64041 .41179 L p .931 .926 .782 r
F P
0 g
s
.52314 .54233 m .51332 .54019 L .51221 .54165 L p .371 .102 .369 r
F P
0 g
s
.51332 .54019 m .52314 .54233 L .52859 .53626 L p .407 .132 .38 r
F P
0 g
s
.49818 .58938 m .49868 .59083 L .50221 .58345 L p 0 0 .365 r
F P
0 g
s
.50221 .58345 m .50214 .58151 L .49818 .58938 L p 0 0 .365 r
F P
0 g
s
.52116 .54448 m .51221 .54165 L .51086 .54342 L p .36 .096 .371 r
F P
0 g
s
.51221 .54165 m .52116 .54448 L .52314 .54233 L p .371 .102 .369 r
F P
0 g
s
.55494 .52227 m .55053 .52374 L .55377 .51481 L p .41 .059 .255 r
F P
0 g
s
.55377 .51481 m .55715 .51368 L .55494 .52227 L p .41 .059 .255 r
F P
0 g
s
.54625 .52505 m .55053 .52374 L .55377 .51481 L p .413 .061 .257 r
F P
0 g
s
.61148 .48073 m .59729 .49302 L .59672 .48656 L p .269 0 .304 r
F P
0 g
s
.59672 .48656 m .61127 .47481 L .61148 .48073 L p .269 0 .304 r
F P
0 g
s
.51879 .5471 m .51086 .54342 L .50691 .54865 L p .347 .098 .387 r
F P
0 g
s
.51086 .54342 m .51879 .5471 L .52116 .54448 L p .36 .096 .371 r
F P
0 g
s
.39351 .53337 m .40182 .5429 L .41253 .53274 L p .826 .814 .838 r
F P
0 g
s
.41253 .53274 m .4051 .52397 L .39351 .53337 L p .826 .814 .838 r
F P
0 g
s
.50104 .55674 m .50515 .56433 L .5124 .55453 L p .332 .114 .425 r
F P
0 g
s
.5124 .55453 m .50691 .54865 L .50104 .55674 L p .332 .114 .425 r
F P
0 g
s
.40182 .5429 m .39351 .53337 L .37749 .54331 L p .787 .803 .866 r
F P
0 g
s
.49868 .59083 m .5015 .59586 L .50371 .59008 L p .091 .096 .57 r
F P
0 g
s
.50371 .59008 m .50221 .58345 L .49868 .59083 L p .091 .096 .57 r
F P
0 g
s
.50691 .54865 m .5124 .55453 L .51879 .5471 L p .347 .098 .387 r
F P
0 g
s
.63472 .61997 m .6475 .60812 L .63405 .60675 L p .807 .901 .908 r
F P
0 g
s
.63405 .60675 m .62336 .61881 L .63472 .61997 L p .807 .901 .908 r
F P
0 g
s
.75789 .59136 m .76409 .58245 L .72615 .57503 L p .699 .741 .884 r
F P
0 g
s
.72615 .57503 m .72114 .58319 L .75789 .59136 L p .699 .741 .884 r
F P
0 g
s
.56746 .51738 m .55494 .52227 L .55715 .51368 L p .427 .09 .29 r
F P
0 g
s
.55715 .51368 m .56702 .50992 L .56746 .51738 L p .427 .09 .29 r
F P
0 g
s
.55453 .63806 m .57151 .63933 L .56834 .64184 L p .41 0 0 r
F P
0 g
s
.56834 .64184 m .55186 .63991 L .55453 .63806 L p .41 0 0 r
F P
0 g
s
.5015 .59586 m .50622 .60408 L .50666 .60088 L p 0 .05 .575 r
F P
0 g
s
.50666 .60088 m .50371 .59008 L .5015 .59586 L p 0 .05 .575 r
F P
0 g
s
.3682 .33778 m .35298 .36132 L .30235 .3308 L p .566 .606 .852 r
F P
0 g
s
.30235 .3308 m .32044 .29919 L .3682 .33778 L p .566 .606 .852 r
F P
0 g
s
.32044 .29919 m .30235 .3308 L .22411 .29344 L p .593 .64 .867 r
F P
0 g
s
.71338 .59386 m .72114 .58319 L .69241 .57726 L p .728 .75 .87 r
F P
0 g
s
.69241 .57726 m .68605 .5876 L .71338 .59386 L p .728 .75 .87 r
F P
0 g
s
.42886 .45471 m .42336 .46322 L .42005 .45253 L p .134 .152 .614 r
F P
0 g
s
.42005 .45253 m .42582 .44219 L .42886 .45471 L p .134 .152 .614 r
F P
0 g
s
.49897 .57406 m .50091 .57976 L .50567 .57111 L p .14 0 .41 r
F P
0 g
s
.50567 .57111 m .50515 .56433 L .49897 .57406 L p .14 0 .41 r
F P
0 g
s
.54625 .52505 m .53519 .52773 L .52859 .53626 L p .412 .084 .296 r
F P
0 g
s
.39902 .3689 m .38563 .38681 L .35298 .36132 L p .533 .561 .83 r
F P
0 g
s
.35298 .36132 m .3682 .33778 L .39902 .3689 L p .533 .561 .83 r
F P
0 g
s
.58371 .50904 m .56746 .51738 L .56702 .50992 L p .448 .139 .348 r
F P
0 g
s
.56702 .50992 m .58156 .50297 L .58371 .50904 L p .448 .139 .348 r
F P
0 g
s
.8177 .58596 m .8191 .58416 L .76868 .5753 L p .683 .736 .891 r
F P
0 g
s
.76868 .5753 m .76756 .57685 L .8177 .58596 L p .683 .736 .891 r
F P
0 g
s
.41971 .49462 m .42145 .50159 L .42315 .49703 L p .966 .93 .615 r
F P
0 g
s
.66226 .35792 m .67287 .38054 L .70516 .35942 L p .825 .808 .834 r
F P
0 g
s
.70516 .35942 m .69176 .33046 L .66226 .35792 L p .825 .808 .834 r
F P
0 g
s
.50622 .60408 m .51002 .60961 L p .50964 .60951 L 0 0 .538 r
F P
0 g
s
.51335 .61446 m .51237 .61385 L p .50964 .60951 L 0 0 .538 r
F P
0 g
s
.51002 .60961 m .51335 .61446 L p .50964 .60951 L 0 0 .538 r
F P
0 g
s
.51237 .61385 m .50666 .60088 L .50622 .60408 L p 0 0 .538 r
F P
0 g
s
.50567 .59967 m .50666 .60088 L p .50899 .60934 L .779 .463 0 r
F P
0 g
s
.51056 .61499 m .50873 .60928 L p .50899 .60934 L .779 .463 0 r
F P
0 g
s
.50873 .60928 m .50567 .59967 L p .50899 .60934 L .779 .463 0 r
F P
0 g
s
.67709 .59952 m .68605 .5876 L .66459 .58351 L p .769 .778 .86 r
F P
0 g
s
.66459 .58351 m .65734 .59554 L .67709 .59952 L p .769 .778 .86 r
F P
0 g
s
.57151 .63933 m .58812 .6366 L .5844 .63943 L p .219 0 0 r
F P
0 g
s
.5844 .63943 m .56834 .64184 L .57151 .63933 L p .219 0 0 r
F P
0 g
s
.22411 .29344 m .24622 .24912 L .32044 .29919 L p .593 .64 .867 r
F P
0 g
s
.82003 .58227 m .8191 .58416 L .76868 .5753 L p .681 .734 .89 r
F P
0 g
s
.41609 .50098 m .41835 .50776 L .42145 .50159 L p .956 .948 .704 r
F P
0 g
s
.42145 .50159 m .41971 .49462 L .41609 .50098 L p .956 .948 .704 r
F P
0 g
s
.6097 .62872 m .62336 .61881 L .61518 .61994 L p .726 .987 .89 r
F P
0 g
s
.61518 .61994 m .60302 .62996 L .6097 .62872 L p .726 .987 .89 r
F P
0 g
s
.62557 .45384 m .6307 .44294 L p .62966 .44624 L 0 0 0 r
F P
0 g
s
.62284 .46104 m .62836 .44907 L p .62871 .4523 L 0 0 .112 r
F P
0 g
s
.62836 .44907 m .62966 .44624 L .62871 .4523 L p 0 0 .112 r
F P
0 g
s
.62922 .43837 m .62884 .44885 L p .62966 .44624 L .837 .744 .225 r
F P
0 g
s
.62884 .44885 m .62871 .4523 L .62966 .44624 L p .837 .744 .225 r
F P
0 g
s
.62932 .4431 m .62898 .45475 L p .62871 .4523 L 0 0 .065 r
F P
0 g
s
.62898 .45475 m .62893 .45679 L .62871 .4523 L p 0 0 .065 r
F P
0 g
s
.6307 .44294 m .63283 .43841 L .62966 .44624 L p 0 0 0 r
F P
0 g
s
.32778 .56465 m .31794 .55034 L .2786 .55906 L p .689 .784 .923 r
F P
0 g
s
.31794 .55034 m .32778 .56465 L .35605 .55368 L p .709 .804 .924 r
F P
0 g
s
.62241 .46683 m .61148 .48073 L .61127 .47481 L p .086 0 .263 r
F P
0 g
s
.61127 .47481 m .62284 .46104 L .62241 .46683 L p .086 0 .263 r
F P
0 g
s
.51335 .61446 m .52344 .62512 L .52171 .62636 L p .644 .182 0 r
F P
0 g
s
.41862 .39441 m .40641 .40842 L .38563 .38681 L p .496 .509 .801 r
F P
0 g
s
.38563 .38681 m .39902 .3689 L .41862 .39441 L p .496 .509 .801 r
F P
0 g
s
.59941 .4981 m .58371 .50904 L .58156 .50297 L p .434 .156 .391 r
F P
0 g
s
.58156 .50297 m .59729 .49302 L .59941 .4981 L p .434 .156 .391 r
F P
0 g
s
.42951 .46453 m .42444 .47165 L .42336 .46322 L p .017 .001 .493 r
F P
0 g
s
.42336 .46322 m .42886 .45471 L .42951 .46453 L p .017 .001 .493 r
F P
0 g
s
.50091 .57976 m .50088 .5819 L .5049 .57391 L p 0 0 .059 r
F P
0 g
s
.5049 .57391 m .50567 .57111 L .50091 .57976 L p 0 0 .059 r
F P
0 g
s
.82389 .57575 m .82003 .58227 L .76933 .57366 L p .675 .735 .895 r
F P
0 g
s
.76868 .5753 m .76933 .57366 L .82003 .58227 L p .681 .734 .89 r
F P
0 g
s
.41021 .50848 m .4131 .51532 L .41835 .50776 L p .926 .948 .788 r
F P
0 g
s
.41835 .50776 m .41609 .50098 L .41021 .50848 L p .926 .948 .788 r
F P
0 g
s
.52344 .62512 m .5365 .63406 L .53443 .63651 L p .749 .229 0 r
F P
0 g
s
.53443 .63651 m .52171 .62636 L .52344 .62512 L p .749 .229 0 r
F P
0 g
s
.6475 .60812 m .65734 .59554 L .64191 .59377 L p .821 .841 .863 r
F P
0 g
s
.64191 .59377 m .63405 .60675 L .6475 .60812 L p .821 .841 .863 r
F P
0 g
s
.50214 .58151 m .50221 .58345 L .50544 .57623 L p 0 0 .004 r
F P
0 g
s
.50544 .57623 m .50617 .57351 L .50214 .58151 L p 0 0 .004 r
F P
0 g
s
.48234 .78518 m .52571 .79033 L .52189 .83867 L p .716 .68 .814 r
F P
0 g
s
.52189 .83867 m .46558 .83315 L .48234 .78518 L p .716 .68 .814 r
F P
0 g
s
.58193 .83672 m .52189 .83867 L .52571 .79033 L p .689 .656 .813 r
F P
0 g
s
.76409 .58245 m .76756 .57685 L .72895 .56987 L p .694 .734 .882 r
F P
0 g
s
.72895 .56987 m .72615 .57503 L .76409 .58245 L p .694 .734 .882 r
F P
0 g
s
.5365 .63406 m .55186 .63991 L .54969 .64311 L p .693 .197 .06 r
F P
0 g
s
.54969 .64311 m .53443 .63651 L .5365 .63406 L p .693 .197 .06 r
F P
0 g
s
.63359 .42301 m .63283 .43841 L .63971 .42878 L p .966 .937 .679 r
F P
0 g
s
.63971 .42878 m .64041 .41179 L .63359 .42301 L p .966 .937 .679 r
F P
0 g
s
.50515 .56433 m .50567 .57111 L .51163 .56141 L p 0 0 .143 r
F P
0 g
s
.51163 .56141 m .5124 .55453 L .50515 .56433 L p 0 0 .143 r
F P
0 g
s
.40121 .51668 m .4051 .52397 L .4131 .51532 L p .878 .931 .853 r
F P
0 g
s
.4131 .51532 m .41021 .50848 L .40121 .51668 L p .878 .931 .853 r
F P
0 g
s
.52859 .53626 m .54062 .53376 L .54625 .52505 L p .412 .084 .296 r
F P
0 g
s
.55053 .52374 m .54625 .52505 L .54062 .53376 L p .375 .002 .196 r
F P
0 g
s
.61293 .48526 m .59941 .4981 L .59729 .49302 L p .366 .126 .411 r
F P
0 g
s
.59729 .49302 m .61148 .48073 L .61293 .48526 L p .366 .126 .411 r
F P
0 g
s
.50221 .58345 m .50371 .59008 L .50475 .58548 L p 0 0 .275 r
F P
0 g
s
.50475 .58548 m .50544 .57623 L .50221 .58345 L p 0 0 .275 r
F P
0 g
s
.54062 .53376 m .52859 .53626 L .52314 .54233 L p .34 .021 .271 r
F P
0 g
s
.35605 .55368 m .34809 .54196 L .31794 .55034 L p .709 .804 .924 r
F P
0 g
s
.34809 .54196 m .35605 .55368 L .37749 .54331 L p .739 .831 .922 r
F P
0 g
s
.42893 .47179 m .42434 .47797 L .42444 .47165 L p 0 0 .354 r
F P
0 g
s
.42444 .47165 m .42951 .46453 L .42893 .47179 L p 0 0 .354 r
F P
0 g
s
.43051 .41579 m .41896 .42677 L .40641 .40842 L p .454 .448 .762 r
F P
0 g
s
.40641 .40842 m .41862 .39441 L .43051 .41579 L p .454 .448 .762 r
F P
0 g
s
.64394 .37944 m .65259 .3978 L .67287 .38054 L p .865 .82 .803 r
F P
0 g
s
.67287 .38054 m .66226 .35792 L .64394 .37944 L p .865 .82 .803 r
F P
0 g
s
.55186 .63991 m .56834 .64184 L .56605 .64539 L p .581 .117 .116 r
F P
0 g
s
.56605 .64539 m .54969 .64311 L .55186 .63991 L p .581 .117 .116 r
F P
0 g
s
.5537 .52958 m .54685 .53184 L .55053 .52374 L p .385 .011 .201 r
F P
0 g
s
.55053 .52374 m .55494 .52227 L .5537 .52958 L p .385 .011 .201 r
F P
0 g
s
.54062 .53376 m .54685 .53184 L .55053 .52374 L p .375 .002 .196 r
F P
0 g
s
.38845 .52516 m .39351 .53337 L .4051 .52397 L p .827 .9 .892 r
F P
0 g
s
.4051 .52397 m .40121 .51668 L .38845 .52516 L p .827 .9 .892 r
F P
0 g
s
.72114 .58319 m .72615 .57503 L .69653 .5694 L p .719 .734 .863 r
F P
0 g
s
.69653 .5694 m .69241 .57726 L .72114 .58319 L p .719 .734 .863 r
F P
0 g
s
.52571 .79033 m .57182 .78928 L .58193 .83672 L p .689 .656 .813 r
F P
0 g
s
.6407 .82635 m .58193 .83672 L .57182 .78928 L p .658 .636 .816 r
F P
0 g
s
.37749 .54331 m .37115 .53359 L .34809 .54196 L p .739 .831 .922 r
F P
0 g
s
.37115 .53359 m .37749 .54331 L .39351 .53337 L p .779 .864 .912 r
F P
0 g
s
.39351 .53337 m .38845 .52516 L .37115 .53359 L p .779 .864 .912 r
F P
0 g
s
.50371 .59008 m .50553 .59674 L p .50491 .59597 L 0 0 .258 r
F P
0 g
s
.50666 .60088 m .50567 .59967 L p .50491 .59597 L 0 0 .258 r
F P
0 g
s
.50553 .59674 m .50666 .60088 L p .50491 .59597 L 0 0 .258 r
F P
0 g
s
.50567 .59967 m .50475 .58548 L .50371 .59008 L p 0 0 .258 r
F P
0 g
s
.5037 .58294 m .50475 .58548 L p .50399 .5948 L .876 .722 .205 r
F P
0 g
s
.50353 .60039 m .50359 .59431 L p .50399 .5948 L .876 .722 .205 r
F P
0 g
s
.50359 .59431 m .5037 .58294 L p .50399 .5948 L .876 .722 .205 r
F P
0 g
s
.42434 .47797 m .42893 .47179 L .42794 .47675 L p 0 0 .213 r
F P
0 g
s
.62336 .61881 m .63405 .60675 L .62412 .6075 L p .856 .953 .874 r
F P
0 g
s
.62412 .6075 m .61518 .61994 L .62336 .61881 L p .856 .953 .874 r
F P
0 g
s
.53191 .54156 m .52314 .54233 L .52116 .54448 L p .143 0 .127 r
F P
0 g
s
.52314 .54233 m .53191 .54156 L .54062 .53376 L p .34 .021 .271 r
F P
0 g
s
.57022 .52296 m .5537 .52958 L .55494 .52227 L p .461 .128 .314 r
F P
0 g
s
.55494 .52227 m .56746 .51738 L .57022 .52296 L p .461 .128 .314 r
F P
0 g
s
.5124 .55453 m .51163 .56141 L .52056 .55061 L p 0 0 0 r
F P
0 g
s
.52056 .55061 m .51879 .5471 L .5124 .55453 L p 0 0 0 r
F P
0 g
s
.52666 .54542 m .52116 .54448 L .51879 .5471 L p .022 0 .038 r
F P
0 g
s
.52116 .54448 m .52571 .54526 L p .52896 .54236 L .143 0 .127 r
F P
0 g
s
.51879 .5471 m .52056 .55061 L .52666 .54542 L p .022 0 .038 r
F P
0 g
s
.54685 .53184 m .54062 .53376 L .53191 .54156 L p .287 0 .07 r
F P
0 g
s
.53191 .54156 m .54158 .53802 L .54685 .53184 L p .287 0 .07 r
F P
0 g
s
.55567 .534 m .54158 .53802 L .54685 .53184 L p .342 0 .098 r
F P
0 g
s
.54158 .53802 m .55518 .53414 L p .55909 .53512 L .41 0 .093 r
F P
0 g
s
.55518 .53414 m .55567 .534 L .55909 .53512 L p .41 0 .093 r
F P
0 g
s
.55909 .53512 m .56549 .53636 L p .56318 .53614 L .267 0 0 r
F P
0 g
s
.55909 .53512 m .52702 .5327 L p .54158 .53802 L .41 0 .093 r
F P
0 g
s
.52538 .49758 m .5263 .53055 L p .527 .53143 L .411 .451 .792 r
F P
0 g
s
.5263 .53055 m .52636 .53265 L p .52682 .53178 L .411 .451 .792 r
F P
0 g
s
.5263 .53055 m .52682 .53178 L .527 .53143 L .411 .451 .792 r
F
.52685 .53244 m .52698 .53218 L p .52636 .53265 L F P
0 g
s
.52698 .53218 m .53788 .51054 L p .52883 .52791 L .411 .451 .792 r
F P
0 g
s
.52683 .53175 m .52698 .53218 L .52716 .53113 L .411 .451 .792 r
F
.52636 .53265 m .52698 .53218 L .52683 .53175 L F
.52698 .53218 m .52698 .53218 L .52683 .53175 L F
.52702 .5327 m .52636 .53265 L p .52732 .53316 L .41 0 .093 r
F P
0 g
s
.52732 .53316 m .54158 .53802 L p .52702 .5327 L .41 0 .093 r
F P
0 g
s
.52678 .5327 m .55909 .53512 L .56318 .53614 L .267 0 0 r
F
.52625 .53258 m .52603 .53272 L .52627 .53269 L .667 .643 .817 r
F
.51998 .49433 m .526 .53252 L .52625 .53258 L F
.526 .53252 m .52603 .53272 L .52625 .53258 L F
.56549 .53636 m .56368 .53928 L .5282 .53304 L p .267 0 0 r
F P
0 g
s
.52596 .53259 m .52603 .53272 L p .52601 .5326 L .667 .643 .817 r
F P
0 g
s
.49584 .50225 m .51016 .50349 L .52591 .5325 L p .622 .623 .83 r
F P
0 g
s
.52666 .54542 m .53191 .54156 L p .52896 .54236 L .143 0 .127 r
F P
0 g
s
.52571 .54526 m .52666 .54542 L p .52896 .54236 L .143 0 .127 r
F P
0 g
s
.54158 .53802 m .53191 .54156 L .52666 .54542 L p .109 0 0 r
F P
0 g
s
.52666 .54542 m .5257 .5329 L p .54158 .53802 L .109 0 0 r
F P
0 g
s
.52576 .53274 m .52603 .53272 L .52584 .53282 L .622 .623 .83 r
F
.52492 .53409 m .52538 .5332 L p .52553 .53311 L .804 .991 .878 r
F P
0 g
s
.49244 .50834 m .52567 .53285 L p .4881 .52664 L .75 .635 .732 r
F P
0 g
s
.52567 .53285 m .52566 .53286 L .4881 .52664 L .75 .635 .732 r
F
.52557 .53296 m .52553 .53311 L .52538 .5332 L .804 .991 .878 r
F
.52553 .53311 m .52085 .54958 L .52492 .53409 L F
.52666 .54542 m .52056 .55061 L p .52557 .53296 L F P
0 g
s
.52567 .53285 m .5257 .53287 L p .52566 .53286 L .75 .635 .732 r
F P
0 g
s
.49244 .50834 m .49584 .50225 L p .52584 .53282 L .622 .623 .83 r
F P
0 g
s
.52584 .53282 m .52583 .53283 L .52583 .53283 L .109 0 0 r
F
.5257 .5329 m .5257 .53287 L p .52583 .53283 L F P
0 g
s
.52603 .53272 m .54158 .53802 L p .5257 .5329 L .109 0 0 r
F P
0 g
s
.52603 .53272 m .52611 .53275 L p .52627 .53269 L .41 0 .093 r
F P
0 g
s
.52611 .53275 m .52613 .53275 L p .52636 .53265 L .41 0 .093 r
F P
0 g
s
.52603 .53272 m .52638 .53337 L p .52627 .53269 L .667 .643 .817 r
F P
0 g
s
.52638 .53337 m .52636 .53265 L p .52627 .53269 L .667 .643 .817 r
F P
0 g
s
.52613 .53275 m .52732 .53316 L p .52636 .53265 L .41 0 .093 r
F P
0 g
s
.52568 .5326 m .5266 .53269 L .52679 .53274 L .267 0 0 r
F
.52735 .53289 m .52668 .53278 L p .52679 .53274 L F P
0 g
s
.52591 .5325 m .52603 .53272 L p .52576 .53274 L .622 .623 .83 r
F P
0 g
s
.52618 .53269 m .52568 .5326 L .52603 .53272 L p .41 0 .093 r
F P
0 g
s
.52568 .5326 m .52626 .53267 L p .52636 .53265 L .41 0 .093 r
F P
0 g
s
.52627 .53269 m .52636 .53265 L .52603 .53272 L .41 0 .093 r
F
.52636 .53265 m .52638 .53337 L .52668 .53278 L p .411 .451 .792 r
F P
0 g
s
.52654 .53271 m .52679 .53274 L .52668 .53278 L .267 0 0 r
F
.52668 .53278 m .52685 .53244 L p .52639 .53264 L .411 .451 .792 r
F P
0 g
s
.52636 .53265 m .52668 .53278 L .52639 .53264 L .411 .451 .792 r
F
.52668 .53278 m .52668 .53278 L p .52679 .53274 L .267 0 0 r
F P
0 g
s
.52668 .53278 m .52568 .5326 L p .52654 .53271 L .267 0 0 r
F P
0 g
s
.52685 .53244 m .52668 .53278 L p .52682 .5324 L .842 .998 .819 r
F P
0 g
s
.52668 .53278 m .52638 .53337 L p .52665 .53279 L .842 .998 .819 r
F P
0 g
s
.52678 .5327 m .56549 .53636 L .5282 .53304 L .267 0 0 r
F
.56368 .53928 m .56549 .53636 L .58116 .53947 L p .536 .001 0 r
F P
0 g
s
.58116 .53947 m .58116 .53947 L p .58083 .53946 L .536 .001 0 r
F P
0 g
s
.56368 .53928 m .58116 .53947 L .58083 .53946 L .536 .001 0 r
F
.58161 .54243 m .56368 .53928 L p .58083 .53946 L F P
0 g
s
.58116 .53947 m .58153 .54193 L p .58083 .53946 L .536 .001 0 r
F P
0 g
s
.58153 .54193 m .58161 .54243 L p .58083 .53946 L .536 .001 0 r
F P
0 g
s
.58161 .54243 m .5638 .5393 L p .58253 .54543 L .58 .023 0 r
F P
0 g
s
.5829 .54555 m .58182 .54295 L p .58253 .54543 L .58 .023 0 r
F P
0 g
s
.58182 .54295 m .58161 .54243 L p .58253 .54543 L .58 .023 0 r
F P
0 g
s
.5638 .5393 m .56369 .53928 L p .56375 .5393 L .58 .023 0 r
F P
0 g
s
.56375 .5393 m .5829 .54555 L .5638 .5393 L .58 .023 0 r
F
.5703 .54371 m .56369 .53928 L .52668 .53278 L p .285 0 0 r
F P
0 g
s
.52668 .53278 m .52568 .5326 L p .52656 .53282 L .285 0 0 r
F P
0 g
s
.52665 .53279 m .52668 .53278 L .52665 .53279 L .842 .998 .819 r
F
.52668 .53278 m .52668 .53278 L .52665 .53279 L F
.52665 .53273 m .52638 .53337 L .52627 .53349 L F
.52682 .5324 m .52667 .53273 L .52665 .53273 L F
.52667 .53273 m .52638 .53337 L .52665 .53273 L F
.52646 .53266 m .52702 .5327 L p .52678 .5327 L .267 0 0 r
F P
0 g
s
.52702 .5327 m .55909 .53512 L p .52689 .53271 L .267 0 0 r
F P
0 g
s
.52702 .5327 m .52689 .53271 L .52678 .5327 L .267 0 0 r
F
.5257 .53287 m .52666 .54542 L p .52557 .53296 L .804 .991 .878 r
F P
0 g
s
.5257 .53287 m .52638 .53337 L .52529 .53318 L p .75 .635 .732 r
F P
0 g
s
.52643 .53292 m .52651 .53282 L p .52625 .53351 L .842 .998 .819 r
F P
0 g
s
.52651 .53282 m .52682 .5324 L p .52651 .533 L .842 .998 .819 r
F P
0 g
s
.52651 .53282 m .52651 .533 L .52625 .53351 L .842 .998 .819 r
F
.56685 .54324 m .5703 .54371 L p .56768 .54306 L .285 0 0 r
F P
0 g
s
.52656 .53282 m .56685 .54324 L .56768 .54306 L .285 0 0 r
F
.52625 .53351 m .5266 .53282 L .52628 .53348 L .842 .998 .819 r
F
.5266 .53282 m .52661 .53282 L .52628 .53348 L F
.52651 .53282 m .56685 .54324 L p .52656 .53282 L .285 0 0 r
F P
0 g
s
.52656 .53282 m .5703 .54371 L .52668 .53278 L .285 0 0 r
F
.5282 .53304 m .52735 .53289 L p .52678 .5327 L .267 0 0 r
F P
0 g
s
.56685 .54324 m .52651 .53282 L p .55574 .53519 L .651 .114 0 r
F P
0 g
s
.55574 .53519 m .56604 .54341 L p .56685 .54324 L .651 .114 0 r
F P
0 g
s
.56604 .54341 m .56641 .54371 L .56685 .54324 L p .651 .114 0 r
F P
0 g
s
.52568 .5326 m .52651 .53282 L p .52656 .53282 L .285 0 0 r
F P
0 g
s
.52648 .53268 m .52646 .53266 L .52678 .5327 L .267 0 0 r
F
.52626 .53263 m .52627 .53269 L .52627 .53263 L .667 .643 .817 r
F
.52568 .5326 m .52636 .53265 L p .52648 .53268 L .267 0 0 r
F P
0 g
s
.52636 .53265 m .52646 .53266 L p .52648 .53268 L .267 0 0 r
F P
0 g
s
.52538 .49758 m .51998 .49433 L p .52626 .53263 L .667 .643 .817 r
F P
0 g
s
.52626 .53263 m .52627 .53263 L .52538 .49758 L .667 .643 .817 r
F
.52651 .53282 m .52568 .5326 L .52633 .53266 L p .651 .114 0 r
F P
0 g
s
.52638 .53337 m .5257 .53287 L p .52584 .53282 L .622 .623 .83 r
F P
0 g
s
.52603 .53272 m .52638 .53337 L p .52584 .53282 L .622 .623 .83 r
F P
0 g
s
.51449 .55486 m .52492 .53409 L p .52085 .54958 L .804 .991 .878 r
F P
0 g
s
.50391 .56311 m .49971 .56476 L p .5265 .53276 L .77 .756 .84 r
F P
0 g
s
.52698 .53218 m .52651 .53282 L p .5265 .53276 L .77 .756 .84 r
F P
0 g
s
.52651 .53282 m .50391 .56311 L p .5265 .53276 L .77 .756 .84 r
F P
0 g
s
.49971 .56476 m .49724 .55379 L .52633 .53266 L p .77 .756 .84 r
F P
0 g
s
.52633 .53266 m .52698 .53218 L p .5265 .53276 L .77 .756 .84 r
F P
0 g
s
.5265 .53276 m .52651 .5328 L .52633 .53266 L .651 .114 0 r
F
.52651 .5328 m .52651 .53282 L .52633 .53266 L F
.49971 .56476 m .52633 .53266 L .5265 .53276 L .77 .756 .84 r
F
.52633 .53266 m .52647 .53267 L p .5265 .53276 L .651 .114 0 r
F P
0 g
s
.52647 .53267 m .52647 .53267 L p .52651 .5328 L .651 .114 0 r
F P
0 g
s
.52529 .53318 m .52481 .5331 L p .5257 .53287 L .75 .635 .732 r
F P
0 g
s
.5257 .53287 m .49244 .50834 L p .52584 .53282 L .622 .623 .83 r
F P
0 g
s
.52481 .5331 m .4881 .52664 L p .5257 .53287 L .75 .635 .732 r
F P
0 g
s
.52538 .5332 m .52568 .5326 L p .52557 .53296 L .804 .991 .878 r
F P
0 g
s
.52636 .53265 m .52538 .49758 L p .52627 .53269 L .667 .643 .817 r
F P
0 g
s
.48642 .55077 m .49724 .55379 L .52633 .53266 L p .787 .811 .871 r
F P
0 g
s
.52633 .53266 m .52698 .53218 L p .52627 .53251 L .787 .811 .871 r
F P
0 g
s
.52698 .53218 m .52601 .53246 L p .52619 .53254 L .787 .811 .871 r
F P
0 g
s
.52538 .53235 m .52591 .5325 L .52576 .53274 L .622 .623 .83 r
F
.49584 .50225 m .52591 .5325 L .52538 .53235 L F
.51998 .49433 m .51016 .50349 L .52596 .53259 L p .667 .643 .817 r
F P
0 g
s
.51998 .49433 m .52596 .53259 L .52601 .5326 L .667 .643 .817 r
F
.52716 .53113 m .52698 .53218 L .52883 .52791 L .411 .451 .792 r
F
.52762 .49991 m .527 .53143 L .53788 .51054 L F
.52538 .49758 m .527 .53143 L .52762 .49991 L F
.53788 .51054 m .53167 .49857 L .52821 .49803 L p F P
0 g
s
.52821 .49803 m .52538 .49758 L p .53101 .50342 L .411 .451 .792 r
F P
0 g
s
.53101 .50342 m .53788 .51054 L .52821 .49803 L .411 .451 .792 r
F
.53167 .49857 m .53788 .51054 L .54345 .49949 L p .379 .412 .77 r
F P
0 g
s
.54601 .51661 m .53718 .50975 L .53576 .51257 L p .424 .494 .828 r
F P
0 g
s
.53576 .51257 m .52598 .532 L p .54017 .52109 L .424 .494 .828 r
F P
0 g
s
.54017 .52109 m .54601 .51661 L .53576 .51257 L .424 .494 .828 r
F
.52598 .532 m .52568 .5326 L p .52607 .53229 L F P
0 g
s
.52615 .53242 m .52698 .53218 L .52589 .53199 L p .75 .635 .732 r
F P
0 g
s
.52589 .53199 m .52541 .5319 L p .52615 .53242 L .75 .635 .732 r
F P
0 g
s
.52698 .53218 m .52698 .53218 L .52716 .53113 L .411 .451 .792 r
F
.54928 .52368 m .54601 .51661 L p .52607 .53229 L .424 .494 .828 r
F P
0 g
s
.52568 .5326 m .52615 .53242 L p .52607 .53229 L .424 .494 .828 r
F P
0 g
s
.52615 .53242 m .54928 .52368 L p .52607 .53229 L .424 .494 .828 r
F P
0 g
s
.52607 .53229 m .54601 .51661 L .52598 .532 L .424 .494 .828 r
F
.48583 .54401 m .52612 .53243 L p .48867 .52545 L .75 .635 .732 r
F P
0 g
s
.52612 .53243 m .52615 .53242 L p .52611 .53241 L .75 .635 .732 r
F P
0 g
s
.52612 .53243 m .52611 .53241 L .48867 .52545 L .75 .635 .732 r
F
.52541 .5319 m .48867 .52545 L p .52615 .53242 L F P
0 g
s
.52591 .5325 m .52591 .5325 L .52576 .53274 L .622 .623 .83 r
F
.52568 .5326 m .52633 .53266 L p .52626 .5325 L 0 .116 .665 r
F P
0 g
s
.52622 .5324 m .52615 .53242 L p .52626 .5325 L 0 .116 .665 r
F P
0 g
s
.52615 .53242 m .52568 .5326 L p .52626 .5325 L 0 .116 .665 r
F P
0 g
s
.52664 .53223 m .52622 .5324 L p .52651 .53267 L 0 .116 .665 r
F P
0 g
s
.52633 .53266 m .52651 .53267 L p .52622 .5324 L 0 .116 .665 r
F P
0 g
s
.52619 .53254 m .52633 .53266 L .52627 .53251 L .787 .811 .871 r
F
.52568 .5326 m .52603 .53272 L p .52584 .53282 L .109 0 0 r
F P
0 g
s
.52584 .53282 m .52583 .53283 L .52568 .5326 L .109 0 0 r
F
.52568 .5326 m .5257 .53287 L p .52557 .53296 L .804 .991 .878 r
F P
0 g
s
.5257 .53287 m .52568 .5326 L p .52583 .53283 L .109 0 0 r
F P
0 g
s
.48642 .55077 m .52633 .53266 L .52619 .53254 L .787 .811 .871 r
F
.48583 .54401 m .48642 .55077 L p .52619 .53254 L F P
0 g
s
.52601 .53246 m .48583 .54401 L p .52619 .53254 L .787 .811 .871 r
F P
0 g
s
.52647 .53267 m .52651 .53267 L p .52651 .53268 L .651 .114 0 r
F P
0 g
s
.52651 .53268 m .52651 .53282 L .52647 .53267 L .651 .114 0 r
F
.5266 .53269 m .52678 .5327 L .52735 .53289 L .267 0 0 r
F
.52651 .53267 m .55574 .53519 L p .52651 .53282 L .651 .114 0 r
F P
0 g
s
.5266 .53282 m .52682 .5324 L .52661 .53282 L .842 .998 .819 r
F
.52513 .53467 m .52643 .53292 L p .52625 .53351 L F P
0 g
s
.54685 .53184 m .5537 .52958 L .55567 .534 L p .342 0 .098 r
F P
0 g
s
.54928 .52368 m .52664 .53223 L p .55574 .53519 L 0 .116 .665 r
F P
0 g
s
.52682 .5324 m .52668 .53278 L .52665 .53279 L .842 .998 .819 r
F
.52682 .5324 m .52698 .53218 L .52685 .53244 L p F P
0 g
s
.52651 .53267 m .55574 .53519 L p .52664 .53223 L 0 .116 .665 r
F P
0 g
s
.51653 .55343 m .51449 .55486 L p .52085 .54958 L .804 .991 .878 r
F P
0 g
s
.51449 .55486 m .52056 .55061 L .51163 .56141 L p .759 .982 .739 r
F P
0 g
s
.52638 .53337 m .51576 .55445 L p .52627 .53349 L .842 .998 .819 r
F P
0 g
s
.50391 .56311 m .52513 .53467 L p .52617 .53371 L .842 .998 .819 r
F P
0 g
s
.52513 .53467 m .52628 .53348 L .52617 .53371 L .842 .998 .819 r
F
.51163 .56141 m .50927 .56521 L .51099 .56179 L p .759 .982 .739 r
F P
0 g
s
.51099 .56179 m .51449 .55486 L p .51266 .55905 L .759 .982 .739 r
F P
0 g
s
.51266 .55905 m .51163 .56141 L .51099 .56179 L .759 .982 .739 r
F
.50927 .56521 m .51163 .56141 L .50567 .57111 L p .607 .799 .377 r
F P
0 g
s
.50567 .57111 m .5049 .57391 L .50927 .56521 L p .607 .799 .377 r
F P
0 g
s
.51055 .56481 m .50794 .56912 L .50768 .56724 L p .836 .995 .756 r
F P
0 g
s
.50768 .56724 m .50719 .56362 L p .50941 .56441 L .836 .995 .756 r
F P
0 g
s
.50941 .56441 m .51055 .56481 L .50768 .56724 L .836 .995 .756 r
F
.50985 .55877 m .52617 .53371 L .51576 .55445 L .842 .998 .819 r
F
.50391 .56311 m .52617 .53371 L .50985 .55877 L F
.52056 .55061 m .51653 .55343 L p .52085 .54958 L .804 .991 .878 r
F P
0 g
s
.68605 .5876 m .69241 .57726 L .66963 .57311 L p .757 .747 .843 r
F P
0 g
s
.66963 .57311 m .66459 .58351 L .68605 .5876 L p .757 .747 .843 r
F P
0 g
s
.21666 .54761 m .22691 .56868 L .2786 .55906 L p .666 .775 .931 r
F P
0 g
s
.42375 .48236 m .42794 .47675 L .42714 .47962 L p 0 0 .1 r
F P
0 g
s
.82943 .56489 m .82389 .57575 L .77237 .56793 L p .672 .731 .894 r
F P
0 g
s
.76933 .57366 m .77237 .56793 L .82389 .57575 L p .675 .735 .895 r
F P
0 g
s
.76756 .57685 m .76868 .5753 L .72987 .56848 L p .698 .723 .869 r
F P
0 g
s
.72987 .56848 m .72895 .56987 L .76756 .57685 L p .698 .723 .869 r
F P
0 g
s
.43692 .43368 m .42582 .44219 L .41896 .42677 L p .412 .38 .714 r
F P
0 g
s
.41896 .42677 m .43051 .41579 L .43692 .43368 L p .412 .38 .714 r
F P
0 g
s
.56834 .64184 m .5844 .63943 L .58197 .64315 L p .415 0 .08 r
F P
0 g
s
.58197 .64315 m .56605 .64539 L .56834 .64184 L p .415 0 .08 r
F P
0 g
s
.62315 .47121 m .61293 .48526 L .61148 .48073 L p .22 .033 .402 r
F P
0 g
s
.61148 .48073 m .62241 .46683 L .62315 .47121 L p .22 .033 .402 r
F P
0 g
s
.62871 .4523 m .62241 .46683 L .62284 .46104 L p 0 0 .112 r
F P
0 g
s
.42318 .48494 m .42714 .47962 L .42684 .48056 L p 0 0 .045 r
F P
0 g
s
.58696 .51333 m .57022 .52296 L .56746 .51738 L p .506 .21 .398 r
F P
0 g
s
.56746 .51738 m .58371 .50904 L .58696 .51333 L p .506 .21 .398 r
F P
0 g
s
.50666 .60088 m .51237 .61385 L .51056 .61499 L p .779 .463 0 r
F P
0 g
s
.42298 .48578 m .42684 .48056 L .42648 .48167 L p 0 0 .026 r
F P
0 g
s
.44488 .77584 m .48234 .78518 L .46558 .83315 L p .738 .705 .82 r
F P
0 g
s
.46558 .83315 m .41702 .82223 L .44488 .77584 L p .738 .705 .82 r
F P
0 g
s
.4227 .48679 m .42648 .48167 L .42517 .48495 L p 0 0 0 r
F P
0 g
s
.76933 .57366 m .76868 .5753 L .72987 .56848 L p .696 .72 .868 r
F P
0 g
s
.6019 .50163 m .58696 .51333 L .58371 .50904 L p .49 .228 .444 r
F P
0 g
s
.58371 .50904 m .59941 .4981 L .6019 .50163 L p .49 .228 .444 r
F P
0 g
s
.65734 .59554 m .66459 .58351 L .64748 .58123 L p .809 .784 .829 r
F P
0 g
s
.64748 .58123 m .64191 .59377 L .65734 .59554 L p .809 .784 .829 r
F P
0 g
s
.60302 .62996 m .61518 .61994 L .60969 .62264 L p .604 .921 .679 r
F P
0 g
s
.51237 .61385 m .52171 .62636 L .51971 .6288 L p .896 .478 .102 r
F P
0 g
s
.51971 .6288 m .51056 .61499 L .51237 .61385 L p .896 .478 .102 r
F P
0 g
s
.42177 .48979 m .42517 .48495 L .42253 .49011 L p 0 0 0 r
F P
0 g
s
.52171 .62636 m .53443 .63651 L .5325 .63966 L p .843 .417 .22 r
F P
0 g
s
.5325 .63966 m .51971 .6288 L .52171 .62636 L p .843 .417 .22 r
F P
0 g
s
.61464 .48842 m .6019 .50163 L .59941 .4981 L p .424 .203 .472 r
F P
0 g
s
.59941 .4981 m .61293 .48526 L .61464 .48842 L p .424 .203 .472 r
F P
0 g
s
.77237 .56793 m .76933 .57366 L .73031 .56701 L p .685 .723 .878 r
F P
0 g
s
.72987 .56848 m .73031 .56701 L .76933 .57366 L p .696 .72 .868 r
F P
0 g
s
.53443 .63651 m .54969 .64311 L .54794 .64669 L p .75 .341 .275 r
F P
0 g
s
.54794 .64669 m .5325 .63966 L .53443 .63651 L p .75 .341 .275 r
F P
0 g
s
.63313 .39624 m .64041 .41179 L .65259 .3978 L p .907 .829 .758 r
F P
0 g
s
.65259 .3978 m .64394 .37944 L .63313 .39624 L p .907 .829 .758 r
F P
0 g
s
.50794 .56912 m .51055 .56481 L .50617 .57351 L p .707 .86 .444 r
F P
0 g
s
.50617 .57351 m .50544 .57623 L .50794 .56912 L p .707 .86 .444 r
F P
0 g
s
.63032 .4317 m .62966 .44624 L .63283 .43841 L p .951 .891 .497 r
F P
0 g
s
.63283 .43841 m .63359 .42301 L .63032 .4317 L p .951 .891 .497 r
F P
0 g
s
.43949 .44835 m .42886 .45471 L .42582 .44219 L p .37 .308 .656 r
F P
0 g
s
.42582 .44219 m .43692 .43368 L .43949 .44835 L p .37 .308 .656 r
F P
0 g
s
.41797 .4967 m .41609 .50098 L .41971 .49462 L p .616 .83 .434 r
F P
0 g
s
.41971 .49462 m .42253 .49011 L .41797 .4967 L p .616 .83 .434 r
F P
0 g
s
.72615 .57503 m .72895 .56987 L .69879 .56447 L p .712 .723 .859 r
F P
0 g
s
.69879 .56447 m .69653 .5694 L .72615 .57503 L p .712 .723 .859 r
F P
0 g
s
.54969 .64311 m .56605 .64539 L .56451 .6492 L p .642 .253 .293 r
F P
0 g
s
.56451 .6492 m .54794 .64669 L .54969 .64311 L p .642 .253 .293 r
F P
0 g
s
.5844 .63943 m .59857 .63285 L .59583 .63655 L p .14 0 0 r
F P
0 g
s
.59583 .63655 m .58197 .64315 L .5844 .63943 L p .14 0 0 r
F P
0 g
s
.63405 .60675 m .64191 .59377 L .63008 .59388 L p .875 .868 .828 r
F P
0 g
s
.63008 .59388 m .62412 .6075 L .63405 .60675 L p .875 .868 .828 r
F P
0 g
s
.35023 .79485 m .37837 .80855 L .32545 .86453 L p .746 .759 .863 r
F P
0 g
s
.32545 .86453 m .28729 .84723 L .35023 .79485 L p .746 .759 .863 r
F P
0 g
s
.50544 .57623 m .50475 .58548 L .5037 .58294 L p 0 0 0 r
F P
0 g
s
.5037 .58294 m .50794 .56912 L .50544 .57623 L p 0 0 0 r
F P
0 g
s
.41085 .50408 m .41021 .50848 L .41609 .50098 L p .714 .954 .673 r
F P
0 g
s
.41609 .50098 m .41797 .4967 L .41085 .50408 L p .714 .954 .673 r
F P
0 g
s
.2786 .55906 m .2707 .54221 L .21666 .54761 L p .666 .775 .931 r
F P
0 g
s
.2707 .54221 m .2786 .55906 L .31794 .55034 L p .673 .793 .939 r
F P
0 g
s
.69241 .57726 m .69653 .5694 L .67304 .56522 L p .743 .723 .833 r
F P
0 g
s
.67304 .56522 m .66963 .57311 L .69241 .57726 L p .743 .723 .833 r
F P
0 g
s
.62424 .47422 m .61464 .48842 L .61293 .48526 L p .298 .131 .479 r
F P
0 g
s
.61293 .48526 m .62315 .47121 L .62424 .47422 L p .298 .131 .479 r
F P
0 g
s
.43955 .4599 m .42951 .46453 L .42886 .45471 L p .33 .233 .592 r
F P
0 g
s
.42886 .45471 m .43949 .44835 L .43955 .4599 L p .33 .233 .592 r
F P
0 g
s
.56605 .64539 m .58197 .64315 L .58056 .64702 L p .507 .14 .277 r
F P
0 g
s
.58056 .64702 m .56451 .6492 L .56605 .64539 L p .507 .14 .277 r
F P
0 g
s
.62893 .45679 m .62315 .47121 L .62241 .46683 L p 0 0 .319 r
F P
0 g
s
.62241 .46683 m .62871 .4523 L .62893 .45679 L p 0 0 .319 r
F P
0 g
s
.61592 .49025 m .60379 .50369 L .6019 .50163 L p .455 .247 .506 r
F P
0 g
s
.6019 .50163 m .61464 .48842 L .61592 .49025 L p .455 .247 .506 r
F P
0 g
s
.58696 .51333 m .6019 .50163 L .60379 .50369 L p .523 .271 .475 r
F P
0 g
s
.40058 .5116 m .40121 .51668 L .41021 .50848 L p .755 .995 .848 r
F P
0 g
s
.41021 .50848 m .41085 .50408 L .40058 .5116 L p .755 .995 .848 r
F P
0 g
s
.66459 .58351 m .66963 .57311 L .65133 .57034 L p .789 .74 .808 r
F P
0 g
s
.65133 .57034 m .64748 .58123 L .66459 .58351 L p .789 .74 .808 r
F P
0 g
s
.72895 .56987 m .72987 .56848 L .69955 .56315 L p .717 .705 .838 r
F P
0 g
s
.69955 .56315 m .69879 .56447 L .72895 .56987 L p .717 .705 .838 r
F P
0 g
s
.77237 .56793 m .77672 .55846 L .82943 .56489 L p .672 .731 .894 r
F P
0 g
s
.77672 .55846 m .77237 .56793 L .73278 .56175 L p .68 .717 .877 r
F P
0 g
s
.73031 .56701 m .73278 .56175 L .77237 .56793 L p .685 .723 .878 r
F P
0 g
s
.60379 .50369 m .58971 .51579 L .58696 .51333 L p .523 .271 .475 r
F P
0 g
s
.57022 .52296 m .58696 .51333 L .58971 .51579 L p .551 .256 .42 r
F P
0 g
s
.61518 .61994 m .62412 .6075 L .61725 .6098 L p .886 .99 .791 r
F P
0 g
s
.61725 .6098 m .60969 .62264 L .61518 .61994 L p .886 .99 .791 r
F P
0 g
s
.50475 .58548 m .50567 .59967 L .50353 .60039 L p .876 .722 .205 r
F P
0 g
s
.73031 .56701 m .72987 .56848 L .69955 .56315 L p .713 .7 .837 r
F P
0 g
s
.51971 .6288 m .5325 .63966 L .53094 .64266 L p .854 .494 .368 r
F P
0 g
s
.5325 .63966 m .54794 .64669 L .54665 .64985 L p .764 .41 .384 r
F P
0 g
s
.54665 .64985 m .53094 .64266 L .5325 .63966 L p .764 .41 .384 r
F P
0 g
s
.43828 .46841 m .42893 .47179 L .42951 .46453 L p .293 .16 .523 r
F P
0 g
s
.42951 .46453 m .43955 .4599 L .43828 .46841 L p .293 .16 .523 r
F P
0 g
s
.51056 .61499 m .51971 .6288 L .51787 .63147 L p .935 .586 .338 r
F P
0 g
s
.53094 .64266 m .51787 .63147 L .51971 .6288 L p .854 .494 .368 r
F P
0 g
s
.54794 .64669 m .56451 .6492 L .56352 .65247 L p .665 .322 .382 r
F P
0 g
s
.56352 .65247 m .54665 .64985 L .54794 .64669 L p .665 .322 .382 r
F P
0 g
s
.31794 .55034 m .31192 .53689 L .2707 .54221 L p .673 .793 .939 r
F P
0 g
s
.31192 .53689 m .31794 .55034 L .34809 .54196 L p .684 .821 .949 r
F P
0 g
s
.38646 .51877 m .38845 .52516 L .40121 .51668 L p .746 .966 .934 r
F P
0 g
s
.40121 .51668 m .40058 .5116 L .38646 .51877 L p .746 .966 .934 r
F P
0 g
s
.73278 .56175 m .73031 .56701 L .69985 .56175 L p .698 .706 .854 r
F P
0 g
s
.69955 .56315 m .69985 .56175 L .73031 .56701 L p .713 .7 .837 r
F P
0 g
s
.62511 .47599 m .61592 .49025 L .61464 .48842 L p .339 .186 .522 r
F P
0 g
s
.61464 .48842 m .62424 .47422 L .62511 .47599 L p .339 .186 .522 r
F P
0 g
s
.58971 .51579 m .57407 .52611 L .57022 .52296 L p .551 .256 .42 r
F P
0 g
s
.5537 .52958 m .57022 .52296 L .57407 .52611 L p .518 .182 .337 r
F P
0 g
s
.62721 .40915 m .63359 .42301 L .64041 .41179 L p .948 .831 .695 r
F P
0 g
s
.64041 .41179 m .63313 .39624 L .62721 .40915 L p .948 .831 .695 r
F P
0 g
s
.61638 .49086 m .60447 .50435 L .60379 .50369 L p .469 .267 .523 r
F P
0 g
s
.60379 .50369 m .61592 .49025 L .61638 .49086 L p .469 .267 .523 r
F P
0 g
s
.58971 .51579 m .60379 .50369 L .60447 .50435 L p .537 .29 .488 r
F P
0 g
s
.50567 .59967 m .51056 .61499 L .50848 .61706 L p .974 .679 .292 r
F P
0 g
s
.51787 .63147 m .50848 .61706 L .51056 .61499 L p .935 .586 .338 r
F P
0 g
s
.50848 .61706 m .50353 .60039 L .50567 .59967 L p .974 .679 .292 r
F P
0 g
s
.59857 .63285 m .60715 .62497 L p .60639 .6262 L 0 0 0 r
F P
0 g
s
.59583 .63655 m .60492 .62764 L p .60465 .62982 L 0 0 .021 r
F P
0 g
s
.60492 .62764 m .60639 .6262 L .60465 .62982 L p 0 0 .021 r
F P
0 g
s
.61049 .61629 m .60578 .62719 L p .60639 .6262 L .689 .797 .331 r
F P
0 g
s
.60578 .62719 m .60465 .62982 L .60639 .6262 L p .689 .797 .331 r
F P
0 g
s
.60715 .62497 m .60969 .62264 L .60639 .6262 L p 0 0 0 r
F P
0 g
s
.61289 .61296 m .60639 .6262 L .60969 .62264 L p .841 .952 .602 r
F P
0 g
s
.60639 .6262 m .61185 .61508 L p .61049 .61629 L .689 .797 .331 r
F P
0 g
s
.61185 .61508 m .61289 .61296 L .61049 .61629 L p .689 .797 .331 r
F P
0 g
s
.61011 .60362 m .60948 .61718 L p .61049 .61629 L .939 .827 .38 r
F P
0 g
s
.60465 .62982 m .60998 .61747 L p .60939 .61918 L 0 0 0 r
F P
0 g
s
.60998 .61747 m .61049 .61629 L .60939 .61918 L p 0 0 0 r
F P
0 g
s
.60939 .61918 m .60445 .63142 L p .60465 .62982 L 0 0 0 r
F P
0 g
s
.60387 .63285 m .6092 .61964 L p .609 .62112 L 0 0 .106 r
F P
0 g
s
.6092 .61964 m .60939 .61918 L .609 .62112 L p 0 0 .106 r
F P
0 g
s
.609 .62112 m .60366 .6349 L .60387 .63285 L p 0 0 .106 r
F P
0 g
s
.60366 .6349 m .60899 .62116 L p .60893 .62181 L 0 0 .163 r
F P
0 g
s
.60899 .62116 m .609 .62112 L .60893 .62181 L p 0 0 .163 r
F P
0 g
s
.60893 .62181 m .60361 .63561 L .60366 .6349 L p 0 0 .163 r
F P
0 g
s
.60361 .63561 m .60891 .62189 L p .60889 .62239 L 0 0 .211 r
F P
0 g
s
.60891 .62189 m .60893 .62181 L .60889 .62239 L p 0 0 .211 r
F P
0 g
s
.60889 .62239 m .6036 .63621 L .60361 .63561 L p 0 0 .211 r
F P
0 g
s
.6036 .63621 m .60869 .62291 L p .60884 .62419 L 0 0 .235 r
F P
0 g
s
.60869 .62291 m .60889 .62239 L .60884 .62419 L p 0 0 .235 r
F P
0 g
s
.60884 .62391 m .60884 .62419 L .60889 .62239 L p .737 .607 .037 r
F P
0 g
s
.60908 .6067 m .60889 .62236 L p .60893 .62181 L .778 .652 .096 r
F P
0 g
s
.60889 .62236 m .60889 .62239 L .60893 .62181 L p .778 .652 .096 r
F P
0 g
s
.6092 .60613 m .60894 .62161 L p .609 .62112 L .794 .671 .121 r
F P
0 g
s
.60894 .62161 m .60893 .62181 L .609 .62112 L p .794 .671 .121 r
F P
0 g
s
.60903 .62023 m .609 .62112 L .60939 .61918 L p .863 .741 .226 r
F P
0 g
s
.609 .62112 m .60938 .60547 L .6092 .60613 L p .794 .671 .121 r
F P
0 g
s
.60893 .62181 m .6092 .60613 L .60908 .6067 L p .778 .652 .096 r
F P
0 g
s
.60889 .62239 m .60907 .60742 L p .60885 .60846 L .737 .607 .037 r
F P
0 g
s
.60907 .60742 m .60908 .6067 L .60885 .60846 L p .737 .607 .037 r
F P
0 g
s
.6038 .59542 m .60847 .61026 L p .60885 .60846 L .909 .616 .122 r
F P
0 g
s
.60885 .60846 m .60884 .62391 L p .60889 .62239 L .737 .607 .037 r
F P
0 g
s
.60884 .62419 m .60885 .61035 L p .60892 .61169 L 0 0 .106 r
F P
0 g
s
.60885 .61035 m .60885 .60846 L .60892 .61169 L p 0 0 .106 r
F P
0 g
s
.60892 .61169 m .60909 .62636 L p .60884 .62419 L 0 0 .106 r
F P
0 g
s
.60938 .60547 m .60903 .62023 L p .60939 .61918 L .863 .741 .226 r
F P
0 g
s
.60948 .61718 m .60939 .61918 L .61049 .61629 L p .939 .827 .38 r
F P
0 g
s
.60939 .61918 m .61011 .60362 L .60938 .60547 L p .863 .741 .226 r
F P
0 g
s
.60911 .62741 m .60892 .61169 L .61 .61673 L p 0 0 .299 r
F P
0 g
s
.60494 .60092 m .60903 .61369 L p .60892 .61169 L .779 .478 0 r
F P
0 g
s
.60903 .61369 m .61 .61673 L .60892 .61169 L p .779 .478 0 r
F P
0 g
s
.60847 .61026 m .60892 .61169 L .60885 .60846 L p .909 .616 .122 r
F P
0 g
s
.60909 .62636 m .60911 .62741 L .60884 .62419 L p 0 0 .106 r
F P
0 g
s
.60445 .63142 m .60387 .63285 L .60465 .62982 L p 0 0 0 r
F P
0 g
s
.57407 .52611 m .55567 .534 L .5537 .52958 L p .518 .182 .337 r
F P
0 g
s
.62966 .44624 m .63032 .4317 L .62922 .43837 L p .837 .744 .225 r
F P
0 g
s
.83546 .54993 m .82943 .56489 L .77672 .55846 L p .666 .726 .894 r
F P
0 g
s
.64191 .59377 m .64748 .58123 L .6338 .5805 L p .854 .79 .788 r
F P
0 g
s
.6338 .5805 m .63008 .59388 L .64191 .59377 L p .854 .79 .788 r
F P
0 g
s
.69653 .5694 m .69879 .56447 L .67487 .56029 L p .731 .707 .828 r
F P
0 g
s
.67487 .56029 m .67304 .56522 L .69653 .5694 L p .731 .707 .828 r
F P
0 g
s
.6407 .82635 m .69273 .80787 L .74768 .86092 L p .63 .653 .855 r
F P
0 g
s
.80471 .82886 m .74768 .86092 L .69273 .80787 L p .6 .647 .868 r
F P
0 g
s
.61698 .49158 m .60535 .50515 L .60447 .50435 L p .478 .28 .532 r
F P
0 g
s
.60447 .50435 m .61638 .49086 L .61698 .49158 L p .478 .28 .532 r
F P
0 g
s
.59076 .51657 m .60447 .50435 L .60535 .50515 L p .545 .302 .497 r
F P
0 g
s
.60447 .50435 m .59076 .51657 L .58971 .51579 L p .537 .29 .488 r
F P
0 g
s
.57182 .78928 m .61663 .78128 L .6407 .82635 L p .658 .636 .816 r
F P
0 g
s
.69273 .80787 m .6407 .82635 L .61663 .78128 L p .622 .62 .827 r
F P
0 g
s
.36777 .52537 m .37115 .53359 L .38845 .52516 L p .723 .912 .96 r
F P
0 g
s
.38845 .52516 m .38646 .51877 L .36777 .52537 L p .723 .912 .96 r
F P
0 g
s
.43669 .47416 m .42794 .47675 L .42893 .47179 L p .259 .093 .457 r
F P
0 g
s
.42893 .47179 m .43828 .46841 L .43669 .47416 L p .259 .093 .457 r
F P
0 g
s
.58197 .64315 m .59583 .63655 L .59439 .64035 L p .3 0 .206 r
F P
0 g
s
.59439 .64035 m .58056 .64702 L .58197 .64315 L p .3 0 .206 r
F P
0 g
s
.43405 .38313 m .41862 .39441 L .39902 .3689 L p .548 .528 .785 r
F P
0 g
s
.39902 .3689 m .41619 .3545 L .43405 .38313 L p .548 .528 .785 r
F P
0 g
s
.41619 .3545 m .39902 .3689 L .3682 .33778 L p .571 .571 .814 r
F P
0 g
s
.34809 .54196 m .34351 .53135 L .31192 .53689 L p .684 .821 .949 r
F P
0 g
s
.34351 .53135 m .34809 .54196 L .37115 .53359 L p .701 .86 .958 r
F P
0 g
s
.57407 .52611 m .58971 .51579 L .59076 .51657 L p .575 .278 .427 r
F P
0 g
s
.56451 .6492 m .58056 .64702 L .57978 .65026 L p .545 .222 .371 r
F P
0 g
s
.57978 .65026 m .56352 .65247 L .56451 .6492 L p .545 .222 .371 r
F P
0 g
s
.6296 .45985 m .62424 .47422 L .62315 .47121 L p .048 0 .441 r
F P
0 g
s
.62315 .47121 m .62893 .45679 L .6296 .45985 L p .048 0 .441 r
F P
0 g
s
.37115 .53359 m .36777 .52537 L .34351 .53135 L p .701 .86 .958 r
F P
0 g
s
.61894 .49371 m .60818 .50748 L .60535 .50515 L p .493 .301 .548 r
F P
0 g
s
.60535 .50515 m .61698 .49158 L .61894 .49371 L p .493 .301 .548 r
F P
0 g
s
.5921 .5175 m .60535 .50515 L .60818 .50748 L p .561 .324 .514 r
F P
0 g
s
.60535 .50515 m .5921 .5175 L .59076 .51657 L p .545 .302 .497 r
F P
0 g
s
.62543 .47657 m .61638 .49086 L .61592 .49025 L p .354 .206 .538 r
F P
0 g
s
.61592 .49025 m .62511 .47599 L .62543 .47657 L p .354 .206 .538 r
F P
0 g
s
.44509 .40698 m .43051 .41579 L .41862 .39441 L p .523 .481 .751 r
F P
0 g
s
.41862 .39441 m .43405 .38313 L .44509 .40698 L p .523 .481 .751 r
F P
0 g
s
.43547 .47744 m .42714 .47962 L .42794 .47675 L p .23 .04 .403 r
F P
0 g
s
.42794 .47675 m .43669 .47416 L .43547 .47744 L p .23 .04 .403 r
F P
0 g
s
.57582 .52709 m .59076 .51657 L .5921 .5175 L p .584 .289 .433 r
F P
0 g
s
.59076 .51657 m .57582 .52709 L .57407 .52611 L p .575 .278 .427 r
F P
0 g
s
.66963 .57311 m .67304 .56522 L .65395 .56204 L p .768 .708 .796 r
F P
0 g
s
.65395 .56204 m .65133 .57034 L .66963 .57311 L p .768 .708 .796 r
F P
0 g
s
.50719 .56362 m .51576 .55445 L .51055 .56481 L p .836 .995 .756 r
F P
0 g
s
.62582 .47727 m .61698 .49158 L .61638 .49086 L p .36 .215 .545 r
F P
0 g
s
.61638 .49086 m .62543 .47657 L .62582 .47727 L p .36 .215 .545 r
F P
0 g
s
.51787 .63147 m .53094 .64266 L .52993 .64475 L p .851 .526 .436 r
F P
0 g
s
.53094 .64266 m .54665 .64985 L .54589 .65203 L p .767 .444 .44 r
F P
0 g
s
.54589 .65203 m .52993 .64475 L .53094 .64266 L p .767 .444 .44 r
F P
0 g
s
.54665 .64985 m .56352 .65247 L .56296 .65464 L p .675 .365 .441 r
F P
0 g
s
.56296 .65464 m .54589 .65203 L .54665 .64985 L p .675 .365 .441 r
F P
0 g
s
.3682 .33778 m .38831 .31918 L .41619 .3545 L p .571 .571 .814 r
F P
0 g
s
.38831 .31918 m .3682 .33778 L .32044 .29919 L p .593 .609 .837 r
F P
0 g
s
.43503 .47851 m .42684 .48056 L .42714 .47962 L p .212 .009 .372 r
F P
0 g
s
.42714 .47962 m .43547 .47744 L .43503 .47851 L p .212 .009 .372 r
F P
0 g
s
.43445 .47977 m .42648 .48167 L .42684 .48056 L p .202 0 .351 r
F P
0 g
s
.42684 .48056 m .43503 .47851 L .43445 .47977 L p .202 0 .351 r
F P
0 g
s
.6272 .47931 m .61894 .49371 L .61698 .49158 L p .387 .248 .568 r
F P
0 g
s
.61698 .49158 m .62582 .47727 L .6272 .47931 L p .387 .248 .568 r
F P
0 g
s
.43257 .48343 m .42517 .48495 L .42648 .48167 L p .185 0 .313 r
F P
0 g
s
.42648 .48167 m .43445 .47977 L .43257 .48343 L p .185 0 .313 r
F P
0 g
s
.69879 .56447 m .69955 .56315 L .67554 .55893 L p .734 .681 .799 r
F P
0 g
s
.67554 .55893 m .67487 .56029 L .69879 .56447 L p .734 .681 .799 r
F P
0 g
s
.60818 .50748 m .59651 .52014 L .5921 .5175 L p .561 .324 .514 r
F P
0 g
s
.57818 .52822 m .5921 .5175 L .59651 .52014 L p .605 .317 .453 r
F P
0 g
s
.5921 .5175 m .57818 .52822 L .57582 .52709 L p .584 .289 .433 r
F P
0 g
s
.73278 .56175 m .73624 .55315 L .77672 .55846 L p .68 .717 .877 r
F P
0 g
s
.73624 .55315 m .73278 .56175 L .70188 .55676 L p .689 .697 .853 r
F P
0 g
s
.69985 .56175 m .70188 .55676 L .73278 .56175 L p .698 .706 .854 r
F P
0 g
s
.50848 .61706 m .51787 .63147 L .51661 .63347 L p .927 .619 .439 r
F P
0 g
s
.52993 .64475 m .51661 .63347 L .51787 .63147 L p .851 .526 .436 r
F P
0 g
s
.62412 .6075 m .63008 .59388 L .62138 .59545 L p .93 .895 .772 r
F P
0 g
s
.62138 .59545 m .61725 .6098 L .62412 .6075 L p .93 .895 .772 r
F P
0 g
s
.45119 .42704 m .43692 .43368 L .43051 .41579 L p .5 .433 .713 r
F P
0 g
s
.43051 .41579 m .44509 .40698 L .45119 .42704 L p .5 .433 .713 r
F P
0 g
s
.69985 .56175 m .69955 .56315 L .67554 .55893 L p .729 .675 .798 r
F P
0 g
s
.41518 .76428 m .44488 .77584 L .41702 .82223 L p .756 .729 .828 r
F P
0 g
s
.41702 .82223 m .37837 .80855 L .41518 .76428 L p .756 .729 .828 r
F P
0 g
s
.42893 .48902 m .42253 .49011 L .42517 .48495 L p .144 0 .225 r
F P
0 g
s
.42517 .48495 m .43257 .48343 L .42893 .48902 L p .144 0 .225 r
F P
0 g
s
.62268 .49707 m .61351 .51105 L .60818 .50748 L p .521 .341 .578 r
F P
0 g
s
.60818 .50748 m .61894 .49371 L .62268 .49707 L p .521 .341 .578 r
F P
0 g
s
.59651 .52014 m .60818 .50748 L .61351 .51105 L p .587 .364 .545 r
F P
0 g
s
.52993 .64475 m .54589 .65203 L .54563 .6528 L p .767 .461 .469 r
F P
0 g
s
.54589 .65203 m .56296 .65464 L .56279 .65541 L p .678 .377 .457 r
F P
0 g
s
.56279 .65541 m .54563 .6528 L .54589 .65203 L p .678 .377 .457 r
F P
0 g
s
.56352 .65247 m .57978 .65026 L .57946 .65246 L p .564 .264 .417 r
F P
0 g
s
.57946 .65246 m .56296 .65464 L .56352 .65247 L p .564 .264 .417 r
F P
0 g
s
.63024 .46161 m .62511 .47599 L .62424 .47422 L p .128 .066 .511 r
F P
0 g
s
.62424 .47422 m .6296 .45985 L .63024 .46161 L p .128 .066 .511 r
F P
0 g
s
.51661 .63347 m .52993 .64475 L .52959 .64552 L p .848 .538 .464 r
F P
0 g
s
.54563 .6528 m .52959 .64552 L .52993 .64475 L p .767 .461 .469 r
F P
0 g
s
.70188 .55676 m .69985 .56175 L .67573 .5575 L p .711 .683 .822 r
F P
0 g
s
.67554 .55893 m .67573 .5575 L .69985 .56175 L p .729 .675 .798 r
F P
0 g
s
.64748 .58123 m .65133 .57034 L .6362 .56872 L p .822 .729 .763 r
F P
0 g
s
.6362 .56872 m .6338 .5805 L .64748 .58123 L p .822 .729 .763 r
F P
0 g
s
.50794 .56912 m .5037 .58294 L .50095 .5831 L p .931 .92 .543 r
F P
0 g
s
.50095 .5831 m .50719 .56362 L .50794 .56912 L p .931 .92 .543 r
F P
0 g
s
.52959 .64552 m .54563 .6528 L .54543 .65345 L p .767 .465 .474 r
F P
0 g
s
.54563 .6528 m .56279 .65541 L .56267 .65608 L p .68 .388 .472 r
F P
0 g
s
.56267 .65608 m .54543 .65345 L .54563 .6528 L p .68 .388 .472 r
F P
0 g
s
.55567 .534 m .57407 .52611 L .57582 .52709 L p .567 .202 .308 r
F P
0 g
s
.62871 .4523 m .62917 .4398 L p .62932 .4431 L 0 0 .065 r
F P
0 g
s
.62893 .45679 m .6293 .44376 L p .62982 .44631 L 0 0 .259 r
F P
0 g
s
.6293 .44376 m .62932 .4431 L .62982 .44631 L p 0 0 .259 r
F P
0 g
s
.62982 .44631 m .6296 .45985 L .62893 .45679 L p 0 0 .259 r
F P
0 g
s
.6296 .45985 m .62982 .44632 L p .63029 .44817 L 0 0 .369 r
F P
0 g
s
.62982 .44632 m .62982 .44631 L .63029 .44817 L p 0 0 .369 r
F P
0 g
s
.63029 .44817 m .63024 .46161 L .6296 .45985 L p 0 0 .369 r
F P
0 g
s
.63024 .46161 m .63029 .44828 L p .63044 .44879 L 0 0 .365 r
F P
0 g
s
.63029 .44828 m .63029 .44817 L .63044 .44879 L p 0 0 .365 r
F P
0 g
s
.63044 .44879 m .63046 .4622 L .63024 .46161 L p 0 0 .365 r
F P
0 g
s
.63046 .4622 m .63044 .44893 L p .63068 .44951 L 0 0 .443 r
F P
0 g
s
.63044 .44893 m .63044 .44879 L .63068 .44951 L p 0 0 .443 r
F P
0 g
s
.63068 .44951 m .63076 .4629 L .63046 .4622 L p 0 0 .443 r
F P
0 g
s
.63076 .4629 m .63069 .45004 L p .63158 .4516 L 0 0 .517 r
F P
0 g
s
.63069 .45004 m .63068 .44951 L .63158 .4516 L p 0 0 .517 r
F P
0 g
s
.63141 .45125 m .63158 .4516 L .63068 .44951 L p .756 .4 0 r
F P
0 g
s
.63063 .4494 m .63068 .44951 L .63044 .44879 L p .765 .41 0 r
F P
0 g
s
.62804 .44386 m .63306 .4542 L p .63158 .4516 L 0 0 .374 r
F P
0 g
s
.63306 .4542 m .63341 .45491 L .63158 .4516 L p 0 0 .374 r
F P
0 g
s
.62622 .44048 m .63141 .45125 L p .63068 .44951 L .756 .4 0 r
F P
0 g
s
.62541 .43827 m .63063 .4494 L p .63044 .44879 L .765 .41 0 r
F P
0 g
s
.62515 .43751 m .63044 .44878 L p .63029 .44817 L .831 .485 0 r
F P
0 g
s
.63044 .44878 m .63044 .44879 L .63029 .44817 L p .831 .485 0 r
F P
0 g
s
.62496 .43688 m .63013 .44784 L p .62982 .44631 L .871 .537 .028 r
F P
0 g
s
.63013 .44784 m .63029 .44817 L .62982 .44631 L p .871 .537 .028 r
F P
0 g
s
.62449 .43491 m .62942 .44546 L p .62932 .4431 L .916 .599 .122 r
F P
0 g
s
.62942 .44546 m .62982 .44631 L .62932 .4431 L p .916 .599 .122 r
F P
0 g
s
.62917 .4398 m .62922 .43837 L .62932 .4431 L p 0 0 .065 r
F P
0 g
s
.52959 .64552 m .51616 .63419 L .51661 .63347 L p .848 .538 .464 r
F P
0 g
s
.51616 .63419 m .52959 .64552 L .5293 .64616 L p .846 .544 .478 r
F P
0 g
s
.54543 .65345 m .5293 .64616 L .52959 .64552 L p .767 .465 .474 r
F P
0 g
s
.58056 .64702 m .59439 .64035 L .59373 .64354 L p .368 .067 .316 r
F P
0 g
s
.59373 .64354 m .57978 .65026 L .58056 .64702 L p .368 .067 .316 r
F P
0 g
s
.62996 .48256 m .62268 .49707 L .61894 .49371 L p .424 .298 .603 r
F P
0 g
s
.61894 .49371 m .6272 .47931 L .62996 .48256 L p .424 .298 .603 r
F P
0 g
s
.42293 .49575 m .41797 .4967 L .42253 .49011 L p .068 0 .061 r
F P
0 g
s
.42253 .49011 m .42893 .48902 L .42293 .49575 L p .068 0 .061 r
F P
0 g
s
.5293 .64616 m .54543 .65345 L .54476 .65547 L p .768 .474 .489 r
F P
0 g
s
.54543 .65345 m .56267 .65608 L .56228 .65812 L p .683 .395 .478 r
F P
0 g
s
.56228 .65812 m .54476 .65547 L .54543 .65345 L p .683 .395 .478 r
F P
0 g
s
.50353 .60039 m .50848 .61706 L .50691 .6189 L p .982 .722 .46 r
F P
0 g
s
.51661 .63347 m .50691 .6189 L .50848 .61706 L p .927 .619 .439 r
F P
0 g
s
.49466 .74785 m .52912 .75287 L .52571 .79033 L p .725 .658 .783 r
F P
0 g
s
.52571 .79033 m .48234 .78518 L .49466 .74785 L p .725 .658 .783 r
F P
0 g
s
.57182 .78928 m .52571 .79033 L .52912 .75287 L p .693 .629 .78 r
F P
0 g
s
.62447 .41902 m .63032 .4317 L .63359 .42301 L p .983 .817 .6 r
F P
0 g
s
.63359 .42301 m .62721 .40915 L .62447 .41902 L p .983 .817 .6 r
F P
0 g
s
.77672 .55846 m .78127 .54541 L .83546 .54993 L p .666 .726 .894 r
F P
0 g
s
.78127 .54541 m .77672 .55846 L .73624 .55315 L p .671 .71 .877 r
F P
0 g
s
.67304 .56522 m .67487 .56029 L .65541 .55689 L p .751 .686 .788 r
F P
0 g
s
.65541 .55689 m .65395 .56204 L .67304 .56522 L p .751 .686 .788 r
F P
0 g
s
.60969 .62264 m .61725 .6098 L .61289 .61296 L p .841 .952 .602 r
F P
0 g
s
.5293 .64616 m .51578 .63483 L .51616 .63419 L p .846 .544 .478 r
F P
0 g
s
.51578 .63483 m .5293 .64616 L .52839 .64819 L p .844 .554 .498 r
F P
0 g
s
.54476 .65547 m .52839 .64819 L .5293 .64616 L p .768 .474 .489 r
F P
0 g
s
.4536 .4439 m .43949 .44835 L .43692 .43368 L p .483 .388 .672 r
F P
0 g
s
.43692 .43368 m .45119 .42704 L .4536 .4439 L p .483 .388 .672 r
F P
0 g
s
.60465 .62982 m .59439 .64035 L .59583 .63655 L p 0 0 .021 r
F P
0 g
s
.50691 .6189 m .51661 .63347 L .51616 .63419 L p .92 .629 .476 r
F P
0 g
s
.56296 .65464 m .57946 .65246 L .57935 .65321 L p .575 .291 .448 r
F P
0 g
s
.57935 .65321 m .56279 .65541 L .56296 .65464 L p .575 .291 .448 r
F P
0 g
s
.63046 .4622 m .62543 .47657 L .62511 .47599 L p .14 .082 .524 r
F P
0 g
s
.62511 .47599 m .63024 .46161 L .63046 .4622 L p .14 .082 .524 r
F P
0 g
s
.61351 .51105 m .60449 .52394 L .59651 .52014 L p .587 .364 .545 r
F P
0 g
s
.58608 .53119 m .59651 .52014 L .60449 .52394 L p .637 .366 .491 r
F P
0 g
s
.59651 .52014 m .58608 .53119 L .57818 .52822 L p .605 .317 .453 r
F P
0 g
s
.56279 .65541 m .57935 .65321 L .57928 .65385 L p .582 .313 .474 r
F P
0 g
s
.57928 .65385 m .56267 .65608 L .56279 .65541 L p .582 .313 .474 r
F P
0 g
s
.55909 .53512 m .57582 .52709 L .57818 .52822 L p .589 .211 .293 r
F P
0 g
s
.57582 .52709 m .55909 .53512 L .55567 .534 L p .567 .202 .308 r
F P
0 g
s
.63076 .4629 m .62582 .47727 L .62543 .47657 L p .167 .111 .545 r
F P
0 g
s
.62543 .47657 m .63046 .4622 L .63076 .4629 L p .167 .111 .545 r
F P
0 g
s
.64112 .33889 m .66226 .35792 L .69176 .33046 L p .803 .756 .809 r
F P
0 g
s
.69176 .33046 m .66533 .30533 L .64112 .33889 L p .803 .756 .809 r
F P
0 g
s
.66533 .30533 m .69176 .33046 L .73847 .29481 L p .776 .756 .834 r
F P
0 g
s
.52839 .64819 m .54476 .65547 L .54369 .65917 L p .768 .494 .52 r
F P
0 g
s
.54476 .65547 m .56228 .65812 L .56168 .66177 L p .688 .421 .513 r
F P
0 g
s
.56168 .66177 m .54369 .65917 L .54476 .65547 L p .688 .421 .513 r
F P
0 g
s
.51616 .63419 m .50633 .61961 L .50691 .6189 L p .92 .629 .476 r
F P
0 g
s
.50633 .61961 m .51616 .63419 L .51578 .63483 L p .916 .633 .493 r
F P
0 g
s
.5037 .58294 m .50353 .60039 L .50147 .60188 L p 1 .828 .51 r
F P
0 g
s
.50691 .6189 m .50147 .60188 L .50353 .60039 L p .982 .722 .46 r
F P
0 g
s
.62651 .36438 m .64394 .37944 L .66226 .35792 L p .831 .753 .777 r
F P
0 g
s
.66226 .35792 m .64112 .33889 L .62651 .36438 L p .831 .753 .777 r
F P
0 g
s
.4141 .50269 m .41085 .50408 L .41797 .4967 L p 0 0 0 r
F P
0 g
s
.41797 .4967 m .42293 .49575 L .4141 .50269 L p 0 0 0 r
F P
0 g
s
.56267 .65608 m .57928 .65385 L .57911 .65587 L p .584 .315 .475 r
F P
0 g
s
.57911 .65587 m .56228 .65812 L .56267 .65608 L p .584 .315 .475 r
F P
0 g
s
.52912 .75287 m .56563 .75269 L .57182 .78928 L p .693 .629 .78 r
F P
0 g
s
.61663 .78128 m .57182 .78928 L .56563 .75269 L p .656 .603 .784 r
F P
0 g
s
.50147 .60188 m .50095 .5831 L .5037 .58294 L p 1 .828 .51 r
F P
0 g
s
.52839 .64819 m .51459 .63686 L .51578 .63483 L p .844 .554 .498 r
F P
0 g
s
.51459 .63686 m .52839 .64819 L .5268 .65192 L p .838 .569 .532 r
F P
0 g
s
.54369 .65917 m .5268 .65192 L .52839 .64819 L p .768 .494 .52 r
F P
0 g
s
.63175 .46495 m .6272 .47931 L .62582 .47727 L p .195 .142 .566 r
F P
0 g
s
.62582 .47727 m .63076 .4629 L .63175 .46495 L p .195 .142 .566 r
F P
0 g
s
.70188 .55676 m .70475 .54855 L .73624 .55315 L p .689 .697 .853 r
F P
0 g
s
.70475 .54855 m .70188 .55676 L .67745 .55253 L p .697 .671 .821 r
F P
0 g
s
.67573 .5575 m .67745 .55253 L .70188 .55676 L p .711 .683 .822 r
F P
0 g
s
.51578 .63483 m .50584 .62024 L .50633 .61961 L p .916 .633 .493 r
F P
0 g
s
.50584 .62024 m .51578 .63483 L .51459 .63686 L p .91 .64 .517 r
F P
0 g
s
.67487 .56029 m .67554 .55893 L .65603 .55551 L p .752 .647 .745 r
F P
0 g
s
.65603 .55551 m .65541 .55689 L .67487 .56029 L p .752 .647 .745 r
F P
0 g
s
.65133 .57034 m .65395 .56204 L .6379 .55971 L p .792 .687 .749 r
F P
0 g
s
.6379 .55971 m .6362 .56872 L .65133 .57034 L p .792 .687 .749 r
F P
0 g
s
.62879 .50138 m .62168 .51545 L .61351 .51105 L p .554 .393 .617 r
F P
0 g
s
.61351 .51105 m .62268 .49707 L .62879 .50138 L p .554 .393 .617 r
F P
0 g
s
.60449 .52394 m .61351 .51105 L .62168 .51545 L p .617 .417 .588 r
F P
0 g
s
.32044 .29919 m .3453 .27395 L .38831 .31918 L p .593 .609 .837 r
F P
0 g
s
.3453 .27395 m .32044 .29919 L .24622 .24912 L p .613 .641 .855 r
F P
0 g
s
.63008 .59388 m .6338 .5805 L .62295 .58098 L p .899 .793 .734 r
F P
0 g
s
.62295 .58098 m .62138 .59545 L .63008 .59388 L p .899 .793 .734 r
F P
0 g
s
.67573 .5575 m .67554 .55893 L .65603 .55551 L p .744 .639 .744 r
F P
0 g
s
.57978 .65026 m .59373 .64354 L .59348 .64563 L p .416 .15 .4 r
F P
0 g
s
.59348 .64563 m .57946 .65246 L .57978 .65026 L p .416 .15 .4 r
F P
0 g
s
.45331 .45759 m .43955 .4599 L .43949 .44835 L p .471 .348 .631 r
F P
0 g
s
.43949 .44835 m .4536 .4439 L .45331 .45759 L p .471 .348 .631 r
F P
0 g
s
.56228 .65812 m .57911 .65587 L .57893 .65943 L p .593 .34 .503 r
F P
0 g
s
.57893 .65943 m .56168 .66177 L .56228 .65812 L p .593 .34 .503 r
F P
0 g
s
.56549 .53636 m .57818 .52822 L .58608 .53119 L p .623 .247 .309 r
F P
0 g
s
.57818 .52822 m .56549 .53636 L .55909 .53512 L p .589 .211 .293 r
F P
0 g
s
.67745 .55253 m .67573 .5575 L .65604 .55401 L p .721 .654 .782 r
F P
0 g
s
.65603 .55551 m .65604 .55401 L .67573 .5575 L p .744 .639 .744 r
F P
0 g
s
.50147 .60188 m .50691 .6189 L .50633 .61961 L p .969 .728 .516 r
F P
0 g
s
.6347 .48676 m .62879 .50138 L .62268 .49707 L p .468 .357 .645 r
F P
0 g
s
.62268 .49707 m .62996 .48256 L .6347 .48676 L p .468 .357 .645 r
F P
0 g
s
.4022 .50904 m .40058 .5116 L .4052 .50822 L p 0 0 0 r
F P
0 g
s
.40058 .5116 m .4022 .50904 L .38672 .51444 L p .489 .902 .874 r
F P
0 g
s
.38817 .51192 m .38672 .51444 L .4022 .50904 L p 0 0 0 r
F P
0 g
s
.4022 .50904 m .4048 .50878 L .39948 .50979 L p 0 0 0 r
F P
0 g
s
.39948 .50979 m .38817 .51192 L p .4022 .50904 L 0 0 0 r
F P
0 g
s
.4052 .50822 m .41085 .50408 L p .4022 .50904 L 0 0 0 r
F P
0 g
s
.41085 .50408 m .4141 .50269 L .4022 .50904 L p 0 0 0 r
F P
0 g
s
.5268 .65192 m .54369 .65917 L .54219 .66498 L p .766 .518 .559 r
F P
0 g
s
.54369 .65917 m .56168 .66177 L .56098 .6674 L p .692 .449 .551 r
F P
0 g
s
.56098 .6674 m .54219 .66498 L .54369 .65917 L p .692 .449 .551 r
F P
0 g
s
.63394 .46817 m .62996 .48256 L .6272 .47931 L p .269 .224 .622 r
F P
0 g
s
.6272 .47931 m .63175 .46495 L .63394 .46817 L p .269 .224 .622 r
F P
0 g
s
.73624 .55315 m .73989 .54132 L .78127 .54541 L p .671 .71 .877 r
F P
0 g
s
.73989 .54132 m .73624 .55315 L .70475 .54855 L p .675 .687 .853 r
F P
0 g
s
.61824 .38383 m .63313 .39624 L .64394 .37944 L p .859 .745 .736 r
F P
0 g
s
.64394 .37944 m .62651 .36438 L .61824 .38383 L p .859 .745 .736 r
F P
0 g
s
.51459 .63686 m .50426 .62236 L .50584 .62024 L p .91 .64 .517 r
F P
0 g
s
.50426 .62236 m .51459 .63686 L .51245 .6407 L p .896 .649 .556 r
F P
0 g
s
.5268 .65192 m .51245 .6407 L .51459 .63686 L p .838 .569 .532 r
F P
0 g
s
.50633 .61961 m .50066 .60259 L .50147 .60188 L p .969 .728 .516 r
F P
0 g
s
.50066 .60259 m .50633 .61961 L .50584 .62024 L p .964 .728 .534 r
F P
0 g
s
.57946 .65246 m .59348 .64563 L .59343 .64637 L p .418 .154 .404 r
F P
0 g
s
.59343 .64637 m .57935 .65321 L .57946 .65246 L p .418 .154 .404 r
F P
0 g
s
.65395 .56204 m .65541 .55689 L .63901 .55413 L p .768 .66 .742 r
F P
0 g
s
.63901 .55413 m .6379 .55971 L .65395 .56204 L p .768 .66 .742 r
F P
0 g
s
.51245 .6407 m .5268 .65192 L .52442 .65786 L p .829 .587 .573 r
F P
0 g
s
.54219 .66498 m .52442 .65786 L .5268 .65192 L p .766 .518 .559 r
F P
0 g
s
.62168 .51545 m .61545 .52821 L .60449 .52394 L p .617 .417 .588 r
F P
0 g
s
.5983 .53494 m .60449 .52394 L .61545 .52821 L p .669 .432 .553 r
F P
0 g
s
.60449 .52394 m .5983 .53494 L .58608 .53119 L p .637 .366 .491 r
F P
0 g
s
.45137 .46794 m .43828 .46841 L .43955 .4599 L p .464 .312 .589 r
F P
0 g
s
.43955 .4599 m .45331 .45759 L .45137 .46794 L p .464 .312 .589 r
F P
0 g
s
.46486 .73913 m .49466 .74785 L .48234 .78518 L p .753 .688 .789 r
F P
0 g
s
.48234 .78518 m .44488 .77584 L .46486 .73913 L p .753 .688 .789 r
F P
0 g
s
.62373 .42628 m .62922 .43837 L .63032 .4317 L p .997 .773 .459 r
F P
0 g
s
.63032 .4317 m .62447 .41902 L .62373 .42628 L p .997 .773 .459 r
F P
0 g
s
.57935 .65321 m .59343 .64637 L .59342 .64701 L p .437 .186 .434 r
F P
0 g
s
.59342 .64701 m .57928 .65385 L .57935 .65321 L p .437 .186 .434 r
F P
0 g
s
.59439 .64035 m .60465 .62982 L .60387 .63285 L p .061 0 .203 r
F P
0 g
s
.60387 .63285 m .59373 .64354 L .59439 .64035 L p .061 0 .203 r
F P
0 g
s
.56168 .66177 m .57893 .65943 L .57902 .66498 L p .606 .375 .541 r
F P
0 g
s
.57902 .66498 m .56098 .6674 L .56168 .66177 L p .606 .375 .541 r
F P
0 g
s
.50584 .62024 m .49995 .60325 L .50066 .60259 L p .964 .728 .534 r
F P
0 g
s
.49995 .60325 m .50584 .62024 L .50426 .62236 L p .951 .727 .563 r
F P
0 g
s
.73847 .29481 m .70423 .26048 L .66533 .30533 L p .776 .756 .834 r
F P
0 g
s
.70423 .26048 m .73847 .29481 L .81201 .24746 L p .752 .753 .853 r
F P
0 g
s
.67745 .55253 m .67983 .54437 L .70475 .54855 L p .697 .671 .821 r
F P
0 g
s
.67983 .54437 m .67745 .55253 L .65751 .54886 L p .703 .638 .782 r
F P
0 g
s
.65604 .55401 m .65751 .54886 L .67745 .55253 L p .721 .654 .782 r
F P
0 g
s
.57928 .65385 m .59342 .64701 L .59339 .64895 L p .448 .207 .455 r
F P
0 g
s
.59339 .64895 m .57911 .65587 L .57928 .65385 L p .448 .207 .455 r
F P
0 g
s
.61725 .6098 m .62138 .59545 L .61543 .59798 L p .974 .908 .682 r
F P
0 g
s
.61543 .59798 m .61289 .61296 L .61725 .6098 L p .974 .908 .682 r
F P
0 g
s
.6338 .5805 m .6362 .56872 L .62341 .56801 L p .856 .716 .707 r
F P
0 g
s
.62341 .56801 m .62295 .58098 L .6338 .5805 L p .856 .716 .707 r
F P
0 g
s
.38672 .51444 m .38646 .51877 L .40058 .5116 L p .489 .902 .874 r
F P
0 g
s
.65541 .55689 m .65603 .55551 L .63945 .55259 L p .763 .609 .687 r
F P
0 g
s
.63945 .55259 m .63901 .55413 L .65541 .55689 L p .763 .609 .687 r
F P
0 g
s
.65604 .55401 m .65603 .55551 L .63945 .55259 L p .753 .6 .686 r
F P
0 g
s
.50095 .5831 m .50147 .60188 L .50066 .60259 L p .985 .821 .598 r
F P
0 g
s
.65751 .54886 m .65604 .55401 L .63945 .55097 L p .729 .62 .737 r
F P
0 g
s
.63945 .55259 m .63945 .55097 L .65604 .55401 L p .753 .6 .686 r
F P
0 g
s
.63773 .50621 m .63259 .52015 L .62168 .51545 L p .586 .449 .661 r
F P
0 g
s
.62168 .51545 m .62879 .50138 L .63773 .50621 L p .586 .449 .661 r
F P
0 g
s
.61545 .52821 m .62168 .51545 L .63259 .52015 L p .643 .473 .638 r
F P
0 g
s
.44898 .47493 m .43669 .47416 L .43828 .46841 L p .46 .28 .55 r
F P
0 g
s
.43828 .46841 m .45137 .46794 L .44898 .47493 L p .46 .28 .55 r
F P
0 g
s
.52442 .65786 m .54219 .66498 L .54025 .67351 L p .761 .542 .6 r
F P
0 g
s
.54219 .66498 m .56098 .6674 L .56039 .67576 L p .695 .479 .591 r
F P
0 g
s
.56039 .67576 m .54025 .67351 L .54219 .66498 L p .695 .479 .591 r
F P
0 g
s
.70475 .54855 m .70784 .53731 L .73989 .54132 L p .675 .687 .853 r
F P
0 g
s
.70784 .53731 m .70475 .54855 L .67983 .54437 L p .678 .656 .821 r
F P
0 g
s
.57911 .65587 m .59339 .64895 L .59354 .6524 L p .463 .235 .482 r
F P
0 g
s
.59354 .6524 m .57893 .65943 L .57911 .65587 L p .463 .235 .482 r
F P
0 g
s
.58116 .53947 m .58608 .53119 L .5983 .53494 L p .676 .345 .406 r
F P
0 g
s
.58608 .53119 m .58116 .53947 L .56549 .53636 L p .623 .247 .309 r
F P
0 g
s
.21114 .52808 m .21666 .54761 L .2707 .54221 L p .654 .776 .938 r
F P
0 g
s
.51576 .55445 m .50719 .56362 L .50391 .56311 L p .842 .998 .819 r
F P
0 g
s
.63777 .47235 m .6347 .48676 L .62996 .48256 L p .336 .301 .671 r
F P
0 g
s
.62996 .48256 m .63394 .46817 L .63777 .47235 L p .336 .301 .671 r
F P
0 g
s
.64204 .49157 m .63773 .50621 L .62879 .50138 L p .512 .42 .688 r
F P
0 g
s
.62879 .50138 m .6347 .48676 L .64204 .49157 L p .512 .42 .688 r
F P
0 g
s
.51245 .6407 m .50138 .62654 L .50426 .62236 L p .896 .649 .556 r
F P
0 g
s
.50138 .62654 m .51245 .6407 L .50915 .64695 L p .878 .656 .598 r
F P
0 g
s
.52442 .65786 m .50915 .64695 L .51245 .6407 L p .829 .587 .573 r
F P
0 g
s
.6362 .56872 m .6379 .55971 L .62385 .55797 L p .816 .662 .691 r
F P
0 g
s
.62385 .55797 m .62341 .56801 L .6362 .56872 L p .816 .662 .691 r
F P
0 g
s
.65751 .54886 m .65972 .54043 L .67983 .54437 L p .703 .638 .782 r
F P
0 g
s
.65972 .54043 m .65751 .54886 L .64069 .54542 L p .705 .6 .736 r
F P
0 g
s
.63945 .55097 m .64069 .54542 L .65751 .54886 L p .729 .62 .737 r
F P
0 g
s
.3669 .51883 m .36777 .52537 L .38646 .51877 L p .594 .911 .979 r
F P
0 g
s
.38646 .51877 m .38672 .51444 L .3669 .51883 L p .594 .911 .979 r
F P
0 g
s
.50066 .60259 m .49954 .58375 L .50095 .5831 L p .985 .821 .598 r
F P
0 g
s
.49954 .58375 m .50066 .60259 L .49995 .60325 L p .972 .811 .623 r
F P
0 g
s
.44715 .47887 m .43547 .47744 L .43669 .47416 L p .456 .255 .517 r
F P
0 g
s
.43669 .47416 m .44898 .47493 L .44715 .47887 L p .456 .255 .517 r
F P
0 g
s
.61404 .39862 m .62721 .40915 L .63313 .39624 L p .885 .731 .685 r
F P
0 g
s
.63313 .39624 m .61824 .38383 L .61404 .39862 L p .885 .731 .685 r
F P
0 g
s
.45978 .40015 m .44509 .40698 L .43405 .38313 L p .567 .504 .744 r
F P
0 g
s
.43405 .38313 m .44956 .37473 L .45978 .40015 L p .567 .504 .744 r
F P
0 g
s
.44956 .37473 m .43405 .38313 L .41619 .3545 L p .582 .543 .776 r
F P
0 g
s
.50426 .62236 m .49763 .60569 L .49995 .60325 L p .951 .727 .563 r
F P
0 g
s
.49763 .60569 m .50426 .62236 L .50138 .62654 L p .93 .722 .6 r
F P
0 g
s
.63259 .52015 m .62834 .53244 L .61545 .52821 L p .643 .473 .638 r
F P
0 g
s
.61182 .53863 m .61545 .52821 L .62834 .53244 L p .69 .498 .621 r
F P
0 g
s
.61545 .52821 m .61182 .53863 L .5983 .53494 L p .669 .432 .553 r
F P
0 g
s
.56098 .6674 m .57902 .66498 L .57963 .67298 L p .618 .416 .586 r
F P
0 g
s
.57963 .67298 m .56039 .67576 L .56098 .6674 L p .618 .416 .586 r
F P
0 g
s
.50915 .64695 m .52442 .65786 L .52112 .6667 L p .816 .604 .614 r
F P
0 g
s
.54025 .67351 m .52112 .6667 L .52442 .65786 L p .761 .542 .6 r
F P
0 g
s
.84038 .53102 m .83546 .54993 L .78127 .54541 L p .659 .723 .896 r
F P
0 g
s
.59373 .64354 m .60387 .63285 L .60366 .6349 L p .137 0 .292 r
F P
0 g
s
.60366 .6349 m .59348 .64563 L .59373 .64354 L p .137 0 .292 r
F P
0 g
s
.44648 .48013 m .43503 .47851 L .43547 .47744 L p .452 .24 .499 r
F P
0 g
s
.43547 .47744 m .44715 .47887 L .44648 .48013 L p .452 .24 .499 r
F P
0 g
s
.44563 .48162 m .43445 .47977 L .43503 .47851 L p .451 .23 .487 r
F P
0 g
s
.43503 .47851 m .44648 .48013 L .44563 .48162 L p .451 .23 .487 r
F P
0 g
s
.6379 .55971 m .63901 .55413 L .62441 .55176 L p .785 .627 .685 r
F P
0 g
s
.62441 .55176 m .62385 .55797 L .6379 .55971 L p .785 .627 .685 r
F P
0 g
s
.46585 .42175 m .45119 .42704 L .44509 .40698 L p .553 .467 .712 r
F P
0 g
s
.44509 .40698 m .45978 .40015 L .46585 .42175 L p .553 .467 .712 r
F P
0 g
s
.63158 .4516 m .63175 .46495 L .63076 .4629 L p 0 0 .517 r
F P
0 g
s
.50719 .56362 m .50095 .5831 L .49954 .58375 L p .959 .887 .717 r
F P
0 g
s
.64069 .54542 m .63945 .55097 L .62463 .54818 L p .732 .578 .682 r
F P
0 g
s
.63945 .55097 m .63945 .55259 L .62474 .55001 L p .757 .554 .622 r
F P
0 g
s
.62474 .55001 m .62463 .54818 L .63945 .55097 L p .757 .554 .622 r
F P
0 g
s
.67983 .54437 m .68267 .53334 L .70784 .53731 L p .678 .656 .821 r
F P
0 g
s
.68267 .53334 m .67983 .54437 L .65972 .54043 L p .677 .619 .783 r
F P
0 g
s
.44284 .48582 m .43257 .48343 L .43445 .47977 L p .449 .213 .463 r
F P
0 g
s
.43445 .47977 m .44563 .48162 L .44284 .48582 L p .449 .213 .463 r
F P
0 g
s
.49995 .60325 m .49823 .58455 L .49954 .58375 L p .972 .811 .623 r
F P
0 g
s
.49823 .58455 m .49995 .60325 L .49763 .60569 L p .952 .792 .646 r
F P
0 g
s
.63901 .55413 m .63945 .55259 L .62474 .55001 L p .769 .565 .622 r
F P
0 g
s
.41619 .3545 m .43352 .34404 L .44956 .37473 L p .582 .543 .776 r
F P
0 g
s
.43352 .34404 m .41619 .3545 L .38831 .31918 L p .6 .58 .802 r
F P
0 g
s
.2707 .54221 m .26677 .5268 L .21114 .52808 L p .654 .776 .938 r
F P
0 g
s
.26677 .5268 m .2707 .54221 L .31192 .53689 L p .653 .795 .951 r
F P
0 g
s
.34168 .52225 m .34351 .53135 L .36777 .52537 L p .634 .866 .986 r
F P
0 g
s
.36777 .52537 m .3669 .51883 L .34168 .52225 L p .634 .866 .986 r
F P
0 g
s
.57893 .65943 m .59354 .6524 L .59418 .65767 L p .491 .29 .535 r
F P
0 g
s
.59418 .65767 m .57902 .66498 L .57893 .65943 L p .491 .29 .535 r
F P
0 g
s
.62474 .55001 m .62441 .55176 L .63901 .55413 L p .769 .565 .622 r
F P
0 g
s
.6239 .43148 m .62932 .4431 L .62922 .43837 L p .978 .707 .309 r
F P
0 g
s
.62922 .43837 m .62373 .42628 L .6239 .43148 L p .978 .707 .309 r
F P
0 g
s
.64069 .54542 m .64294 .53648 L .65972 .54043 L p .705 .6 .736 r
F P
0 g
s
.64294 .53648 m .64069 .54542 L .62578 .54208 L p .701 .553 .683 r
F P
0 g
s
.62463 .54818 m .62578 .54208 L .64069 .54542 L p .732 .578 .682 r
F P
0 g
s
.64613 .52476 m .64294 .53648 L .62834 .53244 L p .661 .527 .69 r
F P
0 g
s
.62834 .53244 m .63259 .52015 L .64613 .52476 L p .661 .527 .69 r
F P
0 g
s
.62578 .54208 m .62834 .53244 L .64294 .53648 L p .701 .553 .683 r
F P
0 g
s
.62834 .53244 m .62578 .54208 L .61182 .53863 L p .69 .498 .621 r
F P
0 g
s
.6497 .51114 m .64613 .52476 L .63259 .52015 L p .612 .503 .706 r
F P
0 g
s
.63259 .52015 m .63773 .50621 L .6497 .51114 L p .612 .503 .706 r
F P
0 g
s
.43757 .49189 m .42893 .48902 L .43257 .48343 L p .443 .174 .409 r
F P
0 g
s
.43257 .48343 m .44284 .48582 L .43757 .49189 L p .443 .174 .409 r
F P
0 g
s
.5964 .54261 m .5983 .53494 L .61182 .53863 L p .713 .45 .525 r
F P
0 g
s
.5983 .53494 m .5964 .54261 L .58116 .53947 L p .676 .345 .406 r
F P
0 g
s
.62138 .59545 m .62295 .58098 L .61481 .58253 L p .943 .792 .665 r
F P
0 g
s
.61481 .58253 m .61543 .59798 L .62138 .59545 L p .943 .792 .665 r
F P
0 g
s
.52112 .6667 m .54025 .67351 L .5379 .68559 L p .755 .566 .64 r
F P
0 g
s
.54025 .67351 m .56039 .67576 L .56013 .6874 L p .698 .511 .631 r
F P
0 g
s
.56013 .6874 m .5379 .68559 L .54025 .67351 L p .698 .511 .631 r
F P
0 g
s
.65972 .54043 m .6625 .52919 L .68267 .53334 L p .677 .619 .783 r
F P
0 g
s
.6625 .52919 m .65972 .54043 L .64294 .53648 L p .672 .577 .739 r
F P
0 g
s
.30911 .52487 m .31192 .53689 L .34351 .53135 L p .648 .825 .968 r
F P
0 g
s
.34351 .53135 m .34168 .52225 L .30911 .52487 L p .648 .825 .968 r
F P
0 g
s
.31192 .53689 m .30911 .52487 L .26677 .5268 L p .653 .795 .951 r
F P
0 g
s
.49954 .58375 m .50391 .56311 L .50719 .56362 L p .959 .887 .717 r
F P
0 g
s
.59348 .64563 m .60366 .6349 L .60361 .63561 L p .188 0 .351 r
F P
0 g
s
.60361 .63561 m .59343 .64637 L .59348 .64563 L p .188 0 .351 r
F P
0 g
s
.64294 .53648 m .64613 .52476 L .6625 .52919 L p .672 .577 .739 r
F P
0 g
s
.50397 .71874 m .53227 .724 L .52912 .75287 L p .733 .635 .75 r
F P
0 g
s
.52912 .75287 m .49466 .74785 L .50397 .71874 L p .733 .635 .75 r
F P
0 g
s
.56563 .75269 m .52912 .75287 L .53227 .724 L p .696 .601 .746 r
F P
0 g
s
.62578 .54208 m .62463 .54818 L .6106 .54546 L p .729 .524 .614 r
F P
0 g
s
.6106 .54546 m .61182 .53863 L .62578 .54208 L p .729 .524 .614 r
F P
0 g
s
.33169 .78332 m .35023 .79485 L .28729 .84723 L p .753 .775 .871 r
F P
0 g
s
.28729 .84723 m .26204 .83262 L .33169 .78332 L p .753 .775 .871 r
F P
0 g
s
.46876 .44039 m .4536 .4439 L .45119 .42704 L p .543 .435 .681 r
F P
0 g
s
.45119 .42704 m .46585 .42175 L .46876 .44039 L p .543 .435 .681 r
F P
0 g
s
.63341 .45491 m .63394 .46817 L .63175 .46495 L p 0 .062 .592 r
F P
0 g
s
.63175 .46495 m .63158 .4516 L .63341 .45491 L p 0 .062 .592 r
F P
0 g
s
.61182 .53863 m .6106 .54546 L .5964 .54261 L p .713 .45 .525 r
F P
0 g
s
.59343 .64637 m .60361 .63561 L .6036 .63621 L p .227 .034 .397 r
F P
0 g
s
.6036 .63621 m .59342 .64701 L .59343 .64637 L p .227 .034 .397 r
F P
0 g
s
.78127 .54541 m .78495 .52904 L .84038 .53102 L p .659 .723 .896 r
F P
0 g
s
.78495 .52904 m .78127 .54541 L .73989 .54132 L p .66 .704 .88 r
F P
0 g
s
.42943 .49845 m .42293 .49575 L .42893 .48902 L p .426 .101 .31 r
F P
0 g
s
.42893 .48902 m .43757 .49189 L .42943 .49845 L p .426 .101 .31 r
F P
0 g
s
.56039 .67576 m .57963 .67298 L .58134 .68422 L p .629 .457 .63 r
F P
0 g
s
.58134 .68422 m .56013 .6874 L .56039 .67576 L p .629 .457 .63 r
F P
0 g
s
.62463 .54818 m .62474 .55001 L .61082 .54756 L p .755 .499 .546 r
F P
0 g
s
.61082 .54756 m .6106 .54546 L .62463 .54818 L p .755 .499 .546 r
F P
0 g
s
.50391 .56311 m .49954 .58375 L .49823 .58455 L p .921 .835 .744 r
F P
0 g
s
.64394 .47711 m .64204 .49157 L .6347 .48676 L p .406 .383 .721 r
F P
0 g
s
.6347 .48676 m .63777 .47235 L .64394 .47711 L p .406 .383 .721 r
F P
0 g
s
.59342 .64701 m .6036 .63621 L .6036 .63805 L p .221 .03 .397 r
F P
0 g
s
.6036 .63805 m .59339 .64895 L .59342 .64701 L p .221 .03 .397 r
F P
0 g
s
.56563 .75269 m .60089 .74656 L .61663 .78128 L p .656 .603 .784 r
F P
0 g
s
.65584 .76662 m .61663 .78128 L .60089 .74656 L p .613 .582 .795 r
F P
0 g
s
.61663 .78128 m .65584 .76662 L .69273 .80787 L p .622 .62 .827 r
F P
0 g
s
.65257 .49653 m .6497 .51114 L .63773 .50621 L p .55 .481 .731 r
F P
0 g
s
.63773 .50621 m .64204 .49157 L .65257 .49653 L p .55 .481 .731 r
F P
0 g
s
.62441 .55176 m .62474 .55001 L .61082 .54756 L p .77 .512 .544 r
F P
0 g
s
.53227 .724 m .56218 .72465 L .56563 .75269 L p .696 .601 .746 r
F P
0 g
s
.60089 .74656 m .56563 .75269 L .56218 .72465 L p .652 .569 .749 r
F P
0 g
s
.50915 .64695 m .49699 .63361 L .50138 .62654 L p .878 .656 .598 r
F P
0 g
s
.49699 .63361 m .50915 .64695 L .5045 .65637 L p .859 .662 .636 r
F P
0 g
s
.52112 .6667 m .5045 .65637 L .50915 .64695 L p .816 .604 .614 r
F P
0 g
s
.61249 .40961 m .62447 .41902 L .62721 .40915 L p .909 .709 .621 r
F P
0 g
s
.62721 .40915 m .61404 .39862 L .61249 .40961 L p .909 .709 .621 r
F P
0 g
s
.5045 .65637 m .52112 .6667 L .51675 .67918 L p .804 .62 .653 r
F P
0 g
s
.5379 .68559 m .51675 .67918 L .52112 .6667 L p .755 .566 .64 r
F P
0 g
s
.57902 .66498 m .59418 .65767 L .59584 .66543 L p .516 .34 .581 r
F P
0 g
s
.59584 .66543 m .57963 .67298 L .57902 .66498 L p .516 .34 .581 r
F P
0 g
s
.66522 .51581 m .6625 .52919 L .64613 .52476 L p .632 .555 .75 r
F P
0 g
s
.64613 .52476 m .6497 .51114 L .66522 .51581 L p .632 .555 .75 r
F P
0 g
s
.50138 .62654 m .49347 .61094 L .49763 .60569 L p .93 .722 .6 r
F P
0 g
s
.49347 .61094 m .50138 .62654 L .49699 .63361 L p .906 .715 .633 r
F P
0 g
s
.62385 .55797 m .62441 .55176 L .61068 .54961 L p .799 .585 .613 r
F P
0 g
s
.61082 .54756 m .61068 .54961 L .62441 .55176 L p .77 .512 .544 r
F P
0 g
s
.61289 .61296 m .61543 .59798 L .61188 .60092 L p .983 .89 .547 r
F P
0 g
s
.61188 .60092 m .61049 .61629 L .61289 .61296 L p .983 .89 .547 r
F P
0 g
s
.62295 .58098 m .62341 .56801 L .61267 .56818 L p .889 .698 .638 r
F P
0 g
s
.61267 .56818 m .61481 .58253 L .62295 .58098 L p .889 .698 .638 r
F P
0 g
s
.49763 .60569 m .49394 .5882 L .49823 .58455 L p .952 .792 .646 r
F P
0 g
s
.49394 .5882 m .49763 .60569 L .49347 .61094 L p .929 .767 .661 r
F P
0 g
s
.62932 .4431 m .6239 .43148 L .62449 .43491 L p .916 .599 .122 r
F P
0 g
s
.62341 .56801 m .62385 .55797 L .61104 .55674 L p .839 .63 .619 r
F P
0 g
s
.61068 .54961 m .61104 .55674 L .62385 .55797 L p .799 .585 .613 r
F P
0 g
s
.469 .45646 m .45331 .45759 L .4536 .4439 L p .54 .411 .653 r
F P
0 g
s
.4536 .4439 m .46876 .44039 L .469 .45646 L p .54 .411 .653 r
F P
0 g
s
.73989 .54132 m .74272 .5266 L .78495 .52904 L p .66 .704 .88 r
F P
0 g
s
.74272 .5266 m .73989 .54132 L .70784 .53731 L p .659 .677 .857 r
F P
0 g
s
.59339 .64895 m .6036 .63805 L .60391 .64138 L p .262 .088 .447 r
F P
0 g
s
.60391 .64138 m .59354 .6524 L .59339 .64895 L p .262 .088 .447 r
F P
0 g
s
.41848 .50427 m .4141 .50269 L .42293 .49575 L p .375 0 .135 r
F P
0 g
s
.42293 .49575 m .42943 .49845 L .41848 .50427 L p .375 0 .135 r
F P
0 g
s
.51675 .67918 m .5379 .68559 L .53523 .70206 L p .749 .589 .678 r
F P
0 g
s
.5379 .68559 m .56013 .6874 L .56058 .70337 L p .698 .542 .672 r
F P
0 g
s
.56058 .70337 m .53523 .70206 L .5379 .68559 L p .698 .542 .672 r
F P
0 g
s
.6106 .54546 m .61082 .54756 L .59677 .54509 L p .741 .422 .443 r
F P
0 g
s
.59677 .54509 m .5964 .54261 L .6106 .54546 L p .741 .422 .443 r
F P
0 g
s
.61104 .55674 m .61267 .56818 L .62341 .56801 L p .839 .63 .619 r
F P
0 g
s
.49823 .58455 m .49971 .56476 L .50391 .56311 L p .921 .835 .744 r
F P
0 g
s
.49971 .56476 m .49823 .58455 L .49394 .5882 L p .906 .799 .73 r
F P
0 g
s
.68504 .51999 m .68267 .53334 L .6625 .52919 L p .646 .602 .791 r
F P
0 g
s
.6625 .52919 m .66522 .51581 L .68504 .51999 L p .646 .602 .791 r
F P
0 g
s
.63672 .45912 m .63777 .47235 L .63394 .46817 L p .089 .196 .682 r
F P
0 g
s
.63394 .46817 m .63341 .45491 L .63672 .45912 L p .089 .196 .682 r
F P
0 g
s
.70784 .53731 m .71023 .52361 L .74272 .5266 L p .659 .677 .857 r
F P
0 g
s
.71023 .52361 m .70784 .53731 L .68267 .53334 L p .654 .643 .827 r
F P
0 g
s
.56013 .6874 m .58134 .68422 L .58479 .69942 L p .639 .496 .672 r
F P
0 g
s
.58479 .69942 m .56058 .70337 L .56013 .6874 L p .639 .496 .672 r
F P
0 g
s
.38831 .31918 m .40898 .30561 L .43352 .34404 L p .6 .58 .802 r
F P
0 g
s
.40898 .30561 m .38831 .31918 L .3453 .27395 L p .616 .615 .827 r
F P
0 g
s
.68267 .53334 m .68504 .51999 L .71023 .52361 L p .654 .643 .827 r
F P
0 g
s
.61068 .54961 m .61082 .54756 L .59677 .54509 L p .762 .438 .437 r
F P
0 g
s
.39357 .75296 m .41518 .76428 L .37837 .80855 L p .769 .752 .838 r
F P
0 g
s
.37837 .80855 m .35023 .79485 L .39357 .75296 L p .769 .752 .838 r
F P
0 g
s
.5964 .54261 m .59677 .54509 L .58161 .54243 L p .696 .29 .273 r
F P
0 g
s
.58161 .54243 m .58116 .53947 L .5964 .54261 L p .696 .29 .273 r
F P
0 g
s
.47932 .71018 m .50397 .71874 L .49466 .74785 L p .765 .67 .758 r
F P
0 g
s
.49466 .74785 m .46486 .73913 L .47932 .71018 L p .765 .67 .758 r
F P
0 g
s
.51114 .69625 m .53523 .70206 L .53227 .724 L p .741 .612 .715 r
F P
0 g
s
.53227 .724 m .50397 .71874 L .51114 .69625 L p .741 .612 .715 r
F P
0 g
s
.56218 .72465 m .53227 .724 L .53523 .70206 L p .697 .572 .71 r
F P
0 g
s
.46702 .46952 m .45137 .46794 L .45331 .45759 L p .545 .395 .629 r
F P
0 g
s
.45331 .45759 m .469 .45646 L .46702 .46952 L p .545 .395 .629 r
F P
0 g
s
.53523 .70206 m .51114 .69625 L .51675 .67918 L p .749 .589 .678 r
F P
0 g
s
.53523 .70206 m .56058 .70337 L .56218 .72465 L p .697 .572 .71 r
F P
0 g
s
.62982 .44631 m .62449 .43491 L .62496 .43688 L p .871 .537 .028 r
F P
0 g
s
.44107 .72892 m .46486 .73913 L .44488 .77584 L p .773 .716 .799 r
F P
0 g
s
.44488 .77584 m .41518 .76428 L .44107 .72892 L p .773 .716 .799 r
F P
0 g
s
.4048 .50878 m .4022 .50904 L .4141 .50269 L p .226 0 0 r
F P
0 g
s
.4141 .50269 m .41848 .50427 L .4048 .50878 L p .226 0 0 r
F P
0 g
s
.61104 .55674 m .61068 .54961 L .59701 .54756 L p .809 .527 .511 r
F P
0 g
s
.59677 .54509 m .59701 .54756 L .61068 .54961 L p .762 .438 .437 r
F P
0 g
s
.59354 .6524 m .60391 .64138 L .60494 .64651 L p .317 .164 .509 r
F P
0 g
s
.60494 .64651 m .59418 .65767 L .59354 .6524 L p .317 .164 .509 r
F P
0 g
s
.24622 .24912 m .27813 .21351 L .3453 .27395 L p .613 .641 .855 r
F P
0 g
s
.66702 .50116 m .66522 .51581 L .6497 .51114 L p .583 .539 .771 r
F P
0 g
s
.6497 .51114 m .65257 .49653 L .66702 .50116 L p .583 .539 .771 r
F P
0 g
s
.57963 .67298 m .59584 .66543 L .59923 .67609 L p .543 .398 .634 r
F P
0 g
s
.59923 .67609 m .58134 .68422 L .57963 .67298 L p .543 .398 .634 r
F P
0 g
s
.51675 .67918 m .49827 .66962 L .5045 .65637 L p .804 .62 .653 r
F P
0 g
s
.49827 .66962 m .51675 .67918 L .51114 .69625 L p .791 .636 .69 r
F P
0 g
s
.59086 .7198 m .56218 .72465 L .56058 .70337 L p .646 .533 .712 r
F P
0 g
s
.56218 .72465 m .59086 .7198 L .60089 .74656 L p .652 .569 .749 r
F P
0 g
s
.56058 .70337 m .58479 .69942 L .59086 .7198 L p .646 .533 .712 r
F P
0 g
s
.65336 .48192 m .65257 .49653 L .64204 .49157 L p .47 .462 .767 r
F P
0 g
s
.64204 .49157 m .64394 .47711 L .65336 .48192 L p .47 .462 .767 r
F P
0 g
s
.61244 .41768 m .62373 .42628 L .62447 .41902 L p .926 .677 .543 r
F P
0 g
s
.62447 .41902 m .61249 .40961 L .61244 .41768 L p .926 .677 .543 r
F P
0 g
s
.81201 .24746 m .7666 .19859 L .70423 .26048 L p .752 .753 .853 r
F P
0 g
s
.63029 .44817 m .62496 .43688 L .62515 .43751 L p .831 .485 0 r
F P
0 g
s
.46387 .47877 m .44898 .47493 L .45137 .46794 L p .554 .383 .605 r
F P
0 g
s
.45137 .46794 m .46702 .46952 L .46387 .47877 L p .554 .383 .605 r
F P
0 g
s
.47197 .39534 m .45978 .40015 L .44956 .37473 L p .594 .519 .739 r
F P
0 g
s
.44956 .37473 m .46241 .36904 L .47197 .39534 L p .594 .519 .739 r
F P
0 g
s
.46241 .36904 m .44956 .37473 L .43352 .34404 L p .608 .554 .769 r
F P
0 g
s
.59701 .54756 m .59677 .54509 L .58161 .54243 L p .729 .311 .255 r
F P
0 g
s
.5045 .65637 m .49097 .64419 L .49699 .63361 L p .859 .662 .636 r
F P
0 g
s
.49097 .64419 m .5045 .65637 L .49827 .66962 L p .84 .67 .671 r
F P
0 g
s
.47815 .41761 m .46585 .42175 L .45978 .40015 L p .584 .486 .71 r
F P
0 g
s
.45978 .40015 m .47197 .39534 L .47815 .41761 L p .584 .486 .71 r
F P
0 g
s
.61543 .59798 m .61481 .58253 L .60938 .5848 L p .978 .785 .577 r
F P
0 g
s
.60938 .5848 m .61188 .60092 L .61543 .59798 L p .978 .785 .577 r
F P
0 g
s
.63044 .44879 m .62515 .43751 L .62541 .43827 L p .765 .41 0 r
F P
0 g
s
.73356 .78301 m .69273 .80787 L .65584 .76662 L p .584 .609 .843 r
F P
0 g
s
.69273 .80787 m .73356 .78301 L .80471 .82886 L p .6 .647 .868 r
F P
0 g
s
.61267 .56818 m .61104 .55674 L .59931 .55603 L p .86 .59 .529 r
F P
0 g
s
.59701 .54756 m .59931 .55603 L .61104 .55674 L p .809 .527 .511 r
F P
0 g
s
.49699 .63361 m .48761 .61985 L .49347 .61094 L p .906 .715 .633 r
F P
0 g
s
.48761 .61985 m .49699 .63361 L .49097 .64419 L p .885 .711 .66 r
F P
0 g
s
.61814 .4362 m .62705 .4431 L p .62622 .44048 L .848 .386 .038 r
F P
0 g
s
.63068 .44951 m .62572 .43893 L p .62622 .44048 L .756 .4 0 r
F P
0 g
s
.63158 .4516 m .62676 .4416 L p .62804 .44386 L 0 0 .374 r
F P
0 g
s
.62676 .4416 m .62622 .44048 L .62804 .44386 L p 0 0 .374 r
F P
0 g
s
.63341 .45491 m .62926 .44639 L p .6312 .44811 L 0 0 .564 r
F P
0 g
s
.62926 .44639 m .62804 .44386 L .6312 .44811 L p 0 0 .564 r
F P
0 g
s
.6312 .44811 m .63672 .45912 L .63341 .45491 L p 0 0 .564 r
F P
0 g
s
.63672 .45912 m .6312 .44811 L .63652 .45264 L p 0 .244 .759 r
F P
0 g
s
.6268 .44472 m .63372 .45036 L p .6312 .44811 L .451 0 0 r
F P
0 g
s
.63372 .45036 m .63652 .45264 L .6312 .44811 L p .451 0 0 r
F P
0 g
s
.62147 .44043 m .62983 .44703 L p .62804 .44386 L .734 .221 0 r
F P
0 g
s
.62983 .44703 m .6312 .44811 L .62804 .44386 L p .734 .221 0 r
F P
0 g
s
.62705 .4431 m .62804 .44386 L .62622 .44048 L p .848 .386 .038 r
F P
0 g
s
.62572 .43893 m .62541 .43827 L .62622 .44048 L p .756 .4 0 r
F P
0 g
s
.61049 .61629 m .61188 .60092 L .61011 .60362 L p .939 .827 .38 r
F P
0 g
s
.46116 .48398 m .44715 .47887 L .44898 .47493 L p .563 .374 .584 r
F P
0 g
s
.44898 .47493 m .46387 .47877 L .46116 .48398 L p .563 .374 .584 r
F P
0 g
s
.64232 .46376 m .64394 .47711 L .63777 .47235 L p .238 .337 .763 r
F P
0 g
s
.63777 .47235 m .63672 .45912 L .64232 .46376 L p .238 .337 .763 r
F P
0 g
s
.49347 .61094 m .48739 .59644 L .49394 .5882 L p .929 .767 .661 r
F P
0 g
s
.48739 .59644 m .49347 .61094 L .48761 .61985 L p .913 .75 .667 r
F P
0 g
s
.51114 .69625 m .49009 .68733 L .49827 .66962 L p .791 .636 .69 r
F P
0 g
s
.49009 .68733 m .51114 .69625 L .50397 .71874 L p .778 .653 .724 r
F P
0 g
s
.48192 .43714 m .46876 .44039 L .46585 .42175 L p .576 .46 .684 r
F P
0 g
s
.46585 .42175 m .47815 .41761 L .48192 .43714 L p .576 .46 .684 r
F P
0 g
s
.50397 .71874 m .47932 .71018 L .49009 .68733 L p .778 .653 .724 r
F P
0 g
s
.60884 .62419 m .6036 .63805 L .6036 .63621 L p 0 0 .235 r
F P
0 g
s
.46013 .4856 m .44648 .48013 L .44715 .47887 L p .568 .368 .57 r
F P
0 g
s
.44715 .47887 m .46116 .48398 L .46013 .4856 L p .568 .368 .57 r
F P
0 g
s
.59747 .37604 m .61824 .38383 L .62651 .36438 L p .81 .682 .723 r
F P
0 g
s
.62651 .36438 m .60233 .35422 L .59747 .37604 L p .81 .682 .723 r
F P
0 g
s
.60233 .35422 m .62651 .36438 L .64112 .33889 L p .794 .7 .761 r
F P
0 g
s
.68616 .50508 m .68504 .51999 L .66522 .51581 L p .607 .59 .808 r
F P
0 g
s
.66522 .51581 m .66702 .50116 L .68616 .50508 L p .607 .59 .808 r
F P
0 g
s
.49394 .5882 m .49014 .5739 L .49971 .56476 L p .906 .799 .73 r
F P
0 g
s
.49014 .5739 m .49394 .5882 L .48739 .59644 L p .913 .778 .699 r
F P
0 g
s
.59418 .65767 m .60494 .64651 L .60733 .65386 L p .376 .25 .579 r
F P
0 g
s
.60733 .65386 m .59584 .66543 L .59418 .65767 L p .376 .25 .579 r
F P
0 g
s
.58134 .68422 m .59923 .67609 L .60531 .69057 L p .565 .449 .68 r
F P
0 g
s
.60531 .69057 m .58479 .69942 L .58134 .68422 L p .565 .449 .68 r
F P
0 g
s
.59931 .55603 m .59701 .54756 L .5829 .54555 L p .808 .44 .359 r
F P
0 g
s
.58161 .54243 m .5829 .54555 L .59701 .54756 L p .729 .311 .255 r
F P
0 g
s
.4588 .4875 m .44563 .48162 L .44648 .48013 L p .57 .364 .562 r
F P
0 g
s
.44648 .48013 m .46013 .4856 L .4588 .4875 L p .57 .364 .562 r
F P
0 g
s
.45441 .49258 m .44284 .48582 L .44563 .48162 L p .576 .354 .542 r
F P
0 g
s
.44563 .48162 m .4588 .4875 L .45441 .49258 L p .576 .354 .542 r
F P
0 g
s
.61481 .58253 m .61267 .56818 L .60434 .56921 L p .919 .679 .559 r
F P
0 g
s
.59931 .55603 m .60434 .56921 L .61267 .56818 L p .86 .59 .529 r
F P
0 g
s
.64112 .33889 m .61199 .32528 L .60233 .35422 L p .794 .7 .761 r
F P
0 g
s
.61199 .32528 m .64112 .33889 L .66533 .30533 L p .776 .713 .793 r
F P
0 g
s
.43352 .34404 m .44805 .33715 L .46241 .36904 L p .608 .554 .769 r
F P
0 g
s
.44805 .33715 m .43352 .34404 L .40898 .30561 L p .619 .588 .796 r
F P
0 g
s
.60434 .56921 m .60938 .5848 L .61481 .58253 L p .919 .679 .559 r
F P
0 g
s
.63134 .73451 m .60089 .74656 L .59086 .7198 L p .6 .541 .76 r
F P
0 g
s
.60089 .74656 m .63134 .73451 L .65584 .76662 L p .613 .582 .795 r
F P
0 g
s
.61316 .42323 m .6239 .43148 L .62373 .42628 L p .932 .633 .452 r
F P
0 g
s
.62373 .42628 m .61244 .41768 L .61316 .42323 L p .932 .633 .452 r
F P
0 g
s
.49724 .55379 m .49971 .56476 L .49014 .5739 L p .882 .788 .751 r
F P
0 g
s
.44642 .4989 m .43757 .49189 L .44284 .48582 L p .588 .333 .498 r
F P
0 g
s
.44284 .48582 m .45441 .49258 L .44642 .4989 L p .588 .333 .498 r
F P
0 g
s
.3676 .51391 m .3669 .51883 L .38672 .51444 L p .409 .84 .951 r
F P
0 g
s
.38672 .51444 m .38817 .51192 L .3676 .51391 L p .409 .84 .951 r
F P
0 g
s
.59566 .39248 m .61404 .39862 L .61824 .38383 L p .824 .659 .679 r
F P
0 g
s
.61824 .38383 m .59747 .37604 L .59566 .39248 L p .824 .659 .679 r
F P
0 g
s
.6036 .63805 m .60884 .62419 L .60911 .62741 L p 0 0 .343 r
F P
0 g
s
.60911 .62741 m .60391 .64138 L .6036 .63805 L p 0 0 .343 r
F P
0 g
s
.48372 .45477 m .469 .45646 L .46876 .44039 L p .575 .444 .665 r
F P
0 g
s
.46876 .44039 m .48192 .43714 L .48372 .45477 L p .575 .444 .665 r
F P
0 g
s
.66672 .48627 m .66702 .50116 L .65257 .49653 L p .522 .529 .804 r
F P
0 g
s
.65257 .49653 m .65336 .48192 L .66672 .48627 L p .522 .529 .804 r
F P
0 g
s
.71103 .50803 m .71023 .52361 L .68504 .51999 L p .626 .635 .84 r
F P
0 g
s
.68504 .51999 m .68616 .50508 L .71103 .50803 L p .626 .635 .84 r
F P
0 g
s
.58479 .69942 m .60531 .69057 L .61538 .70964 L p .584 .496 .721 r
F P
0 g
s
.61538 .70964 m .59086 .7198 L .58479 .69942 L p .584 .496 .721 r
F P
0 g
s
.49827 .66962 m .48314 .65862 L .49097 .64419 L p .84 .67 .671 r
F P
0 g
s
.48314 .65862 m .49827 .66962 L .49009 .68733 L p .824 .679 .704 r
F P
0 g
s
.43536 .50428 m .42943 .49845 L .43757 .49189 L p .598 .295 .426 r
F P
0 g
s
.43757 .49189 m .44642 .4989 L .43536 .50428 L p .598 .295 .426 r
F P
0 g
s
.59086 .7198 m .61538 .70964 L .63134 .73451 L p .6 .541 .76 r
F P
0 g
s
.48613 .41491 m .47815 .41761 L .47197 .39534 L p .602 .498 .708 r
F P
0 g
s
.47197 .39534 m .47987 .39239 L .48613 .41491 L p .602 .498 .708 r
F P
0 g
s
.47987 .39239 m .47197 .39534 L .46241 .36904 L p .612 .529 .737 r
F P
0 g
s
.34181 .51481 m .34168 .52225 L .3669 .51883 L p .553 .848 .998 r
F P
0 g
s
.3669 .51883 m .3676 .51391 L .34181 .51481 L p .553 .848 .998 r
F P
0 g
s
.46241 .36904 m .47079 .3658 L .47987 .39239 L p .612 .529 .737 r
F P
0 g
s
.47079 .3658 m .46241 .36904 L .44805 .33715 L p .622 .562 .765 r
F P
0 g
s
.59584 .66543 m .60733 .65386 L .61197 .66405 L p .427 .329 .641 r
F P
0 g
s
.61197 .66405 m .59923 .67609 L .59584 .66543 L p .427 .329 .641 r
F P
0 g
s
.61401 .4269 m .62449 .43491 L .6239 .43148 L p .93 .59 .367 r
F P
0 g
s
.6239 .43148 m .61316 .42323 L .61401 .4269 L p .93 .59 .367 r
F P
0 g
s
.56369 .53928 m .5703 .54371 L .5829 .54555 L p .58 .023 0 r
F P
0 g
s
.65088 .46834 m .65336 .48192 L .64394 .47711 L p .354 .443 .814 r
F P
0 g
s
.64394 .47711 m .64232 .46376 L .65088 .46834 L p .354 .443 .814 r
F P
0 g
s
.60434 .56921 m .59931 .55603 L .58985 .55606 L p .878 .553 .432 r
F P
0 g
s
.5829 .54555 m .58985 .55606 L .59931 .55603 L p .808 .44 .359 r
F P
0 g
s
.74355 .50973 m .74272 .5266 L .71023 .52361 L p .638 .672 .866 r
F P
0 g
s
.71023 .52361 m .71103 .50803 L .74355 .50973 L p .638 .672 .866 r
F P
0 g
s
.59579 .40465 m .61249 .40961 L .61404 .39862 L p .834 .629 .627 r
F P
0 g
s
.61404 .39862 m .59566 .39248 L .59579 .40465 L p .834 .629 .627 r
F P
0 g
s
.61188 .60092 m .60938 .5848 L .60639 .58717 L p .994 .767 .477 r
F P
0 g
s
.60639 .58717 m .61011 .60362 L .61188 .60092 L p .994 .767 .477 r
F P
0 g
s
.48347 .47079 m .46702 .46952 L .469 .45646 L p .581 .441 .655 r
F P
0 g
s
.469 .45646 m .48372 .45477 L .48347 .47079 L p .581 .441 .655 r
F P
0 g
s
.60391 .64138 m .60911 .62741 L .61024 .6324 L p .026 0 .458 r
F P
0 g
s
.61024 .6324 m .60494 .64651 L .60391 .64138 L p .026 0 .458 r
F P
0 g
s
.45951 .70033 m .47932 .71018 L .46486 .73913 L p .792 .704 .768 r
F P
0 g
s
.46486 .73913 m .44107 .72892 L .45951 .70033 L p .792 .704 .768 r
F P
0 g
s
.58985 .55606 m .5829 .54555 L .5703 .54371 L p .8 .363 .209 r
F P
0 g
s
.42224 .50787 m .41848 .50427 L .42943 .49845 L p .583 .21 .299 r
F P
0 g
s
.42943 .49845 m .43536 .50428 L .42224 .50787 L p .583 .21 .299 r
F P
0 g
s
.49097 .64419 m .48037 .63243 L .48761 .61985 L p .885 .711 .66 r
F P
0 g
s
.48037 .63243 m .49097 .64419 L .48314 .65862 L p .867 .712 .687 r
F P
0 g
s
.49055 .43456 m .48192 .43714 L .47815 .41761 L p .594 .473 .684 r
F P
0 g
s
.47815 .41761 m .48613 .41491 L .49055 .43456 L p .594 .473 .684 r
F P
0 g
s
.66533 .30533 m .62879 .28676 L .61199 .32528 L p .776 .713 .793 r
F P
0 g
s
.62879 .28676 m .66533 .30533 L .70423 .26048 L p .757 .722 .819 r
F P
0 g
s
.7862 .51004 m .78495 .52904 L .74272 .5266 L p .647 .7 .885 r
F P
0 g
s
.74272 .5266 m .74355 .50973 L .7862 .51004 L p .647 .7 .885 r
F P
0 g
s
.30881 .51462 m .30911 .52487 L .34168 .52225 L p .608 .817 .98 r
F P
0 g
s
.34168 .52225 m .34181 .51481 L .30881 .51462 L p .608 .817 .98 r
F P
0 g
s
.49009 .68733 m .47301 .67714 L .48314 .65862 L p .824 .679 .704 r
F P
0 g
s
.47301 .67714 m .49009 .68733 L .47932 .71018 L p .808 .691 .736 r
F P
0 g
s
.48761 .61985 m .48021 .60855 L .48739 .59644 L p .913 .75 .667 r
F P
0 g
s
.48021 .60855 m .48761 .61985 L .48037 .63243 L p .899 .742 .678 r
F P
0 g
s
.61464 .42897 m .62496 .43688 L .62449 .43491 L p .922 .552 .301 r
F P
0 g
s
.62449 .43491 m .61401 .4269 L .61464 .42897 L p .922 .552 .301 r
F P
0 g
s
.48083 .48416 m .46387 .47877 L .46702 .46952 L p .595 .447 .649 r
F P
0 g
s
.46702 .46952 m .48347 .47079 L .48083 .48416 L p .595 .447 .649 r
F P
0 g
s
.48888 .41394 m .48613 .41491 L .47987 .39239 L p .602 .498 .709 r
F P
0 g
s
.47987 .39239 m .48257 .39144 L .48888 .41394 L p .602 .498 .709 r
F P
0 g
s
.48257 .39144 m .47987 .39239 L .47079 .3658 L p .622 .534 .734 r
F P
0 g
s
.3453 .27395 m .37127 .25571 L .40898 .30561 L p .616 .615 .827 r
F P
0 g
s
.37127 .25571 m .3453 .27395 L .27813 .21351 L p .629 .644 .846 r
F P
0 g
s
.8425 .50881 m .84038 .53102 L .78495 .52904 L p .651 .72 .899 r
F P
0 g
s
.78495 .52904 m .7862 .51004 L .8425 .50881 L p .651 .72 .899 r
F P
0 g
s
.68489 .48965 m .68616 .50508 L .66702 .50116 L p .563 .587 .835 r
F P
0 g
s
.66702 .50116 m .66672 .48627 L .68489 .48965 L p .563 .587 .835 r
F P
0 g
s
.48739 .59644 m .48204 .58716 L .49014 .5739 L p .913 .778 .699 r
F P
0 g
s
.48204 .58716 m .48739 .59644 L .48021 .60855 L p .914 .764 .681 r
F P
0 g
s
.47079 .3658 m .47372 .36476 L .48257 .39144 L p .622 .534 .734 r
F P
0 g
s
.47372 .36476 m .47079 .3658 L .45752 .33324 L p .632 .566 .763 r
F P
0 g
s
.44805 .33715 m .45752 .33324 L .47079 .3658 L p .622 .562 .765 r
F P
0 g
s
.40729 .50989 m .4048 .50878 L .41848 .50427 L p .493 .012 .041 r
F P
0 g
s
.41848 .50427 m .42224 .50787 L .40729 .50989 L p .493 .012 .041 r
F P
0 g
s
.47932 .71018 m .45951 .70033 L .47301 .67714 L p .808 .691 .736 r
F P
0 g
s
.45752 .33324 m .44805 .33715 L .4264 .2969 L p .632 .594 .793 r
F P
0 g
s
.40898 .30561 m .4264 .2969 L .44805 .33715 L p .619 .588 .796 r
F P
0 g
s
.48537 .39046 m .48257 .39144 L .48888 .41394 L p .623 .511 .706 r
F P
0 g
s
.48257 .39144 m .48537 .39046 L .47665 .36372 L p .622 .534 .734 r
F P
0 g
s
.47665 .36372 m .47372 .36476 L .48257 .39144 L p .622 .534 .734 r
F P
0 g
s
.60938 .5848 m .60434 .56921 L .59913 .57087 L p .942 .661 .476 r
F P
0 g
s
.59913 .57087 m .60639 .58717 L .60938 .5848 L p .942 .661 .476 r
F P
0 g
s
.58985 .55606 m .59913 .57087 L .60434 .56921 L p .878 .553 .432 r
F P
0 g
s
.26596 .51341 m .26677 .5268 L .30911 .52487 L p .633 .792 .958 r
F P
0 g
s
.30911 .52487 m .30881 .51462 L .26596 .51341 L p .633 .792 .958 r
F P
0 g
s
.59688 .41336 m .61244 .41768 L .61249 .40961 L p .84 .597 .571 r
F P
0 g
s
.61249 .40961 m .59579 .40465 L .59688 .41336 L p .84 .597 .571 r
F P
0 g
s
.61485 .42965 m .62515 .43751 L .62496 .43688 L p .922 .551 .297 r
F P
0 g
s
.62496 .43688 m .61464 .42897 L .61485 .42965 L p .922 .551 .297 r
F P
0 g
s
.49379 .45246 m .48372 .45477 L .48192 .43714 L p .59 .458 .669 r
F P
0 g
s
.48192 .43714 m .49055 .43456 L .49379 .45246 L p .59 .458 .669 r
F P
0 g
s
.47704 .4924 m .46116 .48398 L .46387 .47877 L p .614 .453 .64 r
F P
0 g
s
.46387 .47877 m .48083 .48416 L .47704 .4924 L p .614 .453 .64 r
F P
0 g
s
.63652 .45264 m .64232 .46376 L .63672 .45912 L p 0 .244 .759 r
F P
0 g
s
.49014 .5739 m .48704 .56935 L .49724 .55379 L p .882 .788 .751 r
F P
0 g
s
.48704 .56935 m .49014 .5739 L .48204 .58716 L p .907 .774 .703 r
F P
0 g
s
.47372 .36476 m .47665 .36372 L .46418 .33083 L p .632 .566 .763 r
F P
0 g
s
.46418 .33083 m .46085 .33204 L .47372 .36476 L p .632 .566 .763 r
F P
0 g
s
.45752 .33324 m .46085 .33204 L .47372 .36476 L p .632 .566 .763 r
F P
0 g
s
.49352 .43357 m .49055 .43456 L .48613 .41491 L p .602 .478 .684 r
F P
0 g
s
.48613 .41491 m .48888 .41394 L .49352 .43357 L p .602 .478 .684 r
F P
0 g
s
.61514 .43044 m .62541 .43827 L .62515 .43751 L p .91 .514 .236 r
F P
0 g
s
.62515 .43751 m .61485 .42965 L .61514 .43044 L p .91 .514 .236 r
F P
0 g
s
.4264 .2969 m .40898 .30561 L .37127 .25571 L p .631 .62 .821 r
F P
0 g
s
.59923 .67609 m .61197 .66405 L .62013 .67763 L p .472 .399 .694 r
F P
0 g
s
.62013 .67763 m .60531 .69057 L .59923 .67609 L p .472 .399 .694 r
F P
0 g
s
.48888 .41394 m .49165 .413 L .48537 .39046 L p .623 .511 .706 r
F P
0 g
s
.49366 .38776 m .48537 .39046 L .49165 .413 L p .622 .51 .705 r
F P
0 g
s
.48537 .39046 m .49366 .38776 L .48553 .36084 L p .632 .541 .733 r
F P
0 g
s
.48553 .36084 m .47665 .36372 L .48537 .39046 L p .632 .541 .733 r
F P
0 g
s
.49724 .55379 m .48642 .55077 L .48275 .5662 L p .875 .775 .748 r
F P
0 g
s
.48275 .5662 m .48704 .56935 L .49724 .55379 L p .875 .775 .748 r
F P
0 g
s
.60494 .64651 m .61024 .6324 L .61304 .63956 L p .147 .113 .559 r
F P
0 g
s
.61304 .63956 m .60733 .65386 L .60494 .64651 L p .147 .113 .559 r
F P
0 g
s
.4753 .49493 m .46013 .4856 L .46116 .48398 L p .628 .456 .63 r
F P
0 g
s
.46116 .48398 m .47704 .4924 L .4753 .49493 L p .628 .456 .63 r
F P
0 g
s
.61617 .43271 m .62622 .44048 L .62541 .43827 L p .889 .464 .158 r
F P
0 g
s
.62541 .43827 m .61514 .43044 L .61617 .43271 L p .889 .464 .158 r
F P
0 g
s
.47294 .49772 m .4588 .4875 L .46013 .4856 L p .635 .454 .621 r
F P
0 g
s
.46013 .4856 m .4753 .49493 L .47294 .49772 L p .635 .454 .621 r
F P
0 g
s
.47665 .36372 m .48553 .36084 L .47433 .32763 L p .641 .571 .761 r
F P
0 g
s
.47433 .32763 m .46418 .33083 L .47665 .36372 L p .641 .571 .761 r
F P
0 g
s
.49165 .413 m .48888 .41394 L .49352 .43357 L p .605 .48 .683 r
F P
0 g
s
.20946 .51096 m .21114 .52808 L .26677 .5268 L p .644 .774 .943 r
F P
0 g
s
.26677 .5268 m .26596 .51341 L .20946 .51096 L p .644 .774 .943 r
F P
0 g
s
.46501 .50392 m .45441 .49258 L .4588 .4875 L p .651 .45 .598 r
F P
0 g
s
.4588 .4875 m .47294 .49772 L .46501 .50392 L p .651 .45 .598 r
F P
0 g
s
.61011 .60362 m .60639 .58717 L .60509 .58895 L p .991 .74 .385 r
F P
0 g
s
.60509 .58895 m .60938 .60547 L .61011 .60362 L p .991 .74 .385 r
F P
0 g
s
.42365 .71891 m .44107 .72892 L .41518 .76428 L p .791 .744 .809 r
F P
0 g
s
.41518 .76428 m .39357 .75296 L .42365 .71891 L p .791 .744 .809 r
F P
0 g
s
.66329 .47221 m .66672 .48627 L .65336 .48192 L p .444 .53 .851 r
F P
0 g
s
.65336 .48192 m .65088 .46834 L .66329 .47221 L p .444 .53 .851 r
F P
0 g
s
.38999 .51063 m .38817 .51192 L .4048 .50878 L p .204 0 0 r
F P
0 g
s
.4048 .50878 m .40729 .50989 L .38999 .51063 L p .204 0 0 r
F P
0 g
s
.49352 .43357 m .4965 .43253 L .49165 .413 L p .605 .48 .683 r
F P
0 g
s
.4999 .41011 m .49165 .413 L .4965 .43253 L p .613 .485 .682 r
F P
0 g
s
.49165 .413 m .4999 .41011 L .49366 .38776 L p .622 .51 .705 r
F P
0 g
s
.45265 .50883 m .44642 .4989 L .45441 .49258 L p .681 .445 .558 r
F P
0 g
s
.45441 .49258 m .46501 .50392 L .45265 .50883 L p .681 .445 .558 r
F P
0 g
s
.68595 .74678 m .65584 .76662 L .63134 .73451 L p .565 .566 .813 r
F P
0 g
s
.65584 .76662 m .68595 .74678 L .73356 .78301 L p .584 .609 .843 r
F P
0 g
s
.3214 .77574 m .33169 .78332 L .26204 .83262 L p .756 .785 .877 r
F P
0 g
s
.26204 .83262 m .24789 .82292 L .3214 .77574 L p .756 .785 .877 r
F P
0 g
s
.62622 .44048 m .61617 .43271 L .61814 .4362 L p .848 .386 .038 r
F P
0 g
s
.48314 .65862 m .47153 .64836 L .48037 .63243 L p .867 .712 .687 r
F P
0 g
s
.47153 .64836 m .48314 .65862 L .47301 .67714 L p .849 .717 .717 r
F P
0 g
s
.49623 .4695 m .48347 .47079 L .48372 .45477 L p .594 .458 .665 r
F P
0 g
s
.48372 .45477 m .49379 .45246 L .49623 .4695 L p .594 .458 .665 r
F P
0 g
s
.50742 .38351 m .49366 .38776 L .4999 .41011 L p .637 .519 .702 r
F P
0 g
s
.49366 .38776 m .50742 .38351 L .50044 .35668 L p .647 .549 .73 r
F P
0 g
s
.50044 .35668 m .48553 .36084 L .49366 .38776 L p .647 .549 .73 r
F P
0 g
s
.59828 .41939 m .61316 .42323 L .61244 .41768 L p .841 .561 .514 r
F P
0 g
s
.61244 .41768 m .59688 .41336 L .59828 .41939 L p .841 .561 .514 r
F P
0 g
s
.49726 .45138 m .49379 .45246 L .49055 .43456 L p .597 .462 .668 r
F P
0 g
s
.49055 .43456 m .49352 .43357 L .49726 .45138 L p .597 .462 .668 r
F P
0 g
s
.57421 .39121 m .59566 .39248 L .59747 .37604 L p .77 .608 .678 r
F P
0 g
s
.59747 .37604 m .5734 .37319 L .57421 .39121 L p .77 .608 .678 r
F P
0 g
s
.5734 .37319 m .59747 .37604 L .60233 .35422 L p .766 .636 .718 r
F P
0 g
s
.60233 .35422 m .57458 .34934 L .5734 .37319 L p .766 .636 .718 r
F P
0 g
s
.57458 .34934 m .60233 .35422 L .61199 .32528 L p .758 .66 .753 r
F P
0 g
s
.46085 .33204 m .45752 .33324 L .43782 .29203 L p .641 .598 .79 r
F P
0 g
s
.4264 .2969 m .43782 .29203 L .45752 .33324 L p .632 .594 .793 r
F P
0 g
s
.70925 .49152 m .71103 .50803 L .68616 .50508 L p .594 .635 .861 r
F P
0 g
s
.68616 .50508 m .68489 .48965 L .70925 .49152 L p .594 .635 .861 r
F P
0 g
s
.59913 .57087 m .58985 .55606 L .58495 .55688 L p .893 .534 .356 r
F P
0 g
s
.5703 .54371 m .58495 .55688 L .58985 .55606 L p .8 .363 .209 r
F P
0 g
s
.43885 .51114 m .43536 .50428 L .44642 .4989 L p .699 .42 .498 r
F P
0 g
s
.44642 .4989 m .45265 .50883 L .43885 .51114 L p .699 .42 .498 r
F P
0 g
s
.48553 .36084 m .50044 .35668 L .49143 .32309 L p .654 .579 .758 r
F P
0 g
s
.49143 .32309 m .47433 .32763 L .48553 .36084 L p .654 .579 .758 r
F P
0 g
s
.48204 .58716 m .47968 .58442 L .48704 .56935 L p .907 .774 .703 r
F P
0 g
s
.48704 .56935 m .48275 .5662 L .47707 .58205 L p .905 .77 .702 r
F P
0 g
s
.47707 .58205 m .47968 .58442 L .48704 .56935 L p .905 .77 .702 r
F P
0 g
s
.4965 .43253 m .49352 .43357 L .49726 .45138 L p .599 .464 .668 r
F P
0 g
s
.60531 .69057 m .62013 .67763 L .63344 .69528 L p .51 .462 .739 r
F P
0 g
s
.63344 .69528 m .61538 .70964 L .60531 .69057 L p .51 .462 .739 r
F P
0 g
s
.60938 .60547 m .60509 .58895 L .60475 .5896 L p .982 .72 .331 r
F P
0 g
s
.60475 .5896 m .6092 .60613 L .60938 .60547 L p .982 .72 .331 r
F P
0 g
s
.46085 .33204 m .46418 .33083 L .44588 .28903 L p .641 .598 .79 r
F P
0 g
s
.44588 .28903 m .44185 .29053 L .46085 .33204 L p .641 .598 .79 r
F P
0 g
s
.43782 .29203 m .44185 .29053 L .46085 .33204 L p .641 .598 .79 r
F P
0 g
s
.58495 .55688 m .5703 .54371 L .56685 .54324 L p .811 .354 .149 r
F P
0 g
s
.4965 .43253 m .50525 .42918 L .4999 .41011 L p .613 .485 .682 r
F P
0 g
s
.51337 .40537 m .4999 .41011 L .50525 .42918 L p .628 .493 .679 r
F P
0 g
s
.4999 .41011 m .51337 .40537 L .50742 .38351 L p .637 .519 .702 r
F P
0 g
s
.37941 .74347 m .39357 .75296 L .35023 .79485 L p .777 .77 .846 r
F P
0 g
s
.35023 .79485 m .33169 .78332 L .37941 .74347 L p .777 .77 .846 r
F P
0 g
s
.36914 .51033 m .3676 .51391 L .38817 .51192 L p .238 .739 .901 r
F P
0 g
s
.38817 .51192 m .38999 .51063 L .36914 .51033 L p .238 .739 .901 r
F P
0 g
s
.48037 .63243 m .47248 .62334 L .48021 .60855 L p .899 .742 .678 r
F P
0 g
s
.47248 .62334 m .48037 .63243 L .47153 .64836 L p .884 .742 .699 r
F P
0 g
s
.61 .61673 m .61024 .6324 L .60911 .62741 L p 0 0 .299 r
F P
0 g
s
.64457 .45685 m .65088 .46834 L .64232 .46376 L p .171 .424 .86 r
F P
0 g
s
.64232 .46376 m .63652 .45264 L .64457 .45685 L p .171 .424 .86 r
F P
0 g
s
.49726 .45138 m .50071 .45013 L .4965 .43253 L p .599 .464 .668 r
F P
0 g
s
.50525 .42918 m .4965 .43253 L .50071 .45013 L p .605 .467 .667 r
F P
0 g
s
.57618 .40448 m .59579 .40465 L .59566 .39248 L p .77 .576 .636 r
F P
0 g
s
.59566 .39248 m .57421 .39121 L .57618 .40448 L p .77 .576 .636 r
F P
0 g
s
.49766 .48646 m .48083 .48416 L .48347 .47079 L p .607 .476 .677 r
F P
0 g
s
.48347 .47079 m .49623 .4695 L .49766 .48646 L p .607 .476 .677 r
F P
0 g
s
.60639 .58717 m .59913 .57087 L .59677 .57248 L p .954 .644 .404 r
F P
0 g
s
.59677 .57248 m .60509 .58895 L .60639 .58717 L p .954 .644 .404 r
F P
0 g
s
.6092 .60613 m .60475 .5896 L .6045 .59017 L p .975 .707 .298 r
F P
0 g
s
.6045 .59017 m .60908 .6067 L .6092 .60613 L p .975 .707 .298 r
F P
0 g
s
.62804 .44386 m .61814 .4362 L .62147 .44043 L p .734 .221 0 r
F P
0 g
s
.46418 .33083 m .47433 .32763 L .45821 .28509 L p .648 .602 .788 r
F P
0 g
s
.45821 .28509 m .44588 .28903 L .46418 .33083 L p .648 .602 .788 r
F P
0 g
s
.60733 .65386 m .61304 .63956 L .61859 .64933 L p .257 .237 .645 r
F P
0 g
s
.61859 .64933 m .61197 .66405 L .60733 .65386 L p .257 .237 .645 r
F P
0 g
s
.59959 .42327 m .61401 .4269 L .61316 .42323 L p .837 .521 .456 r
F P
0 g
s
.61316 .42323 m .59828 .41939 L .59959 .42327 L p .837 .521 .456 r
F P
0 g
s
.4245 .51175 m .42224 .50787 L .43536 .50428 L p .688 .342 .384 r
F P
0 g
s
.43536 .50428 m .43885 .51114 L .4245 .51175 L p .688 .342 .384 r
F P
0 g
s
.48021 .60855 m .47496 .60191 L .48204 .58716 L p .914 .764 .681 r
F P
0 g
s
.47496 .60191 m .48021 .60855 L .47248 .62334 L p .908 .759 .685 r
F P
0 g
s
.47968 .58442 m .48204 .58716 L .47496 .60191 L p .915 .767 .683 r
F P
0 g
s
.60908 .6067 m .6045 .59017 L .60398 .59199 L p .959 .681 .243 r
F P
0 g
s
.60398 .59199 m .60885 .60846 L .60908 .6067 L p .959 .681 .243 r
F P
0 g
s
.5262 .37868 m .50742 .38351 L .51337 .40537 L p .66 .532 .698 r
F P
0 g
s
.50742 .38351 m .5262 .37868 L .52109 .35229 L p .668 .562 .726 r
F P
0 g
s
.52109 .35229 m .50044 .35668 L .50742 .38351 L p .668 .562 .726 r
F P
0 g
s
.58495 .55688 m .59677 .57248 L .59913 .57087 L p .893 .534 .356 r
F P
0 g
s
.50073 .46824 m .49623 .4695 L .49379 .45246 L p .596 .46 .666 r
F P
0 g
s
.49379 .45246 m .49726 .45138 L .50073 .46824 L p .596 .46 .666 r
F P
0 g
s
.49584 .50225 m .47704 .4924 L .48083 .48416 L p .625 .506 .697 r
F P
0 g
s
.48083 .48416 m .49766 .48646 L .49584 .50225 L p .625 .506 .697 r
F P
0 g
s
.61199 .32528 m .57866 .31791 L .57458 .34934 L p .758 .66 .753 r
F P
0 g
s
.57866 .31791 m .61199 .32528 L .62879 .28676 L p .748 .679 .784 r
F P
0 g
s
.61538 .70964 m .63344 .69528 L .65426 .718 L p .54 .517 .779 r
F P
0 g
s
.65426 .718 m .63134 .73451 L .61538 .70964 L p .54 .517 .779 r
F P
0 g
s
.63134 .73451 m .65426 .718 L .68595 .74678 L p .565 .566 .813 r
F P
0 g
s
.47301 .67714 m .46016 .66774 L .47153 .64836 L p .849 .717 .717 r
F P
0 g
s
.46016 .66774 m .47301 .67714 L .45951 .70033 L p .831 .725 .748 r
F P
0 g
s
.49244 .50834 m .4753 .49493 L .47704 .4924 L p .649 .525 .699 r
F P
0 g
s
.47704 .4924 m .49584 .50225 L .49244 .50834 L p .649 .525 .699 r
F P
0 g
s
.48603 .51345 m .47294 .49772 L .4753 .49493 L p .674 .529 .679 r
F P
0 g
s
.4753 .49493 m .49244 .50834 L .48603 .51345 L p .674 .529 .679 r
F P
0 g
s
.50044 .35668 m .52109 .35229 L .51544 .31867 L p .674 .592 .755 r
F P
0 g
s
.51544 .31867 m .49143 .32309 L .50044 .35668 L p .674 .592 .755 r
F P
0 g
s
.50071 .45013 m .49726 .45138 L .50073 .46824 L p .597 .461 .666 r
F P
0 g
s
.47018 .51734 m .46501 .50392 L .47294 .49772 L p .717 .537 .645 r
F P
0 g
s
.47294 .49772 m .48603 .51345 L .47018 .51734 L p .717 .537 .645 r
F P
0 g
s
.74136 .49152 m .74355 .50973 L .71103 .50803 L p .617 .673 .881 r
F P
0 g
s
.71103 .50803 m .70925 .49152 L .74136 .49152 L p .617 .673 .881 r
F P
0 g
s
.50071 .45013 m .51051 .44573 L .50525 .42918 L p .605 .467 .667 r
F P
0 g
s
.51899 .42326 m .50525 .42918 L .51051 .44573 L p .616 .471 .662 r
F P
0 g
s
.50525 .42918 m .51899 .42326 L .51337 .40537 L p .628 .493 .679 r
F P
0 g
s
.68057 .47469 m .68489 .48965 L .66672 .48627 L p .512 .597 .875 r
F P
0 g
s
.66672 .48627 m .66329 .47221 L .68057 .47469 L p .512 .597 .875 r
F P
0 g
s
.34312 .50895 m .34181 .51481 L .3676 .51391 L p .483 .816 .999 r
F P
0 g
s
.3676 .51391 m .36914 .51033 L .34312 .50895 L p .483 .816 .999 r
F P
0 g
s
.60053 .42543 m .61464 .42897 L .61401 .4269 L p .83 .485 .401 r
F P
0 g
s
.61401 .4269 m .59959 .42327 L .60053 .42543 L p .83 .485 .401 r
F P
0 g
s
.57864 .41396 m .59688 .41336 L .59579 .40465 L p .766 .54 .59 r
F P
0 g
s
.59579 .40465 m .57618 .40448 L .57864 .41396 L p .766 .54 .59 r
F P
0 g
s
.5312 .39945 m .51337 .40537 L .51899 .42326 L p .649 .503 .672 r
F P
0 g
s
.51337 .40537 m .5312 .39945 L .5262 .37868 L p .66 .532 .698 r
F P
0 g
s
.4449 .69099 m .45951 .70033 L .44107 .72892 L p .811 .733 .779 r
F P
0 g
s
.44107 .72892 m .42365 .71891 L .4449 .69099 L p .811 .733 .779 r
F P
0 g
s
.84401 .7918 m .80471 .82886 L .73356 .78301 L p .569 .645 .886 r
F P
0 g
s
.4694 .55458 m .48642 .55077 L .48583 .54401 L p .858 .73 .72 r
F P
0 g
s
.48642 .55077 m .4694 .55458 L .47027 .5637 L p .88 .757 .721 r
F P
0 g
s
.47027 .5637 m .48275 .5662 L .48642 .55077 L p .88 .757 .721 r
F P
0 g
s
.48275 .5662 m .47027 .5637 L .46888 .57746 L p .904 .764 .698 r
F P
0 g
s
.46888 .57746 m .47707 .58205 L .48275 .5662 L p .904 .764 .698 r
F P
0 g
s
.45461 .51734 m .45265 .50883 L .46501 .50392 L p .745 .537 .613 r
F P
0 g
s
.46501 .50392 m .47018 .51734 L .45461 .51734 L p .745 .537 .613 r
F P
0 g
s
.47433 .32763 m .49143 .32309 L .47908 .27962 L p .66 .608 .785 r
F P
0 g
s
.47908 .27962 m .45821 .28509 L .47433 .32763 L p .66 .608 .785 r
F P
0 g
s
.43782 .29203 m .4264 .2969 L .39335 .24394 L p .642 .624 .817 r
F P
0 g
s
.37127 .25571 m .39335 .24394 L .4264 .2969 L p .631 .62 .821 r
F P
0 g
s
.40905 .51129 m .40729 .50989 L .42224 .50787 L p .619 .161 .145 r
F P
0 g
s
.42224 .50787 m .4245 .51175 L .40905 .51129 L p .619 .161 .145 r
F P
0 g
s
.60885 .60846 m .60398 .59199 L .6038 .59542 L p .909 .616 .122 r
F P
0 g
s
.50073 .46824 m .50511 .46653 L .50071 .45013 L p .597 .461 .666 r
F P
0 g
s
.51051 .44573 m .50071 .45013 L .50511 .46653 L p .599 .461 .665 r
F P
0 g
s
.47968 .58442 m .47707 .58205 L .47105 .59795 L p .916 .768 .683 r
F P
0 g
s
.47105 .59795 m .47303 .59986 L .47968 .58442 L p .916 .768 .683 r
F P
0 g
s
.47496 .60191 m .47303 .59986 L .47968 .58442 L p .915 .767 .683 r
F P
0 g
s
.55205 .39403 m .57421 .39121 L .5734 .37319 L p .725 .573 .684 r
F P
0 g
s
.5734 .37319 m .54883 .37458 L .55205 .39403 L p .725 .573 .684 r
F P
0 g
s
.54883 .37458 m .5734 .37319 L .57458 .34934 L p .727 .603 .718 r
F P
0 g
s
.60509 .58895 m .59677 .57248 L .59617 .57313 L p .957 .633 .361 r
F P
0 g
s
.59617 .57313 m .60475 .5896 L .60509 .58895 L p .957 .633 .361 r
F P
0 g
s
.45951 .70033 m .4449 .69099 L .46016 .66774 L p .831 .725 .748 r
F P
0 g
s
.60083 .42612 m .61485 .42965 L .61464 .42897 L p .831 .479 .389 r
F P
0 g
s
.61464 .42897 m .60053 .42543 L .60083 .42612 L p .831 .479 .389 r
F P
0 g
s
.62205 .44361 m .62824 .44595 L p .6268 .44472 L .269 0 0 r
F P
0 g
s
.6312 .44811 m .62565 .44373 L p .6268 .44472 L .451 0 0 r
F P
0 g
s
.63652 .45264 m .6268 .44472 L .63467 .44839 L p 0 .383 .82 r
F P
0 g
s
.62824 .44595 m .63467 .44839 L .6268 .44472 L p .269 0 0 r
F P
0 g
s
.62565 .44373 m .62147 .44043 L .6268 .44472 L p .451 0 0 r
F P
0 g
s
.54883 .37458 m .5262 .37868 L .5312 .39945 L p .689 .55 .691 r
F P
0 g
s
.5262 .37868 m .54883 .37458 L .54649 .34925 L p .695 .579 .721 r
F P
0 g
s
.54649 .34925 m .52109 .35229 L .5262 .37868 L p .695 .579 .721 r
F P
0 g
s
.50464 .48514 m .49766 .48646 L .49623 .4695 L p .604 .477 .68 r
F P
0 g
s
.49623 .4695 m .50073 .46824 L .50464 .48514 L p .604 .477 .68 r
F P
0 g
s
.48603 .51345 m .4881 .52664 L .46983 .52344 L p .754 .623 .715 r
F P
0 g
s
.4881 .52664 m .48603 .51345 L .49244 .50834 L p .75 .635 .732 r
F P
0 g
s
.48867 .52545 m .48219 .53715 L .48583 .54401 L p .75 .635 .732 r
F P
0 g
s
.46865 .55159 m .48583 .54401 L .48219 .53715 L p .841 .688 .692 r
F P
0 g
s
.48583 .54401 m .46865 .55159 L .4694 .55458 L p .858 .73 .72 r
F P
0 g
s
.60123 .42694 m .61514 .43044 L .61485 .42965 L p .827 .463 .366 r
F P
0 g
s
.61485 .42965 m .60083 .42612 L .60123 .42694 L p .827 .463 .366 r
F P
0 g
s
.70423 .26048 m .65661 .23448 L .62879 .28676 L p .757 .722 .819 r
F P
0 g
s
.65661 .23448 m .70423 .26048 L .7666 .19859 L p .739 .727 .841 r
F P
0 g
s
.57458 .34934 m .54649 .34925 L .54883 .37458 L p .727 .603 .718 r
F P
0 g
s
.54649 .34925 m .57458 .34934 L .57866 .31791 L p .726 .629 .751 r
F P
0 g
s
.61024 .6324 m .61 .61673 L .61306 .624 L p 0 0 .488 r
F P
0 g
s
.61306 .624 m .61304 .63956 L .61024 .6324 L p 0 0 .488 r
F P
0 g
s
.60247 .42931 m .61617 .43271 L .61514 .43044 L p .822 .444 .339 r
F P
0 g
s
.61514 .43044 m .60123 .42694 L .60247 .42931 L p .822 .444 .339 r
F P
0 g
s
.60475 .5896 m .59617 .57313 L .59574 .57371 L p .957 .625 .336 r
F P
0 g
s
.59574 .57371 m .6045 .59017 L .60475 .5896 L p .957 .625 .336 r
F P
0 g
s
.59677 .57248 m .58495 .55688 L .58382 .55745 L p .899 .522 .308 r
F P
0 g
s
.56685 .54324 m .58382 .55745 L .58495 .55688 L p .811 .354 .149 r
F P
0 g
s
.58382 .55745 m .56685 .54324 L .56641 .54371 L p .831 .374 .133 r
F P
0 g
s
.55582 .40863 m .57618 .40448 L .57421 .39121 L p .718 .54 .647 r
F P
0 g
s
.57421 .39121 m .55205 .39403 L .55582 .40863 L p .718 .54 .647 r
F P
0 g
s
.44 .51614 m .43885 .51114 L .45265 .50883 L p .749 .494 .545 r
F P
0 g
s
.45265 .50883 m .45461 .51734 L .44 .51614 L p .749 .494 .545 r
F P
0 g
s
.46983 .52344 m .47018 .51734 L .47621 .51586 L p .754 .623 .715 r
F P
0 g
s
.47569 .51983 m .46983 .52344 L .47621 .51586 L .754 .623 .715 r
F
.4704 .52223 m .46918 .5282 L .47414 .53161 L p .754 .624 .715 r
F P
0 g
s
.47414 .53161 m .48219 .53715 L p .47466 .52763 L .754 .624 .715 r
F P
0 g
s
.47466 .52763 m .4704 .52223 L .47414 .53161 L .754 .624 .715 r
F
.47621 .51586 m .48603 .51345 L p .47569 .51983 L .754 .623 .715 r
F P
0 g
s
.52109 .35229 m .54649 .34925 L .54528 .31634 L p .697 .607 .752 r
F P
0 g
s
.54528 .31634 m .51544 .31867 L .52109 .35229 L p .697 .607 .752 r
F P
0 g
s
.5312 .39945 m .55205 .39403 L .54883 .37458 L p .689 .55 .691 r
F P
0 g
s
.48219 .53715 m .48867 .52545 L .4704 .52223 L p .754 .624 .715 r
F P
0 g
s
.30999 .50645 m .30881 .51462 L .34181 .51481 L p .578 .804 .985 r
F P
0 g
s
.34181 .51481 m .34312 .50895 L .30999 .50645 L p .578 .804 .985 r
F P
0 g
s
.58103 .42043 m .59828 .41939 L .59688 .41336 L p .76 .502 .543 r
F P
0 g
s
.59688 .41336 m .57864 .41396 L .58103 .42043 L p .76 .502 .543 r
F P
0 g
s
.47153 .64836 m .4633 .6405 L .47248 .62334 L p .884 .742 .699 r
F P
0 g
s
.4633 .6405 m .47153 .64836 L .46016 .66774 L p .868 .746 .726 r
F P
0 g
s
.51899 .42326 m .53632 .41566 L .5312 .39945 L p .649 .503 .672 r
F P
0 g
s
.55205 .39403 m .5312 .39945 L .53632 .41566 L p .679 .517 .66 r
F P
0 g
s
.50511 .46653 m .50073 .46824 L .50464 .48514 L p .601 .475 .681 r
F P
0 g
s
.61197 .66405 m .61859 .64933 L .62828 .66225 L p .348 .344 .713 r
F P
0 g
s
.62828 .66225 m .62013 .67763 L .61197 .66405 L p .348 .344 .713 r
F P
0 g
s
.6563 .45999 m .66329 .47221 L .65088 .46834 L p .345 .548 .907 r
F P
0 g
s
.65088 .46834 m .64457 .45685 L .6563 .45999 L p .345 .548 .907 r
F P
0 g
s
.58382 .55745 m .59617 .57313 L .59677 .57248 L p .899 .522 .308 r
F P
0 g
s
.51016 .50349 m .49584 .50225 L .49766 .48646 L p .62 .519 .718 r
F P
0 g
s
.6045 .59017 m .59574 .57371 L .5949 .57572 L p .956 .613 .296 r
F P
0 g
s
.5949 .57572 m .60398 .59199 L .6045 .59017 L p .956 .613 .296 r
F P
0 g
s
.51051 .44573 m .52478 .4376 L .51899 .42326 L p .616 .471 .662 r
F P
0 g
s
.53632 .41566 m .51899 .42326 L .52478 .4376 L p .634 .474 .649 r
F P
0 g
s
.39153 .50997 m .38999 .51063 L .40729 .50989 L p .358 0 0 r
F P
0 g
s
.40729 .50989 m .40905 .51129 L .39153 .50997 L p .358 0 0 r
F P
0 g
s
.49766 .48646 m .50464 .48514 L .51016 .50349 L p .62 .519 .718 r
F P
0 g
s
.46742 .54815 m .48219 .53715 L .46918 .5282 L p .807 .62 .649 r
F P
0 g
s
.48219 .53715 m .46742 .54815 L .46865 .55159 L p .841 .688 .692 r
F P
0 g
s
.47707 .58205 m .46888 .57746 L .46506 .5932 L p .918 .77 .682 r
F P
0 g
s
.46506 .5932 m .47105 .59795 L .47707 .58205 L p .918 .77 .682 r
F P
0 g
s
.78375 .48924 m .7862 .51004 L .74355 .50973 L p .633 .701 .895 r
F P
0 g
s
.74355 .50973 m .74136 .49152 L .78375 .48924 L p .633 .701 .895 r
F P
0 g
s
.60486 .43279 m .61814 .4362 L .61617 .43271 L p .796 .373 .242 r
F P
0 g
s
.61617 .43271 m .60247 .42931 L .60486 .43279 L p .796 .373 .242 r
F P
0 g
s
.50511 .46653 m .5165 .45974 L .51051 .44573 L p .599 .461 .665 r
F P
0 g
s
.52478 .4376 m .51051 .44573 L .5165 .45974 L p .603 .455 .654 r
F P
0 g
s
.47303 .59986 m .47496 .60191 L .4675 .61799 L p .913 .767 .686 r
F P
0 g
s
.47248 .62334 m .4675 .61799 L .47496 .60191 L p .908 .759 .685 r
F P
0 g
s
.57866 .31791 m .54528 .31634 L .54649 .34925 L p .726 .629 .751 r
F P
0 g
s
.45427 .52071 m .45461 .51734 L .46615 .51734 L p .76 .59 .666 r
F P
0 g
s
.46608 .51821 m .45427 .52071 L .46615 .51734 L .76 .59 .666 r
F
.47018 .51734 m .46983 .52344 L .45427 .52071 L p F P
0 g
s
.45483 .5195 m .45462 .52289 L .46541 .52682 L p .76 .59 .666 r
F P
0 g
s
.46541 .52682 m .46918 .5282 L p .46548 .52595 L .76 .59 .666 r
F P
0 g
s
.46548 .52595 m .45483 .5195 L .46541 .52682 L .76 .59 .666 r
F
.46615 .51734 m .47018 .51734 L p .46608 .51821 L F P
0 g
s
.53632 .41566 m .55582 .40863 L .55205 .39403 L p .679 .517 .66 r
F P
0 g
s
.4675 .61799 m .47248 .62334 L .4633 .6405 L p .897 .761 .704 r
F P
0 g
s
.50464 .48514 m .51099 .48206 L .50511 .46653 L p .601 .475 .681 r
F P
0 g
s
.5165 .45974 m .50511 .46653 L .51099 .48206 L p .596 .469 .678 r
F P
0 g
s
.49143 .32309 m .51544 .31867 L .50852 .27473 L p .676 .617 .782 r
F P
0 g
s
.50852 .27473 m .47908 .27962 L .49143 .32309 L p .676 .617 .782 r
F P
0 g
s
.59617 .57313 m .58382 .55745 L .58315 .55805 L p .903 .519 .289 r
F P
0 g
s
.58315 .55805 m .59574 .57371 L .59617 .57313 L p .903 .519 .289 r
F P
0 g
s
.42546 .51442 m .4245 .51175 L .43885 .51114 L p .736 .405 .421 r
F P
0 g
s
.43885 .51114 m .44 .51614 L .42546 .51442 L p .736 .405 .421 r
F P
0 g
s
.56641 .54371 m .58315 .55805 L .58382 .55745 L p .831 .374 .133 r
F P
0 g
s
.60139 .59564 m .60372 .59996 L p .60494 .60092 L .705 .317 0 r
F P
0 g
s
.60892 .61169 m .60573 .60154 L p .60494 .60092 L .779 .478 0 r
F P
0 g
s
.61 .61673 m .60494 .60092 L .60847 .6088 L p 0 0 .349 r
F P
0 g
s
.60372 .59996 m .60847 .6088 L .60494 .60092 L p .705 .317 0 r
F P
0 g
s
.60573 .60154 m .6038 .59542 L .60494 .60092 L p .779 .478 0 r
F P
0 g
s
.5597 .41913 m .57864 .41396 L .57618 .40448 L p .708 .503 .608 r
F P
0 g
s
.57618 .40448 m .55582 .40863 L .5597 .41913 L p .708 .503 .608 r
F P
0 g
s
.44185 .29053 m .43782 .29203 L .40797 .23752 L p .648 .627 .815 r
F P
0 g
s
.39335 .24394 m .40797 .23752 L .43782 .29203 L p .642 .624 .817 r
F P
0 g
s
.58299 .42453 m .59959 .42327 L .59828 .41939 L p .751 .465 .498 r
F P
0 g
s
.59828 .41939 m .58103 .42043 L .58299 .42453 L p .751 .465 .498 r
F P
0 g
s
.51099 .48206 m .50464 .48514 L .51016 .50349 L p .611 .513 .719 r
F P
0 g
s
.70392 .47521 m .70925 .49152 L .68489 .48965 L p .562 .646 .891 r
F P
0 g
s
.68489 .48965 m .68057 .47469 L .70392 .47521 L p .562 .646 .891 r
F P
0 g
s
.47303 .59986 m .47105 .59795 L .46411 .61459 L p .915 .77 .686 r
F P
0 g
s
.46411 .61459 m .46581 .61626 L .47303 .59986 L p .915 .77 .686 r
F P
0 g
s
.4675 .61799 m .46581 .61626 L .47303 .59986 L p .913 .767 .686 r
F P
0 g
s
.52478 .4376 m .54148 .42772 L .53632 .41566 L p .634 .474 .649 r
F P
0 g
s
.55582 .40863 m .53632 .41566 L .54148 .42772 L p .664 .482 .629 r
F P
0 g
s
.46918 .5282 m .4704 .52223 L .45483 .5195 L p .76 .59 .666 r
F P
0 g
s
.267 .5026 m .26596 .51341 L .30881 .51462 L p .617 .785 .962 r
F P
0 g
s
.30881 .51462 m .30999 .50645 L .267 .5026 L p .617 .785 .962 r
F P
0 g
s
.59574 .57371 m .58315 .55805 L .58251 .5606 L p .912 .522 .251 r
F P
0 g
s
.58251 .5606 m .5949 .57572 L .59574 .57371 L p .912 .522 .251 r
F P
0 g
s
.51016 .50349 m .51998 .49433 L .51099 .48206 L p .611 .513 .719 r
F P
0 g
s
.60398 .59199 m .5949 .57572 L .5948 .5798 L p .941 .578 .195 r
F P
0 g
s
.5948 .5798 m .6038 .59542 L .60398 .59199 L p .941 .578 .195 r
F P
0 g
s
.3706 .50788 m .36914 .51033 L .38999 .51063 L p .138 .666 .871 r
F P
0 g
s
.38999 .51063 m .39153 .50997 L .3706 .50788 L p .138 .666 .871 r
F P
0 g
s
.44185 .29053 m .44588 .28903 L .41831 .23355 L p .648 .627 .815 r
F P
0 g
s
.41831 .23355 m .41314 .23554 L .44185 .29053 L p .648 .627 .815 r
F P
0 g
s
.40797 .23752 m .41314 .23554 L .44185 .29053 L p .648 .627 .815 r
F P
0 g
s
.43976 .51816 m .44 .51614 L .45461 .51734 L p .764 .55 .608 r
F P
0 g
s
.45461 .51734 m .45427 .52071 L .43976 .51816 L p .764 .55 .608 r
F P
0 g
s
.60862 .43688 m .62147 .44043 L .61814 .4362 L p .746 .262 .09 r
F P
0 g
s
.61814 .4362 m .60486 .43279 L .60862 .43688 L p .746 .262 .09 r
F P
0 g
s
.63467 .44839 m .64457 .45685 L .63652 .45264 L p 0 .383 .82 r
F P
0 g
s
.54528 .31634 m .57866 .31791 L .58702 .27611 L p .721 .652 .78 r
F P
0 g
s
.62879 .28676 m .58702 .27611 L .57866 .31791 L p .748 .679 .784 r
F P
0 g
s
.31818 .77307 m .3214 .77574 L .24789 .82292 L p .757 .79 .88 r
F P
0 g
s
.24789 .82292 m .24336 .81951 L .31818 .77307 L p .757 .79 .88 r
F P
0 g
s
.54148 .42772 m .5597 .41913 L .55582 .40863 L p .664 .482 .629 r
F P
0 g
s
.58315 .55805 m .56641 .54371 L .57038 .54867 L p .866 .419 .093 r
F P
0 g
s
.57038 .54867 m .58251 .5606 L .58315 .55805 L p .866 .419 .093 r
F P
0 g
s
.46219 .53959 m .46918 .5282 L .45462 .52289 L p .782 .57 .613 r
F P
0 g
s
.46918 .5282 m .46219 .53959 L .46742 .54815 L p .807 .62 .649 r
F P
0 g
s
.41224 .71079 m .42365 .71891 L .39357 .75296 L p .802 .765 .819 r
F P
0 g
s
.39357 .75296 m .37941 .74347 L .41224 .71079 L p .802 .765 .819 r
F P
0 g
s
.58702 .27611 m .62879 .28676 L .65661 .23448 L p .736 .694 .81 r
F P
0 g
s
.41001 .51229 m .40905 .51129 L .4245 .51175 L p .672 .223 .178 r
F P
0 g
s
.4245 .51175 m .42546 .51442 L .41001 .51229 L p .672 .223 .178 r
F P
0 g
s
.5165 .45974 m .5307 .44815 L .52478 .4376 L p .603 .455 .654 r
F P
0 g
s
.54148 .42772 m .52478 .4376 L .5307 .44815 L p .615 .444 .628 r
F P
0 g
s
.39335 .24394 m .37127 .25571 L .31236 .18771 L p .641 .647 .841 r
F P
0 g
s
.27813 .21351 m .31236 .18771 L .37127 .25571 L p .629 .644 .846 r
F P
0 g
s
.58424 .42679 m .60053 .42543 L .59959 .42327 L p .744 .436 .462 r
F P
0 g
s
.59959 .42327 m .58299 .42453 L .58424 .42679 L p .744 .436 .462 r
F P
0 g
s
.56641 .54371 m .55574 .53519 L .56621 .54437 L p .588 .091 0 r
F P
0 g
s
.56621 .54437 m .57038 .54867 L .56641 .54371 L p .588 .091 0 r
F P
0 g
s
.46016 .66774 m .45145 .66035 L .4633 .6405 L p .868 .746 .726 r
F P
0 g
s
.45145 .66035 m .46016 .66774 L .4449 .69099 L p .848 .752 .757 r
F P
0 g
s
.44588 .28903 m .45821 .28509 L .43411 .2283 L p .654 .63 .813 r
F P
0 g
s
.43411 .2283 m .41831 .23355 L .44588 .28903 L p .654 .63 .813 r
F P
0 g
s
.52337 .47003 m .51099 .48206 L .51998 .49433 L p .592 .485 .701 r
F P
0 g
s
.51099 .48206 m .52337 .47003 L .5165 .45974 L p .596 .469 .678 r
F P
0 g
s
.61304 .63956 m .61306 .624 L .61929 .63381 L p .021 .125 .634 r
F P
0 g
s
.61929 .63381 m .61859 .64933 L .61304 .63956 L p .021 .125 .634 r
F P
0 g
s
.84029 .48416 m .8425 .50881 L .7862 .51004 L p .643 .721 .905 r
F P
0 g
s
.7862 .51004 m .78375 .48924 L .84029 .48416 L p .643 .721 .905 r
F P
0 g
s
.56322 .42622 m .58103 .42043 L .57864 .41396 L p .695 .464 .569 r
F P
0 g
s
.57864 .41396 m .5597 .41913 L .56322 .42622 L p .695 .464 .569 r
F P
0 g
s
.51544 .31867 m .54528 .31634 L .54541 .27265 L p .698 .633 .781 r
F P
0 g
s
.54541 .27265 m .50852 .27473 L .51544 .31867 L p .698 .633 .781 r
F P
0 g
s
.47105 .59795 m .46506 .5932 L .45916 .61003 L p .92 .778 .686 r
F P
0 g
s
.45916 .61003 m .46411 .61459 L .47105 .59795 L p .92 .778 .686 r
F P
0 g
s
.5307 .44815 m .5165 .45974 L .52337 .47003 L p .586 .44 .65 r
F P
0 g
s
.62013 .67763 m .62828 .66225 L .64397 .67865 L p .417 .429 .764 r
F P
0 g
s
.64397 .67865 m .63344 .69528 L .62013 .67763 L p .417 .429 .764 r
F P
0 g
s
.58467 .4275 m .60083 .42612 L .60053 .42543 L p .74 .422 .445 r
F P
0 g
s
.60053 .42543 m .58424 .42679 L .58467 .4275 L p .74 .422 .445 r
F P
0 g
s
.45462 .52289 m .45483 .5195 L .44031 .51695 L p .764 .55 .608 r
F P
0 g
s
.42531 .51562 m .42546 .51442 L .44 .51614 L p .762 .497 .533 r
F P
0 g
s
.44 .51614 m .43976 .51816 L .42531 .51562 L p .762 .497 .533 r
F P
0 g
s
.58518 .42836 m .60123 .42694 L .60083 .42612 L p .739 .418 .439 r
F P
0 g
s
.60083 .42612 m .58467 .4275 L .58518 .42836 L p .739 .418 .439 r
F P
0 g
s
.58702 .27611 m .54541 .27265 L .54528 .31634 L p .721 .652 .78 r
F P
0 g
s
.46581 .61626 m .4675 .61799 L .45845 .63575 L p .903 .772 .706 r
F P
0 g
s
.4633 .6405 m .45845 .63575 L .4675 .61799 L p .897 .761 .704 r
F P
0 g
s
.34474 .50478 m .34312 .50895 L .36914 .51033 L p .437 .787 .997 r
F P
0 g
s
.36914 .51033 m .3706 .50788 L .34474 .50478 L p .437 .787 .997 r
F P
0 g
s
.21033 .49703 m .20946 .51096 L .26596 .51341 L p .636 .771 .945 r
F P
0 g
s
.26596 .51341 m .267 .5026 L .21033 .49703 L p .636 .771 .945 r
F P
0 g
s
.67258 .46135 m .68057 .47469 L .66329 .47221 L p .458 .624 .923 r
F P
0 g
s
.66329 .47221 m .6563 .45999 L .67258 .46135 L p .458 .624 .923 r
F P
0 g
s
.58683 .43073 m .60247 .42931 L .60123 .42694 L p .728 .388 .405 r
F P
0 g
s
.60123 .42694 m .58518 .42836 L .58683 .43073 L p .728 .388 .405 r
F P
0 g
s
.5307 .44815 m .54623 .43597 L .54148 .42772 L p .615 .444 .628 r
F P
0 g
s
.5597 .41913 m .54148 .42772 L .54623 .43597 L p .645 .444 .597 r
F P
0 g
s
.44031 .51695 m .44045 .51903 L .45462 .52289 L p .764 .55 .608 r
F P
0 g
s
.45226 .53072 m .45462 .52289 L .44045 .51903 L p .775 .516 .543 r
F P
0 g
s
.45462 .52289 m .45226 .53072 L .46219 .53959 L p .782 .57 .613 r
F P
0 g
s
.45845 .63575 m .4633 .6405 L .45145 .66035 L p .881 .767 .732 r
F P
0 g
s
.39153 .50997 m .39259 .50968 L .37178 .50645 L p .083 .622 .855 r
F P
0 g
s
.39259 .50968 m .39251 .50986 L .38975 .50937 L p .396 0 0 r
F P
0 g
s
.37183 .50623 m .37178 .50645 L .39259 .50968 L p .396 0 0 r
F P
0 g
s
.38975 .50937 m .37183 .50623 L p .39259 .50968 L .396 0 0 r
F P
0 g
s
.39259 .50968 m .39153 .50997 L .40343 .51087 L p .422 0 0 r
F P
0 g
s
.40343 .51087 m .40905 .51129 L p .39259 .50968 L .422 0 0 r
F P
0 g
s
.40905 .51129 m .41001 .51229 L .39259 .50968 L p .422 0 0 r
F P
0 g
s
.54623 .43597 m .56322 .42622 L .5597 .41913 L p .645 .444 .597 r
F P
0 g
s
.5949 .57572 m .58251 .5606 L .58418 .5664 L p .911 .506 .154 r
F P
0 g
s
.58418 .5664 m .5948 .5798 L .5949 .57572 L p .911 .506 .154 r
F P
0 g
s
.4573 .56431 m .47027 .5637 L .4694 .55458 L p .906 .727 .648 r
F P
0 g
s
.47027 .5637 m .4573 .56431 L .45765 .5744 L p .92 .756 .661 r
F P
0 g
s
.45765 .5744 m .46888 .57746 L .47027 .5637 L p .92 .756 .661 r
F P
0 g
s
.61415 .4408 m .6268 .44472 L .62147 .44043 L p .604 .038 0 r
F P
0 g
s
.62147 .44043 m .60862 .43688 L .61415 .4408 L p .604 .038 0 r
F P
0 g
s
.4449 .69099 m .43514 .68353 L .45145 .66035 L p .848 .752 .757 r
F P
0 g
s
.43514 .68353 m .4449 .69099 L .42365 .71891 L p .827 .76 .789 r
F P
0 g
s
.45629 .55833 m .4694 .55458 L .46865 .55159 L p .895 .703 .635 r
F P
0 g
s
.4694 .55458 m .45629 .55833 L .4573 .56431 L p .906 .727 .648 r
F P
0 g
s
.37148 .73736 m .37941 .74347 L .33169 .78332 L p .783 .784 .853 r
F P
0 g
s
.33169 .78332 m .3214 .77574 L .37148 .73736 L p .783 .784 .853 r
F P
0 g
s
.60847 .6088 m .61306 .624 L .61 .61673 L p 0 0 .349 r
F P
0 g
s
.56595 .43063 m .58299 .42453 L .58103 .42043 L p .68 .426 .531 r
F P
0 g
s
.58103 .42043 m .56322 .42622 L .56595 .43063 L p .68 .426 .531 r
F P
0 g
s
.42365 .71891 m .41224 .71079 L .43514 .68353 L p .827 .76 .789 r
F P
0 g
s
.4558 .55639 m .46865 .55159 L .46742 .54815 L p .889 .687 .624 r
F P
0 g
s
.46865 .55159 m .4558 .55639 L .45629 .55833 L p .895 .703 .635 r
F P
0 g
s
.23895 .81604 m .24336 .81951 L .31818 .77307 L p .758 .793 .881 r
F P
0 g
s
.52903 .4752 m .51998 .49433 L .52538 .49758 L p .567 .475 .71 r
F P
0 g
s
.51998 .49433 m .52903 .4752 L .52337 .47003 L p .592 .485 .701 r
F P
0 g
s
.45821 .28509 m .47908 .27962 L .46109 .22129 L p .664 .635 .811 r
F P
0 g
s
.46109 .22129 m .43411 .2283 L .45821 .28509 L p .664 .635 .811 r
F P
0 g
s
.46581 .61626 m .46411 .61459 L .45526 .63262 L p .906 .775 .706 r
F P
0 g
s
.45526 .63262 m .45684 .63419 L .46581 .61626 L p .906 .775 .706 r
F P
0 g
s
.45845 .63575 m .45684 .63419 L .46581 .61626 L p .903 .772 .706 r
F P
0 g
s
.45513 .5541 m .46742 .54815 L .46219 .53959 L p .875 .651 .595 r
F P
0 g
s
.46742 .54815 m .45513 .5541 L .4558 .55639 L p .889 .687 .624 r
F P
0 g
s
.58975 .43417 m .60486 .43279 L .60247 .42931 L p .707 .335 .341 r
F P
0 g
s
.60247 .42931 m .58683 .43073 L .58975 .43417 L p .707 .335 .341 r
F P
0 g
s
.44045 .51903 m .44031 .51695 L .42585 .5144 L p .762 .497 .533 r
F P
0 g
s
.6038 .59542 m .5948 .5798 L .59673 .58647 L p .873 .491 .015 r
F P
0 g
s
.59673 .58647 m .60494 .60092 L .6038 .59542 L p .873 .491 .015 r
F P
0 g
s
.46888 .57746 m .45765 .5744 L .45601 .58791 L p .931 .776 .668 r
F P
0 g
s
.45601 .58791 m .46506 .5932 L .46888 .57746 L p .931 .776 .668 r
F P
0 g
s
.40994 .51292 m .41001 .51229 L .42546 .51442 L p .747 .41 .412 r
F P
0 g
s
.42546 .51442 m .42531 .51562 L .40994 .51292 L p .747 .41 .412 r
F P
0 g
s
.52337 .47003 m .5359 .4547 L .5307 .44815 L p .586 .44 .65 r
F P
0 g
s
.54623 .43597 m .5307 .44815 L .5359 .4547 L p .59 .41 .605 r
F P
0 g
s
.55574 .53519 m .55352 .52936 L .54928 .52368 L p 0 .116 .665 r
F P
0 g
s
.55352 .52936 m .55574 .53519 L .56621 .54437 L p 0 0 .487 r
F P
0 g
s
.73511 .4731 m .74136 .49152 L .70925 .49152 L p .597 .683 .902 r
F P
0 g
s
.70925 .49152 m .70392 .47521 L .73511 .4731 L p .597 .683 .902 r
F P
0 g
s
.42585 .5144 m .42615 .51568 L .44045 .51903 L p .762 .497 .533 r
F P
0 g
s
.43996 .52379 m .44045 .51903 L .42615 .51568 L p .76 .424 .417 r
F P
0 g
s
.44045 .51903 m .43996 .52379 L .45226 .53072 L p .775 .516 .543 r
F P
0 g
s
.5359 .4547 m .52337 .47003 L .52903 .4752 L p .558 .414 .642 r
F P
0 g
s
.45253 .5477 m .46219 .53959 L .45226 .53072 L p .845 .588 .55 r
F P
0 g
s
.46219 .53959 m .45253 .5477 L .45513 .5541 L p .875 .651 .595 r
F P
0 g
s
.76056 .75446 m .73356 .78301 L .68595 .74678 L p .544 .604 .864 r
F P
0 g
s
.73356 .78301 m .76056 .75446 L .84401 .7918 L p .569 .645 .886 r
F P
0 g
s
.64583 .45058 m .6563 .45999 L .64457 .45685 L p .226 .58 .944 r
F P
0 g
s
.64457 .45685 m .63467 .44839 L .64583 .45058 L p .226 .58 .944 r
F P
0 g
s
.56767 .433 m .58424 .42679 L .58299 .42453 L p .668 .396 .5 r
F P
0 g
s
.58299 .42453 m .56595 .43063 L .56767 .433 L p .668 .396 .5 r
F P
0 g
s
.46411 .61459 m .45916 .61003 L .45075 .62816 L p .912 .786 .708 r
F P
0 g
s
.45075 .62816 m .45526 .63262 L .46411 .61459 L p .912 .786 .708 r
F P
0 g
s
.31173 .50052 m .30999 .50645 L .34312 .50895 L p .556 .791 .987 r
F P
0 g
s
.34312 .50895 m .34474 .50478 L .31173 .50052 L p .556 .791 .987 r
F P
0 g
s
.37178 .50645 m .3706 .50788 L .39153 .50997 L p .083 .622 .855 r
F P
0 g
s
.63344 .69528 m .64397 .67865 L .66831 .69898 L p .471 .498 .804 r
F P
0 g
s
.66831 .69898 m .65426 .718 L .63344 .69528 L p .471 .498 .804 r
F P
0 g
s
.53109 .4765 m .52538 .49758 L .53167 .49857 L p .513 .426 .694 r
F P
0 g
s
.52538 .49758 m .53109 .4765 L .52903 .4752 L p .567 .475 .71 r
F P
0 g
s
.55 .44101 m .56595 .43063 L .56322 .42622 L p .624 .406 .565 r
F P
0 g
s
.56322 .42622 m .54623 .43597 L .55 .44101 L p .624 .406 .565 r
F P
0 g
s
.58251 .5606 m .57038 .54867 L .57633 .5577 L p .839 .387 0 r
F P
0 g
s
.57633 .5577 m .58418 .5664 L .58251 .5606 L p .839 .387 0 r
F P
0 g
s
.5359 .4547 m .55 .44101 L .54623 .43597 L p .59 .41 .605 r
F P
0 g
s
.42615 .51568 m .42585 .5144 L .41046 .5117 L p .747 .41 .412 r
F P
0 g
s
.59415 .43792 m .60862 .43688 L .60486 .43279 L p .659 .231 .219 r
F P
0 g
s
.60486 .43279 m .58975 .43417 L .59415 .43792 L p .659 .231 .219 r
F P
0 g
s
.39251 .50986 m .39259 .50968 L .41001 .51229 L p .682 .228 .168 r
F P
0 g
s
.41001 .51229 m .40994 .51292 L .39251 .50986 L p .682 .228 .168 r
F P
0 g
s
.56825 .43374 m .58467 .4275 L .58424 .42679 L p .661 .38 .483 r
F P
0 g
s
.58424 .42679 m .56767 .433 L .56825 .43374 L p .661 .38 .483 r
F P
0 g
s
.46506 .5932 m .45601 .58791 L .45167 .60377 L p .933 .793 .682 r
F P
0 g
s
.45167 .60377 m .45916 .61003 L .46506 .5932 L p .933 .793 .682 r
F P
0 g
s
.61859 .64933 m .61929 .63381 L .63007 .6463 L p .184 .279 .728 r
F P
0 g
s
.63007 .6463 m .62828 .66225 L .61859 .64933 L p .184 .279 .728 r
F P
0 g
s
.45684 .63419 m .45845 .63575 L .44643 .65584 L p .88 .767 .733 r
F P
0 g
s
.45145 .66035 m .44643 .65584 L .45845 .63575 L p .881 .767 .732 r
F P
0 g
s
.44691 .53885 m .45226 .53072 L .43996 .52379 L p .818 .52 .485 r
F P
0 g
s
.45226 .53072 m .44691 .53885 L .45253 .5477 L p .845 .588 .55 r
F P
0 g
s
.56896 .4346 m .58518 .42836 L .58467 .4275 L p .656 .367 .471 r
F P
0 g
s
.58467 .4275 m .56825 .43374 L .56896 .4346 L p .656 .367 .471 r
F P
0 g
s
.44643 .65584 m .45145 .66035 L .43514 .68353 L p .859 .773 .765 r
F P
0 g
s
.41046 .5117 m .41086 .51241 L .42615 .51568 L p .747 .41 .412 r
F P
0 g
s
.42651 .51827 m .42615 .51568 L .41086 .51241 L p .694 .239 .167 r
F P
0 g
s
.42615 .51568 m .42651 .51827 L .43996 .52379 L p .76 .424 .417 r
F P
0 g
s
.31818 .77307 m .31494 .77039 L .23895 .81604 L p .758 .793 .881 r
F P
0 g
s
.22675 .80546 m .23895 .81604 L .31494 .77039 L p .759 .798 .885 r
F P
0 g
s
.57113 .43698 m .58683 .43073 L .58518 .42836 L p .644 .344 .448 r
F P
0 g
s
.58518 .42836 m .56896 .4346 L .57113 .43698 L p .644 .344 .448 r
F P
0 g
s
.6268 .44472 m .61415 .4408 L .62205 .44361 L p .269 0 0 r
F P
0 g
s
.47908 .27962 m .50852 .27473 L .49931 .21518 L p .678 .643 .808 r
F P
0 g
s
.49931 .21518 m .46109 .22129 L .47908 .27962 L p .678 .643 .808 r
F P
0 g
s
.52903 .4752 m .53935 .45792 L .5359 .4547 L p .558 .414 .642 r
F P
0 g
s
.55 .44101 m .5359 .4547 L .53935 .45792 L p .564 .375 .584 r
F P
0 g
s
.55235 .44361 m .56767 .433 L .56595 .43063 L p .605 .373 .537 r
F P
0 g
s
.56595 .43063 m .55 .44101 L .55235 .44361 L p .605 .373 .537 r
F P
0 g
s
.53935 .45792 m .52903 .4752 L .53109 .4765 L p .531 .388 .632 r
F P
0 g
s
.45684 .63419 m .45526 .63262 L .44322 .65274 L p .896 .794 .74 r
F P
0 g
s
.44322 .65274 m .44475 .65424 L .45684 .63419 L p .896 .794 .74 r
F P
0 g
s
.44643 .65584 m .44475 .65424 L .45684 .63419 L p .88 .767 .733 r
F P
0 g
s
.34605 .50226 m .34474 .50478 L .3706 .50788 L p .416 .77 .996 r
F P
0 g
s
.3706 .50788 m .37178 .50645 L .34605 .50226 L p .416 .77 .996 r
F P
0 g
s
.41086 .51241 m .41046 .5117 L .39302 .50863 L p .682 .227 .167 r
F P
0 g
s
.65426 .718 m .66831 .69898 L .7051 .72392 L p .512 .555 .837 r
F P
0 g
s
.7051 .72392 m .68595 .74678 L .65426 .718 L p .512 .555 .837 r
F P
0 g
s
.53935 .45792 m .55235 .44361 L .55 .44101 L p .564 .375 .584 r
F P
0 g
s
.43802 .52984 m .43996 .52379 L .42651 .51827 L p .79 .422 .36 r
F P
0 g
s
.43996 .52379 m .43802 .52984 L .44691 .53885 L p .818 .52 .485 r
F P
0 g
s
.69474 .46015 m .70392 .47521 L .68057 .47469 L p .534 .673 .927 r
F P
0 g
s
.68057 .47469 m .67258 .46135 L .69474 .46015 L p .534 .673 .927 r
F P
0 g
s
.5948 .5798 m .58418 .5664 L .58829 .5752 L p .856 .432 0 r
F P
0 g
s
.58829 .5752 m .59673 .58647 L .5948 .5798 L p .856 .432 0 r
F P
0 g
s
.57481 .44023 m .58975 .43417 L .58683 .43073 L p .617 .289 .393 r
F P
0 g
s
.58683 .43073 m .57113 .43698 L .57481 .44023 L p .617 .289 .393 r
F P
0 g
s
.68595 .74678 m .7051 .72392 L .76056 .75446 L p .544 .604 .864 r
F P
0 g
s
.54345 .49949 m .541 .49422 L .5378 .49571 L p .379 .412 .77 r
F P
0 g
s
.5394 .49917 m .54345 .49949 L .5378 .49571 L .379 .412 .77 r
F
.54545 .50345 m .54273 .49869 L .54088 .50238 L p .339 .408 .786 r
F P
0 g
s
.54088 .50238 m .53718 .50975 L p .54244 .50574 L .339 .408 .786 r
F P
0 g
s
.54244 .50574 m .54545 .50345 L .54088 .50238 L .339 .408 .786 r
F
.5378 .49571 m .53167 .49857 L p .5394 .49917 L .379 .412 .77 r
F P
0 g
s
.53356 .47771 m .53167 .49857 L .541 .49422 L p .378 .311 .654 r
F P
0 g
s
.53167 .49857 m .53356 .47771 L .53109 .4765 L p .513 .426 .694 r
F P
0 g
s
.26889 .49465 m .267 .5026 L .30999 .50645 L p .606 .778 .963 r
F P
0 g
s
.30999 .50645 m .31173 .50052 L .26889 .49465 L p .606 .778 .963 r
F P
0 g
s
.54541 .27265 m .58702 .27611 L .60191 .21886 L p .715 .672 .807 r
F P
0 g
s
.65661 .23448 m .60191 .21886 L .58702 .27611 L p .736 .694 .81 r
F P
0 g
s
.54052 .45883 m .53109 .4765 L .53356 .47771 L p .511 .367 .621 r
F P
0 g
s
.53109 .4765 m .54052 .45883 L .53935 .45792 L p .531 .388 .632 r
F P
0 g
s
.55315 .4444 m .56825 .43374 L .56767 .433 L p .595 .354 .521 r
F P
0 g
s
.56767 .433 m .55235 .44361 L .55315 .4444 L p .595 .354 .521 r
F P
0 g
s
.40797 .23752 m .39335 .24394 L .34189 .17104 L p .649 .65 .838 r
F P
0 g
s
.31236 .18771 m .34189 .17104 L .39335 .24394 L p .641 .647 .841 r
F P
0 g
s
.39356 .50892 m .39302 .50863 L .37233 .505 L p .394 0 0 r
F P
0 g
s
.39356 .50892 m .37288 .50486 L p .37477 .50519 L .073 .607 .861 r
F P
0 g
s
.39302 .50863 m .39356 .50892 L p .40621 .51143 L .682 .227 .167 r
F P
0 g
s
.39464 .50862 m .39356 .50892 L p .37477 .50519 L .073 .607 .861 r
F P
0 g
s
.39356 .50892 m .41086 .51241 L p .40621 .51143 L .682 .227 .167 r
F P
0 g
s
.41169 .51339 m .41086 .51241 L .39356 .50892 L p .437 0 0 r
F P
0 g
s
.41086 .51241 m .41169 .51339 L .42651 .51827 L p .694 .239 .167 r
F P
0 g
s
.40582 .70561 m .41224 .71079 L .37941 .74347 L p .81 .781 .826 r
F P
0 g
s
.37941 .74347 m .37148 .73736 L .40582 .70561 L p .81 .781 .826 r
F P
0 g
s
.61306 .624 m .60847 .6088 L .61545 .61908 L p 0 .001 .576 r
F P
0 g
s
.61545 .61908 m .61929 .63381 L .61306 .624 L p 0 .001 .576 r
F P
0 g
s
.45526 .63262 m .45075 .62816 L .43878 .64814 L p .897 .793 .738 r
F P
0 g
s
.43878 .64814 m .44322 .65274 L .45526 .63262 L p .897 .793 .738 r
F P
0 g
s
.55412 .4453 m .56896 .4346 L .56825 .43374 L p .587 .341 .51 r
F P
0 g
s
.56825 .43374 m .55315 .4444 L .55412 .4453 L p .587 .341 .51 r
F P
0 g
s
.43514 .68353 m .42967 .67879 L .44643 .65584 L p .859 .773 .765 r
F P
0 g
s
.42967 .67879 m .43514 .68353 L .41224 .71079 L p .836 .778 .796 r
F P
0 g
s
.60022 .44109 m .61415 .4408 L .60862 .43688 L p .545 .032 0 r
F P
0 g
s
.60862 .43688 m .59415 .43792 L .60022 .44109 L p .545 .032 0 r
F P
0 g
s
.57038 .54867 m .56621 .54437 L .57383 .55494 L p .698 .219 0 r
F P
0 g
s
.57383 .55494 m .57633 .5577 L .57038 .54867 L p .698 .219 0 r
F P
0 g
s
.55235 .44361 m .53935 .45792 L .54052 .45883 L p .547 .352 .568 r
F P
0 g
s
.45916 .61003 m .45167 .60377 L .44409 .62139 L p .926 .807 .708 r
F P
0 g
s
.44409 .62139 m .45075 .62816 L .45916 .61003 L p .926 .807 .708 r
F P
0 g
s
.53718 .50975 m .54601 .51661 L .54545 .50345 L p .339 .408 .786 r
F P
0 g
s
.59452 .58597 m .60139 .59564 L .59673 .58647 L p .738 .304 0 r
F P
0 g
s
.60139 .59564 m .59452 .58597 L .59879 .59178 L p 0 0 .428 r
F P
0 g
s
.60486 .60079 m .59673 .58647 L .60139 .59564 L p .705 .317 0 r
F P
0 g
s
.59879 .59178 m .60336 .598 L p .60139 .59564 L 0 0 .428 r
F P
0 g
s
.60494 .60092 m .60486 .60079 L p .60139 .59564 L .705 .317 0 r
F P
0 g
s
.77667 .46775 m .78375 .48924 L .74136 .49152 L p .621 .709 .909 r
F P
0 g
s
.74136 .49152 m .73511 .4731 L .77667 .46775 L p .621 .709 .909 r
F P
0 g
s
.55702 .44767 m .57113 .43698 L .56896 .4346 L p .57 .313 .487 r
F P
0 g
s
.56896 .4346 m .55412 .4453 L .55702 .44767 L p .57 .313 .487 r
F P
0 g
s
.54052 .45883 m .55315 .4444 L .55235 .44361 L p .547 .352 .568 r
F P
0 g
s
.42658 .52184 m .42651 .51827 L .41169 .51339 L p .709 .226 .097 r
F P
0 g
s
.42651 .51827 m .42658 .52184 L .43802 .52984 L p .79 .422 .36 r
F P
0 g
s
.541 .49422 m .54026 .47914 L .53356 .47771 L p .378 .311 .654 r
F P
0 g
s
.54194 .45984 m .53356 .47771 L .54026 .47914 L p .458 .308 .59 r
F P
0 g
s
.53356 .47771 m .54194 .45984 L .54052 .45883 L p .511 .367 .621 r
F P
0 g
s
.55315 .4444 m .54052 .45883 L .54194 .45984 L p .537 .339 .559 r
F P
0 g
s
.36901 .7352 m .37148 .73736 L .3214 .77574 L p .786 .793 .858 r
F P
0 g
s
.3214 .77574 m .31818 .77307 L .36901 .7352 L p .786 .793 .858 r
F P
0 g
s
.44475 .65424 m .44643 .65584 L .42967 .67879 L p .868 .786 .768 r
F P
0 g
s
.54194 .45984 m .55412 .4453 L .55315 .4444 L p .537 .339 .559 r
F P
0 g
s
.41224 .71079 m .40582 .70561 L .42967 .67879 L p .836 .778 .796 r
F P
0 g
s
.50852 .27473 m .54541 .27265 L .54749 .21324 L p .695 .655 .806 r
F P
0 g
s
.54749 .21324 m .49931 .21518 L .50852 .27473 L p .695 .655 .806 r
F P
0 g
s
.66122 .45046 m .67258 .46135 L .6563 .45999 L p .413 .673 .968 r
F P
0 g
s
.6563 .45999 m .64583 .45058 L .66122 .45046 L p .413 .673 .968 r
F P
0 g
s
.58002 .44337 m .59415 .43792 L .58975 .43417 L p .557 .179 .281 r
F P
0 g
s
.58975 .43417 m .57481 .44023 L .58002 .44337 L p .557 .179 .281 r
F P
0 g
s
.54612 .46212 m .55702 .44767 L .55412 .4453 L p .508 .301 .534 r
F P
0 g
s
.55412 .4453 m .54194 .45984 L .54612 .46212 L p .508 .301 .534 r
F P
0 g
s
.54026 .47914 m .54612 .46212 L .54194 .45984 L p .458 .308 .59 r
F P
0 g
s
.31317 .49686 m .31173 .50052 L .34474 .50478 L p .546 .782 .986 r
F P
0 g
s
.34474 .50478 m .34605 .50226 L .31317 .49686 L p .546 .782 .986 r
F P
0 g
s
.37233 .505 m .37288 .50486 L .39356 .50892 L p .394 0 0 r
F P
0 g
s
.39356 .50892 m .39464 .50862 L .41169 .51339 L p .437 0 0 r
F P
0 g
s
.34615 .50171 m .34605 .50226 L .37178 .50645 L p .21 .689 .934 r
F P
0 g
s
.37178 .50645 m .37183 .50623 L .34615 .50171 L p .21 .689 .934 r
F P
0 g
s
.56178 .45049 m .57481 .44023 L .57113 .43698 L p .528 .247 .431 r
F P
0 g
s
.57113 .43698 m .55702 .44767 L .56178 .45049 L p .528 .247 .431 r
F P
0 g
s
.60191 .21886 m .54749 .21324 L .54541 .27265 L p .715 .672 .807 r
F P
0 g
s
.44475 .65424 m .44322 .65274 L .42619 .67553 L p .868 .786 .768 r
F P
0 g
s
.42619 .67553 m .42793 .67716 L .44475 .65424 L p .868 .786 .768 r
F P
0 g
s
.42967 .67879 m .42793 .67716 L .44475 .65424 L p .868 .786 .768 r
F P
0 g
s
.41291 .51472 m .41169 .51339 L .39464 .50862 L p .417 0 0 r
F P
0 g
s
.41169 .51339 m .41291 .51472 L .42658 .52184 L p .709 .226 .097 r
F P
0 g
s
.44673 .55983 m .45629 .55833 L .4558 .55639 L p .948 .709 .544 r
F P
0 g
s
.45629 .55833 m .44673 .55983 L .4474 .56437 L p .952 .729 .563 r
F P
0 g
s
.4474 .56437 m .4573 .56431 L .45629 .55833 L p .952 .729 .563 r
F P
0 g
s
.56621 .54437 m .56325 .54073 L p .5631 .54068 L 0 0 .487 r
F P
0 g
s
.56325 .54073 m .56621 .54437 L .57383 .55494 L p .683 .21 0 r
F P
0 g
s
.57383 .55494 m .57157 .55241 L .56325 .54073 L p .683 .21 0 r
F P
0 g
s
.56325 .54073 m .57157 .55241 L p .56361 .54086 L .79 .351 0 r
F P
0 g
s
.55541 .52711 m .55352 .52936 L .56325 .54073 L p .685 .287 0 r
F P
0 g
s
.56325 .54073 m .55976 .53527 L .55541 .52711 L p .685 .287 0 r
F P
0 g
s
.55976 .53527 m .56325 .54073 L p .56361 .54086 L .79 .351 0 r
F P
0 g
s
.56325 .54073 m .55352 .52936 L p .5631 .54068 L 0 0 .487 r
F P
0 g
s
.44644 .55835 m .4558 .55639 L .45513 .5541 L p .946 .699 .534 r
F P
0 g
s
.4558 .55639 m .44644 .55835 L .44673 .55983 L p .948 .709 .544 r
F P
0 g
s
.55409 .52425 m .54928 .52368 L .55352 .52936 L p 0 0 .541 r
F P
0 g
s
.55541 .52711 m .55976 .53527 L p .5593 .53462 L .848 .476 0 r
F P
0 g
s
.55352 .52936 m .55541 .52711 L p .55406 .52449 L 0 0 .541 r
F P
0 g
s
.55395 .52712 m .55541 .52711 L p .5593 .53462 L .848 .476 0 r
F P
0 g
s
.55541 .52711 m .55409 .52425 L p .55406 .52449 L 0 0 .541 r
F P
0 g
s
.44604 .55659 m .45513 .5541 L .45253 .5477 L p .938 .672 .506 r
F P
0 g
s
.45513 .5541 m .44604 .55659 L .44644 .55835 L p .946 .699 .534 r
F P
0 g
s
.4573 .56431 m .4474 .56437 L .44778 .57212 L p .959 .759 .591 r
F P
0 g
s
.44778 .57212 m .45765 .5744 L .4573 .56431 L p .959 .759 .591 r
F P
0 g
s
.62828 .66225 m .63007 .6463 L .64728 .66158 L p .304 .395 .791 r
F P
0 g
s
.64728 .66158 m .64397 .67865 L .62828 .66225 L p .304 .395 .791 r
F P
0 g
s
.55268 .5208 m .54601 .51661 L .54928 .52368 L p 0 .053 .615 r
F P
0 g
s
.54928 .52368 m .55409 .52425 L .55268 .5208 L p 0 .053 .615 r
F P
0 g
s
.44455 .55148 m .45253 .5477 L .44691 .53885 L p .919 .614 .452 r
F P
0 g
s
.45253 .5477 m .44455 .55148 L .44604 .55659 L p .938 .672 .506 r
F P
0 g
s
.63282 .44451 m .64583 .45058 L .63467 .44839 L p .139 .624 .917 r
F P
0 g
s
.63467 .44839 m .62205 .44361 L .63282 .44451 L p .139 .624 .917 r
F P
0 g
s
.21222 .48668 m .21033 .49703 L .267 .5026 L p .63 .767 .945 r
F P
0 g
s
.267 .5026 m .26889 .49465 L .21222 .48668 L p .63 .767 .945 r
F P
0 g
s
.31494 .77039 m .31818 .77307 L .36901 .7352 L p .786 .793 .858 r
F P
0 g
s
.45765 .5744 m .44778 .57212 L .44689 .58311 L p .962 .792 .625 r
F P
0 g
s
.44689 .58311 m .45601 .58791 L .45765 .5744 L p .962 .792 .625 r
F P
0 g
s
.58418 .5664 m .57633 .5577 L .58262 .56852 L p .798 .346 0 r
F P
0 g
s
.58262 .56852 m .58829 .5752 L .58418 .5664 L p .798 .346 0 r
F P
0 g
s
.44322 .65274 m .43878 .64814 L .42145 .67066 L p .874 .8 .774 r
F P
0 g
s
.42145 .67066 m .42619 .67553 L .44322 .65274 L p .874 .8 .774 r
F P
0 g
s
.41314 .23554 m .40797 .23752 L .36158 .16196 L p .653 .652 .836 r
F P
0 g
s
.34189 .17104 m .36158 .16196 L .40797 .23752 L p .649 .65 .838 r
F P
0 g
s
.44123 .54369 m .44691 .53885 L .43802 .52984 L p .884 .526 .363 r
F P
0 g
s
.44691 .53885 m .44123 .54369 L .44455 .55148 L p .919 .614 .452 r
F P
0 g
s
.45075 .62816 m .44409 .62139 L .43233 .6409 L p .91 .816 .743 r
F P
0 g
s
.43233 .6409 m .43878 .64814 L .45075 .62816 L p .91 .816 .743 r
F P
0 g
s
.37288 .50486 m .37233 .505 L .34663 .50048 L p .21 .689 .934 r
F P
0 g
s
.5524 .46378 m .56178 .45049 L .55702 .44767 L p .437 .21 .47 r
F P
0 g
s
.55702 .44767 m .54612 .46212 L .5524 .46378 L p .437 .21 .47 r
F P
0 g
s
.42793 .67716 m .42967 .67879 L .40582 .70561 L p .842 .79 .801 r
F P
0 g
s
.60818 .4427 m .62205 .44361 L .61415 .4408 L p .273 0 0 r
F P
0 g
s
.61415 .4408 m .60022 .44109 L .60818 .4427 L p .273 0 0 r
F P
0 g
s
.54995 .51128 m .54545 .50345 L .54601 .51661 L p 0 .096 .634 r
F P
0 g
s
.54601 .51661 m .55268 .5208 L .54995 .51128 L p 0 .096 .634 r
F P
0 g
s
.54799 .47745 m .5524 .46378 L .54612 .46212 L p .328 .174 .515 r
F P
0 g
s
.54612 .46212 m .54026 .47914 L .54799 .47745 L p .328 .174 .515 r
F P
0 g
s
.7666 .19859 m .70206 .16083 L .65661 .23448 L p .739 .727 .841 r
F P
0 g
s
.34663 .50048 m .34723 .50002 L .37288 .50486 L p .21 .689 .934 r
F P
0 g
s
.37421 .50343 m .37288 .50486 L .34723 .50002 L p .409 .76 .995 r
F P
0 g
s
.37288 .50486 m .37421 .50343 L .39464 .50862 L p .073 .607 .861 r
F P
0 g
s
.45601 .58791 m .44689 .58311 L .44362 .59695 L p .96 .82 .661 r
F P
0 g
s
.44362 .59695 m .45167 .60377 L .45601 .58791 L p .96 .82 .661 r
F P
0 g
s
.60191 .21886 m .65661 .23448 L .70206 .16083 L p .723 .705 .833 r
F P
0 g
s
.43529 .53442 m .43802 .52984 L .42658 .52184 L p .829 .396 .208 r
F P
0 g
s
.43802 .52984 m .43529 .53442 L .44123 .54369 L p .884 .526 .363 r
F P
0 g
s
.56796 .45238 m .58002 .44337 L .57481 .44023 L p .439 .113 .315 r
F P
0 g
s
.57481 .44023 m .56178 .45049 L .56796 .45238 L p .439 .113 .315 r
F P
0 g
s
.40382 .70379 m .40582 .70561 L .37148 .73736 L p .814 .792 .832 r
F P
0 g
s
.37148 .73736 m .36901 .7352 L .40382 .70379 L p .814 .792 .832 r
F P
0 g
s
.39667 .50803 m .39464 .50862 L .37421 .50343 L p .099 .609 .892 r
F P
0 g
s
.39464 .50862 m .39667 .50803 L .41291 .51472 L p .417 0 0 r
F P
0 g
s
.41314 .23554 m .41831 .23355 L .37553 .15634 L p .655 .653 .836 r
F P
0 g
s
.36158 .16196 m .3685 .15909 L .38642 .1898 L p .653 .652 .836 r
F P
0 g
s
.37553 .15634 m .38642 .1898 L .41313 .23554 L .655 .653 .836 r
F
.38642 .1898 m .41314 .23554 L p .41313 .23554 L .653 .652 .836 r
F P
0 g
s
.36158 .16196 m .38642 .1898 L .41313 .23554 L .653 .652 .836 r
F
.37553 .15634 m .3685 .15909 L .38642 .1898 L p .655 .653 .836 r
F P
0 g
s
.38642 .1898 m .41314 .23554 L p .41313 .23554 L .655 .653 .836 r
F P
0 g
s
.58668 .44527 m .60022 .44109 L .59415 .43792 L p .425 0 .06 r
F P
0 g
s
.59415 .43792 m .58002 .44337 L .58668 .44527 L p .425 0 .06 r
F P
0 g
s
.54742 .48696 m .54799 .47745 L .54026 .47914 L p .218 .168 .585 r
F P
0 g
s
.54026 .47914 m .541 .49422 L .54742 .48696 L p .218 .168 .585 r
F P
0 g
s
.42793 .67716 m .42619 .67553 L .40182 .70196 L p .842 .79 .801 r
F P
0 g
s
.40182 .70196 m .40382 .70379 L .42793 .67716 L p .842 .79 .801 r
F P
0 g
s
.40582 .70561 m .40382 .70379 L .42793 .67716 L p .842 .79 .801 r
F P
0 g
s
.31334 .49595 m .31317 .49686 L .34605 .50226 L p .472 .776 .997 r
F P
0 g
s
.34605 .50226 m .34615 .50171 L .31334 .49595 L p .472 .776 .997 r
F P
0 g
s
.72455 .45559 m .73511 .4731 L .70392 .47521 L p .582 .703 .926 r
F P
0 g
s
.70392 .47521 m .69474 .46015 L .72455 .45559 L p .582 .703 .926 r
F P
0 g
s
.27047 .48979 m .26889 .49465 L .31173 .50052 L p .601 .773 .963 r
F P
0 g
s
.31173 .50052 m .31317 .49686 L .27047 .48979 L p .601 .773 .963 r
F P
0 g
s
.36901 .7352 m .36654 .73304 L .31494 .77039 L p .786 .793 .858 r
F P
0 g
s
.30617 .76219 m .31494 .77039 L .36654 .73304 L p .788 .801 .863 r
F P
0 g
s
.31494 .77039 m .30617 .76219 L .22675 .80546 L p .759 .798 .885 r
F P
0 g
s
.59673 .58647 m .58829 .5752 L .59452 .58597 L p .738 .304 0 r
F P
0 g
s
.8323 .45836 m .84029 .48416 L .78375 .48924 L p .636 .726 .913 r
F P
0 g
s
.78375 .48924 m .77667 .46775 L .8323 .45836 L p .636 .726 .913 r
F P
0 g
s
.61929 .63381 m .61545 .61908 L .62707 .63155 L p 0 .21 .723 r
F P
0 g
s
.62707 .63155 m .63007 .6463 L .61929 .63381 L p 0 .21 .723 r
F P
0 g
s
.42658 .52184 m .41291 .51472 L p .4205 .52043 L .692 .153 0 r
F P
0 g
s
.42645 .5249 m .4265 .52376 L p .4205 .52043 L .692 .153 0 r
F P
0 g
s
.4265 .52376 m .42658 .52184 L p .4205 .52043 L .692 .153 0 r
F P
0 g
s
.41291 .51472 m .41467 .51574 L .42645 .5249 L p .692 .153 0 r
F P
0 g
s
.41467 .51574 m .41291 .51472 L .39667 .50803 L p .32 0 0 r
F P
0 g
s
.39975 .5069 m .41467 .51574 L p .40316 .51081 L .32 0 0 r
F P
0 g
s
.39667 .50803 m .39756 .5077 L p .40316 .51081 L .32 0 0 r
F P
0 g
s
.39756 .5077 m .39975 .5069 L p .40316 .51081 L .32 0 0 r
F P
0 g
s
.42658 .52184 m .42645 .5249 L .43529 .53442 L p .829 .396 .208 r
F P
0 g
s
.41831 .23355 m .43411 .2283 L .39695 .14892 L p .659 .654 .834 r
F P
0 g
s
.39695 .14892 m .37553 .15634 L .41831 .23355 L p .659 .654 .834 r
F P
0 g
s
.54822 .49001 m .54742 .48696 L .54262 .49239 L p .27 .282 .688 r
F P
0 g
s
.54282 .49316 m .54822 .49001 L .54262 .49239 L .27 .282 .688 r
F
.541 .49422 m .54345 .49949 L .54822 .49001 L p F P
0 g
s
.54828 .49233 m .54751 .48919 L .54375 .49667 L p .227 .261 .689 r
F P
0 g
s
.54375 .49667 m .54273 .49869 L p .54392 .49733 L .227 .261 .689 r
F P
0 g
s
.54392 .49733 m .54828 .49233 L .54375 .49667 L .227 .261 .689 r
F
.54262 .49239 m .541 .49422 L p .54282 .49316 L .27 .282 .688 r
F P
0 g
s
.42619 .67553 m .42145 .67066 L .39643 .69638 L p .848 .803 .807 r
F P
0 g
s
.39643 .69638 m .40182 .70196 L .42619 .67553 L p .848 .803 .807 r
F P
0 g
s
.36654 .73304 m .36901 .7352 L .40382 .70379 L p .814 .792 .832 r
F P
0 g
s
.60847 .6088 m .60139 .59564 L .60934 .60681 L p 0 0 .495 r
F P
0 g
s
.60934 .60681 m .61545 .61908 L .60847 .6088 L p 0 0 .495 r
F P
0 g
s
.40382 .70379 m .40182 .70196 L .36654 .73304 L p .814 .792 .832 r
F P
0 g
s
.45167 .60377 m .44362 .59695 L .43691 .61314 L p .949 .841 .702 r
F P
0 g
s
.43691 .61314 m .44409 .62139 L .45167 .60377 L p .949 .841 .702 r
F P
0 g
s
.34723 .50002 m .34663 .50048 L .3138 .49471 L p .473 .776 .997 r
F P
0 g
s
.20956 .78721 m .22675 .80546 L .30617 .76219 L p .761 .809 .891 r
F P
0 g
s
.55943 .4632 m .56796 .45238 L .56178 .45049 L p .295 .033 .336 r
F P
0 g
s
.56178 .45049 m .5524 .46378 L .55943 .4632 L p .295 .033 .336 r
F P
0 g
s
.43878 .64814 m .43233 .6409 L .41477 .66263 L p .886 .823 .781 r
F P
0 g
s
.41477 .66263 m .42145 .67066 L .43878 .64814 L p .886 .823 .781 r
F P
0 g
s
.34723 .50002 m .34881 .49752 L .37421 .50343 L p .409 .76 .995 r
F P
0 g
s
.37684 .50113 m .37421 .50343 L .34881 .49752 L p .407 .746 .993 r
F P
0 g
s
.37421 .50343 m .37684 .50113 L .39667 .50803 L p .099 .609 .892 r
F P
0 g
s
.57633 .5577 m .57383 .55494 L .58074 .5664 L p .759 .296 0 r
F P
0 g
s
.58074 .5664 m .58262 .56852 L .57633 .5577 L p .759 .296 0 r
F P
0 g
s
.68195 .44725 m .69474 .46015 L .67258 .46135 L p .518 .714 .961 r
F P
0 g
s
.67258 .46135 m .66122 .45046 L .68195 .44725 L p .518 .714 .961 r
F P
0 g
s
.3138 .49471 m .31448 .49388 L .34723 .50002 L p .473 .776 .997 r
F P
0 g
s
.34881 .49752 m .34723 .50002 L .31448 .49388 L p .541 .776 .985 r
F P
0 g
s
.54273 .49869 m .54545 .50345 L .54828 .49233 L p .227 .261 .689 r
F P
0 g
s
.64397 .67865 m .64728 .66158 L .67367 .67969 L p .39 .483 .834 r
F P
0 g
s
.67367 .67969 m .66831 .69898 L .64397 .67865 L p .39 .483 .834 r
F P
0 g
s
.40182 .70196 m .39643 .69638 L .35991 .72643 L p .819 .804 .837 r
F P
0 g
s
.35991 .72643 m .36654 .73304 L .40182 .70196 L p .819 .804 .837 r
F P
0 g
s
.36654 .73304 m .35991 .72643 L .30617 .76219 L p .788 .801 .863 r
F P
0 g
s
.57505 .45227 m .58668 .44527 L .58002 .44337 L p .259 0 .078 r
F P
0 g
s
.58002 .44337 m .56796 .45238 L .57505 .45227 L p .259 0 .078 r
F P
0 g
s
.55473 .47295 m .55943 .4632 L .5524 .46378 L p .123 0 .36 r
F P
0 g
s
.5524 .46378 m .54799 .47745 L .55473 .47295 L p .123 0 .36 r
F P
0 g
s
.64715 .44264 m .66122 .45046 L .64583 .45058 L p .398 .739 .992 r
F P
0 g
s
.64583 .45058 m .63282 .44451 L .64715 .44264 L p .398 .739 .992 r
F P
0 g
s
.27072 .48846 m .27047 .48979 L .31317 .49686 L p .576 .776 .974 r
F P
0 g
s
.31317 .49686 m .31334 .49595 L .27072 .48846 L p .576 .776 .974 r
F P
0 g
s
.43411 .2283 m .46109 .22129 L .43364 .13909 L p .666 .658 .832 r
F P
0 g
s
.43364 .13909 m .39695 .14892 L .43411 .2283 L p .666 .658 .832 r
F P
0 g
s
.57157 .55241 m .57383 .55494 L .58074 .5664 L p .763 .298 0 r
F P
0 g
s
.59466 .44509 m .60818 .4427 L .60022 .44109 L p .139 0 0 r
F P
0 g
s
.60022 .44109 m .58668 .44527 L .59466 .44509 L p .139 0 0 r
F P
0 g
s
.61849 .44187 m .63282 .44451 L .62205 .44361 L p .152 .686 .848 r
F P
0 g
s
.62205 .44361 m .60818 .4427 L .61849 .44187 L p .152 .686 .848 r
F P
0 g
s
.39975 .5069 m .39667 .50803 L .37684 .50113 L p .151 .611 .929 r
F P
0 g
s
.54904 .49926 m .54828 .49233 L .54545 .50345 L p 0 0 .537 r
F P
0 g
s
.54545 .50345 m .54995 .51128 L .54904 .49926 L p 0 0 .537 r
F P
0 g
s
.44409 .62139 m .43691 .61314 L .42561 .63135 L p .929 .854 .747 r
F P
0 g
s
.42561 .63135 m .43233 .6409 L .44409 .62139 L p .929 .854 .747 r
F P
0 g
s
.21394 .48035 m .21222 .48668 L .26889 .49465 L p .627 .765 .945 r
F P
0 g
s
.26889 .49465 m .27047 .48979 L .21394 .48035 L p .627 .765 .945 r
F P
0 g
s
.42145 .67066 m .41477 .66263 L .38881 .68712 L p .856 .823 .815 r
F P
0 g
s
.38881 .68712 m .39643 .69638 L .42145 .67066 L p .856 .823 .815 r
F P
0 g
s
.58829 .5752 m .58262 .56852 L .58989 .58035 L p .736 .279 0 r
F P
0 g
s
.58989 .58035 m .59452 .58597 L .58829 .5752 L p .736 .279 0 r
F P
0 g
s
.55267 .47913 m .55473 .47295 L .54799 .47745 L p .002 0 .398 r
F P
0 g
s
.54799 .47745 m .54742 .48696 L .55267 .47913 L p .002 0 .398 r
F P
0 g
s
.31448 .49388 m .3138 .49471 L .27115 .48721 L p .576 .776 .974 r
F P
0 g
s
.31448 .49388 m .31633 .49026 L .34881 .49752 L p .541 .776 .985 r
F P
0 g
s
.35188 .49349 m .34881 .49752 L .31633 .49026 L p .536 .766 .982 r
F P
0 g
s
.34881 .49752 m .35188 .49349 L .37684 .50113 L p .407 .746 .993 r
F P
0 g
s
.57157 .55241 m .56647 .54671 L .55976 .53527 L p .79 .351 0 r
F P
0 g
s
.56647 .54671 m .57157 .55241 L .5789 .5644 L p .805 .351 0 r
F P
0 g
s
.58074 .5664 m .5789 .5644 L .57157 .55241 L p .763 .298 0 r
F P
0 g
s
.43991 .55173 m .44455 .55148 L .44123 .54369 L p .951 .601 .23 r
F P
0 g
s
.44455 .55148 m .43991 .55173 L .44078 .55607 L p .976 .672 .316 r
F P
0 g
s
.44078 .55607 m .44604 .55659 L .44455 .55148 L p .976 .672 .316 r
F P
0 g
s
.43786 .54485 m .44123 .54369 L .43529 .53442 L p .892 .474 .081 r
F P
0 g
s
.44123 .54369 m .43786 .54485 L .43991 .55173 L p .951 .601 .23 r
F P
0 g
s
.44604 .55659 m .44078 .55607 L .44101 .55754 L p .984 .703 .354 r
F P
0 g
s
.44101 .55754 m .44644 .55835 L .44604 .55659 L p .984 .703 .354 r
F P
0 g
s
.44644 .55835 m .44101 .55754 L .44117 .55877 L p .988 .718 .375 r
F P
0 g
s
.44117 .55877 m .44673 .55983 L .44644 .55835 L p .988 .718 .375 r
F P
0 g
s
.56078 .46673 m .56642 .46012 L .56571 .46043 L p 0 0 .025 r
F P
0 g
s
.56571 .46043 m .55943 .4632 L p .56078 .46673 L 0 0 .025 r
F P
0 g
s
.55762 .47084 m .56078 .46673 L .55646 .47118 L p 0 0 0 r
F P
0 g
s
.55646 .47118 m .55473 .47295 L p .55762 .47084 L 0 0 0 r
F P
0 g
s
.55762 .47084 m .55722 .47215 L .55792 .47075 L p 0 0 0 r
F P
0 g
s
.56078 .46673 m .55762 .47084 L .55775 .47061 L p .731 .915 .553 r
F P
0 g
s
.56796 .45238 m .55943 .4632 L .56642 .46012 L p .037 0 .057 r
F P
0 g
s
.55943 .4632 m .55473 .47295 L .56078 .46673 L p 0 0 .025 r
F P
0 g
s
.55775 .47061 m .56276 .46171 L p .56078 .46673 L .731 .915 .553 r
F P
0 g
s
.56204 .46257 m .56276 .46171 L .55762 .47084 L p 0 0 0 r
F P
0 g
s
.55792 .47075 m .56204 .46257 L p .55762 .47084 L 0 0 0 r
F P
0 g
s
.56642 .46012 m .56078 .46673 L .56141 .46592 L p .595 .853 .501 r
F P
0 g
s
.57316 .4523 m .56796 .45238 L p .56642 .46012 L .037 0 .057 r
F P
0 g
s
.56141 .46592 m .56678 .45902 L p .56642 .46012 L .595 .853 .501 r
F P
0 g
s
.56642 .46012 m .57505 .45227 L .57316 .4523 L p .037 0 .057 r
F P
0 g
s
.44673 .55983 m .44117 .55877 L .4415 .56251 L p .992 .74 .407 r
F P
0 g
s
.4415 .56251 m .4474 .56437 L .44673 .55983 L p .992 .74 .407 r
F P
0 g
s
.7643 .44688 m .77667 .46775 L .73511 .4731 L p .613 .722 .924 r
F P
0 g
s
.73511 .4731 m .72455 .45559 L .7643 .44688 L p .613 .722 .924 r
F P
0 g
s
.27115 .48721 m .27191 .48597 L .31448 .49388 L p .576 .776 .974 r
F P
0 g
s
.31633 .49026 m .31448 .49388 L .27191 .48597 L p .598 .77 .962 r
F P
0 g
s
.4474 .56437 m .4415 .56251 L .44159 .56889 L p .998 .779 .463 r
F P
0 g
s
.44159 .56889 m .44778 .57212 L .4474 .56437 L p .998 .779 .463 r
F P
0 g
s
.43529 .53442 m .42645 .5249 L p .43058 .53108 L .761 .266 0 r
F P
0 g
s
.43388 .53602 m .4345 .53531 L p .43058 .53108 L .761 .266 0 r
F P
0 g
s
.4345 .53531 m .43529 .53442 L p .43058 .53108 L .761 .266 0 r
F P
0 g
s
.42727 .52601 m .43388 .53602 L p .43102 .53174 L .761 .266 0 r
F P
0 g
s
.42645 .5249 m .42727 .52601 L p .43102 .53174 L .761 .266 0 r
F P
0 g
s
.42727 .52601 m .42645 .5249 L .42574 .52435 L p .49 0 0 r
F P
0 g
s
.42574 .52435 m .41467 .51574 L p .42727 .52601 L .49 0 0 r
F P
0 g
s
.42727 .52601 m .41765 .51556 L p .42279 .51916 L 0 .312 .803 r
F P
0 g
s
.43067 .52469 m .42727 .52601 L p .42279 .51916 L 0 .312 .803 r
F P
0 g
s
.41765 .51556 m .42727 .52601 L p .42159 .52138 L .49 0 0 r
F P
0 g
s
.41467 .51574 m .41627 .51564 L p .42159 .52138 L .49 0 0 r
F P
0 g
s
.41627 .51564 m .41765 .51556 L p .42159 .52138 L .49 0 0 r
F P
0 g
s
.43388 .53602 m .42727 .52601 L p .42978 .52862 L 0 .079 .638 r
F P
0 g
s
.43529 .53442 m .43388 .53602 L p .43714 .54191 L .892 .474 .081 r
F P
0 g
s
.43561 .53467 m .43388 .53602 L p .42978 .52862 L 0 .079 .638 r
F P
0 g
s
.43388 .53602 m .43786 .54485 L p .43714 .54191 L .892 .474 .081 r
F P
0 g
s
.29402 .74818 m .30617 .76219 L .35991 .72643 L p .792 .816 .871 r
F P
0 g
s
.30617 .76219 m .29402 .74818 L .20956 .78721 L p .761 .809 .891 r
F P
0 g
s
.38092 .49784 m .37684 .50113 L .35188 .49349 L p .416 .726 .989 r
F P
0 g
s
.37684 .50113 m .38092 .49784 L .39975 .5069 L p .151 .611 .929 r
F P
0 g
s
.44778 .57212 m .44159 .56889 L .44069 .57798 L p .999 .823 .53 r
F P
0 g
s
.44069 .57798 m .44689 .58311 L .44778 .57212 L p .999 .823 .53 r
F P
0 g
s
.63007 .6463 m .62707 .63155 L .64516 .64606 L p .175 .361 .809 r
F P
0 g
s
.64516 .64606 m .64728 .66158 L .63007 .6463 L p .175 .361 .809 r
F P
0 g
s
.39643 .69638 m .38881 .68712 L .35062 .71533 L p .825 .822 .846 r
F P
0 g
s
.35062 .71533 m .35991 .72643 L .39643 .69638 L p .825 .822 .846 r
F P
0 g
s
.60336 .598 m .60934 .60681 L .60139 .59564 L p 0 0 .428 r
F P
0 g
s
.66831 .69898 m .67367 .67969 L .71358 .70094 L p .453 .55 .865 r
F P
0 g
s
.71358 .70094 m .7051 .72392 L .66831 .69898 L p .453 .55 .865 r
F P
0 g
s
.55271 .48109 m .55267 .47913 L .54742 .48696 L p .115 .096 .557 r
F P
0 g
s
.54742 .48696 m .54822 .49001 L .55271 .48109 L p .115 .096 .557 r
F P
0 g
s
.43233 .6409 m .42561 .63135 L .40797 .65168 L p .901 .859 .79 r
F P
0 g
s
.40797 .65168 m .41477 .66263 L .43233 .6409 L p .901 .859 .79 r
F P
0 g
s
.46109 .22129 m .49931 .21518 L .48601 .13066 L p .678 .665 .83 r
F P
0 g
s
.48601 .13066 m .43364 .13909 L .46109 .22129 L p .678 .665 .83 r
F P
0 g
s
.44689 .58311 m .44069 .57798 L .43779 .58975 L p .992 .864 .603 r
F P
0 g
s
.43779 .58975 m .44362 .59695 L .44689 .58311 L p .992 .864 .603 r
F P
0 g
s
.35991 .72643 m .35062 .71533 L .29402 .74818 L p .792 .816 .871 r
F P
0 g
s
.61545 .61908 m .60934 .60681 L .62162 .61955 L p 0 .142 .687 r
F P
0 g
s
.62162 .61955 m .62707 .63155 L .61545 .61908 L p 0 .142 .687 r
F P
0 g
s
.58287 .44963 m .59466 .44509 L .58668 .44527 L p 0 0 0 r
F P
0 g
s
.58668 .44527 m .57505 .45227 L .58287 .44963 L p 0 0 0 r
F P
0 g
s
.21426 .47855 m .21394 .48035 L .27047 .48979 L p .618 .767 .951 r
F P
0 g
s
.27047 .48979 m .27072 .48846 L .21426 .47855 L p .618 .767 .951 r
F P
0 g
s
.41765 .51556 m .41467 .51574 L .39975 .5069 L p 0 .404 .82 r
F P
0 g
s
.54749 .21324 m .60191 .21886 L .62714 .13751 L p .707 .688 .829 r
F P
0 g
s
.70206 .16083 m .62714 .13751 L .60191 .21886 L p .723 .705 .833 r
F P
0 g
s
.55323 .52523 m .55409 .52425 L .55541 .52711 L p .796 .447 0 r
F P
0 g
s
.55541 .52711 m .55395 .52712 L .55323 .52523 L p .796 .447 0 r
F P
0 g
s
.5524 .52294 m .55268 .5208 L .55409 .52425 L p .782 .445 0 r
F P
0 g
s
.55409 .52425 m .55323 .52523 L .5524 .52294 L p .782 .445 0 r
F P
0 g
s
.58262 .56852 m .58074 .5664 L .58828 .57855 L p .74 .274 0 r
F P
0 g
s
.58828 .57855 m .58989 .58035 L .58262 .56852 L p .74 .274 0 r
F P
0 g
s
.55031 .51624 m .54995 .51128 L .55268 .5208 L p .772 .463 0 r
F P
0 g
s
.55268 .5208 m .5524 .52294 L .55031 .51624 L p .772 .463 0 r
F P
0 g
s
.55192 .48247 m .552 .48027 L .54751 .48919 L p .066 .065 .545 r
F P
0 g
s
.54751 .48919 m .54828 .49233 L .55192 .48247 L p .066 .065 .545 r
F P
0 g
s
.70975 .44003 m .72455 .45559 L .69474 .46015 L p .578 .732 .948 r
F P
0 g
s
.69474 .46015 m .68195 .44725 L .70975 .44003 L p .578 .732 .948 r
F P
0 g
s
.55976 .53527 m .55632 .53279 L .55395 .52712 L p .848 .476 0 r
F P
0 g
s
.55632 .53279 m .55976 .53527 L .56647 .54671 L p .886 .487 .046 r
F P
0 g
s
.60434 .44214 m .61849 .44187 L .60818 .4427 L p .278 .782 .81 r
F P
0 g
s
.60818 .4427 m .59466 .44509 L .60434 .44214 L p .278 .782 .81 r
F P
0 g
s
.27191 .48597 m .27403 .48114 L .31633 .49026 L p .598 .77 .962 r
F P
0 g
s
.31991 .48449 m .31633 .49026 L .27403 .48114 L p .595 .765 .961 r
F P
0 g
s
.31633 .49026 m .31991 .48449 L .35188 .49349 L p .536 .766 .982 r
F P
0 g
s
.44362 .59695 m .43779 .58975 L .43168 .60395 L p .976 .894 .675 r
F P
0 g
s
.43168 .60395 m .43691 .61314 L .44362 .59695 L p .976 .894 .675 r
F P
0 g
s
.55035 .48768 m .55192 .48247 L .54828 .49233 L p 0 0 .239 r
F P
0 g
s
.54828 .49233 m .54904 .49926 L .55035 .48768 L p 0 0 .239 r
F P
0 g
s
.63178 .4379 m .64715 .44264 L .63282 .44451 L p .439 .815 .992 r
F P
0 g
s
.63282 .44451 m .61849 .44187 L .63178 .4379 L p .439 .815 .992 r
F P
0 g
s
.66631 .43715 m .68195 .44725 L .66122 .45046 L p .526 .766 .985 r
F P
0 g
s
.66122 .45046 m .64715 .44264 L .66631 .43715 L p .526 .766 .985 r
F P
0 g
s
.5789 .5644 m .58074 .5664 L .58828 .57855 L p .748 .28 0 r
F P
0 g
s
.40451 .50481 m .39975 .5069 L .38092 .49784 L p .252 .617 .957 r
F P
0 g
s
.39975 .5069 m .40451 .50481 L .41765 .51556 L p 0 .404 .82 r
F P
0 g
s
.27191 .48597 m .27115 .48721 L .21466 .47728 L p .618 .767 .951 r
F P
0 g
s
.35698 .48803 m .35188 .49349 L .31991 .48449 L p .535 .752 .976 r
F P
0 g
s
.35188 .49349 m .35698 .48803 L .38092 .49784 L p .416 .726 .989 r
F P
0 g
s
.54818 .50606 m .54904 .49926 L .54995 .51128 L p .77 .516 0 r
F P
0 g
s
.54995 .51128 m .55031 .51624 L .54818 .50606 L p .77 .516 0 r
F P
0 g
s
.41477 .66263 m .40797 .65168 L .38138 .67424 L p .867 .858 .83 r
F P
0 g
s
.38138 .67424 m .38881 .68712 L .41477 .66263 L p .867 .858 .83 r
F P
0 g
s
.49931 .21518 m .54749 .21324 L .55217 .12858 L p .691 .674 .829 r
F P
0 g
s
.55217 .12858 m .48601 .13066 L .49931 .21518 L p .691 .674 .829 r
F P
0 g
s
.7051 .72392 m .71358 .70094 L .77366 .72546 L p .502 .604 .888 r
F P
0 g
s
.77366 .72546 m .76056 .75446 L .7051 .72392 L p .502 .604 .888 r
F P
0 g
s
.21466 .47728 m .2155 .47556 L .27191 .48597 L p .618 .767 .951 r
F P
0 g
s
.27403 .48114 m .27191 .48597 L .2155 .47556 L p .626 .763 .945 r
F P
0 g
s
.55473 .47295 m .55267 .47913 L .55762 .47084 L p 0 0 0 r
F P
0 g
s
.57349 .45474 m .58287 .44963 L .57505 .45227 L p 0 0 0 r
F P
0 g
s
.57505 .45227 m .56642 .46012 L .57349 .45474 L p 0 0 0 r
F P
0 g
s
.5789 .5644 m .57387 .55921 L .56647 .54671 L p .805 .351 0 r
F P
0 g
s
.57387 .55921 m .5789 .5644 L .58668 .5768 L p .779 .31 0 r
F P
0 g
s
.58828 .57855 m .58668 .5768 L .5789 .5644 L p .748 .28 0 r
F P
0 g
s
.56647 .54671 m .5606 .54183 L .55632 .53279 L p .886 .487 .046 r
F P
0 g
s
.5606 .54183 m .56647 .54671 L .57387 .55921 L p .876 .447 .043 r
F P
0 g
s
.62714 .13751 m .55217 .12858 L .54749 .21324 L p .707 .688 .829 r
F P
0 g
s
.59452 .58597 m .58989 .58035 L .59919 .59288 L p .613 .148 0 r
F P
0 g
s
.59771 .59122 m .59919 .59288 L .59906 .5927 L p .645 .166 0 r
F P
0 g
s
.59906 .5927 m .58989 .58035 L p .59771 .59122 L .645 .166 0 r
F P
0 g
s
.60213 .59633 m .59452 .58597 L p .59919 .59288 L .613 .148 0 r
F P
0 g
s
.58989 .58035 m .58828 .57855 L .59771 .59122 L p .645 .166 0 r
F P
0 g
s
.58668 .5768 m .58828 .57855 L .59771 .59122 L p .656 .174 0 r
F P
0 g
s
.5962 .58957 m .58668 .5768 L p .59719 .59054 L .656 .174 0 r
F P
0 g
s
.59771 .59122 m .5962 .58957 L p .59719 .59054 L .656 .174 0 r
F P
0 g
s
.59771 .59122 m .61053 .60419 L p .59638 .58976 L .525 .021 0 r
F P
0 g
s
.5962 .58957 m .59771 .59122 L p .59638 .58976 L .525 .021 0 r
F P
0 g
s
.5962 .58957 m .60895 .60264 L p .59343 .58687 L .523 .02 0 r
F P
0 g
s
.59158 .58499 m .5962 .58957 L p .59343 .58687 L .523 .02 0 r
F P
0 g
s
.59919 .59288 m .59771 .59122 L .59819 .59171 L p 0 .042 .574 r
F P
0 g
s
.59819 .59171 m .61053 .60419 L p .59919 .59288 L 0 .042 .574 r
F P
0 g
s
.59919 .59288 m .60336 .598 L .60213 .59633 L p .613 .148 0 r
F P
0 g
s
.43691 .61314 m .43168 .60395 L .42094 .62024 L p .95 .911 .743 r
F P
0 g
s
.42094 .62024 m .42561 .63135 L .43691 .61314 L p .95 .911 .743 r
F P
0 g
s
.86483 .7537 m .84401 .7918 L .76056 .75446 L p .539 .648 .905 r
F P
0 g
s
.3872 .49358 m .38092 .49784 L .35698 .48803 L p .441 .703 .977 r
F P
0 g
s
.38092 .49784 m .3872 .49358 L .40451 .50481 L p .252 .617 .957 r
F P
0 g
s
.55762 .47084 m .55267 .47913 L p .55636 .47346 L 0 0 .327 r
F P
0 g
s
.55267 .47913 m .55271 .48109 L .55722 .47215 L p 0 0 .327 r
F P
0 g
s
.55595 .47291 m .5565 .47132 L .55299 .47829 L p 0 0 .298 r
F P
0 g
s
.55299 .47829 m .552 .48027 L p .5529 .47858 L 0 0 .298 r
F P
0 g
s
.5529 .47858 m .55595 .47291 L .55299 .47829 L 0 0 .298 r
F
.55192 .48247 m .55035 .48768 L .5511 .48454 L p .75 .761 .252 r
F P
0 g
s
.552 .48027 m .55192 .48247 L .55595 .47291 L p 0 0 .298 r
F P
0 g
s
.5511 .48454 m .55296 .47667 L p .5522 .48091 L .75 .761 .252 r
F P
0 g
s
.55192 .48247 m .5511 .48454 L .5522 .48091 L .75 .761 .252 r
F
.55296 .47667 m .55595 .47291 L .55255 .48098 L p F P
0 g
s
.55255 .48098 m .55192 .48247 L p .55199 .48208 L .75 .761 .252 r
F P
0 g
s
.55199 .48208 m .55296 .47667 L .55255 .48098 L .75 .761 .252 r
F
.55722 .47215 m .55751 .47121 L p .55636 .47346 L 0 0 .327 r
F P
0 g
s
.55751 .47121 m .55762 .47084 L p .55636 .47346 L 0 0 .327 r
F P
0 g
s
.76056 .75446 m .77366 .72546 L .86483 .7537 L p .539 .648 .905 r
F P
0 g
s
.81785 .43282 m .8323 .45836 L .77667 .46775 L p .632 .735 .922 r
F P
0 g
s
.77667 .46775 m .7643 .44688 L .81785 .43282 L p .632 .735 .922 r
F P
0 g
s
.64728 .66158 m .64516 .64606 L .67244 .66231 L p .302 .47 .86 r
F P
0 g
s
.67244 .66231 m .67367 .67969 L .64728 .66158 L p .302 .47 .86 r
F P
0 g
s
.54729 .49422 m .55035 .48768 L .54904 .49926 L p .867 .688 .16 r
F P
0 g
s
.54904 .49926 m .54818 .50606 L .54729 .49422 L p .867 .688 .16 r
F P
0 g
s
.59162 .44425 m .60434 .44214 L .59466 .44509 L p .474 .893 .814 r
F P
0 g
s
.59466 .44509 m .58287 .44963 L .59162 .44425 L p .474 .893 .814 r
F P
0 g
s
.38881 .68712 m .38138 .67424 L .34158 .69945 L p .831 .847 .859 r
F P
0 g
s
.34158 .69945 m .35062 .71533 L .38881 .68712 L p .831 .847 .859 r
F P
0 g
s
.43388 .53602 m .43561 .53467 L .43839 .54299 L p 0 0 .442 r
F P
0 g
s
.43839 .54299 m .43786 .54485 L .43388 .53602 L p 0 0 .442 r
F P
0 g
s
.43786 .54485 m .43839 .54299 L .43971 .54921 L p 0 0 .265 r
F P
0 g
s
.43971 .54921 m .43991 .55173 L .43786 .54485 L p 0 0 .265 r
F P
0 g
s
.60934 .60681 m .60336 .598 L .61597 .61094 L p 0 .084 .629 r
F P
0 g
s
.61597 .61094 m .62162 .61955 L .60934 .60681 L p 0 .084 .629 r
F P
0 g
s
.42727 .52601 m .43067 .52469 L .43561 .53467 L p 0 .079 .638 r
F P
0 g
s
.43991 .55173 m .43971 .54921 L .4402 .55303 L p 0 0 .142 r
F P
0 g
s
.4402 .55303 m .44078 .55607 L .43991 .55173 L p 0 0 .142 r
F P
0 g
s
.56678 .45902 m .57349 .45474 L .56642 .46012 L p .595 .853 .501 r
F P
0 g
s
.44078 .55607 m .4402 .55304 L p .4403 .55431 L .724 .502 0 r
F P
0 g
s
.4403 .55431 m .44101 .55754 L .44078 .55607 L p .724 .502 0 r
F P
0 g
s
.44101 .55754 m .4403 .55433 L p .44037 .55537 L .744 .533 0 r
F P
0 g
s
.4403 .55433 m .4403 .55431 L .44037 .55537 L p .744 .533 0 r
F P
0 g
s
.44037 .55537 m .44117 .55877 L .44101 .55754 L p .744 .533 0 r
F P
0 g
s
.44117 .55877 m .44041 .55554 L p .44049 .55862 L .778 .58 .011 r
F P
0 g
s
.44041 .55554 m .44037 .55537 L .44049 .55862 L p .778 .58 .011 r
F P
0 g
s
.44049 .55862 m .4415 .56251 L .44117 .55877 L p .778 .58 .011 r
F P
0 g
s
.4415 .56251 m .44049 .55862 L .44033 .56409 L p .829 .663 .118 r
F P
0 g
s
.44474 .55803 m .44063 .56367 L p .44049 .55862 L 0 0 .35 r
F P
0 g
s
.44063 .56367 m .44033 .56409 L .44049 .55862 L p 0 0 .35 r
F P
0 g
s
.44499 .55319 m .44057 .55852 L p .44037 .55537 L 0 0 .431 r
F P
0 g
s
.44057 .55852 m .44049 .55862 L .44037 .55537 L p 0 0 .431 r
F P
0 g
s
.44494 .55026 m .44038 .55536 L p .4403 .55431 L 0 0 .464 r
F P
0 g
s
.44038 .55536 m .44037 .55537 L .4403 .55431 L p 0 0 .464 r
F P
0 g
s
.4402 .55304 m .4402 .55303 L .4403 .55431 L p .724 .502 0 r
F P
0 g
s
.27403 .48114 m .27818 .47334 L .31991 .48449 L p .595 .765 .961 r
F P
0 g
s
.32597 .47676 m .31991 .48449 L .27818 .47334 L p .592 .756 .957 r
F P
0 g
s
.31991 .48449 m .32597 .47676 L .35698 .48803 L p .535 .752 .976 r
F P
0 g
s
.2155 .47556 m .2179 .46926 L .27403 .48114 L p .626 .763 .945 r
F P
0 g
s
.27818 .47334 m .27403 .48114 L .2179 .46926 L p .624 .76 .944 r
F P
0 g
s
.62707 .63155 m .62162 .61955 L .64 .63345 L p .041 .323 .807 r
F P
0 g
s
.64 .63345 m .64516 .64606 L .62707 .63155 L p .041 .323 .807 r
F P
0 g
s
.44033 .56409 m .44159 .56889 L .4415 .56251 L p .829 .663 .118 r
F P
0 g
s
.42561 .63135 m .42094 .62024 L .40364 .63833 L p .916 .912 .801 r
F P
0 g
s
.40364 .63833 m .40797 .65168 L .42561 .63135 L p .916 .912 .801 r
F P
0 g
s
.42291 .51351 m .41765 .51556 L .40451 .50481 L p .199 .498 .905 r
F P
0 g
s
.41765 .51556 m .42291 .51351 L .43067 .52469 L p 0 .312 .803 r
F P
0 g
s
.61631 .43586 m .63178 .4379 L .61849 .44187 L p .53 .886 .98 r
F P
0 g
s
.61849 .44187 m .60434 .44214 L .61631 .43586 L p .53 .886 .98 r
F P
0 g
s
.57387 .55921 m .56666 .55318 L .5606 .54183 L p .876 .447 .043 r
F P
0 g
s
.56666 .55318 m .57387 .55921 L .58192 .57204 L p .835 .375 0 r
F P
0 g
s
.58668 .5768 m .58192 .57204 L .57387 .55921 L p .779 .31 0 r
F P
0 g
s
.19229 .76078 m .20956 .78721 L .29402 .74818 L p .761 .825 .902 r
F P
0 g
s
.44159 .56889 m .44033 .56409 L .43929 .57185 L p .883 .763 .261 r
F P
0 g
s
.43929 .57185 m .44069 .57798 L .44159 .56889 L p .883 .763 .261 r
F P
0 g
s
.35062 .71533 m .34158 .69945 L .28207 .72804 L p .795 .837 .884 r
F P
0 g
s
.28207 .72804 m .29402 .74818 L .35062 .71533 L p .795 .837 .884 r
F P
0 g
s
.36472 .4814 m .35698 .48803 L .32597 .47676 L p .539 .734 .965 r
F P
0 g
s
.35698 .48803 m .36472 .4814 L .3872 .49358 L p .441 .703 .977 r
F P
0 g
s
.74701 .42774 m .7643 .44688 L .72455 .45559 L p .612 .742 .937 r
F P
0 g
s
.72455 .45559 m .70975 .44003 L .74701 .42774 L p .612 .742 .937 r
F P
0 g
s
.44069 .57798 m .43929 .57185 L .43652 .58189 L p .923 .858 .419 r
F P
0 g
s
.43652 .58189 m .43779 .58975 L .44069 .57798 L p .923 .858 .419 r
F P
0 g
s
.64893 .43004 m .66631 .43715 L .64715 .44264 L p .561 .819 .994 r
F P
0 g
s
.64715 .44264 m .63178 .4379 L .64893 .43004 L p .561 .819 .994 r
F P
0 g
s
.41166 .50137 m .40451 .50481 L .3872 .49358 L p .369 .616 .946 r
F P
0 g
s
.40451 .50481 m .41166 .50137 L .42291 .51351 L p .199 .498 .905 r
F P
0 g
s
.56276 .46171 m .56678 .45902 L .56078 .46673 L p .731 .915 .553 r
F P
0 g
s
.29402 .74818 m .28207 .72804 L .19229 .76078 L p .761 .825 .902 r
F P
0 g
s
.58111 .44704 m .59162 .44425 L .58287 .44963 L p .656 .97 .831 r
F P
0 g
s
.58287 .44963 m .57349 .45474 L .58111 .44704 L p .656 .97 .831 r
F P
0 g
s
.69168 .42713 m .70975 .44003 L .68195 .44725 L p .588 .767 .964 r
F P
0 g
s
.68195 .44725 m .66631 .43715 L .69168 .42713 L p .588 .767 .964 r
F P
0 g
s
.58192 .57204 m .58668 .5768 L .5962 .58957 L p .691 .2 0 r
F P
0 g
s
.54794 .482 m .55296 .47667 L .55035 .48768 L p .965 .873 .479 r
F P
0 g
s
.55035 .48768 m .54729 .49422 L .54794 .482 L p .965 .873 .479 r
F P
0 g
s
.5469 .52427 m .5524 .52294 L .55323 .52523 L p .968 .645 .318 r
F P
0 g
s
.55323 .52523 m .5475 .52601 L .5469 .52427 L p .968 .645 .318 r
F P
0 g
s
.5475 .52601 m .55323 .52523 L .55395 .52712 L p .963 .632 .304 r
F P
0 g
s
.54528 .5191 m .55031 .51624 L .5524 .52294 L p .975 .668 .342 r
F P
0 g
s
.5524 .52294 m .5469 .52427 L .54528 .5191 L p .975 .668 .342 r
F P
0 g
s
.55395 .52712 m .54801 .52744 L .5475 .52601 L p .963 .632 .304 r
F P
0 g
s
.54801 .52744 m .55395 .52712 L .55632 .53279 L p .957 .614 .29 r
F P
0 g
s
.43779 .58975 m .43652 .58189 L .4309 .59403 L p .941 .93 .574 r
F P
0 g
s
.4309 .59403 m .43168 .60395 L .43779 .58975 L p .941 .93 .574 r
F P
0 g
s
.54313 .51075 m .54818 .50606 L .55031 .51624 L p .987 .715 .395 r
F P
0 g
s
.55031 .51624 m .54528 .5191 L .54313 .51075 L p .987 .715 .395 r
F P
0 g
s
.55632 .53279 m .54965 .53176 L .54801 .52744 L p .957 .614 .29 r
F P
0 g
s
.54965 .53176 m .55632 .53279 L .5606 .54183 L p .942 .577 .263 r
F P
0 g
s
.40797 .65168 m .40364 .63833 L .377 .65801 L p .875 .901 .846 r
F P
0 g
s
.377 .65801 m .38138 .67424 L .40797 .65168 L p .875 .901 .846 r
F P
0 g
s
.60336 .598 m .59919 .59288 L .61193 .60594 L p 0 .04 .57 r
F P
0 g
s
.61193 .60594 m .61597 .61094 L .60336 .598 L p 0 .04 .57 r
F P
0 g
s
.39625 .48821 m .3872 .49358 L .36472 .4814 L p .484 .681 .953 r
F P
0 g
s
.3872 .49358 m .39625 .48821 L .41166 .50137 L p .369 .616 .946 r
F P
0 g
s
.5606 .54183 m .55266 .53884 L .54965 .53176 L p .942 .577 .263 r
F P
0 g
s
.55266 .53884 m .5606 .54183 L .56666 .55318 L p .917 .522 .219 r
F P
0 g
s
.54127 .49994 m .54729 .49422 L .54818 .50606 L p .996 .78 .491 r
F P
0 g
s
.54818 .50606 m .54313 .51075 L .54127 .49994 L p .996 .78 .491 r
F P
0 g
s
.56045 .46288 m .56132 .46173 L .5565 .47132 L p 0 0 0 r
F P
0 g
s
.5565 .47132 m .55595 .47291 L .56045 .46288 L p 0 0 0 r
F P
0 g
s
.67367 .67969 m .67244 .66231 L .71348 .67999 L p .395 .549 .89 r
F P
0 g
s
.71348 .67999 m .71358 .70094 L .67367 .67969 L p .395 .549 .89 r
F P
0 g
s
.60213 .43568 m .61631 .43586 L .60434 .44214 L p .637 .936 .966 r
F P
0 g
s
.60434 .44214 m .59162 .44425 L .60213 .43568 L p .637 .936 .966 r
F P
0 g
s
.55646 .4655 m .56045 .46288 L .55595 .47291 L p .903 .97 .662 r
F P
0 g
s
.55595 .47291 m .55296 .47667 L .55646 .4655 L p .903 .97 .662 r
F P
0 g
s
.57331 .44948 m .58111 .44704 L .57349 .45474 L p .774 .997 .84 r
F P
0 g
s
.57349 .45474 m .56678 .45902 L .57331 .44948 L p .774 .997 .84 r
F P
0 g
s
.2179 .46926 m .22276 .45905 L .27818 .47334 L p .624 .76 .944 r
F P
0 g
s
.28534 .46298 m .27818 .47334 L .22276 .45905 L p .622 .756 .942 r
F P
0 g
s
.27818 .47334 m .28534 .46298 L .32597 .47676 L p .592 .756 .957 r
F P
0 g
s
.43168 .60395 m .4309 .59403 L .42092 .60806 L p .933 .969 .704 r
F P
0 g
s
.42092 .60806 m .42094 .62024 L .43168 .60395 L p .933 .969 .704 r
F P
0 g
s
.58192 .57204 m .57422 .56564 L .56666 .55318 L p .835 .375 0 r
F P
0 g
s
.57422 .56564 m .58192 .57204 L .59158 .58499 L p .755 .258 0 r
F P
0 g
s
.5962 .58957 m .59158 .58499 L .58192 .57204 L p .691 .2 0 r
F P
0 g
s
.33527 .46739 m .32597 .47676 L .28534 .46298 L p .592 .745 .95 r
F P
0 g
s
.32597 .47676 m .33527 .46739 L .36472 .4814 L p .539 .734 .965 r
F P
0 g
s
.62162 .61955 m .61597 .61094 L .63435 .62439 L p 0 .288 .787 r
F P
0 g
s
.63435 .62439 m .64 .63345 L .62162 .61955 L p 0 .288 .787 r
F P
0 g
s
.44156 .53104 m .43561 .53467 L .43067 .52469 L p .207 .318 .758 r
F P
0 g
s
.43561 .53467 m .44156 .53104 L .44361 .53892 L p .113 .197 .674 r
F P
0 g
s
.44361 .53892 m .43839 .54299 L .43561 .53467 L p .113 .197 .674 r
F P
0 g
s
.43776 .52124 m .43067 .52469 L .42291 .51351 L p .304 .435 .828 r
F P
0 g
s
.43067 .52469 m .43776 .52124 L .44156 .53104 L p .207 .318 .758 r
F P
0 g
s
.54034 .48758 m .54794 .482 L .54729 .49422 L p .984 .838 .616 r
F P
0 g
s
.54729 .49422 m .54127 .49994 L .54034 .48758 L p .984 .838 .616 r
F P
0 g
s
.61053 .60419 m .62855 .61728 L p .61023 .60359 L 0 .238 .733 r
F P
0 g
s
.61053 .60419 m .60895 .60264 L .5962 .58957 L p .525 .021 0 r
F P
0 g
s
.60895 .60264 m .61053 .60419 L p .61023 .60359 L 0 .238 .733 r
F P
0 g
s
.61053 .60419 m .61193 .60594 L .61084 .60482 L p 0 .042 .574 r
F P
0 g
s
.61084 .60482 m .59919 .59288 L p .61053 .60419 L 0 .042 .574 r
F P
0 g
s
.43839 .54299 m .44361 .53892 L .44455 .54468 L p .034 .09 .59 r
F P
0 g
s
.44455 .54468 m .43971 .54921 L .43839 .54299 L p .034 .09 .59 r
F P
0 g
s
.56666 .55318 m .55726 .54831 L .55266 .53884 L p .917 .522 .219 r
F P
0 g
s
.55726 .54831 m .56666 .55318 L .57422 .56564 L p .878 .443 .134 r
F P
0 g
s
.54985 .46947 m .55646 .4655 L .55296 .47667 L p .958 .942 .711 r
F P
0 g
s
.55296 .47667 m .54794 .482 L .54985 .46947 L p .958 .942 .711 r
F P
0 g
s
.43144 .50969 m .42291 .51351 L .41166 .50137 L p .393 .534 .879 r
F P
0 g
s
.42291 .51351 m .43144 .50969 L .43776 .52124 L p .304 .435 .828 r
F P
0 g
s
.64516 .64606 m .64 .63345 L .66736 .64804 L p .217 .457 .875 r
F P
0 g
s
.66736 .64804 m .67244 .66231 L .64516 .64606 L p .217 .457 .875 r
F P
0 g
s
.43971 .54921 m .44455 .54468 L .44484 .54815 L p 0 .005 .52 r
F P
0 g
s
.44484 .54815 m .4402 .55303 L .43971 .54921 L p 0 .005 .52 r
F P
0 g
s
.63142 .42558 m .64893 .43004 L .63178 .4379 L p .616 .861 .989 r
F P
0 g
s
.63178 .4379 m .61631 .43586 L .63142 .42558 L p .616 .861 .989 r
F P
0 g
s
.56853 .45114 m .57331 .44948 L .56678 .45902 L p .827 .998 .84 r
F P
0 g
s
.56678 .45902 m .56276 .46171 L .56853 .45114 L p .827 .998 .84 r
F P
0 g
s
.38138 .67424 m .377 .65801 L .33652 .67943 L p .833 .886 .88 r
F P
0 g
s
.33652 .67943 m .34158 .69945 L .38138 .67424 L p .833 .886 .88 r
F P
0 g
s
.4402 .55303 m .44484 .54815 L .44491 .54931 L p 0 0 .474 r
F P
0 g
s
.44491 .54931 m .4403 .55431 L .4402 .55303 L p 0 0 .474 r
F P
0 g
s
.4403 .55431 m .44491 .54931 L .44494 .55026 L p 0 0 .464 r
F P
0 g
s
.44037 .55537 m .44494 .55026 L .44499 .55319 L p 0 0 .431 r
F P
0 g
s
.37576 .47368 m .36472 .4814 L .33527 .46739 L p .554 .715 .947 r
F P
0 g
s
.36472 .4814 m .37576 .47368 L .39625 .48821 L p .484 .681 .953 r
F P
0 g
s
.44049 .55862 m .44499 .55319 L .44474 .55803 L p 0 0 .35 r
F P
0 g
s
.42199 .49658 m .41166 .50137 L .39625 .48821 L p .471 .611 .908 r
F P
0 g
s
.41166 .50137 m .42199 .49658 L .43144 .50969 L p .393 .534 .879 r
F P
0 g
s
.5901 .4365 m .60213 .43568 L .59162 .44425 L p .722 .955 .948 r
F P
0 g
s
.59162 .44425 m .58111 .44704 L .5901 .4365 L p .722 .955 .948 r
F P
0 g
s
.44033 .56409 m .44474 .55803 L .44371 .56481 L p 0 0 .214 r
F P
0 g
s
.44371 .56481 m .43929 .57185 L .44033 .56409 L p 0 0 .214 r
F P
0 g
s
.42094 .62024 m .42092 .60806 L .40457 .62343 L p .905 .975 .801 r
F P
0 g
s
.40457 .62343 m .40364 .63833 L .42094 .62024 L p .905 .975 .801 r
F P
0 g
s
.56756 .45161 m .56853 .45114 L .56276 .46171 L p .78 .94 .59 r
F P
0 g
s
.56276 .46171 m .56204 .46257 L .56756 .45161 L p .78 .94 .59 r
F P
0 g
s
.67156 .41724 m .69168 .42713 L .66631 .43715 L p .612 .8 .971 r
F P
0 g
s
.66631 .43715 m .64893 .43004 L .67156 .41724 L p .612 .8 .971 r
F P
0 g
s
.79736 .40888 m .81785 .43282 L .7643 .44688 L p .632 .746 .93 r
F P
0 g
s
.7643 .44688 m .74701 .42774 L .79736 .40888 L p .632 .746 .93 r
F P
0 g
s
.43929 .57185 m .44371 .56481 L .44126 .57348 L p 0 0 .016 r
F P
0 g
s
.44126 .57348 m .43652 .58189 L .43929 .57185 L p 0 0 .016 r
F P
0 g
s
.56567 .45163 m .56684 .45076 L .56132 .46173 L p .812 .954 .615 r
F P
0 g
s
.56132 .46173 m .56045 .46288 L .56567 .45163 L p .812 .954 .615 r
F P
0 g
s
.5405 .47419 m .54985 .46947 L .54794 .482 L p .944 .866 .731 r
F P
0 g
s
.54794 .482 m .54034 .48758 L .5405 .47419 L p .944 .866 .731 r
F P
0 g
s
.56087 .4533 m .56567 .45163 L .56045 .46288 L p .88 .972 .841 r
F P
0 g
s
.56045 .46288 m .55646 .4655 L .56087 .4533 L p .88 .972 .841 r
F P
0 g
s
.7256 .41132 m .74701 .42774 L .70975 .44003 L p .62 .763 .947 r
F P
0 g
s
.70975 .44003 m .69168 .42713 L .7256 .41132 L p .62 .763 .947 r
F P
0 g
s
.53344 .51396 m .54313 .51075 L .54528 .5191 L p .929 .682 .543 r
F P
0 g
s
.54528 .5191 m .53539 .52101 L .53344 .51396 L p .929 .682 .543 r
F P
0 g
s
.53539 .52101 m .54528 .5191 L .5469 .52427 L p .925 .653 .505 r
F P
0 g
s
.5469 .52427 m .53673 .52528 L .53539 .52101 L p .925 .653 .505 r
F P
0 g
s
.53673 .52528 m .5469 .52427 L .5475 .52601 L p .922 .638 .487 r
F P
0 g
s
.57422 .56564 m .5636 .55941 L .55726 .54831 L p .878 .443 .134 r
F P
0 g
s
.5636 .55941 m .57422 .56564 L .58358 .5784 L p .812 .326 0 r
F P
0 g
s
.59158 .58499 m .58358 .5784 L .57422 .56564 L p .755 .258 0 r
F P
0 g
s
.5475 .52601 m .5372 .5267 L .53673 .52528 L p .922 .638 .487 r
F P
0 g
s
.5372 .5267 m .5475 .52601 L .54801 .52744 L p .921 .63 .476 r
F P
0 g
s
.71358 .70094 m .71348 .67999 L .77536 .69898 L p .463 .61 .911 r
F P
0 g
s
.77536 .69898 m .77366 .72546 L .71358 .70094 L p .463 .61 .911 r
F P
0 g
s
.54801 .52744 m .5376 .52788 L .5372 .5267 L p .921 .63 .476 r
F P
0 g
s
.5376 .52788 m .54801 .52744 L .54965 .53176 L p .918 .617 .457 r
F P
0 g
s
.53132 .50434 m .54127 .49994 L .54313 .51075 L p .929 .719 .599 r
F P
0 g
s
.54313 .51075 m .53344 .51396 L .53132 .50434 L p .929 .719 .599 r
F P
0 g
s
.40871 .48192 m .39625 .48821 L .37576 .47368 L p .533 .665 .921 r
F P
0 g
s
.39625 .48821 m .40871 .48192 L .42199 .49658 L p .471 .611 .908 r
F P
0 g
s
.61597 .61094 m .61193 .60594 L .63013 .61903 L p 0 .259 .758 r
F P
0 g
s
.63013 .61903 m .63435 .62439 L .61597 .61094 L p 0 .259 .758 r
F P
0 g
s
.54965 .53176 m .53887 .53139 L .5376 .52788 L p .918 .617 .457 r
F P
0 g
s
.53887 .53139 m .54965 .53176 L .55266 .53884 L p .911 .589 .422 r
F P
0 g
s
.34158 .69945 m .33652 .67943 L .27527 .70215 L p .794 .865 .902 r
F P
0 g
s
.27527 .70215 m .28207 .72804 L .34158 .69945 L p .794 .865 .902 r
F P
0 g
s
.58111 .43746 m .5901 .4365 L .58111 .44704 L p .773 .952 .933 r
F P
0 g
s
.58111 .44704 m .57331 .44948 L .58111 .43746 L p .773 .952 .933 r
F P
0 g
s
.58358 .5784 m .59158 .58499 L .60421 .59795 L p .603 .075 0 r
F P
0 g
s
.60421 .59795 m .59158 .58499 L p .60616 .5998 L .523 .02 0 r
F P
0 g
s
.60421 .59795 m .62185 .61052 L p .60119 .59508 L 0 .163 .626 r
F P
0 g
s
.59577 .59102 m .58358 .5784 L p .59787 .59194 L .603 .075 0 r
F P
0 g
s
.60421 .59795 m .59577 .59102 L p .59787 .59194 L .603 .075 0 r
F P
0 g
s
.59577 .59102 m .60421 .59795 L p .60119 .59508 L 0 .163 .626 r
F P
0 g
s
.61244 .60292 m .59577 .59102 L p .61547 .60575 L 0 .163 .626 r
F P
0 g
s
.62185 .61052 m .61244 .60292 L p .61547 .60575 L 0 .163 .626 r
F P
0 g
s
.61244 .60292 m .63621 .61319 L p .60847 .59922 L 0 .358 .763 r
F P
0 g
s
.59577 .59102 m .61244 .60292 L p .59303 .58983 L .469 0 0 r
F P
0 g
s
.59782 .59386 m .58291 .583 L p .6015 .59554 L .469 0 0 r
F P
0 g
s
.61244 .60292 m .59782 .59386 L p .6015 .59554 L .469 0 0 r
F P
0 g
s
.56523 .57554 m .58291 .583 L .59782 .59386 L p .558 0 0 r
F P
0 g
s
.57724 .58497 m .56523 .57554 L p .58283 .58543 L .558 0 0 r
F P
0 g
s
.59782 .59386 m .57724 .58497 L p .58283 .58543 L .558 0 0 r
F P
0 g
s
.57724 .58497 m .59782 .59386 L p .59337 .59182 L 0 .318 .667 r
F P
0 g
s
.5939 .59183 m .57724 .58497 L p .60166 .59534 L 0 .318 .667 r
F P
0 g
s
.61878 .6026 m .5939 .59183 L p .60166 .59534 L 0 .318 .667 r
F P
0 g
s
.58291 .583 m .59577 .59102 L p .59303 .58983 L .469 0 0 r
F P
0 g
s
.57194 .57126 m .58358 .5784 L .59577 .59102 L p .688 .149 0 r
F P
0 g
s
.59577 .59102 m .58291 .583 L .57194 .57126 L p .688 .149 0 r
F P
0 g
s
.5939 .59183 m .61797 .59405 L p .58481 .58773 L .004 .551 .83 r
F P
0 g
s
.57724 .58497 m .5939 .59183 L p .57075 .58444 L .326 0 0 r
F P
0 g
s
.56155 .58329 m .5508 .57808 L p .57332 .58527 L .326 0 0 r
F P
0 g
s
.5939 .59183 m .56155 .58329 L p .57332 .58527 L .326 0 0 r
F P
0 g
s
.5508 .57808 m .57724 .58497 L p .57075 .58444 L .326 0 0 r
F P
0 g
s
.54281 .57002 m .56523 .57554 L .57724 .58497 L p .59 .027 0 r
F P
0 g
s
.57724 .58497 m .5508 .57808 L .54281 .57002 L p .59 .027 0 r
F P
0 g
s
.51985 .57486 m .5508 .57808 L .56155 .58329 L p .326 0 0 r
F P
0 g
s
.52327 .57918 m .51985 .57486 L p .53998 .57893 L .326 0 0 r
F P
0 g
s
.56155 .58329 m .52327 .57918 L p .53998 .57893 L .326 0 0 r
F P
0 g
s
.48703 .57648 m .51985 .57486 L .52327 .57918 L p .24 0 0 r
F P
0 g
s
.52327 .57918 m .48254 .58099 L .48703 .57648 L p .24 0 0 r
F P
0 g
s
.52327 .57918 m .52711 .57791 L p .50468 .57946 L .082 .643 .757 r
F P
0 g
s
.48254 .58099 m .52327 .57918 L p .50468 .57946 L .082 .643 .757 r
F P
0 g
s
.56155 .58329 m .5765 .58318 L p .5482 .58105 L .005 .575 .774 r
F P
0 g
s
.52327 .57918 m .56155 .58329 L p .5482 .58105 L .005 .575 .774 r
F P
0 g
s
.56155 .58329 m .5939 .59183 L p .58481 .58773 L .004 .551 .83 r
F P
0 g
s
.59782 .59386 m .61878 .6026 L p .59337 .59182 L 0 .318 .667 r
F P
0 g
s
.59782 .59386 m .61244 .60292 L p .60847 .59922 L 0 .358 .763 r
F P
0 g
s
.60895 .60264 m .60421 .59795 L p .60616 .5998 L .523 .02 0 r
F P
0 g
s
.43652 .58189 m .44126 .57348 L .43637 .58394 L p 0 0 0 r
F P
0 g
s
.43637 .58394 m .4309 .59403 L .43652 .58189 L p 0 0 0 r
F P
0 g
s
.55283 .45605 m .56087 .4533 L .55646 .4655 L p .897 .928 .83 r
F P
0 g
s
.55646 .4655 m .54985 .46947 L .55283 .45605 L p .897 .928 .83 r
F P
0 g
s
.52946 .49255 m .54034 .48758 L .54127 .49994 L p .918 .756 .665 r
F P
0 g
s
.54127 .49994 m .53132 .50434 L .52946 .49255 L p .918 .756 .665 r
F P
0 g
s
.6152 .42321 m .63142 .42558 L .61631 .43586 L p .672 .885 .976 r
F P
0 g
s
.61631 .43586 m .60213 .43568 L .6152 .42321 L p .672 .885 .976 r
F P
0 g
s
.55266 .53884 m .54114 .53719 L .53887 .53139 L p .911 .589 .422 r
F P
0 g
s
.54114 .53719 m .55266 .53884 L .55726 .54831 L p .896 .543 .366 r
F P
0 g
s
.22276 .45905 m .23104 .44547 L .28534 .46298 L p .622 .756 .942 r
F P
0 g
s
.29637 .45046 m .28534 .46298 L .23104 .44547 L p .621 .749 .938 r
F P
0 g
s
.28534 .46298 m .29637 .45046 L .33527 .46739 L p .592 .745 .95 r
F P
0 g
s
.40364 .63833 m .40457 .62343 L .37893 .63964 L p .865 .957 .865 r
F P
0 g
s
.37893 .63964 m .377 .65801 L .40364 .63833 L p .865 .957 .865 r
F P
0 g
s
.44887 .5164 m .43776 .52124 L .43144 .50969 L p .475 .49 .794 r
F P
0 g
s
.43776 .52124 m .44887 .5164 L .45206 .52614 L p .437 .421 .743 r
F P
0 g
s
.45206 .52614 m .44156 .53104 L .43776 .52124 L p .437 .421 .743 r
F P
0 g
s
.44156 .53104 m .45206 .52614 L .45375 .53373 L p .399 .355 .693 r
F P
0 g
s
.45375 .53373 m .44361 .53892 L .44156 .53104 L p .399 .355 .693 r
F P
0 g
s
.34853 .45689 m .33527 .46739 L .29637 .45046 L p .597 .733 .939 r
F P
0 g
s
.33527 .46739 m .34853 .45689 L .37576 .47368 L p .554 .715 .947 r
F P
0 g
s
.44368 .50463 m .43144 .50969 L .42199 .49658 L p .515 .555 .835 r
F P
0 g
s
.43144 .50969 m .44368 .50463 L .44887 .5164 L p .475 .49 .794 r
F P
0 g
s
.57548 .43826 m .58111 .43746 L .57331 .44948 L p .797 .945 .921 r
F P
0 g
s
.57331 .44948 m .56853 .45114 L .57548 .43826 L p .797 .945 .921 r
F P
0 g
s
.44361 .53892 m .45375 .53373 L .45454 .53917 L p .365 .299 .649 r
F P
0 g
s
.45454 .53917 m .44455 .54468 L .44361 .53892 L p .365 .299 .649 r
F P
0 g
s
.61193 .60594 m .61053 .60419 L .62855 .61728 L p 0 .238 .733 r
F P
0 g
s
.62855 .61728 m .63013 .61903 L .61193 .60594 L p 0 .238 .733 r
F P
0 g
s
.55726 .54831 m .54463 .54506 L .54114 .53719 L p .896 .543 .366 r
F P
0 g
s
.54463 .54506 m .55726 .54831 L .5636 .55941 L p .87 .474 .283 r
F P
0 g
s
.52823 .47906 m .5405 .47419 L .54034 .48758 L p .893 .783 .732 r
F P
0 g
s
.54034 .48758 m .52946 .49255 L .52823 .47906 L p .893 .783 .732 r
F P
0 g
s
.64 .63345 m .63435 .62439 L .66122 .63786 L p .135 .446 .88 r
F P
0 g
s
.66122 .63786 m .66736 .64804 L .64 .63345 L p .135 .446 .88 r
F P
0 g
s
.54172 .45965 m .55283 .45605 L .54985 .46947 L p .888 .865 .811 r
F P
0 g
s
.54985 .46947 m .5405 .47419 L .54172 .45965 L p .888 .865 .811 r
F P
0 g
s
.44455 .54468 m .45454 .53917 L .45486 .54244 L p .338 .249 .605 r
F P
0 g
s
.45486 .54244 m .44484 .54815 L .44455 .54468 L p .338 .249 .605 r
F P
0 g
s
.4309 .59403 m .43637 .58394 L .42765 .59568 L p .707 .892 .514 r
F P
0 g
s
.42765 .59568 m .42092 .60806 L .4309 .59403 L p .707 .892 .514 r
F P
0 g
s
.44484 .54815 m .45486 .54244 L .45492 .54352 L p .327 .23 .59 r
F P
0 g
s
.45492 .54352 m .44491 .54931 L .44484 .54815 L p .327 .23 .59 r
F P
0 g
s
.44491 .54931 m .45492 .54352 L .45494 .5444 L p .316 .212 .574 r
F P
0 g
s
.45494 .5444 m .44494 .55026 L .44491 .54931 L p .316 .212 .574 r
F P
0 g
s
.43584 .49085 m .42199 .49658 L .40871 .48192 L p .551 .612 .867 r
F P
0 g
s
.42199 .49658 m .43584 .49085 L .44368 .50463 L p .515 .555 .835 r
F P
0 g
s
.67244 .66231 m .66736 .64804 L .70813 .66303 L p .337 .552 .913 r
F P
0 g
s
.70813 .66303 m .71348 .67999 L .67244 .66231 L p .337 .552 .913 r
F P
0 g
s
.57417 .43849 m .57548 .43826 L .56853 .45114 L p .84 .992 .853 r
F P
0 g
s
.56853 .45114 m .56756 .45161 L .57417 .43849 L p .84 .992 .853 r
F P
0 g
s
.44494 .55026 m .45494 .5444 L .455 .54707 L p .306 .2 .566 r
F P
0 g
s
.455 .54707 m .44499 .55319 L .44494 .55026 L p .306 .2 .566 r
F P
0 g
s
.39053 .46522 m .37576 .47368 L .34853 .45689 L p .578 .701 .926 r
F P
0 g
s
.37576 .47368 m .39053 .46522 L .40871 .48192 L p .533 .665 .921 r
F P
0 g
s
.28207 .72804 m .27527 .70215 L .18165 .72622 L p .758 .845 .917 r
F P
0 g
s
.18165 .72622 m .19229 .76078 L .28207 .72804 L p .758 .845 .917 r
F P
0 g
s
.44499 .55319 m .455 .54707 L .45487 .55151 L p .272 .145 .518 r
F P
0 g
s
.45487 .55151 m .44474 .55803 L .44499 .55319 L p .272 .145 .518 r
F P
0 g
s
.65118 .4102 m .67156 .41724 L .64893 .43004 L p .644 .823 .969 r
F P
0 g
s
.64893 .43004 m .63142 .42558 L .65118 .4102 L p .644 .823 .969 r
F P
0 g
s
.57197 .43817 m .57345 .43763 L .56684 .45076 L p .849 .987 .855 r
F P
0 g
s
.56684 .45076 m .56567 .45163 L .57197 .43817 L p .849 .987 .855 r
F P
0 g
s
.60125 .42219 m .6152 .42321 L .60213 .43568 L p .715 .891 .96 r
F P
0 g
s
.60213 .43568 m .5901 .4365 L .60125 .42219 L p .715 .891 .96 r
F P
0 g
s
.60421 .59795 m .60895 .60264 L .62696 .61552 L p 0 .21 .697 r
F P
0 g
s
.62855 .61728 m .62696 .61552 L .60895 .60264 L p 0 .238 .733 r
F P
0 g
s
.56628 .43906 m .57197 .43817 L .56567 .45163 L p .822 .919 .901 r
F P
0 g
s
.56567 .45163 m .56087 .4533 L .56628 .43906 L p .822 .919 .901 r
F P
0 g
s
.44474 .55803 m .45487 .55151 L .45422 .55763 L p .224 .066 .446 r
F P
0 g
s
.45422 .55763 m .44371 .56481 L .44474 .55803 L p .224 .066 .446 r
F P
0 g
s
.58358 .5784 m .57194 .57126 L .5636 .55941 L p .812 .326 0 r
F P
0 g
s
.51759 .50801 m .53132 .50434 L .53344 .51396 L p .852 .654 .634 r
F P
0 g
s
.53344 .51396 m .51971 .51669 L .51759 .50801 L p .852 .654 .634 r
F P
0 g
s
.51971 .51669 m .53344 .51396 L .53539 .52101 L p .852 .625 .595 r
F P
0 g
s
.77366 .72546 m .77536 .69898 L .86997 .71863 L p .511 .655 .924 r
F P
0 g
s
.86997 .71863 m .86483 .7537 L .77366 .72546 L p .511 .655 .924 r
F P
0 g
s
.53539 .52101 m .5214 .52289 L .51971 .51669 L p .852 .625 .595 r
F P
0 g
s
.5214 .52289 m .53539 .52101 L .53673 .52528 L p .85 .603 .566 r
F P
0 g
s
.5153 .49698 m .52946 .49255 L .53132 .50434 L p .847 .684 .68 r
F P
0 g
s
.53132 .50434 m .51759 .50801 L .5153 .49698 L p .847 .684 .68 r
F P
0 g
s
.5636 .55941 m .5496 .55458 L .54463 .54506 L p .87 .474 .283 r
F P
0 g
s
.5496 .55458 m .5636 .55941 L .57194 .57126 L p .825 .373 .154 r
F P
0 g
s
.52758 .46384 m .54172 .45965 L .5405 .47419 L p .857 .796 .791 r
F P
0 g
s
.5405 .47419 m .52823 .47906 L .52758 .46384 L p .857 .796 .791 r
F P
0 g
s
.55683 .44076 m .56628 .43906 L .56087 .4533 L p .831 .888 .883 r
F P
0 g
s
.56087 .4533 m .55283 .45605 L .55683 .44076 L p .831 .888 .883 r
F P
0 g
s
.53673 .52528 m .52249 .52657 L .5214 .52289 L p .85 .603 .566 r
F P
0 g
s
.52249 .52657 m .53673 .52528 L .5372 .5267 L p .847 .589 .548 r
F P
0 g
s
.44371 .56481 m .45422 .55763 L .45243 .56539 L p .146 0 .333 r
F P
0 g
s
.45243 .56539 m .44126 .57348 L .44371 .56481 L p .146 0 .333 r
F P
0 g
s
.42464 .47496 m .40871 .48192 L .39053 .46522 L p .581 .658 .89 r
F P
0 g
s
.40871 .48192 m .42464 .47496 L .43584 .49085 L p .551 .612 .867 r
F P
0 g
s
.5372 .5267 m .52285 .52779 L .52249 .52657 L p .847 .589 .548 r
F P
0 g
s
.52285 .52779 m .5372 .5267 L .5376 .52788 L p .847 .586 .543 r
F P
0 g
s
.5376 .52788 m .52317 .52879 L .52285 .52779 L p .847 .586 .543 r
F P
0 g
s
.52317 .52879 m .5376 .52788 L .53887 .53139 L p .847 .577 .531 r
F P
0 g
s
.377 .65801 m .37893 .63964 L .33962 .65607 L p .823 .928 .903 r
F P
0 g
s
.33962 .65607 m .33652 .67943 L .377 .65801 L p .823 .928 .903 r
F P
0 g
s
.42092 .60806 m .42765 .59568 L .41323 .60818 L p .78 .985 .733 r
F P
0 g
s
.41323 .60818 m .40457 .62343 L .42092 .60806 L p .78 .985 .733 r
F P
0 g
s
.53887 .53139 m .52414 .53182 L .52317 .52879 L p .847 .577 .531 r
F P
0 g
s
.52414 .53182 m .53887 .53139 L .54114 .53719 L p .844 .556 .502 r
F P
0 g
s
.513 .48377 m .52823 .47906 L .52946 .49255 L p .834 .712 .729 r
F P
0 g
s
.52946 .49255 m .5153 .49698 L .513 .48377 L p .834 .712 .729 r
F P
0 g
s
.46362 .51107 m .44887 .5164 L .44368 .50463 L p .581 .529 .762 r
F P
0 g
s
.44887 .5164 m .46362 .51107 L .46645 .52086 L p .563 .483 .723 r
F P
0 g
s
.46645 .52086 m .45206 .52614 L .44887 .5164 L p .563 .483 .723 r
F P
0 g
s
.70179 .39807 m .7256 .41132 L .69168 .42713 L p .635 .782 .952 r
F P
0 g
s
.69168 .42713 m .67156 .41724 L .70179 .39807 L p .635 .782 .952 r
F P
0 g
s
.45206 .52614 m .46645 .52086 L .46808 .52835 L p .543 .435 .681 r
F P
0 g
s
.46808 .52835 m .45375 .53373 L .45206 .52614 L p .543 .435 .681 r
F P
0 g
s
.59068 .42195 m .60125 .42219 L .5901 .4365 L p .741 .888 .946 r
F P
0 g
s
.5901 .4365 m .58111 .43746 L .59068 .42195 L p .741 .888 .946 r
F P
0 g
s
.62696 .61552 m .62185 .61052 L .60421 .59795 L p 0 .21 .697 r
F P
0 g
s
.45926 .49907 m .44368 .50463 L .43584 .49085 L p .598 .577 .801 r
F P
0 g
s
.44368 .50463 m .45926 .49907 L .46362 .51107 L p .581 .529 .762 r
F P
0 g
s
.54114 .53719 m .52585 .53678 L .52414 .53182 L p .844 .556 .502 r
F P
0 g
s
.52585 .53678 m .54114 .53719 L .54463 .54506 L p .836 .52 .454 r
F P
0 g
s
.63435 .62439 m .63013 .61903 L .65658 .63181 L p .077 .433 .874 r
F P
0 g
s
.65658 .63181 m .66122 .63786 L .63435 .62439 L p .077 .433 .874 r
F P
0 g
s
.45375 .53373 m .46808 .52835 L .46898 .53367 L p .528 .398 .647 r
F P
0 g
s
.46898 .53367 m .45454 .53917 L .45375 .53373 L p .528 .398 .647 r
F P
0 g
s
.54378 .44315 m .55683 .44076 L .55283 .45605 L p .83 .847 .859 r
F P
0 g
s
.55283 .45605 m .54172 .45965 L .54378 .44315 L p .83 .847 .859 r
F P
0 g
s
.44126 .57348 m .45243 .56539 L .44872 .57437 L p .016 0 .149 r
F P
0 g
s
.44872 .57437 m .43637 .58394 L .44126 .57348 L p .016 0 .149 r
F P
0 g
s
.45454 .53917 m .46898 .53367 L .46936 .53678 L p .515 .372 .625 r
F P
0 g
s
.46936 .53678 m .45486 .54244 L .45454 .53917 L p .515 .372 .625 r
F P
0 g
s
.7717 .38781 m .79736 .40888 L .74701 .42774 L p .637 .758 .936 r
F P
0 g
s
.74701 .42774 m .7256 .41132 L .7717 .38781 L p .637 .758 .936 r
F P
0 g
s
.45281 .48474 m .43584 .49085 L .42464 .47496 L p .613 .622 .836 r
F P
0 g
s
.43584 .49085 m .45281 .48474 L .45926 .49907 L p .598 .577 .801 r
F P
0 g
s
.23104 .44547 m .24419 .42911 L .29637 .45046 L p .621 .749 .938 r
F P
0 g
s
.31221 .43659 m .29637 .45046 L .24419 .42911 L p .623 .742 .932 r
F P
0 g
s
.29637 .45046 m .31221 .43659 L .34853 .45689 L p .597 .733 .939 r
F P
0 g
s
.45486 .54244 m .46936 .53678 L .46948 .53785 L p .507 .352 .605 r
F P
0 g
s
.46948 .53785 m .45492 .54352 L .45486 .54244 L p .507 .352 .605 r
F P
0 g
s
.63201 .40562 m .65118 .4102 L .63142 .42558 L p .675 .837 .961 r
F P
0 g
s
.63142 .42558 m .6152 .42321 L .63201 .40562 L p .675 .837 .961 r
F P
0 g
s
.51067 .46838 m .52758 .46384 L .52823 .47906 L p .814 .735 .776 r
F P
0 g
s
.52823 .47906 m .513 .48377 L .51067 .46838 L p .814 .735 .776 r
F P
0 g
s
.45492 .54352 m .46948 .53785 L .46956 .5387 L p .498 .332 .586 r
F P
0 g
s
.46956 .5387 m .45494 .5444 L .45492 .54352 L p .498 .332 .586 r
F P
0 g
s
.54463 .54506 m .5284 .54352 L .52585 .53678 L p .836 .52 .454 r
F P
0 g
s
.5284 .54352 m .54463 .54506 L .5496 .55458 L p .82 .465 .383 r
F P
0 g
s
.58406 .422 m .59068 .42195 L .58111 .43746 L p .754 .882 .937 r
F P
0 g
s
.58111 .43746 m .57548 .43826 L .58406 .422 L p .754 .882 .937 r
F P
0 g
s
.45494 .5444 m .46956 .5387 L .46976 .54125 L p .497 .33 .585 r
F P
0 g
s
.46976 .54125 m .455 .54707 L .45494 .5444 L p .497 .33 .585 r
F P
0 g
s
.36617 .44576 m .34853 .45689 L .31221 .43659 L p .608 .723 .926 r
F P
0 g
s
.34853 .45689 m .36617 .44576 L .39053 .46522 L p .578 .701 .926 r
F P
0 g
s
.455 .54707 m .46976 .54125 L .46997 .54549 L p .484 .304 .56 r
F P
0 g
s
.46997 .54549 m .45487 .55151 L .455 .54707 L p .484 .304 .56 r
F P
0 g
s
.4986 .50131 m .5153 .49698 L .51759 .50801 L p .781 .625 .686 r
F P
0 g
s
.51759 .50801 m .50107 .51167 L .4986 .50131 L p .781 .625 .686 r
F P
0 g
s
.50107 .51167 m .51759 .50801 L .51971 .51669 L p .782 .596 .649 r
F P
0 g
s
.51971 .51669 m .50302 .51967 L .50107 .51167 L p .782 .596 .649 r
F P
0 g
s
.50302 .51967 m .51971 .51669 L .5214 .52289 L p .78 .573 .619 r
F P
0 g
s
.52741 .44644 m .54378 .44315 L .54172 .45965 L p .815 .798 .836 r
F P
0 g
s
.54172 .45965 m .52758 .46384 L .52741 .44644 L p .815 .798 .836 r
F P
0 g
s
.49551 .48853 m .513 .48377 L .5153 .49698 L p .777 .655 .728 r
F P
0 g
s
.5153 .49698 m .4986 .50131 L .49551 .48853 L p .777 .655 .728 r
F P
0 g
s
.40923 .45657 m .39053 .46522 L .36617 .44576 L p .606 .692 .904 r
F P
0 g
s
.39053 .46522 m .40923 .45657 L .42464 .47496 L p .581 .658 .89 r
F P
0 g
s
.58248 .422 m .58406 .422 L .57548 .43826 L p .789 .921 .926 r
F P
0 g
s
.57548 .43826 m .57417 .43849 L .58248 .422 L p .789 .921 .926 r
F P
0 g
s
.5214 .52289 m .50444 .52535 L .50302 .51967 L p .78 .573 .619 r
F P
0 g
s
.50444 .52535 m .5214 .52289 L .52249 .52657 L p .777 .55 .591 r
F P
0 g
s
.57194 .57126 m .5563 .56504 L .5496 .55458 L p .825 .373 .154 r
F P
0 g
s
.5563 .56504 m .57194 .57126 L .58291 .583 L p .736 .216 0 r
F P
0 g
s
.45487 .55151 m .46997 .54549 L .46987 .55124 L p .459 .256 .515 r
F P
0 g
s
.46987 .55124 m .45422 .55763 L .45487 .55151 L p .459 .256 .515 r
F P
0 g
s
.48076 .50594 m .46362 .51107 L .45926 .49907 L p .656 .567 .743 r
F P
0 g
s
.46362 .51107 m .48076 .50594 L .4834 .51593 L p .648 .531 .706 r
F P
0 g
s
.4834 .51593 m .46645 .52086 L .46362 .51107 L p .648 .531 .706 r
F P
0 g
s
.63013 .61903 m .62855 .61728 L .6548 .6298 L p .037 .425 .866 r
F P
0 g
s
.6548 .6298 m .65658 .63181 L .63013 .61903 L p .037 .425 .866 r
F P
0 g
s
.52249 .52657 m .50528 .52868 L .50444 .52535 L p .777 .55 .591 r
F P
0 g
s
.50528 .52868 m .52249 .52657 L .52285 .52779 L p .776 .542 .582 r
F P
0 g
s
.46645 .52086 m .4834 .51593 L .48516 .52354 L p .639 .493 .669 r
F P
0 g
s
.48516 .52354 m .46808 .52835 L .46645 .52086 L p .639 .493 .669 r
F P
0 g
s
.43637 .58394 m .44872 .57437 L .44197 .58424 L p 0 0 0 r
F P
0 g
s
.44197 .58424 m .42765 .59568 L .43637 .58394 L p 0 0 0 r
F P
0 g
s
.52285 .52779 m .50555 .52979 L .50528 .52868 L p .776 .542 .582 r
F P
0 g
s
.50555 .52979 m .52285 .52779 L .52317 .52879 L p .774 .535 .573 r
F P
0 g
s
.47705 .4936 m .45926 .49907 L .45281 .48474 L p .663 .606 .781 r
F P
0 g
s
.45926 .49907 m .47705 .4936 L .48076 .50594 L p .656 .567 .743 r
F P
0 g
s
.52317 .52879 m .50578 .53069 L .50555 .52979 L p .774 .535 .573 r
F P
0 g
s
.50578 .53069 m .52317 .52879 L .52414 .53182 L p .775 .531 .567 r
F P
0 g
s
.58 .42144 m .58175 .42112 L .57345 .43763 L p .792 .917 .923 r
F P
0 g
s
.57345 .43763 m .57197 .43817 L .58 .42144 L p .792 .917 .923 r
F P
0 g
s
.66736 .64804 m .66122 .63786 L .70115 .65065 L p .289 .551 .924 r
F P
0 g
s
.70115 .65065 m .70813 .66303 L .66736 .64804 L p .289 .551 .924 r
F P
0 g
s
.57327 .42166 m .58 .42144 L .57197 .43817 L p .768 .867 .922 r
F P
0 g
s
.57197 .43817 m .56628 .43906 L .57327 .42166 L p .768 .867 .922 r
F P
0 g
s
.40457 .62343 m .41323 .60818 L .39027 .62062 L p .793 .996 .862 r
F P
0 g
s
.39027 .62062 m .37893 .63964 L .40457 .62343 L p .793 .996 .862 r
F P
0 g
s
.44375 .46797 m .42464 .47496 L .40923 .45657 L p .627 .661 .864 r
F P
0 g
s
.42464 .47496 m .44375 .46797 L .45281 .48474 L p .613 .622 .836 r
F P
0 g
s
.46808 .52835 m .48516 .52354 L .48627 .52891 L p .63 .466 .642 r
F P
0 g
s
.48627 .52891 m .46898 .53367 L .46808 .52835 L p .63 .466 .642 r
F P
0 g
s
.52414 .53182 m .5065 .53343 L .50578 .53069 L p .775 .531 .567 r
F P
0 g
s
.5065 .53343 m .52414 .53182 L .52585 .53678 L p .771 .51 .54 r
F P
0 g
s
.71348 .67999 m .70813 .66303 L .76976 .67731 L p .425 .617 .93 r
F P
0 g
s
.76976 .67731 m .77536 .69898 L .71348 .67999 L p .425 .617 .93 r
F P
0 g
s
.62696 .61552 m .62855 .61728 L .6548 .6298 L p .037 .425 .866 r
F P
0 g
s
.49171 .47334 m .51067 .46838 L .513 .48377 L p .768 .683 .769 r
F P
0 g
s
.513 .48377 m .49551 .48853 L .49171 .47334 L p .768 .683 .769 r
F P
0 g
s
.5496 .55458 m .53195 .55172 L .5284 .54352 L p .82 .465 .383 r
F P
0 g
s
.53195 .55172 m .5496 .55458 L .5563 .56504 L p .789 .379 .272 r
F P
0 g
s
.45422 .55763 m .46987 .55124 L .46917 .55841 L p .42 .177 .437 r
F P
0 g
s
.46917 .55841 m .45243 .56539 L .45422 .55763 L p .42 .177 .437 r
F P
0 g
s
.48076 .50594 m .4986 .50131 L .50107 .51167 L p .717 .576 .695 r
F P
0 g
s
.50107 .51167 m .4834 .51593 L .48076 .50594 L p .717 .576 .695 r
F P
0 g
s
.4834 .51593 m .50107 .51167 L .50302 .51967 L p .713 .544 .659 r
F P
0 g
s
.46898 .53367 m .48627 .52891 L .48689 .53211 L p .622 .438 .612 r
F P
0 g
s
.48689 .53211 m .46936 .53678 L .46898 .53367 L p .622 .438 .612 r
F P
0 g
s
.47705 .4936 m .49551 .48853 L .4986 .50131 L p .72 .608 .732 r
F P
0 g
s
.4986 .50131 m .48076 .50594 L .47705 .4936 L p .72 .608 .732 r
F P
0 g
s
.33652 .67943 m .33962 .65607 L .27912 .67173 L p .782 .897 .925 r
F P
0 g
s
.27912 .67173 m .27527 .70215 L .33652 .67943 L p .782 .897 .925 r
F P
0 g
s
.56214 .42231 m .57327 .42166 L .56628 .43906 L p .776 .85 .907 r
F P
0 g
s
.56628 .43906 m .55683 .44076 L .56214 .42231 L p .776 .85 .907 r
F P
0 g
s
.52585 .53678 m .50767 .53788 L .5065 .53343 L p .771 .51 .54 r
F P
0 g
s
.50767 .53788 m .52585 .53678 L .5284 .54352 L p .764 .477 .499 r
F P
0 g
s
.50302 .51967 m .48516 .52354 L .4834 .51593 L p .713 .544 .659 r
F P
0 g
s
.50817 .45053 m .52741 .44644 L .52758 .46384 L p .788 .75 .818 r
F P
0 g
s
.52758 .46384 m .51067 .46838 L .50817 .45053 L p .788 .75 .818 r
F P
0 g
s
.48516 .52354 m .50302 .51967 L .50444 .52535 L p .709 .519 .63 r
F P
0 g
s
.47194 .47881 m .45281 .48474 L .44375 .46797 L p .666 .642 .816 r
F P
0 g
s
.45281 .48474 m .47194 .47881 L .47705 .4936 L p .663 .606 .781 r
F P
0 g
s
.62185 .61052 m .62696 .61552 L .65301 .6278 L p 0 .414 .854 r
F P
0 g
s
.6548 .6298 m .65301 .6278 L .62696 .61552 L p .037 .425 .866 r
F P
0 g
s
.46936 .53678 m .48689 .53211 L .48708 .53315 L p .621 .436 .611 r
F P
0 g
s
.48708 .53315 m .46948 .53785 L .46936 .53678 L p .621 .436 .611 r
F P
0 g
s
.61564 .4029 m .63201 .40562 L .6152 .42321 L p .697 .839 .951 r
F P
0 g
s
.6152 .42321 m .60125 .42219 L .61564 .4029 L p .697 .839 .951 r
F P
0 g
s
.46948 .53785 m .48708 .53315 L .48722 .534 L p .616 .423 .597 r
F P
0 g
s
.48722 .534 m .46956 .5387 L .46948 .53785 L p .616 .423 .597 r
F P
0 g
s
.49551 .48853 m .47705 .4936 L .47194 .47881 L p .718 .64 .77 r
F P
0 g
s
.46956 .5387 m .48722 .534 L .48764 .53657 L p .613 .412 .585 r
F P
0 g
s
.48764 .53657 m .46976 .54125 L .46956 .5387 L p .613 .412 .585 r
F P
0 g
s
.50444 .52535 m .48627 .52891 L .48516 .52354 L p .709 .519 .63 r
F P
0 g
s
.47194 .47881 m .49171 .47334 L .49551 .48853 L p .718 .64 .77 r
F P
0 g
s
.48627 .52891 m .50444 .52535 L .50528 .52868 L p .705 .502 .611 r
F P
0 g
s
.67745 .38814 m .70179 .39807 L .67156 .41724 L p .653 .795 .951 r
F P
0 g
s
.67156 .41724 m .65118 .4102 L .67745 .38814 L p .653 .795 .951 r
F P
0 g
s
.46976 .54125 m .48764 .53657 L .4883 .54078 L p .607 .396 .569 r
F P
0 g
s
.4883 .54078 m .46997 .54549 L .46976 .54125 L p .607 .396 .569 r
F P
0 g
s
.50528 .52868 m .48689 .53211 L .48627 .52891 L p .705 .502 .611 r
F P
0 g
s
.48689 .53211 m .50528 .52868 L .50555 .52979 L p .701 .488 .596 r
F P
0 g
s
.50555 .52979 m .48708 .53315 L .48689 .53211 L p .701 .488 .596 r
F P
0 g
s
.48708 .53315 m .50555 .52979 L .50578 .53069 L p .698 .474 .581 r
F P
0 g
s
.54672 .42366 m .56214 .42231 L .55683 .44076 L p .779 .824 .887 r
F P
0 g
s
.55683 .44076 m .54378 .44315 L .54672 .42366 L p .779 .824 .887 r
F P
0 g
s
.50578 .53069 m .48722 .534 L .48708 .53315 L p .698 .474 .581 r
F P
0 g
s
.48722 .534 m .50578 .53069 L .5065 .53343 L p .699 .475 .58 r
F P
0 g
s
.5284 .54352 m .50928 .54389 L .50767 .53788 L p .764 .477 .499 r
F P
0 g
s
.50928 .54389 m .5284 .54352 L .53195 .55172 L p .752 .43 .44 r
F P
0 g
s
.45243 .56539 m .46917 .55841 L .46719 .56654 L p .35 .053 .313 r
F P
0 g
s
.46719 .56654 m .44872 .57437 L .45243 .56539 L p .35 .053 .313 r
F P
0 g
s
.5065 .53343 m .48764 .53657 L .48722 .534 L p .699 .475 .58 r
F P
0 g
s
.48764 .53657 m .5065 .53343 L .50767 .53788 L p .695 .457 .559 r
F P
0 g
s
.46997 .54549 m .4883 .54078 L .48904 .54649 L p .593 .355 .526 r
F P
0 g
s
.48904 .54649 m .46987 .55124 L .46997 .54549 L p .593 .355 .526 r
F P
0 g
s
.48697 .45554 m .50817 .45053 L .51067 .46838 L p .752 .706 .808 r
F P
0 g
s
.51067 .46838 m .49171 .47334 L .48697 .45554 L p .752 .706 .808 r
F P
0 g
s
.44375 .46797 m .46497 .46136 L .47194 .47881 L p .666 .642 .816 r
F P
0 g
s
.49171 .47334 m .47194 .47881 L .46497 .46136 L p .712 .67 .807 r
F P
0 g
s
.44397 .58925 m .43104 .59486 L p .43061 .5942 L 0 0 0 r
F P
0 g
s
.42765 .59568 m .43023 .59362 L p .43061 .5942 L 0 0 0 r
F P
0 g
s
.43061 .5942 m .41323 .60818 L .42765 .59568 L p 0 0 0 r
F P
0 g
s
.41323 .60818 m .43061 .5942 L .41221 .60304 L p .583 .937 .779 r
F P
0 g
s
.43104 .59486 m .41221 .60304 L .43061 .5942 L p 0 0 0 r
F P
0 g
s
.43023 .59362 m .44197 .58424 L .43061 .5942 L p 0 0 0 r
F P
0 g
s
.50767 .53788 m .4883 .54078 L .48764 .53657 L p .695 .457 .559 r
F P
0 g
s
.61244 .60292 m .62185 .61052 L .6471 .62203 L p 0 .398 .83 r
F P
0 g
s
.65301 .6278 m .6471 .62203 L .62185 .61052 L p 0 .414 .854 r
F P
0 g
s
.46497 .46136 m .48697 .45554 L .49171 .47334 L p .712 .67 .807 r
F P
0 g
s
.4883 .54078 m .50767 .53788 L .50928 .54389 L p .686 .427 .525 r
F P
0 g
s
.60314 .40149 m .61564 .4029 L .60125 .42219 L p .712 .838 .942 r
F P
0 g
s
.60125 .42219 m .59068 .42195 L .60314 .40149 L p .712 .838 .942 r
F P
0 g
s
.40923 .45657 m .43128 .44822 L .44375 .46797 L p .627 .661 .864 r
F P
0 g
s
.46497 .46136 m .44375 .46797 L .43128 .44822 L p .667 .674 .848 r
F P
0 g
s
.52761 .42601 m .54672 .42366 L .54378 .44315 L p .774 .792 .868 r
F P
0 g
s
.54378 .44315 m .52741 .44644 L .52761 .42601 L p .774 .792 .868 r
F P
0 g
s
.36617 .44576 m .38833 .43476 L .40923 .45657 L p .606 .692 .904 r
F P
0 g
s
.43128 .44822 m .40923 .45657 L .38833 .43476 L p .636 .693 .885 r
F P
0 g
s
.46987 .55124 m .48904 .54649 L .48964 .55355 L p .571 .303 .471 r
F P
0 g
s
.48964 .55355 m .46917 .55841 L .46987 .55124 L p .571 .303 .471 r
F P
0 g
s
.5563 .56504 m .53667 .5608 L .53195 .55172 L p .789 .379 .272 r
F P
0 g
s
.53667 .5608 m .5563 .56504 L .56523 .57554 L p .727 .246 .102 r
F P
0 g
s
.58291 .583 m .56523 .57554 L .5563 .56504 L p .736 .216 0 r
F P
0 g
s
.50928 .54389 m .48904 .54649 L .4883 .54078 L p .686 .427 .525 r
F P
0 g
s
.31221 .43659 m .33347 .42214 L .36617 .44576 L p .608 .723 .926 r
F P
0 g
s
.38833 .43476 m .36617 .44576 L .33347 .42214 L p .625 .716 .912 r
F P
0 g
s
.53195 .55172 m .51135 .55122 L .50928 .54389 L p .752 .43 .44 r
F P
0 g
s
.51135 .55122 m .53195 .55172 L .53667 .5608 L p .726 .355 .348 r
F P
0 g
s
.66122 .63786 m .65658 .63181 L .69571 .64329 L p .255 .554 .93 r
F P
0 g
s
.69571 .64329 m .70115 .65065 L .66122 .63786 L p .255 .554 .93 r
F P
0 g
s
.24419 .42911 m .26328 .41097 L .31221 .43659 L p .623 .742 .932 r
F P
0 g
s
.33347 .42214 m .31221 .43659 L .26328 .41097 L p .628 .736 .925 r
F P
0 g
s
.48904 .54649 m .50928 .54389 L .51135 .55122 L p .67 .376 .466 r
F P
0 g
s
.59524 .40084 m .60314 .40149 L .59068 .42195 L p .719 .835 .936 r
F P
0 g
s
.59068 .42195 m .58406 .422 L .59524 .40084 L p .719 .835 .936 r
F P
0 g
s
.74273 .37039 m .7717 .38781 L .7256 .41132 L p .646 .769 .938 r
F P
0 g
s
.7256 .41132 m .70179 .39807 L .74273 .37039 L p .646 .769 .938 r
F P
0 g
s
.44872 .57437 m .46719 .56654 L .46319 .57501 L p .23 0 .11 r
F P
0 g
s
.46319 .57501 m .44197 .58424 L .44872 .57437 L p .23 0 .11 r
F P
0 g
s
.37893 .63964 m .39027 .62062 L .35447 .6317 L p .775 .967 .923 r
F P
0 g
s
.35447 .6317 m .33962 .65607 L .37893 .63964 L p .775 .967 .923 r
F P
0 g
s
.50527 .42955 m .52761 .42601 L .52741 .44644 L p .758 .757 .852 r
F P
0 g
s
.52741 .44644 m .50817 .45053 L .50527 .42955 L p .758 .757 .852 r
F P
0 g
s
.51135 .55122 m .48964 .55355 L .48904 .54649 L p .67 .376 .466 r
F P
0 g
s
.43128 .44822 m .45562 .44071 L .46497 .46136 L p .667 .674 .848 r
F P
0 g
s
.48697 .45554 m .46497 .46136 L .45562 .44071 L p .703 .696 .84 r
F P
0 g
s
.59324 .40062 m .59524 .40084 L .58406 .422 L p .743 .861 .935 r
F P
0 g
s
.58406 .422 m .58248 .422 L .59324 .40062 L p .743 .861 .935 r
F P
0 g
s
.46917 .55841 m .48964 .55355 L .48982 .56135 L p .528 .209 .37 r
F P
0 g
s
.48982 .56135 m .46719 .56654 L .46917 .55841 L p .528 .209 .37 r
F P
0 g
s
.65443 .3812 m .67745 .38814 L .65118 .4102 L p .669 .802 .946 r
F P
0 g
s
.65118 .4102 m .63201 .40562 L .65443 .3812 L p .669 .802 .946 r
F P
0 g
s
.48078 .4344 m .50527 .42955 L .50817 .45053 L p .733 .724 .842 r
F P
0 g
s
.50817 .45053 m .48697 .45554 L .48078 .4344 L p .733 .724 .842 r
F P
0 g
s
.59035 .39983 m .59251 .39972 L .58175 .42112 L p .745 .859 .933 r
F P
0 g
s
.58175 .42112 m .58 .42144 L .59035 .39983 L p .745 .859 .933 r
F P
0 g
s
.27527 .70215 m .27912 .67173 L .18527 .68489 L p .746 .867 .936 r
F P
0 g
s
.18527 .68489 m .18165 .72622 L .27527 .70215 L p .746 .867 .936 r
F P
0 g
s
.45562 .44071 m .48078 .4344 L .48697 .45554 L p .703 .696 .84 r
F P
0 g
s
.58228 .39943 m .59035 .39983 L .58 .42144 L p .728 .827 .926 r
F P
0 g
s
.58 .42144 m .57327 .42166 L .58228 .39943 L p .728 .827 .926 r
F P
0 g
s
.6471 .62203 m .63621 .61319 L .61244 .60292 L p 0 .398 .83 r
F P
0 g
s
.48964 .55355 m .51135 .55122 L .51386 .55947 L p .641 .298 .375 r
F P
0 g
s
.53667 .5608 m .51386 .55947 L .51135 .55122 L p .726 .355 .348 r
F P
0 g
s
.65658 .63181 m .6548 .6298 L .69358 .64085 L p .231 .554 .933 r
F P
0 g
s
.69358 .64085 m .69571 .64329 L .65658 .63181 L p .231 .554 .933 r
F P
0 g
s
.56907 .39918 m .58228 .39943 L .57327 .42166 L p .734 .817 .916 r
F P
0 g
s
.57327 .42166 m .56214 .42231 L .56907 .39918 L p .734 .817 .916 r
F P
0 g
s
.51386 .55947 m .48982 .56135 L .48964 .55355 L p .641 .298 .375 r
F P
0 g
s
.38833 .43476 m .41431 .42452 L .43128 .44822 L p .636 .693 .885 r
F P
0 g
s
.45562 .44071 m .43128 .44822 L .41431 .42452 L p .665 .701 .873 r
F P
0 g
s
.77536 .69898 m .76976 .67731 L .86451 .68945 L p .489 .663 .939 r
F P
0 g
s
.86451 .68945 m .86997 .71863 L .77536 .69898 L p .489 .663 .939 r
F P
0 g
s
.41221 .60304 m .39027 .62062 L .41323 .60818 L p .583 .937 .779 r
F P
0 g
s
.51386 .55947 m .53667 .5608 L .54281 .57002 L p .672 .23 .193 r
F P
0 g
s
.56523 .57554 m .54281 .57002 L .53667 .5608 L p .727 .246 .102 r
F P
0 g
s
.70813 .66303 m .70115 .65065 L .76157 .66147 L p .398 .624 .944 r
F P
0 g
s
.76157 .66147 m .76976 .67731 L .70813 .66303 L p .398 .624 .944 r
F P
0 g
s
.65301 .6278 m .6548 .6298 L .69358 .64085 L p .231 .554 .933 r
F P
0 g
s
.55082 .39953 m .56907 .39918 L .56214 .42231 L p .738 .802 .904 r
F P
0 g
s
.56214 .42231 m .54672 .42366 L .55082 .39953 L p .738 .802 .904 r
F P
0 g
s
.46719 .56654 m .48982 .56135 L .48913 .56937 L p .454 .064 .21 r
F P
0 g
s
.48913 .56937 m .46319 .57501 L .46719 .56654 L p .454 .064 .21 r
F P
0 g
s
.6471 .62203 m .65301 .6278 L .69145 .63841 L p .206 .554 .933 r
F P
0 g
s
.69358 .64085 m .69145 .63841 L .65301 .6278 L p .231 .554 .933 r
F P
0 g
s
.44197 .58424 m .46319 .57501 L .45605 .58314 L p .03 0 0 r
F P
0 g
s
.45605 .58314 m .43061 .5942 L .44197 .58424 L p .03 0 0 r
F P
0 g
s
.63473 .37669 m .65443 .3812 L .63201 .40562 L p .682 .805 .94 r
F P
0 g
s
.63201 .40562 m .61564 .4029 L .63473 .37669 L p .682 .805 .94 r
F P
0 g
s
.33347 .42214 m .36005 .40802 L .38833 .43476 L p .625 .716 .912 r
F P
0 g
s
.41431 .42452 m .38833 .43476 L .36005 .40802 L p .644 .715 .9 r
F P
0 g
s
.52797 .40096 m .55082 .39953 L .54672 .42366 L p .737 .783 .89 r
F P
0 g
s
.54672 .42366 m .52761 .42601 L .52797 .40096 L p .737 .783 .89 r
F P
0 g
s
.41431 .42452 m .44297 .41577 L .45562 .44071 L p .665 .701 .873 r
F P
0 g
s
.48078 .4344 m .45562 .44071 L .44297 .41577 L p .691 .716 .868 r
F P
0 g
s
.48982 .56135 m .51386 .55947 L .51669 .56771 L p .586 .175 .231 r
F P
0 g
s
.54281 .57002 m .51669 .56771 L .51386 .55947 L p .672 .23 .193 r
F P
0 g
s
.51669 .56771 m .48913 .56937 L .48982 .56135 L p .586 .175 .231 r
F P
0 g
s
.50152 .40398 m .52797 .40096 L .52761 .42601 L p .729 .76 .878 r
F P
0 g
s
.52761 .42601 m .50527 .42955 L .50152 .40398 L p .729 .76 .878 r
F P
0 g
s
.71302 .35688 m .74273 .37039 L .70179 .39807 L p .655 .777 .938 r
F P
0 g
s
.70179 .39807 m .67745 .38814 L .71302 .35688 L p .655 .777 .938 r
F P
0 g
s
.26328 .41097 m .28901 .39209 L .33347 .42214 L p .628 .736 .925 r
F P
0 g
s
.36005 .40802 m .33347 .42214 L .28901 .39209 L p .637 .732 .917 r
F P
0 g
s
.63621 .61319 m .61878 .6026 L .59782 .59386 L p 0 .358 .763 r
F P
0 g
s
.44297 .41577 m .47261 .40884 L .48078 .4344 L p .691 .716 .868 r
F P
0 g
s
.50527 .42955 m .48078 .4344 L .47261 .40884 L p .713 .737 .87 r
F P
0 g
s
.63621 .61319 m .6471 .62203 L .68433 .6314 L p .164 .552 .929 r
F P
0 g
s
.69145 .63841 m .68433 .6314 L .6471 .62203 L p .206 .554 .933 r
F P
0 g
s
.47261 .40884 m .50152 .40398 L .50527 .42955 L p .713 .737 .87 r
F P
0 g
s
.61957 .37407 m .63473 .37669 L .61564 .4029 L p .691 .804 .935 r
F P
0 g
s
.61564 .4029 m .60314 .40149 L .61957 .37407 L p .691 .804 .935 r
F P
0 g
s
.33962 .65607 m .35447 .6317 L .29872 .63931 L p .749 .926 .948 r
F P
0 g
s
.29872 .63931 m .27912 .67173 L .33962 .65607 L p .749 .926 .948 r
F P
0 g
s
.51669 .56771 m .54281 .57002 L .5508 .57808 L p .558 .029 0 r
F P
0 g
s
.61006 .37274 m .61957 .37407 L .60314 .40149 L p .694 .802 .932 r
F P
0 g
s
.60314 .40149 m .59524 .40084 L .61006 .37274 L p .694 .802 .932 r
F P
0 g
s
.46319 .57501 m .48913 .56937 L .48703 .57648 L p .314 0 0 r
F P
0 g
s
.48703 .57648 m .45605 .58314 L .46319 .57501 L p .314 0 0 r
F P
0 g
s
.70115 .65065 m .69571 .64329 L .75484 .652 L p .377 .63 .953 r
F P
0 g
s
.75484 .652 m .76157 .66147 L .70115 .65065 L p .377 .63 .953 r
F P
0 g
s
.36005 .40802 m .39134 .39531 L .41431 .42452 L p .644 .715 .9 r
F P
0 g
s
.44297 .41577 m .41431 .42452 L .39134 .39531 L p .663 .72 .892 r
F P
0 g
s
.60751 .37229 m .61006 .37274 L .59524 .40084 L p .708 .816 .933 r
F P
0 g
s
.59524 .40084 m .59324 .40062 L .60751 .37229 L p .708 .816 .933 r
F P
0 g
s
.39027 .62062 m .41221 .60304 L .38301 .60892 L p .662 .966 .919 r
F P
0 g
s
.38301 .60892 m .35447 .6317 L .39027 .62062 L p .662 .966 .919 r
F P
0 g
s
.43061 .5942 m .45605 .58314 L .44397 .58925 L p 0 0 0 r
F P
0 g
s
.60405 .37127 m .60677 .37137 L .59251 .39972 L p .709 .815 .931 r
F P
0 g
s
.59251 .39972 m .59035 .39983 L .60405 .37127 L p .709 .815 .931 r
F P
0 g
s
.59432 .37027 m .60405 .37127 L .59035 .39983 L p .7 .798 .926 r
F P
0 g
s
.59035 .39983 m .58228 .39943 L .59432 .37027 L p .7 .798 .926 r
F P
0 g
s
.48913 .56937 m .51669 .56771 L .51985 .57486 L p .471 0 0 r
F P
0 g
s
.5508 .57808 m .51985 .57486 L .51669 .56771 L p .558 .029 0 r
F P
0 g
s
.51985 .57486 m .48703 .57648 L .48913 .56937 L p .471 0 0 r
F P
0 g
s
.61878 .6026 m .63621 .61319 L .67098 .62064 L p .118 .554 .919 r
F P
0 g
s
.68433 .6314 m .67098 .62064 L .63621 .61319 L p .164 .552 .929 r
F P
0 g
s
.57826 .3691 m .59432 .37027 L .58228 .39943 L p .705 .793 .92 r
F P
0 g
s
.58228 .39943 m .56907 .39918 L .57826 .3691 L p .705 .793 .92 r
F P
0 g
s
.68487 .3471 m .71302 .35688 L .67745 .38814 L p .665 .781 .935 r
F P
0 g
s
.67745 .38814 m .65443 .3812 L .68487 .3471 L p .665 .781 .935 r
F P
0 g
s
.69571 .64329 m .69358 .64085 L .7522 .64886 L p .365 .634 .958 r
F P
0 g
s
.7522 .64886 m .75484 .652 L .69571 .64329 L p .365 .634 .958 r
F P
0 g
s
.55614 .36849 m .57826 .3691 L .56907 .39918 L p .708 .785 .912 r
F P
0 g
s
.56907 .39918 m .55082 .39953 L .55614 .36849 L p .708 .785 .912 r
F P
0 g
s
.39134 .39531 m .42581 .38471 L .44297 .41577 L p .663 .72 .892 r
F P
0 g
s
.47261 .40884 m .44297 .41577 L .42581 .38471 L p .68 .73 .888 r
F P
0 g
s
.28901 .39209 m .32148 .37393 L .36005 .40802 L p .637 .732 .917 r
F P
0 g
s
.39134 .39531 m .36005 .40802 L .32148 .37393 L p .648 .731 .909 r
F P
0 g
s
.76976 .67731 m .76157 .66147 L .8547 .6681 L p .472 .673 .952 r
F P
0 g
s
.8547 .6681 m .86451 .68945 L .76976 .67731 L p .472 .673 .952 r
F P
0 g
s
.69145 .63841 m .69358 .64085 L .7522 .64886 L p .365 .634 .958 r
F P
0 g
s
.52847 .36907 m .55614 .36849 L .55082 .39953 L p .708 .773 .903 r
F P
0 g
s
.55082 .39953 m .52797 .40096 L .52847 .36907 L p .708 .773 .903 r
F P
0 g
s
.42581 .38471 m .4616 .37683 L .47261 .40884 L p .68 .73 .888 r
F P
0 g
s
.50152 .40398 m .47261 .40884 L .4616 .37683 L p .695 .744 .889 r
F P
0 g
s
.68433 .6314 m .69145 .63841 L .74954 .64571 L p .353 .639 .962 r
F P
0 g
s
.7522 .64886 m .74954 .64571 L .69145 .63841 L p .365 .634 .958 r
F P
0 g
s
.49649 .37167 m .52847 .36907 L .52797 .40096 L p .704 .759 .895 r
F P
0 g
s
.52797 .40096 m .50152 .40398 L .49649 .37167 L p .704 .759 .895 r
F P
0 g
s
.4616 .37683 m .49649 .37167 L .50152 .40398 L p .695 .744 .889 r
F P
0 g
s
.52711 .57791 m .51389 .57849 L p .48254 .58099 L .082 .643 .757 r
F P
0 g
s
.45635 .58307 m .48703 .57648 L .48254 .58099 L p .057 0 0 r
F P
0 g
s
.51389 .57849 m .47434 .58022 L .48254 .58099 L p .082 .643 .757 r
F P
0 g
s
.45605 .58314 m .45635 .58307 L p .48254 .58099 L .057 0 0 r
F P
0 g
s
.48254 .58099 m .44397 .58925 L .45605 .58314 L p .057 0 0 r
F P
0 g
s
.66062 .34061 m .68487 .3471 L .65443 .3812 L p .672 .782 .932 r
F P
0 g
s
.65443 .3812 m .63473 .37669 L .66062 .34061 L p .672 .782 .932 r
F P
0 g
s
.5939 .59183 m .61878 .6026 L .64938 .60736 L p .048 .548 .882 r
F P
0 g
s
.67098 .62064 m .64938 .60736 L .61878 .6026 L p .118 .554 .919 r
F P
0 g
s
.27912 .67173 m .29872 .63931 L .21078 .64012 L p .721 .887 .957 r
F P
0 g
s
.21078 .64012 m .18527 .68489 L .27912 .67173 L p .721 .887 .957 r
F P
0 g
s
.67098 .62064 m .68433 .6314 L .74066 .63663 L p .332 .646 .967 r
F P
0 g
s
.74954 .64571 m .74066 .63663 L .68433 .6314 L p .353 .639 .962 r
F P
0 g
s
.64191 .33658 m .66062 .34061 L .63473 .37669 L p .676 .782 .929 r
F P
0 g
s
.63473 .37669 m .61957 .37407 L .64191 .33658 L p .676 .782 .929 r
F P
0 g
s
.41221 .60304 m .44397 .58925 L .42431 .59093 L p .464 .89 .868 r
F P
0 g
s
.42431 .59093 m .38301 .60892 L .41221 .60304 L p .464 .89 .868 r
F P
0 g
s
.32148 .37393 m .35986 .35777 L .39134 .39531 L p .648 .731 .909 r
F P
0 g
s
.42581 .38471 m .39134 .39531 L .35986 .35777 L p .66 .734 .904 r
F P
0 g
s
.35447 .6317 m .38301 .60892 L .33685 .60875 L p .68 .936 .966 r
F P
0 g
s
.33685 .60875 m .29872 .63931 L .35447 .6317 L p .68 .936 .966 r
F P
0 g
s
.63016 .33448 m .64191 .33658 L .61957 .37407 L p .679 .781 .928 r
F P
0 g
s
.61957 .37407 m .61006 .37274 L .63016 .33448 L p .679 .781 .928 r
F P
0 g
s
.76157 .66147 m .75484 .652 L .84628 .65519 L p .46 .679 .959 r
F P
0 g
s
.84628 .65519 m .8547 .6681 L .76157 .66147 L p .46 .679 .959 r
F P
0 g
s
.6269 .3338 m .63016 .33448 L .61006 .37274 L p .685 .788 .928 r
F P
0 g
s
.61006 .37274 m .60751 .37229 L .6269 .3338 L p .685 .788 .928 r
F P
0 g
s
.64938 .60736 m .61797 .59405 L .5939 .59183 L p .048 .548 .882 r
F P
0 g
s
.62271 .33251 m .62616 .33284 L .60677 .37137 L p .685 .787 .927 r
F P
0 g
s
.60677 .37137 m .60405 .37127 L .62271 .33251 L p .685 .787 .927 r
F P
0 g
s
.61067 .33085 m .62271 .33251 L .60405 .37127 L p .682 .779 .924 r
F P
0 g
s
.60405 .37127 m .59432 .37027 L .61067 .33085 L p .682 .779 .924 r
F P
0 g
s
.35986 .35777 m .40225 .34454 L .42581 .38471 L p .66 .734 .904 r
F P
0 g
s
.4616 .37683 m .42581 .38471 L .40225 .34454 L p .671 .74 .902 r
F P
0 g
s
.59073 .32876 m .61067 .33085 L .59432 .37027 L p .684 .776 .921 r
F P
0 g
s
.59432 .37027 m .57826 .3691 L .59073 .32876 L p .684 .776 .921 r
F P
0 g
s
.64938 .60736 m .67098 .62064 L .72352 .62259 L p .306 .657 .971 r
F P
0 g
s
.74066 .63663 m .72352 .62259 L .67098 .62064 L p .332 .646 .967 r
F P
0 g
s
.56341 .32709 m .59073 .32876 L .57826 .3691 L p .687 .772 .916 r
F P
0 g
s
.57826 .3691 m .55614 .36849 L .56341 .32709 L p .687 .772 .916 r
F P
0 g
s
.44397 .58925 m .48254 .58099 L .47434 .58022 L p .247 .761 .796 r
F P
0 g
s
.47434 .58022 m .42431 .59093 L .44397 .58925 L p .247 .761 .796 r
F P
0 g
s
.40225 .34454 m .44637 .33503 L .4616 .37683 L p .671 .74 .902 r
F P
0 g
s
.49649 .37167 m .4616 .37683 L .44637 .33503 L p .68 .748 .903 r
F P
0 g
s
.5292 .32694 m .56341 .32709 L .55614 .36849 L p .687 .765 .911 r
F P
0 g
s
.55614 .36849 m .52847 .36907 L .5292 .32694 L p .687 .765 .911 r
F P
0 g
s
.75484 .652 m .7522 .64886 L .84301 .65087 L p .455 .683 .963 r
F P
0 g
s
.84301 .65087 m .84628 .65519 L .75484 .652 L p .455 .683 .963 r
F P
0 g
s
.48956 .32934 m .5292 .32694 L .52847 .36907 L p .685 .757 .906 r
F P
0 g
s
.52847 .36907 m .49649 .37167 L .48956 .32934 L p .685 .757 .906 r
F P
0 g
s
.61797 .59405 m .5765 .58318 L .56155 .58329 L p .004 .551 .83 r
F P
0 g
s
.44637 .33503 m .48956 .32934 L .49649 .37167 L p .68 .748 .903 r
F P
0 g
s
.74954 .64571 m .7522 .64886 L .84301 .65087 L p .453 .685 .965 r
F P
0 g
s
.74066 .63663 m .74954 .64571 L .83953 .64658 L p .447 .688 .968 r
F P
0 g
s
.84301 .65087 m .83953 .64658 L .74954 .64571 L p .453 .685 .965 r
F P
0 g
s
.5765 .58318 m .52711 .57791 L .52327 .57918 L p .005 .575 .774 r
F P
0 g
s
.61797 .59405 m .64938 .60736 L .69539 .60526 L p .28 .675 .971 r
F P
0 g
s
.72352 .62259 m .69539 .60526 L .64938 .60736 L p .306 .657 .971 r
F P
0 g
s
.38301 .60892 m .42431 .59093 L .39244 .58428 L p .573 .915 .968 r
F P
0 g
s
.39244 .58428 m .33685 .60875 L .38301 .60892 L p .573 .915 .968 r
F P
0 g
s
.29872 .63931 m .33685 .60875 L .26272 .5972 L p .677 .897 .976 r
F P
0 g
s
.26272 .5972 m .21078 .64012 L .29872 .63931 L p .677 .897 .976 r
F P
0 g
s
.72352 .62259 m .74066 .63663 L .82801 .63414 L p .439 .697 .974 r
F P
0 g
s
.83953 .64658 m .82801 .63414 L .74066 .63663 L p .447 .688 .968 r
F P
0 g
s
.5765 .58318 m .61797 .59405 L .65382 .58761 L p .264 .7 .963 r
F P
0 g
s
.69539 .60526 m .65382 .58761 L .61797 .59405 L p .28 .675 .971 r
F P
0 g
s
.42431 .59093 m .47434 .58022 L .46022 .56963 L p .446 .859 .957 r
F P
0 g
s
.46022 .56963 m .39244 .58428 L .42431 .59093 L p .446 .859 .957 r
F P
0 g
s
.69539 .60526 m .72352 .62259 L .8054 .61468 L p .426 .71 .983 r
F P
0 g
s
.82801 .63414 m .8054 .61468 L .72352 .62259 L p .439 .697 .974 r
F P
0 g
s
.52711 .57791 m .5765 .58318 L .59839 .5733 L p .28 .739 .953 r
F P
0 g
s
.65382 .58761 m .59839 .5733 L .5765 .58318 L p .264 .7 .963 r
F P
0 g
s
.47434 .58022 m .52711 .57791 L .53172 .56627 L p .34 .793 .948 r
F P
0 g
s
.53172 .56627 m .46022 .56963 L .47434 .58022 L p .34 .793 .948 r
F P
0 g
s
.59839 .5733 m .53172 .56627 L .52711 .57791 L p .28 .739 .953 r
F P
0 g
s
.33685 .60875 m .39244 .58428 L .34031 .56231 L p .614 .889 .989 r
F P
0 g
s
.34031 .56231 m .26272 .5972 L .33685 .60875 L p .614 .889 .989 r
F P
0 g
s
.65382 .58761 m .69539 .60526 L .76733 .59066 L p .418 .73 .99 r
F P
0 g
s
.8054 .61468 m .76733 .59066 L .69539 .60526 L p .426 .71 .983 r
F P
0 g
s
.59839 .5733 m .65382 .58761 L .71 .56591 L p .418 .756 .995 r
F P
0 g
s
.76733 .59066 m .71 .56591 L .65382 .58761 L p .418 .73 .99 r
F P
0 g
s
.39244 .58428 m .46022 .56963 L .43617 .541 L p .542 .864 .995 r
F P
0 g
s
.43617 .541 m .34031 .56231 L .39244 .58428 L p .542 .864 .995 r
F P
0 g
s
.53172 .56627 m .59839 .5733 L .6322 .54568 L p .436 .789 .997 r
F P
0 g
s
.71 .56591 m .6322 .54568 L .59839 .5733 L p .418 .756 .995 r
F P
0 g
s
.46022 .56963 m .53172 .56627 L .53777 .53587 L p .479 .827 .997 r
F P
0 g
s
.53777 .53587 m .43617 .541 L .46022 .56963 L p .479 .827 .997 r
F P
0 g
s
.6322 .54568 m .53777 .53587 L .53172 .56627 L p .436 .789 .997 r
F P
0 g
s
.25 Mabswid
.67926 0 m
.94495 .42182 L
s
.94495 .42182 m
1 .82462 L
s
1 .82462 m
.70489 .4415 L
s
.70489 .4415 m
.67926 0 L
s
.06678 .25008 m
0 .67149 L
s
0 .67149 m
.70489 .4415 L
s
.70489 .4415 m
.67926 0 L
s
.67926 0 m
.06678 .25008 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 279.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00015b000`400?l00000o`00003o`Oooool2
o`0005gooooo002nooooo`?o000000?oooooo`000?ooool0G?ooool00;cooooo0_l00004ooooo`;o
0000G?ooool00;Wooooo0ol00006ooooo`03o`000?oooooo000005_ooooo002gooooo`;o00002Ooo
ool00ol0003oooooo`00001Kooooo`00]Oooool2o`0000_ooooo00Co0000oooooooooooo0000F_oo
ool00;;ooooo0ol0000=ooooo`05o`000?ooooooooooooooool00000FOooool00;3ooooo0_l0000@
ooooo`05o`000?ooooooooooooooool00000FOooool00:gooooo0ol0000Booooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0E_ooool00:_ooooo0_l0000Fooooo`05o`000?oooooooooo
ooooool00000F?ooool00:Sooooo0ol0000Hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0EOooool00:Kooooo0_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0E?ooool00:Cooooo0_l0000Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
E?ooool00:7ooooo0ol0000Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Dooo
ool009oooooo0_l0000Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0D_ooool0
09cooooo0ol0000Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0D_ooool009[o
oooo0_l0000Wooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0DOooool009Oooooo
0ol0000Yooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0D?ooool009Gooooo0_l0
000/ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0D?ooool009?ooooo0_l0000^
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Coooool0093ooooo0ol0000`oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Coooool008kooooo0_l0000cooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0C_ooool008_ooooo0ol0000eooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0COooool008Wooooo0_l0000hooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0COooool008Kooooo0ol0000jooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0C?ooool008Cooooo0_l0000nooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0Boooool008;ooooo0_l00010ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0Boooool007oooooo0ol00012ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0B_ooool007gooooo0_l00015ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0BOooool007[ooooo0ol00017ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0BOooool007Sooooo0_l0001:ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0B?ooool007Gooooo0ol0001<ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0B?ooool007?ooooo0_l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
Aoooool0077ooooo0_l0001Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0A_oo
ool006kooooo0ol0001Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0A_ooool0
06cooooo0_l0001Fooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0AOooool006Wo
oooo0ol0001Hooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0A?ooool006Oooooo
0_l0000Poooooa_o00008?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Cooooo
001Tooooo`?o00007Oooool5o`0000;o[J[D00?o0000ok2/e?n`[=@04?n`[=@00ol0003o];3DokB`
e003okB`e0_o00005Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04?ooooo001R
ooooo`;o00006oooool5o`0000Oo[J[D00?o0000ok2/e?n`[=@04?n`[=@00ol0003o];3DokB`e00>
okB`e0Oo00003_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04;ooooo001Poooo
o`;o00006?ooool5o`0000co[J[D00?o0000ok2/e?n`[=@04?n`[=@00ol0003o];3DokB`e00BokB`
e003o`000?ni]=Go^KCE00?o00002oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
04;ooooo001Mooooo`?o00005_ooool4o`0000;oZZSD00?o0000ojfZe?n]Z]@03On]Z]@00ol0003o
/:cDok2/e00?ok2/e003o`000?nd/=Co];3D01;o];3D00?o0000okVdeOni]=D00oni]=D3o`0000Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`11ooooo`00Foooool2o`0001Kooooo
0ol00007ojZXe003o`000?n]Z]Co[J[D00co[J[D00?o0000ok2/e?n`[=@03on`[=@00ol0003o];3D
okB`e00AokB`e003o`000?ni]=Go^KCE00Oo^KCE0ol00006ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0@Oooool005Sooooo0ol0000Eooooo`?o00002_nZZ=@00ol0003o[J[DojfZ
e00<ojfZe003o`000?n`[=Co/:cD00oo/:cD00?o0000okB`e?nd/=@04Ond/=@00ol0003o^KCEokVd
e@0:okVde@?o00000oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo043ooooo001F
ooooo`;o00005Oooool3o`000003ojRWeOl0003oZZSD00[oZZSD00?o0000ojfZe?n]Z]@03?n]Z]@0
0ol0003o/:cDok2/e00?ok2/e003o`000?nd/=Co];3D017o];3D00?o0000okVdeOni]=D03Oni]=D4
o`0001Sooooo00?o0000ooooooooool0?oooool005?ooooo0ol0000Dooooo`?o00001OnXYmD00ol0
003oZZSDojZXe009ojZXe003o`000?n]Z]Co[J[D00_o[J[D00?o0000ok2/e?n`[=@03on`[=@00ol0
003o];3DokB`e00@okB`e003o`000?ni]=Go^KCE017o^KCE0ol0000Fooooo`03o`000?oooooooooo
03oooooo001Aooooo`;o00004oooool4o`000003ojNWe_l0003oZ:OE00GoZ:OE00?o0000ojZXe?nZ
Z=@02OnZZ=@00ol0003o[J[DojfZe00;ojfZe003o`000?n`[=Co/:cD00oo/:cD00?o0000okB`e?nd
/=@04?nd/=@00ol0003o^KCEokVde@0AokVde@03o`000?ni]=Go^KCE00?o00005?ooool00ol0003o
ooooooooo`0nooooo`00Coooool2o`0001?ooooo0_l000001?nVY]KoYjKFojNVe_l00002ojNWeP03
o`000?nXYmGoZ:OE00CoZ:OE00?o0000ojZXe?nZZ=@02?nZZ=@00ol0003o[J[DojfZe00<ojfZe003
o`000?n`[=Co/:cD00ko/:cD00?o0000okB`e?nd/=@04?nd/=@00ol0003o^KCEokVde@0AokVde@06
o`000?ni]=Go^KCEokVdeOl0003o_K[G0_l0000Cooooo`03o`000?oooooooooo03gooooo001<oooo
o`?o00005?ooool00ol0003oYZKFojJVeP02ojJVeP;oYjKF00?o0000ojNWe_l000001_nXYmD00ol0
003oZZSDojZXe009ojZXe003o`000?n]Z]Co[J[D00_o[J[D00?o0000ok2/e?n`[=@03_n`[=@00ol0
003o];3DokB`e00@okB`e003o`000?ni]=Go^KCE017o^KCE00Co0000okVdeOni]=Go00001?nm^]L0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03gooooo001:ooooo`;o00005Oooool2o`00
00KoYZKF0_nWY]H00ol0003oYjOFo`000006ojRWe@03o`000?nZZ=CoZZSD00SoZZSD00?o0000ojfZ
e?n]Z]@02on]Z]@00ol0003o/:cDok2/e00>ok2/e003o`000?nd/=Co];3D00oo];3D00?o0000okVd
eOni]=D04_ni]=D00ol0003o^KCEo`000006okfje`;o00004Oooool00ol0003oooooooooo`0loooo
o`00Aoooool3o`0001Gooooo0_l000000onTYMOo0000ojJVeP05ojJVeP03o`000?nWY]Ko000000;o
YjOF00?o0000ojRWeOnXYmD00onXYmD00ol0003oZZSDojZXe008ojZXe003o`000?n]Z]Co[J[D00_o
[J[D00?o0000ok2/e?n`[=@03On`[=@00ol0003o];3DokB`e00@okB`e003o`000?ni]=Go^KCE01;o
^KCE00?o0000okVdeOl000002?nm^]L2o`00013ooooo00?o0000ooooooooool0>oooool004Gooooo
0_l0000Fooooo`;o00001?nTYML00ol0003oYZKFojJVeP04ojJVeP;oYjKF00?o0000ojNWe_l00000
1_nXYmD00ol0003oZZSDojZXe008ojZXe003o`000?n]Z]Co[J[D00[o[J[D00?o0000ok2/e?n`[=@0
3On`[=@00ol0003o];3DokB`e00@okB`e003o`000?ni]=Go^KCE01;o^KCE0_l0000;okfje`;o0000
3_ooool00ol0003oooooooooo`0kooooo`00@_ooool3o`0001Oooooo00?o0000ojBUeonTYML01OnT
YML00ol0003oYZKFojJVeP04ojJVeP05ojNVe_l0003oYjOFojNWe_l000001OnXYmD00ol0003oZZSD
ojZXe008ojZXe003o`000?n]Z]Co[J[D00[o[J[D00?o0000ok2/e?n`[=@03On`[=@00ol0003o];3D
okB`e00?okB`e003o`000?ni]=Go^KCE01?o^KCE0_l0000=okfje`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0>_ooool0043ooooo0_l0000Hooooo`;o00002?nTYML00ol0003oYZKFojJV
eP04ojJVeP05o`000?nWY]Ko0000ojNWe_l000001_nXYmD00ol0003oZZSDojZXe007ojZXe003o`00
0?n]Z]Co[J[D00[o[J[D00?o0000ok2/e?n`[=@03On`[=@00ol0003o];3DokB`e00?okB`e003o`00
0?ni]=Go^KCE01?o^KCE00?o0000okfjeonm^]L03Onm^]L2o`0000cooooo00?o0000ooooooooool0
>_ooool003kooooo0_l0000Hooooo`;o00002onTYML00ol0003oYZKFojJVeP04ojJVeP;oYjKF00?o
0000ojNWe_l000001OnXYmD00ol0003oZZSDojZXe008ojZXe003o`000?n]Z]Co[J[D00[o[J[D00?o
0000ok2/e?n`[=@03?n`[=@00ol0003o];3DokB`e00?okB`e003o`000?ni]=Go^KCE01;o^KCE0_l0
000Aokfje`;o00002oooool00ol0003oooooooooo`0iooooo`00>oooool3o`0001Wooooo00?o0000
oj6Tf?l000003?nTYML00ol0003oYZKFojJVeP03ojJVeP03o`000?nWY]Ko000000;oYjOF00?o0000
ojRWeOnXYmD00onXYmD00ol0003oZZSDojZXe007ojZXe003o`000?n]Z]Co[J[D00[o[J[D00?o0000
ok2/e?n`[=@03?n`[=@00ol0003o];3DokB`e00>okB`e003o`000?ni]=Go^KCE01?o^KCE0_l0000C
okfje`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>?ooool003Wooooo0_l0000Joooo
o`;o00000onQY=P00ol0003oY:GGojBUe`09ojBUe`03o`000?nVY]KoYZKF00CoYZKF00Go0000ojNV
e_l0003oYjOFo`000005ojRWe@03o`000?nZZ=CoZZSD00OoZZSD00?o0000ojfZe?n]Z]@02_n]Z]@0
0ol0003o/:cDok2/e00<ok2/e003o`000?nd/=Co];3D00ko];3D00?o0000okVdeOni]=D04_ni]=D0
0ol0003o_K[Go`00000Dokfje`;o00002Oooool00ol0003oooooooooo`0hooooo`00=_ooool3o`00
01_ooooo00?o0000oj6Tf?nQY=P01?nQY=P00ol0003oY:GGojBUe`09ojBUe`03o`000?nVY]KoYZKF
00CoYZKF00Go0000ojNVe_l0003oYjOFo`000005ojRWe@03o`000?nZZ=CoZZSD00OoZZSD00?o0000
ojfZe?n]Z]@02On]Z]@00ol0003o/:cDok2/e00<ok2/e003o`000?nd/=Co];3D00ko];3D00?o0000
okVdeOni]=D04Oni]=D01Ol0003o_K[Gokfjeonm^]Oo000001Go_K[G00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0gooooo`00=?ooool2o`0001gooooo00?o0000oj6Tf?nQY=P01_nQY=P0
0ol0003oY:GGojBUe`09ojBUe`03o`000?nVY]KoYZKF00?oYZKF00Go0000ojNVe_l0003oYjOFo`00
0005ojRWe@03o`000?nZZ=CoZZSD00OoZZSD00?o0000ojfZe?n]Z]@02On]Z]@00ol0003o/:cDok2/
e00<ok2/e003o`000?nd/=Co];3D00ko];3D00?o0000okVdeOni]=D04Oni]=D01Ol0003o_K[Gokfj
eonm^]Oo000001Co_K[G0_l0000:ooooo`03o`000?oooooooooo03Kooooo000aooooo`?o00007Ooo
ool2o`0000[oXJCH00?o0000ojBUeonTYML02?nTYML00ol0003oYZKFojJVeP04ojJVeP05o`000?nW
Y]Ko0000ojNWe_l000001OnXYmD00ol0003oZZSDojZXe006ojZXe003o`000?n]Z]Co[J[D00Wo[J[D
00?o0000ok2/e?n`[=@03?n`[=@00ol0003o];3DokB`e00=okB`e003o`000?ni]=Go^KCE017o^KCE
00?o0000okfjeonm^]L00_nm^]L00ol0003o_K[Gokfje`0Aokfje`04o`000?o0`=[o`<3Jo`0000Wo
oooo00?o0000ooooooooool0=_ooool002oooooo0_l0000Oooooo`03o`000?nQY=SoXJCH00_oXJCH
00?o0000ojBUeonTYML02?nTYML00ol0003oYZKFojJVeP04ojJVeP;o00000_nWYmH00ol0003oZ:OE
ojRWe@02ojRWe@03o`000?nZZ=CoZZSD00OoZZSD00?o0000ojfZe?n]Z]@02On]Z]@00ol0003o/:cD
ok2/e00;ok2/e003o`000?nd/=Co];3D00go];3D00?o0000okVdeOni]=D04Oni]=D00ol0003o_K[G
okfje`02okfje`03o`000?nm^]Oo_K[G013o_K[G00?o0000ol30f_o0`=X00_o0`=X00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03Gooooo000]ooooo`;o00008?ooool00ol0003oXJCHoj6T
f00=oj6Tf003o`000?nTYMOoY:GG00SoY:GG00?o0000ojJVe_nVY]H00onVY]H01Ol0003oYjKFo`00
0?nWYmKo000000GoZ:OE00?o0000ojZXe?nZZ=@01_nZZ=@00ol0003o[J[DojfZe009ojfZe003o`00
0?n`[=Co/:cD00Co/:cD3?l0000;okB`e003o`000?ni]=Go^KCE013o^KCE00?o0000okfjeonm^]L0
0onm^]L00ol0003o_K[Gokfje`0?okfje`03o`000?o0`=[o`<3J00Co`<3J00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0dooooo`00:_ooool3o`0002;ooooo00?o0000oibTf_nQY=P03_nQ
Y=P00ol0003oY:GGojBUe`07ojBUe`03o`000?nVY]KoYZKF00CoYZKF00Go0000ojNVe_l0003oYjOF
o`000004ojRWe@03o`000?nZZ=CoZZSD00KoZZSD00?o0000ojfZe?n]Z]@01?n]Z]@<o`0000Oo/JO>
00?o0000okN/c_ng[<h00_ng[<h7o`0000?o];3D00?o0000okVdeOni]=D04?ni]=D00ol0003o_K[G
okfje`04okfje`03o`000?nm^]Oo_K[G00ko_K[G00?o0000ol30f_o0`=X01_o0`=X00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03Cooooo000Xooooo`;o00009?ooool01Ol0003oW:CJoibT
f_nLY=[o000000koXJCH00?o0000ojBUeonTYML01onTYML00ol0003oYZKFojJVeP04ojJVeP;o0000
00?oYjOFo`000?nXYmD01?nXYmD00ol0003oZZSDojZXe004ojZXe0So00001On]Y<h00ol0003o/JO>
ok6WcP0;ok6WcP03o`000?ng[<ko]jc>00Wo]jc>1_l0000@okVde@03o`000?nm^]Oo_K[G00Co_K[G
00?o0000okfjeonm^]L03Onm^]L00ol0003o`<3Jol30fP08ol30fP03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0<oooool002Gooooo0ol0000Uooooo`03o`000?nLY=[oW:CJ00?oW:CJ00?o
0000oj6Tf?nQY=P03?nQY=P00ol0003oY:GGojBUe`07ojBUe`03o`000?nVY]KoYZKF00?oYZKF00Go
0000ojNVe_l0003oYjOFo`000004ojRWe@03o`000?nZZ=CoZZSD00Co00000_nYX/l00ol0003o[JC>
ojfTcP08ojfTcP03o`000?naYlko/JO>00_o/JO>00?o0000okN/c_ng[<h03?ng[<h00ol0003o_;7?
okbac`04o`0000_o^KCE00?o0000okfjeonm^]L01Onm^]L00ol0003o_K[Gokfje`0<okfje`03o`00
0?o0`=[o`<3J00[o`<3J00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`008ooo
ool2o`0002Oooooo00?o0000oibTf_nLY=X01OnLY=X00ol0003oXJCHoj6Tf00;oj6Tf003o`000?nT
YMOoY:GG00OoY:GG00?o0000ojJVe_nVY]H01?nVY]H2o`0000;oYjOF00Co0000ojRWeOnXYmGoZ:OE
0ol00006ojVRc`03o`000?n]Y<ko[JC>00So[JC>00?o0000ok6Wc_naYlh02onaYlh00ol0003o]jc>
okN/cP0<okN/cP03o`000?nl/Loo_;7?00Co_;7?1?l00007okVde@03o`000?nm^]Oo_K[G00Go_K[G
00?o0000okfjeonm^]L02onm^]L00ol0003o`<3Jol30fP0<ol30fP03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0<_ooool0023ooooo0ol0000Xooooo`03o`000?nLY=[oW:CJ00OoW:CJ00?o
0000oj6Tf?nQY=P02onQY=P00ol0003oY:GGojBUe`07ojBUe`03o`000?nVY]KoYZKF00?oYZKF00Ko
0000ojNVe_l0003oYjOFo`000?nXYmD2o`000003ojNQd?l0003oZJ;?00OoZJ;?00?o0000ojfTc_n]
Y<h01on]Y<h00ol0003o/JO>ok6WcP0;ok6WcP03o`000?ng[<ko]jc>00_o]jc>00?o0000okbaconl
/Ll02Onl/Ll4o`0000;o^KCE00?o0000okfjeonm^]L01_nm^]L00ol0003o_K[Gokfje`0:okfje`03
o`000?o0`=[o`<3J00ko`<3J00?o0000ooooooooool01Oooool00ol0003oooooooooo`0aooooo`00
7_ooool2o`0002[ooooo00?o0000oibTf_nLY=X02OnLY=X2o`0000coXJCH00?o0000ojBUeonTYML0
1onTYML00ol0003oYZKFojJVeP03ojJVeP03o`000?nWY]Ko000000;o00001?nWXM000ol0003oZJ;?
ojVRc`05ojVRc`03o`000?n]Y<ko[JC>00So[JC>00?o0000ok6Wc_naYlh02_naYlh00ol0003o]jc>
okN/cP0;okN/cP03o`000?nl/Loo_;7?00go_;7?0_l00009okfje`03o`000?nm^]Oo_K[G00Wo_K[G
00?o0000ol30f_o0`=X04?o0`=X00ol0003oooooooooo`04ooooo`03o`000?oooooooooo037ooooo
000Looooo`;o0000:oooool00ol0003oW:CJoibTfP0<oibTfP03o`000?nQY=SoXJCH00[oXJCH00?o
0000ojBUeonTYML01_nTYML00ol0003oYZKFojJVeP03ojJVeP?o000000?oYJ3@o`000?nWXM000onW
XM000ol0003oZJ;?ojVRc`05ojVRc`03o`000?n]Y<ko[JC>00So[JC>00?o0000ok6Wc_naYlh02_na
Ylh00ol0003o]jc>okN/cP0;okN/cP03o`000?nl/Loo_;7?00ko_;7?00Co0000ol6hdOl0003o0000
1_nm^]L00ol0003o_K[Gokfje`08okfje`03o`000?o0`=[o`<3J01;o`<3J00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0`ooooo`006Oooool3o`0002cooooo00?o0000oibTf_nLY=X03_nL
Y=X00ol0003oXJCHoj6Tf00:oj6Tf003o`000?nTYMOoY:GG00KoY:GG00?o0000ojJVe_l000000_l0
00001_nTWm7oYJ3@ojFPd?l0003oYJ3@o`0000?oYj7@00?o0000ojVRconYX/l01_nYX/l00ol0003o
[JC>ojfTcP07ojfTcP03o`000?naYlko/JO>00[o/JO>00?o0000okN/c_ng[<h02ong[<h00ol0003o
_;7?okbac`0=okbac`03o`000?o1^=7o`KSA00;o`KSA00?o0000okfjeonm^]L00onm^]L00ol0003o
_K[Gokfje`07okfje`03o`000?o0`=[o`<3J01Co`<3J00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0_ooooo`005oooool2o`0002kooooo00?o0000oibTf_nLY=X04?nLY=X00ol0003oXJCH
oj6Tf00:oj6Tf003o`000?nTYMOoY:GG00GoY:GG0_l00005ojBOd@04ojFPd?l0003oYJ3@o`0000Co
Yj7@00?o0000ojVRconYX/l01OnYX/l00ol0003o[JC>ojfTcP07ojfTcP03o`000?naYlko/JO>00Wo
/JO>00?o0000okN/c_ng[<h02ong[<h00ol0003o_;7?okbac`0>okbac`03o`000?o1^=7o`KSA00?o
`KSA0_l00003okfje`03o`000?nm^]Oo_K[G00Ko_K[G00?o0000ol30f_o0`=X05_o0`=X00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02oooooo000Dooooo`?o0000;oooool00ol0003oW:CJ
oibTfP0BoibTfP03o`000?nQY=SoXJCH00[oXJCH00?o0000ojBUeonTYML00_nTYML2o`000003oj6N
d_nTWm7oY9oA00CoY9oA00Go0000ojFPd?l0003oYJ3@o`000003ojNQd003o`000?nYX/ooZJ;?00Go
ZJ;?00?o0000ojfTc_n]Y<h01on]Y<h00ol0003o/JO>ok6WcP09ok6WcP03o`000?ng[<ko]jc>00_o
]jc>00?o0000okbaconl/Ll03Onl/Ll00ol0003o`KSAol6hd@06ol6hd@;o000000?o_K[Go`000?nm
^]L01_nm^]L00ol0003o`<3Jol30fP0Hol30fP03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0;_ooool001?ooooo0_l0000aooooo`03o`000?nGXmgo000001?oW:CJ0_l0000;oj6Tf004o`00
0?nTYMOo0000o`0000CoXIkB1_nTWm401?nUX=3o0000ojFPd?l00004ojNQd003o`000?nYX/ooZJ;?
00GoZJ;?00?o0000ojfTc_n]Y<h01_n]Y<h00ol0003o/JO>ok6WcP09ok6WcP03o`000?ng[<ko]jc>
00_o]jc>00?o0000okbaconl/Ll03Onl/Ll00ol0003o`KSAol6hd@08ol6hd@?o00001Onm^]L00ol0
003o`<3Jol30fP0Fol30fP;o000000?o`/ONo`000?ooool01Oooool00ol0003oooooooooo`0]oooo
o`004oooool00ol0003oooooo`00000_ooooo`04o`000?nGXmgoUj?MoiNSg@;o00004onLY=X00ol0
003oXJCHoj6Tf008oj6Tf0;o00001onQW]85ojBOd@04o`000?nUX=3o0000o`0000CoYj7@00?o0000
ojVRconYX/l01OnYX/l00ol0003o[JC>ojfTcP06ojfTcP03o`000?naYlko/JO>00Wo/JO>00?o0000
okN/c_ng[<h02ong[<h00ol0003o_;7?okbac`0<okbac`03o`000?o1^=7o`KSA00_o`KSA00?o0000
okfjeonm^]L00_nm^]L00ol0003o`<3Jol30fP0Fol30fP03o`000?o2amko`/ON00;o`/ON00?o0000
ooooooooool00oooool00ol0003oooooooooo`0]ooooo`004oooool01?l0003oooooooooool0000^
ooooo`03o`000?nGXmgoUj?M00?oUj?M00?o0000oibTf_nLY=X04OnLY=X00ol0003oXJCHoj6Tf006
oj6Tf003o`000?nMWM?o000000OoXIkB00?o0000ojBOdOnTWm400onTWm401?nUX=3o0000ojFPd?l0
0004ojNQd003o`000?nYX/ooZJ;?00CoZJ;?00?o0000ojfTc_n]Y<h01_n]Y<h00ol0003o/JO>ok6W
cP09ok6WcP03o`000?ng[<ko]jc>00[o]jc>00?o0000okbaconl/Ll03Onl/Ll00ol0003o`KSAol6h
d@0;ol6hd@?o000000?o_K[Go`000?o0`=X05_o0`=X2o`0000Go`/ON00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0/ooooo`004oooool01Ol0003ooooooooooooooooo000002cooooo00?o
0000oiNSgOnGXmd01OnGXmd00ol0003oW:CJoibTfP0AoibTfP03o`000?nQY=SoXJCH00?oXJCH0_l0
0003oifMd`03o`000?nQW];oXIkB00GoXIkB00?o0000ojBOdOnTWm400_nTWm401?l0003oYJ3@o`00
0?l00004ojNQd003o`000?nYX/ooZJ;?00CoZJ;?00?o0000ojfTc_n]Y<h01_n]Y<h00ol0003o/JO>
ok6WcP09ok6WcP03o`000?ng[<ko]jc>00[o]jc>00?o0000okbaconl/Ll03?nl/Ll00ol0003o`KSA
ol6hd@0<ol6hd@04o`000?o1^=7o`KSAo`0001Ko`<3J0_l00007ol;7gP03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0;?ooool001;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?nGXmgoUj?M00KoUj?M0_l0000BoibTfP05o`000?nQY=SoXJCHoj6Tf?l0
00001_nMWM<00ol0003oXIkBoj6NdP05oj6NdP03o`000?nTWm7oY9oA00;oY9oA0_l000000onUX=3o
0000ojNQd002ojNQd003o`000?nYX/ooZJ;?00GoZJ;?00?o0000ojfTc_n]Y<h01_n]Y<h00ol0003o
/JO>ok6WcP08ok6WcP03o`000?ng[<ko]jc>00[o]jc>00?o0000okbaconl/Ll02onl/Ll00ol0003o
`KSAol6hd@0=ol6hd@05o`000?o1^=7o0000olK1eOl000005?o0`=X00ol0003o`/ONol;7gP08ol;7
gP03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:oooool001;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Wooooo`03o`000?nGXmgoUj?M00WoUj?M00?o0000oibTf_nL
Y=X04?nLY=X00ol0003oXJCHo`000008oifMd`03o`000?nQW];oXIkB00CoXIkB00?o0000ojBOdOnT
Wm400_nTWm401?l0003oYJ3@o`000?l00004ojNQd003o`000?nYX/ooZJ;?00CoZJ;?00?o0000ojfT
c_n]Y<h01_n]Y<h00ol0003o/JO>ok6WcP08ok6WcP03o`000?ng[<ko]jc>00[o]jc>00?o0000okba
conl/Ll02onl/Ll00ol0003o`KSAol6hd@0=ol6hd@;o00000oo6`MD00ol0003o`<3Jol30fP0?ol30
fP;o00002oo2amh00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02[ooooo000Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003oUj?MoiNSg@0:oiNSg@;o
00004OnLY=X00ol0003oWIgCoifMd`07oifMd`03o`000?nQW];oXIkB00GoXIkB00?o0000ojBOdOnT
Wm400_nTWm42o`000003ojFPd?l0003oYj7@00;oYj7@00?o0000ojVRconYX/l01?nYX/l00ol0003o
[JC>ojfTcP06ojfTcP03o`000?naYlko/JO>00?o/JO>3?l00005okN/cP03o`000?nl/Loo_;7?00_o
_;7?00?o0000ol6hdOo1^=403_o1^=400ol0003oa/7EolK1e@03olK1e@03o`000?o0`=[o`<3J00co
`<3J0_l0000>ol;7gP03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:_ooool001;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Uooooo`03o`000?nGXmgoUj?M00coUj?M
00?o0000oibTf_nLY=X03OnLY=X2o`0000[oWIgC00?o0000oj6Nd_nQW]801OnQW]801_l0003oY9oA
ojBOdOnTWm7o0000ojFPd0;o00001?nWXM000ol0003oZJ;?ojVRc`04ojVRc`04o`000?n]Y<ko[JC>
ojfTcP[o00001OnbX/L00ol0003o^:K7okRVa`04okRVa`So00002onl/Ll00ol0003o`KSAol6hd@0=
ol6hd@;o00001_o6`MD00ol0003o`<3Jol30fP0:ol30fP03o`000?o2amko`/ON00ko`/ON00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`004_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02?ooooo00?o0000oiNSgOnGXmd03_nGXmd00ol0003oW:CJoibTfP0;oibT
fP04o`000?nGVmKoUi_Fo`0000[oWIgC00?o0000oj6Nd_nQW]801?nQW]800ol0003oY9oAojBOd@02
ojBOd@?o00001?nWXM000ol0003oZJ;?ojVRc`03ojVRc`Go00001?n]WLP00ol0003o/Z;7ok:Ra`08
ok:Ra`03o`000?nhY/Oo^:K700Wo^:K700?o0000okn]b?no[LP01?l00006okbac`03o`000?o1^=7o
`KSA00go`KSA00?o0000olK1eOl000001oo6`MD00ol0003o`<3Jol30fP07ol30fP;o00004Oo2amh0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Sooooo000Booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool08_ooool00ol0003oUj?MoiNSg@0?oiNSg@;o00002_nLY=X00ol0
003oUi_FoiNKeP02oiNKeP03o`000?nMWM?oWIgC00SoWIgC00?o0000oj6Nd_nQW]801?nQW]801_l0
003oY9oAojBOdOnTWm7o0000ojFPd0;o00000onWXM000ol0003oZJ;?ojVRc`03o`000003ojRKb?l0
003o[Ig800Ko[Ig800?o0000ok:RaonbX/L02?nbX/L00ol0003o^:K7okRVa`09okRVa`03o`000?no
[LSo_jg800Co_jg81?l00002okbac`03o`000?o1^=7o`KSA00co`KSA00Co0000olK1eOo6`MGo0000
2?o6`MD00ol0003o`<3Jol30fP04ol30fP;o00005?o2amh00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Sooooo000Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08?oo
ool00ol0003oUj?MoiNSg@0BoiNSg@03o`000?nLY=[oW:CJ00KoW:CJ00?o0000oiNKe_nGVmH01?nG
VmH00ol0003oWIgCoifMd`07oifMd`03o`000?nQW];oXIkB00GoXIkB00Co0000ojBOdOnTWm7oY9oA
0ol00002ojNQd0Co00001?nXVlP00ol0003o[Ig8ojfMb005ojfMb003o`000?nbX/Oo/Z;700So/Z;7
00?o0000okRVaonhY/L02OnhY/L00ol0003o_jg8okn]b008okn]b0;o00003_o1^=401Ol0003oa/7E
olK1eOo6`MGo000000Woa/7E00?o0000ol30f_o0`=X00_o0`=X00ol0003o`/ONol;7gP0Dol;7gP03
o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool0017ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Oooooo`03o`000?nGXmgoUj?M01?oUj?M0_l00005oibTfP03o`00
0?nGVmKoUi_F00KoUi_F00?o0000oifMdonMWM<01onMWM<00ol0003oXIkBoj6NdP04oj6NdP06o`00
0?nTWm7oY9oAojBOdOl0003oYJ3@0ol00002ojFJb@03o`000?nXVlSoZ9_800CoZ9_800?o0000ojfM
b?n]WLP01On]WLP00ol0003o/Z;7ok:Ra`07ok:Ra`03o`000?nhY/Oo^:K700So^:K700?o0000okn]
b?no[LP02_no[LP01?l0003oa[K;o`000?l0000:ol6hd@03o`000?o6`MGoa/7E00;oa/7E00?o0000
olK1eOo6`MD02?o6`MD01?l0003o`<3Jo`000?l0000Hol;7gP03o`000?oooooooooo00Kooooo00?o
0000ooooooooool09_ooool0017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0M
ooooo`03o`000?nGXmgoUj?M01KoUj?M00Go0000oibTf_nLY=[oW:CJo`00000:oiNKeP03o`000?nM
WM?oWIgC00OoWIgC00?o0000oj6Nd_nQW]801?nQW]800ol0003oY9oAojBOd@04o`0000CoYI[900?o
0000ojRKb?nXVlP00onXVlP00ol0003o[Ig8ojfMb005ojfMb003o`000?nbX/Oo/Z;700Oo/Z;700?o
0000okRVaonhY/L02?nhY/L00ol0003o_jg8okn]b009okn]b003o`000?o6]/_oa[K;00;oa[K;0_l0
0007ol6hd@03o`000?o6`MGoa/7E00?oa/7E00?o0000olK1eOo6`MD02Oo6`MD00ol0003o`/ONol;7
gP0Hol;7gP03o`000?oooooooooo00Kooooo00?o0000ooooooooool09_ooool0017ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Looooo`04o`000?nAY>;o0000o`0001KoUj?M00?o
0000oibTf_l000003?nGVmH00ol0003oWIgCoifMd`06oifMd`03o`000?nQW];oXIkB00CoXIkB0ol0
00000onQV<_oY9W:ojBIbP02o`0000?oYI[900?o0000ojRKb?nXVlP00onXVlP00ol0003o[Ig8ojfM
b005ojfMb003o`000?nbX/Oo/Z;700Oo/Z;700?o0000okRVaonhY/L02?nhY/L00ol0003o_jg8okn]
b009okn]b003o`000?o6]/_oa[K;00Coa[K;0_l00004ol6hd@03o`000?o6`MGoa/7E00Coa/7E00?o
0000olK1eOo6`MD01oo6`MD00ol0003ob/_Ko`00000Jol;7gP03o`000?oooooooooo00Oooooo00?o
0000ooooooooool09Oooool0017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0K
ooooo`04o`000?nAY>;oTJCRoi6ThP;o00005OnGXmd00ol0003oUi_FoiNKeP0<oiNKeP03o`000?nM
WM?oWIgC00KoWIgC00Co0000oj6Nd_nQW];oXIkB0_l000000onNU/_oXIS;oj6Hb`02oj6Hb`03ojBI
b_l0003o000000?oYI[900?o0000ojRKb?nXVlP01?nXVlP00ol0003o[Ig8ojfMb004ojfMb003o`00
0?nbX/Oo/Z;700Oo/Z;700?o0000okRVaonhY/L02?nhY/L00ol0003o_jg8okn]b008okn]b003o`00
0?o6]/_oa[K;00Ooa[K;0_l000000oo1^=7o0000olK1e@06olK1e@03o`000?o6`MGoa/7E00Koa/7E
00Go0000ol[;foo:bm_ob/_Ko`00000Jol;7gP03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool09Oooool0017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`03o`00
0?nAY>;oTJCR00?oTJCR0_l0000CoiNSg@03o`000?n@Vm[o000000goUi_F00?o0000oifMdonMWM<0
1_nMWM<00ol0003oXIkBo`000004oijFb`?oXIS;00Co0000ojBIb_l0003o00000onUV/T00ol0003o
Z9_8ojRKb003ojRKb003o`000?n]WLSo[Ig800Co[Ig800?o0000ok:RaonbX/L01onbX/L00ol0003o
^:K7okRVa`08okRVa`03o`000?no[LSo_jg800So_jg800?o0000olJfboo6]//02Oo6]//00ol0003o
a/7EolK1e@06olK1e@03o`000?o6`MGoa/7E00Goa/7E00?o0000ol[;foo:bm/00_o:bm/00ol0003o
`/ONol;7gP0Eol;7gP;o000000?o`/oTo`000?ooool02?ooool00ol0003oooooooooo`0Tooooo`00
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000oi6Th_nAY>80
1_nAY>82o`00013oUj?M00Go0000oi2Kf_n@Vm[oT9_Jo`00000=oiNKeP03o`000?nMWM?oWIgC00Go
WIgC0_l00005oijFb`05o`000?nQV<_oXIS;oj6HbonTVLX00_l00003ojFJb@03o`000?nXVlSoZ9_8
00?oZ9_800?o0000ojfMb?n]WLP01?n]WLP00ol0003o/Z;7ok:Ra`07ok:Ra`03o`000?nhY/Oo^:K7
00So^:K700?o0000okn]b?no[LP01ono[LP00ol0003oa[K;olJfb`0:olJfb`;o00002?o6`MD00ol0
003oa/7EolK1e@03olK1e@03o`000?o:bm_ob/_K00?ob/_K00?o0000ol;7g_o2amh04_o2amh3o`00
00?o`/oT00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`004?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01Oooooo00?o0000oi6Th_nAY>802?nAY>82o`0000ko
Uj?M00?o0000oi2Kf_n@VmX00_n@VmX00ol0003oUi_FoiNKeP0;oiNKeP03o`000?nMWM?oWIgC00;o
WIgC0_l000000onIU<go0000oijFb`05oijFb`05o`000?nQV<_oXIS;o`000?nTVLX00_l00003ojFJ
b@03o`000?nXVlSoZ9_800?oZ9_800?o0000ojfMb?n]WLP01?n]WLP00ol0003o/Z;7ok:Ra`06ok:R
a`03o`000?nhY/Oo^:K700Oo^:K700?o0000okn]b?no[LP02?no[LP00ol0003oa[K;olJfb`09olJf
b`04o`000?o=`LoocL7?o`0000Ooa/7E00Co0000olK1eOo6`MGoa/7E0_l00007ol[;f`03o`000?o2
amko`/ON00oo`/ON0_l00006ol;?i003o`000?oooooooooo00Sooooo00?o0000ooooooooool08ooo
ool0013ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`03o`000?nAY>;o
TJCR00[oTJCR0_l0000;oiNSg@03o`000?n@Vm[oT9_J00CoT9_J0_l0000<oiNKeP04o`000?nMWM?o
0000o`0000CoVIC=00?o0000oijFbonNU//00onNU//01?l0003oXIS;oj6HbonQV</3o`0000?oYI[9
00?o0000ojRKb?nXVlP00onXVlP00ol0003o[Ig8ojfMb004ojfMb003o`000?nbX/Oo/Z;700Ko/Z;7
00?o0000okRVaonhY/L01onhY/L00ol0003o_jg8okn]b008okn]b003o`000?o6]/_oa[K;00Soa[K;
00?o0000olg1coo=`Ll00_o=`Ll00ol0003oa/7EolK1e@04olK1e@04o`000?o6`MGoa/7Eo`0000Wo
b/_K00?o0000ol;7g_o2amh03Oo2amh2o`0000So`/oT00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Rooooo`004?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo
00?o0000oi6Th_nAY>803?nAY>82o`0000SoUj?M00?o0000oi2Kf_n@VmX01on@VmX00ol0003oUi_F
oiNKeP0:oiNKeP03o`000?nIU<goVIC=00GoVIC=00?o0000oijFbonNU//00onNU//01Ol0003oXIS;
oj6HbonQV<_oY9W:00;o00000onUV/T00ol0003oZ9_8ojRKb002ojRKb003o`000?n]WLSo[Ig800?o
[Ig85ol00007okn]b003o`000?o6]/_oa[K;00Woa[K;00?o0000olg1coo=`Ll00oo=`Ll00ol0003o
a/7EolK1e@03olK1e@03o`000?o6`MGo000000_ob/_K00?o0000ol;7g_o2amh02Oo2amh3o`0000[o
`/oT00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`004?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000oi6Th_nAY>803_nAY>82o`0000KoUj?M
00?o0000oi2Kf_n@VmX02?n@VmX00ol0003oUi_FoiNKeP08oiNKeP;o00001onIU<d00ol0003oWYK;
oijFb`03oijFb`04o`000?nQV<_oXIS;oj6Hb`?o00000onUV/T00ol0003oZ9_8ojRKb003ojRKb003
o`000?n]WLSo000000;o000000?o[9O1o`000?nbVl001onbVl000ol0003o^J70okVQ`007okVQ`003
o`000?o2Z<3o`ZS000Go00000_no[LP00ol0003oa[K;olJfb`08olJfb`03o`000?o=`LoocL7?00Go
cL7?00?o0000olK1eOo6`MD00_o6`MD2o`0000cob/_K00?o0000ol;7g_o2amh01oo2amh2o`0000go
`/oT00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`004?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01?ooooo00?o0000oi6Th_nAY>804?nAY>82o`0000?oUj?M
00?o0000oi2Kf_n@VmX02_n@VmX2o`0000OoUi_F00Co0000oi:Bd?nBT]3o00001onIU<d00ol0003o
WYK;oijFb`03oijFb`05o`000?nQV<_oXIS;oj6HbonTVLX00_l00002ojFJb@04o`000?nXVlSoZ9_8
ojRKb0Co00001?n/Ul400ol0003o/Y_0ok:K`006ok:K`003o`000?niXL3o^J7000Oo^J7000?o0000
ol:X`?o2Z<001Oo2Z<03o`0000Woa[K;00?o0000olg1coo=`Ll01oo=`Ll01Ol0003oa/7EolK1eOo6
`MGo000000kob/_K00?o0000ol;7g_o2amh01?o2amh2o`0000oo`/oT00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Pooooo`004?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01;ooooo00?o0000oi6Th_nAY>804_nAY>82o`000003oiNSgOl0003oT9_J00goT9_J00?o0000
oiNKe_nGVmH00onGVmH00ol0003oTY;@oi:Bd002oi:Bd003o`000?nIU<goVIC=00GoVIC=00?o0000
oijFbonNU//00_nNU//01?l0003oXIS;oj6HbonQV</3o`0000;oYI[99_l00002ol:X`004o`000?o;
/l;o0000o`0000Koa[K;00?o0000olg1coo=`Ll02Oo=`Ll01?l0003oa/7Eo`000?l0000>ol[;f`04
o`000?o2amko`/ONol;7gP?o00004Oo2cn@00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01oooooo000?ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04?ooool00ol0003o
TJCRoi6ThP0Eoi6ThP03o`000?n@Vm[oT9_J00koT9_J00Go0000oiNKe_nGVmKoUi_Fo`000006oi:B
d003o`000?nIU<goVIC=00CoVIC=00?o0000oijFbonNU//00onNU//00ol0003oXIS;oj6Hb`07o`00
00?o[[oW00?o0000ojo1ion_`NL02?n_`NL00ol0003o[l?Yojo3j@07ojo3j@03o`000?n_aN[o[lGZ
00Go[lGZ00Co0000ojo6jon_a^_o[lK[2?l00004olJfb`03o`000?o=`LoocL7?00[ocL7?00?o0000
ol[;fol000003_o:bm/01?l0003o`/ONo`000?l0000Col;?i003o`000?oooooooooo00gooooo00?o
0000ooooooooool07oooool000oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?
ooooo`03o`000?nAY>;oTJCR01GoTJCR00Co0000ohNJgol0003o00003_n@VmX00ol0003oUi_Fo`00
0007oi:Bd003o`000?nIU<goVIC=00GoVIC=00Co0000oijFbonNU/_oWYK;1Ol00009ojjoi`03o`00
0?n_`NOo[l7W00So[l7W00?o0000ojo3jOn_`nT01on_`nT00ol0003o[lGZojo5jP04ojo5jP03o`00
0?n_a^_o[lK[00Co[lK[00?o0000ojk7k?n^an`02?l0000;olg1c`;o000000?ob/_Ko`000?o:bm/0
3_o:bm/00ol0003o`/oTol;?i00Col;?i003o`000?oooooooooo00kooooo00?o0000ooooooooool0
7_ooool000oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>ooooo`03o`000?nA
Y>;oTJCR01GoTJCR00Go0000ohNJgon7V]ooQi[Oo`00000>oi2KfP03o`000?nBT]3oTY;@00OoTY;@
00?o0000oiVDcOnIU<d00onIU<d5o`0000;oZkgV00?o0000ojjoion^_nL02On^_nL00ol0003o[l7W
ojo1i`08ojo1i`03o`000?n_`nWo[l?Y00Oo[l?Y00?o0000ojo5j_n_aNX01?n_aNX00ol0003o[lK[
ojo6j`03ojo6j`03o`000?n^anco[/O/00Co00000on]and00ol0003o[LS]o`000002o`0000OocL7?
00?o0000om?>eOoCc]D00_l0000<ol[;f`;o000000?obmGQo`000?o2cn@05?o2cn@00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01kooooo000?ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool03Oooool00ol0003oTJCRoi6ThP0Eoi6ThP03o`000?n7V]ooQi[O00;oQi[O0_l0
000<oi2KfP;o00002OnBT]05o`0000SoZkgV00?o0000ojjoion^_nL02On^_nL00ol0003o[l7Wojo1
i`07ojo1i`03o`000?n_`nWo[l?Y00Ko[l?Y00?o0000ojo5j_n_aNX01On_aNX00ol0003o[lK[ojo6
j`03ojo6j`03o`000?n^anco[/O/00?o00000on]and00ol0003o[LS]ojg8k@03ojg8k@Go000000?o
cL7?o`000?oCc]D00_oCc]D2o`0000[ob/_K0_l00003ol_Eh@03o`000?o2cnCo`/oT01?o`/oT00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`003oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00cooooo00?o0000oh^Wion;YnL00ol0000Boi6ThP03o`000?n7V]oo
Qi[O00CoQi[O0_l00009oi2KfP04o`000?n8SmCoR8oDo`0000KoTY;@0ol0000<oj^miP03o`000?n^
_nOo[[oW00Wo[[oW00?o0000ojo1ion_`NL01on_`NL00ol0003o[l?Yojo3j@06ojo3j@03o`000?n_
aN[o[lGZ00Co[lGZ00?o0000ojo6jon_a^/00on_a^/00ol0003o[/O/ojk7k004o`0000;o[LO]00?o
0000ojg8kOn]b>d01?n]b>d00ol0003o[<S^ojc8kP02ojc8kPCo00000_oCc]D00ol0003ob/_Kol[;
f`06ol[;f`;o00001Oo;eN400ol0003o`/oTol;?i00Col;?i003o`000?oooooooooo013ooooo00?o
0000ooooooooool07?ooool000oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;
ooooo`03o`000?n;YnOoRjOW00?oRjOW0ol0000?oi6ThP03o`000?n7V]ooQi[O00KoQi[O00?o0000
oi2Kf_n@VmX01_n@VmX01Ol0003oR8oDohR?e?n8SmCo000000;oTY;@0ol000000onX^nOo0000oj^m
iP0<oj^miP03o`000?n^_nOo[[oW00Wo[[oW00?o0000ojo1ion_`NL01on_`NL00ol0003o[l?Yojo3
j@06ojo3j@03o`000?n_aN[o[lGZ00Co[lGZ00?o0000ojo6jon_a^/00on_a^/00ol0003o[/O/ojk7
k003o`0000?o[LO]00?o0000ojg8kOn]b>d00on]b>d00ol0003o[<S^ojc8kP05ojc8kP03o`000?nZ
anoo000000;o00001_o:bm/2o`0000OobmGQ00?o0000ol;?i?o2cn@04oo2cn@00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01cooooo000?ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool02oooool00ol0003oRjOWoh^Wi`05oh^Wi`Co00002_nAY>800ol0003oQi[OohNJg`08
ohNJg`;o00001On@VmX00ol0003oR8oDohR?e002ohR?e0?o00001OnX^nL00ol0003oZkgVoj^miP0;
oj^miP03o`000?n^_nOo[[oW00So[[oW00?o0000ojo1ion_`NL01on_`NL00ol0003o[l?Yojo3j@06
ojo3j@03o`000?n_aN[o[lGZ00Co[lGZ00?o0000ojo6jon_a^/00_n_a^/00ol0003o[/O/ojk7k004
o`0000;o[LO]00?o0000ojg8kOn]b>d00on]b>d00ol0003o[<S^ojc8kP05ojc8kP03o`000?nZanoo
Z/O_00;oZ/O_1?l000000oo:bm_o0000o`000009ol_Eh@03o`000?o2cnCo`/oT01?o`/oT00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Kooooo`003_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00[ooooo00?o0000oh^Wion;YnL02On;YnL3o`0000OoTJCR00?o0000ohNJ
gon7V]l02_n7V]l2o`0000;oT9_J00?o0000ohR?e?n8Sm@00ol00009ojRki`03o`000?n[_NKoZkgV
00[oZkgV00?o0000ojjoion^_nL02?n^_nL00ol0003o[l7Wojo1i`07ojo1i`03o`000?n_`nWo[l?Y
00Ko[l?Y00?o0000ojo5j_n_aNX00on_aNX00ol0003o[lK[ojo6j`03ojo6j`03o`000?n^anco[/O/
00?o00000_n]and00ol0003o[LS]ojg8k@04ojg8k@03o`000?n/b>ko[<S^00Co[<S^00?o0000oj[7
konZanl00onZanl00ol0003oZ/O_oj[7k`03o`0000[obmGQ00?o0000ol;?i?o2cn@04Oo2cn@00ol0
003o`/oTo`00000Dooooo`03o`000?oooooooooo01[ooooo000>ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool02Oooool00ol0003oRjOWoh^Wi`0<oh^Wi`?o00001?nAY>800ol0003o
Qi[OohNJg`0<ohNJg`03o`000?n@Vm[o000000;o00003?nX^nL00ol0003oZkgVoj^miP0:oj^miP03
o`000?n^_nOo[[oW00So[[oW00?o0000ojo1ion_`NL01on_`NL00ol0003o[l?Yojo3j@06ojo3j@03
o`000?n_aN[o[lGZ00?o[lGZ00?o0000ojo6jon_a^/00on_a^/00ol0003o[/O/ojk7k003o`0000;o
[LO]00?o0000ojg8kOn]b>d00on]b>d00ol0003o[<S^ojc8kP04ojc8kP03o`000?nZanooZ/O_00Co
Z/O_00?o0000oj[7kol000000onWa_02o`0000SobmGQ00?o0000ol;?i?o2cn@03?o2cn@5o`0000;o
`=GY00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Jooooo`003_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Sooooo00?o0000oh^Wion;YnL03on;YnL3o`000003oi6T
h_l0003oQi[O00coQi[O0ol000000onU^nSo0000ojRki`0=ojRki`03o`000?n[_NKoZkgV00[oZkgV
00?o0000ojjoion^_nL01on^_nL00ol0003o[l7Wojo1i`07ojo1i`03o`000?n_`nWo[l?Y00Go[l?Y
00?o0000ojo5j_n_aNX01?n_aNX00ol0003o[lK[ojo6j`02ojo6j`03o`000?n^anco[/O/00Co0000
00?o[LO]o`000?n]b>d01?n]b>d00ol0003o[<S^ojc8kP04ojc8kP03o`000?nZanooZ/O_00KoZ/O_
00?o0000ojO6l?nWa_001?nWa_03o`0000GobmGQ00?o0000ol;?i?o2cn@02?o2cn@4o`0000Ko`=GY
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Iooooo`003_ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00Sooooo00?o0000oh^Wion;YnL04On;YnL2o`0000[oQi[O0ol0
0005ojFkj003o`000?nX^nOoZ;_W00coZ;_W00?o0000oj^mi_n[_NH02On[_NH00ol0003o[[oWojjo
i`08ojjoi`03o`000?n_`NOo[l7W00Ko[l7W00?o0000ojo3jOn_`nT01On_`nT00ol0003o[lGZojo5
jP03ojo5jP03o`000?n_a^_o[lK[00?o[lK[00?o0000ojk7k?n^an`00ol00002ojg7k@03o`000?n]
b>go[LS]00;o[LS]00?o0000ojc8k_n/b>h01?n/b>h00ol0003oZ/O_oj[7k`06oj[7k`;o00002OnW
a_02o`0000?obmGQ00?o0000ol;?i?o2cn@01?o2cn@4o`0000[o`=GY00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Hooooo`003_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00Oooooo00?o0000oh^Wion;YnL04_n;YnL00ol0003oO9cVo`000002o`0000?oQi[O0ol00009
ojFkj003o`000?nX^nOoZ;_W00_oZ;_W00?o0000oj^mi_n[_NH02On[_NH00ol0003o[[oWojjoi`08
ojjoi`03o`000?n_`NOo[l7W00;o[l7W7_l000000on]ango0000ojg8k@04ojg8k@03o`000?n/b>ko
[<S^00?o[<S^00?o0000oj[7konZanl01_nZanl00ol0003oYlK`o`00000:ojO6l0?o000000?obmGQ
o`000?o2cn@01Ol0000=ol3Ej@03o`000?oooooooooo01Kooooo00?o0000ooooooooool06?ooool0
00kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?n;YnOoRjOW
01;oRjOW00?o0000ogbLi_mlW>H00_mlW>H3o`0000goYK_X00?o0000ojRkionX^nL02onX^nL00ol0
003oZkgVoj^miP09oj^miP03o`000?n^_nOo[[oW00;o[[oW2_l00004okC2i@03o`000?neaNOo]LGW
00Go]LGW00?o0000okG8jOneb>T00oneb>T00ol0003o]<_[okC;j`02okC;j`03o`000?ncc>go/lc]
00So00000_n]b>d00ol0003o[<S^ojc8kP03ojc8kP03o`000?nZanooZ/O_00KoZ/O_00Co0000ojO6
l?nWa_3o00002OnWa_001?l0003oYLC`ojG4l?nUa?03o`0001;o`=GY00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`003Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Kooooo00?o0000oh^Wion;YnL04On;YnL01?l0003oO9cVogbLi_mlW>H2o`0000?oXk_Z00?o
0000ojFkj?nU^nP02_nU^nP00ol0003oZ;_WojRki`0:ojRki`03o`000?n[_NKoZkgV00OoZkgV1ol0
0005ok6nh`03o`000?nd`^Go]<;U00Ko]<;U00?o0000okG5ioneaNL01OneaNL00ol0003o]LSYokG8
j@03okG8j@05o`000?ndbn_o]<_[okC;jol000000_ncc>d4o`000003ok7=k_l0003o/<g_00;o/<g_
1Ol00002ojc8kP03o`000?nZanooZ/O_00KoZ/O_00Go0000ojO6l?nWa_3oYlK`o`000007ojO6l0;o
00001OnUa?02o`00017o`=GY00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`00
3Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00?o0000oh^Wion;YnL0
4_n;YnL3o`0000KoXk_Z00?o0000ojFkj?nU^nP02_nU^nP00ol0003oZ;_WojRki`0:ojRki`04o`00
0?n[_NKoZkgVoj^miPGo00000_n^^^<00ol0003o/KkSok6nh`07ok6nh`03o`000?nd`^Go]<;U00Ko
]<;U00?o0000okG5ioneaNL01OneaNL00ol0003o]LSYokG8j@02okG8j@03o`000?ndbn_o]<_[00;o
]<_[00?o0000ok?<kOncc>d00ol000000onacNko0000ok3=k`04ok3=k`04o`000?n^c_3o[/k`ojk>
l0Co00001_nZanl00ol0003oYlK`ojO6l002ojO6l003o`000?nWa_3oYlK`00CoYlK`00?o0000ojG4
l?nUa?001onUa?02o`0000oo`=GY00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Foooo
o`003Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Cooooo00?o0000oh^Wion;
YnL04On;YnL2o`0000WoXk_Z00?o0000ojFkj?nU^nP02_nU^nP00ol0003oZ;_WojRki`08ojRki`Go
00002?n^^^<00ol0003o/KkSok6nh`06ok6nh`03o`000?nd`^Go]<;U00Ko]<;U00?o0000okG5ione
aNL01OneaNL00ol0003o]LSYokG8j@02okG8j@03o`000?ndbn_o]<_[00;o]<_[00?o0000ok?<kOl0
00000_l00002ok7=kP03o`000?n`cNoo/<g_00;o/<g_00?o0000ojk>l?n^c_000on^c_000ol0003o
Zlgboj_=lP03o`0000;oZ/O_00?o0000ojO6l?nWa_000onWa_000ol0003oYlK`ojO6l002ojO6l0;o
00003?nUa?000ol0003o`=GYol3Ej@0<ol3Ej@03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool05Oooool000gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`03ooooo`03o`00
0?n;YnOoRjOW00ooRjOW0_l0000<oj>kjP03o`000?nU^nSoYK_X00[oYK_X00?o0000ojRkionX^nL0
1?nX^nL3o`0000;oZKST00?o0000ojjjhon^^^<02?n^^^<00ol0003o/KkSok6nh`06ok6nh`03o`00
0?nd`^Go]<;U00Ko]<;U00?o0000okG5ioneaNL01?neaNL00ol0003o]LSYokG8j@03okG8j@05o`00
0?ndbn_o]<_[okC;jol000000_ncc>d3o`000003ok7=k_l0003o/<g_00?o/<g_00?o0000ojk>l?n^
c_000on^c_000ol0003oZlgboj_=lP04oj_=lP?o00001OnWa_001Ol0003oYlK`ojO6l?nWa_3o0000
00koYLC`0ol0000;ol3Ej@03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool000go
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`03ooooo`03o`000?n;YnOoRjOW00co
RjOW0_l0000?oj>kjP03o`000?nU^nSoYK_X00[oYK_X00?o0000ojRkionX^nL00ol00006ojVhi003
o`000?n^^^?o[[[S00Oo[[[S00?o0000ok6nhona_^<01ona_^<00ol0003o]<;UokC2i@05okC2i@03
o`000?neaNOo]LGW00Co]LGW00?o0000okG8jOneb>T00oneb>T01Ol0003o]<_[okC;jondbn_o0000
00;o/lc]0_l00002ok7=kP05o`000?n`cNoo/<g_ok3=kol000001On^c_000ol0003oZlgboj_=lP04
oj_=lP04o`000?nWbo?oYl_cojO;l`?o00000_nWa_001?l0003oYlK`o`000?l0000=ojG4l0;o0000
0onS`^l00ol0003o`=GYol3Ej@08ol3Ej@03o`000?oooooooooo01cooooo00?o0000ooooooooool0
5?ooool000gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`02ooooo`Go00002On;
YnL01Ol0003oX;c/oj2lk?nP_>co000000koXk_Z00?o0000ojFkj?nU^nP02_nU^nP2o`0000WoZKST
00?o0000ojjjhon^^^<02?n^^^<00ol0003o/KkSok6nh`06ok6nh`03o`000?nd`^Go]<;U00Go]<;U
00?o0000okG5ioneaNL01?neaNL00ol0003o]LSYokG8j@02okG8j@03o`000?ndbn_o]<_[00;o]<_[
00?o0000ok?<kOl000000_l000000onacNko0000ok3=k`02ok3=k`03o`000?n^c_3o[/k`00?o[/k`
00?o0000oj_=l_n[cO801?n[cO800ol0003oYl_cojO;l`05ojO;l`Co00003OnUa?02o`0000KoXl;_
00?o0000ol3EjOo0eNT01_o0eNT00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo
000<ooooo`03o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`000004ohF[kPOo0000
00?oRjOWo`000?nP_>`01?nP_>`2o`0000goXk_Z00?o0000ojFkj?nU^nP01_nU^nP2o`000003ojBg
i_l0003oZKST00[oZKST00?o0000ojjjhon^^^<01on^^^<00ol0003o/KkSok6nh`06ok6nh`03o`00
0?nd`^Go]<;U00Go]<;U00?o0000okG5ioneaNL01?neaNL00ol0003o]LSYokG8j@08o`000003ok?<
kOl0003o000000;o/Lg^00Co0000ok3=kon`cNoo00001On^c_000ol0003oZlgboj_=lP04oj_=lP03
o`000?nWbo?oYl_c00OoYl_c0ol0000;ojG4l0;o00002OnS`^l00ol0003o`=GYol3Ej@05ol3Ej@03
o`000?oooooooooo01kooooo00?o0000ooooooooool04oooool000cooooo00?o0000ooooooooool0
<?ooool01Ol0003ooooooooooooooooo000000[oQJ_^00?o0000oj2lk?nP_>`01_nP_>`00ol0003o
Xk_Zoj>kjP0;oj>kjP03o`000?nU^nSoYK_X00;oYK_X0ol00004ojBgiP03o`000?nY^>CoZKST00Wo
ZKST00?o0000ojjjhon^^^<01_n^^^<00ol0003o/KkSok6nh`06ok6nh`04o`000?nd`^Go]<;UokC2
i@ko00000_nlcNL01_l0003o^m7Zok_Aj_nkdN[o0000ok[Ck@_o00000_n^c_000ol0003oZlgboj_=
lP04oj_=lP03o`000?nWbo?oYl_c00OoYl_c00Co0000oj;8lol0003oX/Sc0_l00008ojG4l003o`00
0?nS`^ooXl;_00[oXl;_1ol0000Rooooo`03o`000?oooooooooo01;ooooo000<ooooo`03o`000?oo
oooooooo037ooooo00Go0000ooooooooooooooooo`000008ohF[kP03o`000?nP_>coX;c/00SoX;c/
0_l0000<oj>kjP04o`000?nU^nSo0000o`0000SoY;OV00?o0000ojVhi?nY^>@02?nY^>@00ol0003o
[[[Sojjjh`07ojjjh`04o`000?na_^?o/KkSok6nh`So00001?nj`^000ol0003o_<SSokc8h`04okc8
h`03o`000?nlcNOo_<gW00;o_<gW00Co0000ok_Aj_nkdN[o00000_njdnd2o`0000;o^=G_00Co0000
okKFlOnfe_7o00000onbe_<3o`0000GoZlgb00?o0000ojO;lonWbo<01_nWbo<2o`0000;oX/Sc00Go
0000oj;8lonRb??oX/Sco`000005ojG4l0;o00003_nS`^l00ol0003o_=W_okcIk`02okcIk`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool04Oooool000cooooo00?o0000ooooooooool0<_oo
ool01Ol0003ooooooooooooooooo000000KoQJ_^00?o0000oj2lk?nP_>`02onP_>`00ol0003oXk_Z
oj>kjP0:oj>kjP03o`000?nT]nKoY;OV00SoY;OV00?o0000ojVhi?nY^>@02OnY^>@00ol0003o[[[S
ojjjh`04ojjjh`Ko00001?nf_=h00ol0003o^/;Pok[2h005ok[2h003o`000?nlb>?o_<SS00?o_<SS
00?o0000okc=ionlcNL00_nlcNL01_l0003o^m7Zok_Aj_nkdN[o0000ok[Ck@;o00000_nheNl01?l0
003o]]KaokKFlOl00004ok;Fl`03o`000?n/e_Ko[=Kf00?o000000?oZlgbo`000?nWbo<01onWbo<0
0ol0003oX/Scoj;8l`02oj;8l`03o`000?nRb??oX/Sc00;oX/Sc0_l000000onUa?3o0000o`00000@
oj?2k`;o00000_nlfNl00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo017ooooo000<oooo
o`03o`000?oooooooooo03?ooooo00Co0000oooooooooooo00001On5Znh00ol0003oX;c/oj2lk00=
oj2lk003o`000?nS^n[oXk_Z00KoXk_Z0_l00002oingj@03o`000?nT]nKoY;OV00SoY;OV00?o0000
ojVhi?nY^>@02?nY^>@00ol0003o[[[Sojjjh`04o`0000;o/;ON00?o0000okJlg_nf_=h01Onf_=h0
0ol0003o^/;Pok[2h005ok[2h003o`000?nlb>?o_<SS00?o_<SS00?o0000okc=ionlcNL00_nlcNL0
1?l0003o^m7Zok_Aj_l00002ok[Ck@;o000000Go^=G_o`000?nfe_7o]]Kao`000004ok;Fl`03o`00
0?n/e_Ko[=Kf00?o[=Kf1?l00005ojO;l`;o00001OnRb?<00ol0003oX/Scoj;8l`03oj;8l`?o0000
3_nS`^l3o`000004oj6nk_l0003o_=W_o`0002Kooooo00?o0000ooooooooool04?ooool000cooooo
00?o0000ooooooooool0=?ooool01?l0003oooooooooool00003ohF[kP03o`000?nO_NkoWkg^00;o
00003OnP_>`2o`0000CoXk_Z0_l00005oingj@03o`000?nT]nKoY;OV00SoY;OV00?o0000ojVhi?nY
^>@01onY^>@3o`0000Ko/;ON00?o0000okJlg_nf_=h01_nf_=h00ol0003o^/;Pok[2h004ok[2h003
o`000?nlb>?o_<SS00?o_<SS00?o0000okc=ionlcNL00_nlcNL01Ol0003o^m7Zok_Aj_l0003o^]?]
00;o00000_nheNl01?l0003o]]KaokKFlOl00003ok;Fl`03o`000?n/e_Ko[=Kf00?o[=Kf00?o0000
ojCBn?nTd_P00_nTd_P3o`000003ojO;lol0003oX/Sc00KoX/Sc00?o0000oj;8lonRb?<00ol00003
oik3lP03o`000?nS`^ooXl;_00WoXl;_0_l00005oj6nkP03o`000?oooooooooo02Gooooo00?o0000
ooooooooool04?ooool000cooooo00?o0000ooooooooool0=Oooool2o`000004ooooool0003oQJ_^
o`0000GoWkg^0_l0000=oj2lk004o`000?nS^n[o0000o`0000SoWkOY00?o0000ojBgi_nT]nH01onT
]nH00ol0003oZKSTojVhi004ojVhi0?o000000?oZ[?Oo`000?n`]mh01on`]mh00ol0003o][cNokJl
gP05okJlgP03o`000?nj`^3o^/;P00Co^/;P00?o0000okc8honlb><00_nlb><00ol0003o_<gWokc=
i`02okc=i`06o`000?nkdN[o^m7Zok_Aj_l0003o^]?]0_l000001OnheNoo0000okKFlOnfe_7o0000
00?o/]Kc00?o0000ojcFm_n/e_H00on/e_H00ol0003oY=;hojCBn005ojCBn0Co00001onRb?<2o`00
00OoW/?b00?o0000oj?2konS`^l01_nS`^l2o`0000SoXKk^00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0?ooooo`002oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo000000So
Wkg^0_l0000<oj2lk003o`000?nO]nWoWkOY00WoWkOY00?o0000ojBgi_nT]nH01onT]nH00ol0003o
ZKSTojVhi003o`0000GoZ[?O00?o0000ok2gg_n`]mh01On`]mh00ol0003o][cNokJlgP05okJlgP03
o`000?nj`^3o^/;P00Co^/;P00?o0000okc8honlb><06_l00002ojcFmP03o`000?nTd_SoY=;h00Co
Y=;h0_l00004oic<n0?o000000?oX/Sco`000?l000000_l00009oik3lP03o`000?nS`^ooXl;_00;o
Xl;_0ol0000;oj6nkP03o`000?oooooooooo02?ooooo0ol0000@ooooo`002oooool00ol0003ooooo
ooooo`0iooooo`03o`000?nO_NkoWkg^00WoWkg^0_l00008oj2lk005o`000?nK^NgoVkW]oi^ikOl0
00002_nO]nT00ol0003oY;OVojBgiP06ojBgiP?o00002?nZ/ml00ol0003o/;ONok2ggP05ok2ggP03
o`000?nf_=ko][cN00Ko][cN00?o0000ok[2h?nj`^001_l00002olK:gP03o`000?o7d^?oam;S00;o
am;S00Go0000olKIj?o6fNSo0000olCMk002o`000005ol7Qkol0003o_N?bokgSl_l000000_ngi?D0
0ol0003o[>;iojcRn@02ojcRn@Go00000_nTd_P2o`0000SoW<ch0ol00002oik3lP03o`000?nN`o;o
W/?b00SoW/?b00Co0000oj?2kol0003o00003onQ_^h00ol0003oooooooooo`0Oooooo`?o00000_oo
ool00ol0003oooooooooo`0>ooooo`002oooool00ol0003oooooooooo`0hooooo`03o`000?nO_Nko
Wkg^00coWkg^0_l00004oj2lk0;o00001OnK^Nd2o`0000WoWkOY00?o0000ojBgi_nT]nH00_nT]nH3
o`000003oj:ah_l0003oZ[?O00WoZ[?O00?o0000ok2gg_n`]mh01?n`]mh00ol0003o][cNokJlgP04
okJlgPGo00000oo2`MX00ol0003oa/[NolK:gP02olK:gP05o`000?o7d^?oam;SolOBhol000000_o6
fNP01_l0003oa=g/o`000?l0003o`N7_o`0000;o_N?b00Co0000okOTmOngi?Go00000on/h_T2o`00
00GoWMcm0ol00006oic<n0?o00000onFa?H00ol0003oW/?bo`000009oik3lP?o00004_nQ_^h00ol0
003oooooooooo`0Kooooo`?o00001Oooool00ol0003oooooooooo`0>ooooo`002oooool00ol0003o
ooooooooo`0hooooo`03o`000?nN_o3o000000;o00003?nO_Nh2o`000003oj2lk?l0003oVkW]00So
VkW]00?o0000oingjOnO]nT01onO]nT01?l0003oY;OVo`000?l00005oj:ahP03o`000?nZ/mooZ[?O
00OoZ[?O00?o0000ok2gg_n`]mh01On`]mh00ol0003o][cNo`000003o`0000;o^kWG00?o0000ol;1
f_o2`MX00oo2`MX00ol0003oa/[NolK:gP02olK:gP05o`000?o7d^?oam;SolOBhol000000_o6fNP0
0ol0003oa=g/o`000002o`0000;o_N?b00Co0000okOTmOngi?Go00000on/h_T00ol0003oWMcmoigL
o@03oigLo@;o00000on?dOh3o`000003oic<n?l0003o000000OoU/Cf0_l00005oik3lPCo00000onL
_Nl00ol0003oXKk^oj6nkP0>oj6nkP?o00006Oooool3o`0000Sooooo00?o0000ooooooooool03_oo
ool000_ooooo00?o0000ooooooooool0=oooool00ol0003oW[o`oijol003oijol0;o00003?nO_Nh0
0ol0003oVkW]oi^ik@09oi^ik@03o`000?nO]nWoWkOY00OoWkOY00?o0000oj:ah_nR/N801_nR/N80
0ol0003oZ[?OojZcg`06ojZcg`03o`000?n`]mko/;ON00;o/;ON1Ol00006ok^ie`03o`000?o2`M[o
`/7J00?o`/7J00?o0000olK:g_o6b]h00_o6b]h01Ol0003oam;SolOBhoo7d^?o000000;oa]WX00?o
0000olCMk?l000003_l00002oigLo@03o`000?n?dOkoSm7n00GoSm7n0ol00009oiK4mP03o`000?nN
`o;oW/?b00?o00002?nL_Nl00ol0003oXKk^oj6nkP09oj6nkPCo00000_nQ_>`00ol0003ooooooooo
o`0Dooooo`?o00002oooool00ol0003oooooooooo`0>ooooo`002oooool00ol0003oooooooooo`0f
ooooo`03o`000?nN_o3oW[o`00KoW[o`0ol00008oinmkP03o`000?nH^o3oV;_`00;o00002OnK^Nd2
o`0000CoWkOY0_l00002oi^ai`03o`000?nR/N;oX[7R00KoX[7R00?o0000ojZcgonZ/ml01?nZ/ml6
o`0000?o/k;G00?o0000ok^ieonk^ML01Onk^ML00ol0003o`/7Jol;1fP03ol;1fP03o`000?o6b]ko
a/[N00;oa/[N00?o0000olOBhol000002?l000001?o5lnko0000okSdl_l00003oj?_m`03o`000?n7
h_[oQn;j00;oQn;j1Ol00003ohoAoP?o00000on6a?`00ol0003oU/CfoiK4mP05oiK4mPCo00003?nL
_Nl00ol0003oXKk^oj6nkP05oj6nkP?o00001onQ_>`00ol0003oooooooooo`0?ooooo`Co00003ooo
ool00ol0003oooooooooo`0=ooooo`002_ooool00ol0003oooooooooo`0fooooo`03o`000?nN_o3o
W[o`00[oW[o`0_l00005oinmkP03o`000?nH^o3oV;_`00?oV;_`0_l00009oi^ik@04o`000?nO]nWo
0000o`0000GoVk7W00?o0000oj:ah_nR/N801_nR/N800ol0003oZ[?OojZcg`03o`0000;oZZcI00?o
0000ok>beonc/]L01Onc/]L00ol0003o^kWGok^ie`04ok^ie`03o`000?o2`M[o`/7J00?o`/7J00?o
0000olK:g_o6b]h01?l000001_oDf=_o0000omCSh_oDhn;o0000om;[iP;o000000?oaO?^o`000?l0
00004_l00007ohK4o003o`000?nFa?KoU/Cf00Oo00003_nL_Nl00ol0003oXKk^oj6nkP04o`0000[o
XKc/00?o0000ooooooooool03?ooool3o`0001?ooooo00?o0000ooooooooool03Oooool000[ooooo
00?o0000ooooooooool0=Oooool00ol0003oW[o`oijol00=oijol0?o000000?oWkg^o`000?nH^o00
1onH^o000ol0003oVkW]oi^ik@07oi^ik@03o`000?nK/NOoVk7W00KoVk7W00?o0000oj:ah_nR/N80
1_nR/N82o`0000KoZZcI00?o0000ok>beonc/]L01?nc/]L00ol0003o^kWGok^ie`04ok^ie`03o`00
0?o2`M[o`/7J00Ko00000_o@c=H01ol0003oe=SKomCHfol0003oe>?Ro`000?oBjnH02Ol00008oooo
o`;o000000?o8ioZo`000?l000000_mU_Od2o`0000?oQ/Cl2?l00002oi>klP03o`000?nC^o;o0000
00coW;g_1?l0000?oj6lk003o`000?oooooooooo00Sooooo0ol0000Fooooo`03o`000?oooooooooo
00gooooo000:ooooo`03o`000?oooooooooo03Gooooo00?o0000oio1lOnO`O400ol0000=oijol003
o`000?nH^o3oV;_`00SoV;_`0_l00004oi^ik@;o00000onC/nd00ol0003oVk7Woi^ai`05oi^ai`03
o`000?nR/N;oX[7R00;oX[7R0_l000000onPZMgo0000ojZ/f@06ojZ/f@03o`000?nc/]Oo/k;G00Co
/k;G00?o0000ok^ieonk^ML00onk^ML4o`0000?obKoA00?o0000om3<e_o@c=H00_o@c=H00ol0003o
e=SKo`000002omCShPSo00002oooool<o`0000;oQ;Kf0ol00006oi>klP03o`000?nC^o;o000000Oo
W;g_1?l00002oibhk003o`000?nQ_>coXKc/00ooXKc/00?o0000ooooooooool01?ooool3o`0001Wo
oooo00?o0000ooooooooool03Oooool000[ooooo00?o0000ooooooooool0=?ooool00ol0003oWl7a
oio1l@04oio1l@?o00002OnN_o000ol0003oUkkcoiNnl`02o`0000WoV;_`0_l000000onK^Ngo0000
oi>ck@05oi>ck@;o00001_nK/NL01?l0003oX[7Ro`000?l00004oj2Yg@03o`000?nZ[=WoZZcI00Go
ZZcI00?o0000ok>beonc/]L01?nc/]L00ol0003o^kWGo`000002o`000003ol2dc_l0003obKoA00Co
bKoA00Go0000om3<e_o@c=Kod<cFo`000002omCHf`?o000000?ohOSGo`000?l000000_l0000=oooo
o`Go00000_liU?400ol0003oJJcgofV/m`02ofV/m`?o00000on4]_H00ol0003oTk_boi>klP04oi>k
lP03o`000?nC^o;o000000;oW;g_1?l00007oibhk003o`000?nQ_>coXKc/00koXKc/00Co0000oooo
oooooooooooo0ol0000Looooo`03o`000?oooooooooo00gooooo000:ooooo`03o`000?oooooooooo
03?ooooo00?o0000oio1lOnO`O402?nO`O43o`0000GoW[o`00?o0000oiNnlonG__<00onG__<3o`00
00SoV;_`00?o0000oi>ckOnC/nd01onC/nd00ol0003oVk7Woi^ai`04oi^ai`03o`000?nPZMgoX:WM
00GoX:WM00?o0000ojZ/fOnZ[=T01?nZ[=T01?l0003o/k;Gok>beonc/]L5o`0000Co`;C>00?o0000
olVodOo9_m400oo9_m401_l0003od<cFom3<e_o@c=Ko0000omCHf`;o000000?oiNgDo`000?l00000
0_l0000>ooooo`Go000000?o:fcLo`000?l000001Ol000000omY[?Oo0000ohBfmP04ohBfmP03o`00
0?nC^o;oTk_b00;oTk_b1_l0000;oibhk003o`000?nQ_>coXKc/00coXKc/1_l0000Oooooo`03o`00
0?oooooooooo00gooooo000:ooooo`03o`000?oooooooooo03;ooooo00?o0000oio1lOnO`O403?nO
`O43o`000003oijol?l0003oUkkc00SoUkkc0_l00004oiRkl005o`000?n=]o;oSKObohfgl_l00000
2?nC/nd00ol0003oVk7Wo`000002o`000003oiBXhol0003oX:WM00KoX:WM00?o0000ojZ/fOnZ[=T0
1?nZ[=T4o`0000?o]Z_>00?o0000ol2dc_o0]<h01?o0]<h00ol0003obKoAolVod@02olVod@03o`00
0?o@c=Ko000000?o000000Cohmg?o`000?l0003ohOSG0_l0000=oooooa_o00000_nD/nd00ol0003o
U;?]o`00000=oibhk003o`000?nQ_>coXKc/00KoXKc/1Ol00003oj:ij@03o`000?oooooooooo01oo
oooo00?o0000ooooooooool03Oooool000Wooooo00?o0000ooooooooool0<oooool00ol0003oWl;a
oio2l@04o`0000_oWl7a00?o0000oiNnlonG__<02_nG__<2o`000003oiRkl?l0003oSKOb00CoSKOb
0_l00007oi>ck@03o`000?nDZ>?oU:SS00?oU:SS00?o0000oj2YgOnPZMd01OnPZMd00ol0003oZZcI
ojZ/f@03o`000003ojZTd?l0003o]Z_>00Go]Z_>00?o0000ol2dc_o0]<h00oo0]<h00ol0003obKoA
olVod@04o`0000;ofl_:00?o0000on?McooSgLl01Ol0000<ooooo`_o00000_mHS>P00ol0003oMIo/
ogFOk002ogFOk003o`000?n8[>goR:c]00?oR:c]00?o0000oiBckOnD/nd01?nD/nd00ol0003oU;?]
o`00000<oibhk004o`000?nQ_>coXKc/oj6lk0Go00002OnR^NT00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00cooooo0009ooooo`03o`000?oooooooooo03;ooooo00?o0000oio2lOnO`_40
1OnO`_44o`0000OoWl7a00?o0000oiO1m?nG`O@00ol00009oiNnl`03o`000?n=]o;oSKOb00KoSKOb
00Co0000oi>ckOnC/ngoTk?]0_l00002ohRZj`03o`000?nDZ>?oU:SS00?oU:SS00?o0000oj2YgOnP
ZMd01OnPZMd2o`0000GoZZC@00?o0000okJ[c_nfZlh00onfZlh00ol0003o`;C>ol2dcP02ol2dcPCo
00000_o@_<H01_l0003ofl_:om_;b_oKbl[o0000on?Mc`Go00002oooool<o`000003oeYad?l0003o
000000;o00001?meWn`00ol0003oR:c]ohR/k@03ohR/k@03o`000?nD/ngoU;?]00CoU;?]00?o0000
oiBckOl000002OnL^>`6o`0000koX[WY00?o0000ooooooooool07oooool00ol0003oooooooooo`0<
ooooo`002Oooool00ol0003oooooooooo`0booooo`03o`000?nO`_7oWl;a00WoWl;a1?l00002oio1
l@03o`000?nG`OCoUl7d00CoUl7d0ol00005oiNnl`03o`000?n9^oOoRK_g00;o00001_n=]o800ol0
003oTk?]o`000005ohRZj`03o`000?nDZ>?oU:SS00?oU:SS00?o0000oj2YgOnPZMd00ol000000onL
WmKo0000ojZTd005ojZTd003o`000?nfZlko]Z_>00?o]Z_>00?o0000ol2dc_l000000_l000000oo4
[/Co0000om2laP03om2laP04o`000?oKbl[ofl_:om_;bP?o000000?omO6fo`000?l000002oooool3
o`000003oa/07_l0003o000000Co000000GoETf[o`000?l0003oFW7@o`000002og67f@Ko00001_n8
[>d00ol0003oU;?]oiBck@04oiBck@;o00000onL^>`6o`0000?oW[GX00?o0000oj:ijOnR^NT03_nR
^NT00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo0009ooooo`03o`000?oooooo
oooo037ooooo00?o0000oj33lOnP`o400_nP`o45o`0000OoWl;a0_l0000:oiO1m0?o000000?oUkkc
o`000?n9^oL01?n9^oL2o`0000GoSKOb00?o0000ohRZjon8Z^/01On8Z^/00ol0003oU:SSoiBXh`02
oiBXh`?o00001OnLWmH00ol0003oZZC@ojZTd003ojZTd004o`000?nfZlko]Z_>okJ[cPCo00001?o4
[/@00ol0003od;c6om2laP02om2laP03o`000?oKbl[o000000;o000000ColMfko`000?l0003o0000
2_ooool6o`000003oaH0@ol0003o000000?o000000GoETf[o`000?l0003oFW7@o`000003og67f@04
o`000?n3V=ooPiSOoh>Hga?o00002_nN]NP00ol0003oX[WYoj:ij@0>oj:ij@03o`000?oooooooooo
01kooooo00?o0000ooooooooool03?ooool000Wooooo00?o0000ooooooooool0<Oooool01Ol0003o
W/Ccoik4lonNa??o000000GoX<?a1Ol00003oio2l@03o`000?nH`oKoV<?f00Co00001onG`O@00ol0
003oRK_gohVkm`06ohVkm`;o000000?oSKObo`000?mk[_<00_mk[_<00ol0003oR:[[ohRZj`04ohRZ
j`06o`000?nDZ>?o0000o`000?n=W=go00001_nLWmH00ol0003oZZC@ojZTd003ojZTd0Co00000ong
XlD00ol0003oa:k4olB^a003olB^a003o`000?o@_<Kod;c600?o00000_oTb;/00ol0003olMfko`00
0002o`0000Oooooo1ol000001Om404go0000o`000?l0003oC25j00;o00000_mFCJ/5o`0000;oLHOI
00?o0000oh>Hgon3V=l00_n3V=l00ol0003oSjGTohnUi004ohnUi003o`000?nH[^KoV:kV00CoV:kV
0_l0000<oijej003o`000?nR^NWoX[WY00koX[WY00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0<ooooo`002Oooool00ol0003oooooooooo`0aooooo`Go00001OnNa?<4o`000004oj33lOl0
003o0000o`0000OoV<?f1?l00002oiO1m004o`000?n8`?WoR<3iohS0n@?o00001On9^oL00ol0003o
Njkcog^^l`03og^^l`;o00001On8Z^/00ol0003oSIcMohfLg@02ohfLg@03o`000?nLWmKoW9oF00?o
W9oF00?o0000ojZTd?nZY=000ol000000onYVlOo0000okNSa@04okNSa@03o`000?o4[/Coa:k400?o
a:k40ol000000ooE][[o0000onC8^`02onC8^`04o`000?oagK_o0000o`0000?ooooo2?l000001?lk
02Go0000o`000?m404d3o`000008od`QN_l0003o0000o`000?mFCJ_o0000ofMR^?l00002ogQfa0?o
000000?oLHOIo`000?n3V=l00_n3V=l00ol0003oSjGTohnUi004ohnUi003o`000?nH[^KoV:kV00Go
V:kV0_l0000;oijej003o`000?nR^NWoX[WY00koX[WY00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0<ooooo`002Oooool00ol0003oooooooooo`0aooooo`03o`000?nP`o7oX<?a00;oX<?a
2Ol000001?nNa??o0000o`000?l00002oiW5mPCo00001OnH`oH2o`0000OoR<3i0ol000001On9^oOo
0000og2cn_m`/o[o000000GoNjkc00Co0000ohRZjol0003o00000_mhW>P00ol0003oSIcMohfLg@02
ohfLg@03o`000?nLWmKoW9oF00;oW9oF0ol00004ojVKa`03o`000?ngXlGo]j?500Co]j?500?o0000
olB^a?o4[/@00ol00003omFf^P04o`000?oTb;_oi<RkonC8^`co000000?o:000o`000?lk02D00_l0
00001Om404go0000oedPJOl0003oC25j00Ko000000GoIf:ho`000?mhM/CoN7K4o`000002ohF7c@Go
000000?oPiSOo`000?n?YN@01On?YN@00ol0003oV:kVoiR^iP05oiR^iP03o`000?nN]NSoW[GX00[o
W[GX00?o0000oj:ijOnR^NT01_nR^NT9o`0001oooooo00?o0000ooooooooool03?ooool000Sooooo
00?o0000ooooooooool0<Oooool5o`0000WoX<?a1?l00003oi?6n@04o`000?nIaOKoVLGfoiW5mPCo
00000_nH`oH01?l0003oRLCkohW4non9a?/3o`0000CoR<3i00?o0000og2cn_m`/oX00om`/oX00ol0
003oNjkcog^^l`02og^^l`03o`000?mhW>SoN9cX00?oN9cX00?o0000ohfLgOn=W=d00_n=W=d01_l0
003oW9oFo`000?l0003oVI?=o`0000KoZI_700?o0000okNSaOngXlD00_ngXlD4o`0000;oaZNj00Ko
0000omFf^_oE][[oeKJjo`000?oTb;/3o`000004oo_FWOl0003o0000oc<000Co000000?o>@00o`00
0?l000000ol000000omJ2dco0000o`000002oedPJ@Go00000_mgFjD3o`0000;oN7K400Go0000ohF7
cOn5QlgoQHO=o`000003oi2Fe@Ko00000_n?YN@00ol0003oV:kVoiR^iP05oiR^iP;o00001OnN]NP?
o`0000SoY;SW00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`002?ooool00ol0
003oooooooooo`0aooooo`03o`000?nQa?7oXLCa00;oXLCa1ol00005oj33l@04o`000?nIaOKoVLGf
oiW5mPCoTlKi0ol000000onIaOKo0000o`000009ohW4n`;o00000_mZ^Od00ol0003oL;?jog2cnP02
og2cnP;o000000GoNjkco`000?mNWO;oGYgbo`000004ogRLj003o`000?n=W=goSIcM00?o00001?nI
Tld00ol0003oZI_7ojVKa`03ojVKa`03o`000?ngXlGo000000;o000000?o^9^ko`000?o6YkX00oo6
YkX00ol0003oeKJjo`000003o`0000;ojl6Z00?o0000oo_FWOl000000ol000000om<00Go0000o`00
0002o`000004od/09_l0003oFP]<oeX;C0;o00000_mM86T6o`0000;oMe^U00?o0000oh=[/?l00000
0ol00003ohF7c@03o`000?n@U]GoT9KE00;oT9KE00?o0000oiRRg?nHX]`00_nHX]`Ao`0000KoX[?U
00?o0000ojBhionT^>L03_nT^>L00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo
0008ooooo`03o`000?oooooooooo037ooooo1Ol00009oj74l@;o000000?oX<?ao`000?l000001Ol0
0003oiW5mP04o`000?nCa_Wo0000o`0000?oR/Kl1Ol00002ohW4n`03o`000?mX__ko000000?oJ[Wm
0_l00002og2cnP03o`000?mNWO;oGYgb00;oGYgb00?o0000ogRLj?mhW>P00_mhW>P2o`0000;oPhkE
00?o0000oiVCcOnITld00_nITld01?l0003oZI_7ojVKaonYVlL4o`0000Co^9^k00Co0000olJW^_o6
Yk[oaZNj0ol00002omR_[P04o`000?o[`J[ojl6Zon_1ZP?o000000?oG00>o`000?m<00D00_l00000
1OmE02Oo0000o`000?l0003oFP]<00;o000000?oKbMTo`000?mM86T01Ol000001?m/C9[o0000ogMK
YOl00002oh=[/003o`000?n<Nk_oS7^k00;o00000_n5Qld00ol0003oT9KEoi2Fe@02oi2Fe@03o`00
0?nHX]coV:;L00CoV:;L00?o0000oif/hOnM[>401_nM[>42o`0000[oX[?U00?o0000ojBhionT^>L0
3_nT^>L00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo0008ooooo`03o`000?oo
oooooooo037ooooo00?o0000oj;5lOnRaO400_nRaO46o`0000KoXLCa00?o0000oi_7m_nKaoH01?nK
aoH4o`000005oiW5m_l0003o0000o`000?n;b?`00ol00003oh[6o0;o00001OmX__h2o`000003ofZi
oOl0003o@9gd00;o@9gd00Wo0000oejMl_mNWO;oGYgbo`000?mhW>So0000ofB8hOl000001?n3S]D0
1?l0003oVI?=oiVCcOnITld4o`0000;oYi6n00?o0000okRK^onhVk/01?nhVk/3o`000003olNO[ol0
003of:n^00;of:n^1Ol000000oonaggo0000o`000003o`000004oeD09ol0003o0000of8<A@;o0000
0om_9f@6o`000005ohEGTol0003o0000ogMKYOl000000_n3Jk001Ol0003oS7^kohak^ol0003oUHW5
00?o00001?n@U]D00ol0003oV:;LoiRRg004oiRRg003o`000?nM[>7oWJcQ00KoWJcQ00?o0000oj:c
iOl000002OnR/nD00ol0003oY;SWojBhi`0>ojBhi`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool02oooool000Sooooo00?o0000ooooooooool0<Oooool00ol0003oX/Gaoj;5l@0:oj;5l@;o
000000?oXLCao`000?l000001Ol00006oi_7mP03o`000?n>b_coS/[l00?o00000on;b?`6o`000005
ofS2o_mX__koJ;knofRno_l000000_lVW>d01Ol0003o@9gdod2Mm?m0WOCo000000;oGYgb00Go0000
ofB8hOmTR>7oI8SQo`000003oh>>e@06o`000?nITlgo0000o`000?nDQl?o00001OnWTKh00ol0003o
^9^kokRK^`04o`0000?oain_1?l000001_oH[jko0000o`000?o]^9Wo0000ook7O@;o000000?oH`0]
o`000?mE02L00_l000000omR34Go0000o`000002oflWI0Oo00000_n5Ei<00ol0003oSFBMo`000003
o`0000?oS7^k00Co0000oiF9aOnERLGoUHW51?l000000on@U]Go0000oiRRg006oiRRg003o`000?nM
[>7oWJcQ00KoWJcQ00?o0000oj:ciOl000002OnR/nD00ol0003oY;SWojBhi`0=ojBhi`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool02oooool000Sooooo00?o0000ooooooooool0<Oooool0
0ol0003oX/Gaoj;5l@0=oj;5l@03o`000?nMb?KoWLSf00CoWLSf1?l000000onKaoKo0000o`000004
o`0000?oS/[l1Ol00002of[5oPCo00000_lBVm`2o`0000;o9Yc]00?o0000od2Mm?l000000_lbOnL0
1?l0003oI8SQofB8hOl00002oh>>e@?o00001?nDQl<01?l0003oYi6nojNA__nWTKh4o`0000?o]i>a
00?o0000olNO[ol000000ol000001?oH[jko0000o`000?l00002onfhV@Oo000000[oI0Xoo`000?l0
003oLR=Io`000?m_9fCo0000ogdjLOl0003oQDEi0ol00002ohEGT`04o`000?n=I9goSFBMo`0000;o
UW:Y0_l000000on<Nk_o0000oiF9a@03oiF9a@04o`000?nKUlkoViO>oi^GcPKo00000onHX]`00ol0
003oWJcQoif/h@06oif/h@03o`000?nR/nGo000000WoX[?U00?o0000ojBhionT^>L03OnT^>L00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo0007ooooo`03o`000?oooooooooo03;o
oooo2Ol00007oj;5l@03o`000?nMb?KoWLSf00WoWLSf00?o0000oi?=o?nCcO`00onCcO`;o`000003
of[5o_l0003o000000;o000000?oI000oa:Kg?lBVm`00_l000000omA003o06OAo`000002oc9oi`03
o`000?mTR>7o000000;o00000_miOL/00ol0003oU8O3oiB7``02oiB7``06o`000?nWTKko0000o`00
0?nUQkCo00001?ngTk43o`000003olNO[ol0003o000000;o00000_oJYj801ol0003okKRIo`000?l0
003oo;MUo`000?m]4d<01?l00003og8SF@;o000000CoOCYao`000?n5AGWo00000_n?DX<2o`000004
ohEGTol0003oSFBMo`0000?oUW:Y00Co0000oib0]?l0003o00001?nERLD00ol0003oViO>oi^GcP02
oi^GcP03o`000?nPX]OoX:;G00;oX:;G:Ol0000Pooooo`03o`000?oooooooooo00_ooooo0007oooo
o`03o`000?oooooooooo03;ooooo00?o0000ojC6lOnTa_401_nTa_46o`000003oj;5lOl0003o0000
00Go00001OnMb?H00ol0003oTlgloi?=o007oi?=o005o`000?mkd?ooNm3oog_@ool000000_mkd?l4
o`0000;o?;gV1_l000000omA003o0000oc9oi`02o`000003ode_dol0003oNGg;00?oNGg;00?o0000
oiB7`onDQl<00ol00004ojF7]0So00000_o8V:H00ol0003ofZNRomZWXP03o`000003onf^Rol0003o
o;MU00Co000000?oKAM:o`000?l000000_l000001On1=FGo0000o`000?n5AGWo000000;oSe:300?o
0000oiIMRonFGH/00_l000001On=I9go0000oiIbZOnFLZWo000000?oW82d0ol000000onERLGo0000
oi^GcP04oi^GcP03o`000?nPX]OoX:;G00GoX:;G00?o0000oj>/gOnS[=d01_nS[=d01Ol0003oYK?R
ojFch_nU/n;o000000OoYK?R00?o0000ojJhi_nV^>H03OnV^>H00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00_ooooo0007ooooo`03o`000?oooooooooo03;ooooo00?o0000ojC6lOnTa_40
3OnTa_400ol0003oX/[eoj;:m@04oj;:m@ko000000?oTlglo`000?l000000_l00003ohgIo`Co0000
00CoV>Wjo`000?l0003o00000_nnmnl00ol0003oh>kJon3^fP02o`000005o`1?cOl0003oCFoCode_
dol000000_miOL/4o`0000;oT7^i00?o0000ojF7]?nUQk@01Ol00002okJ;Z004o`000?o8V:Kob9RV
olRHYPCo00000_oJWiP00ol0003okJj;onf^R`04o`000003ofdGB_l0003o000000;oPCEU0_l00000
1_n=@F_o0000o`000?l0003oSe:3o`0000;oUUf;00?o0000oieZU_nMJYH00ol000000onFLZWo0000
oib0]002oib0]003o`000?nQS[ooXHjo00Go00000_nKUlh00ol0003oX:;Goj2Re`05oj2Re`03o`00
0?nS[=goXjcM00KoXjcM00?o0000ojFch_nU/n800_nU/n800ol0003oYK?RojFchP04ojFchP03o`00
0?nV^>KoY[SV00goY[SV00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`001ooo
ool00ol0003oooooooooo`0booooo`03o`000?nTa_7oY<Ka00goY<Ka00?o0000oj;:mOnRb_D02OnR
b_D00ol0003oVm7joi_AnP07oi_AnP05o`000?n=fOooSMWoohgIool000000_n=fOl00ol0003oV>Wj
oiSYnP02oiSYnP09o`000?nnmnoo__O_o`000?oCi^Co0000on3^f_l0003ogM;=00;o000000?o04o=
o`000?m=Km<00ol000000om_Jkko0000oi1k^@02oi1k^@Co00000_nSOZ/01?l0003o]X^XokJ;Z?nf
RjP5o`0000;oai:N00?o0000omZOV?l000002Ol000001Omf853o0000oh4eIOl0003oSD5[00;o0000
0onJDG<2o`000003oiIMRol0003oWFZF00;oWFZF00?o0000ojAiXonTNJ<00ol000000onLP;Co0000
oj6>_`03oj6>_`04o`000?nUV/[oYI[:ojFJbPOo00000_nPX]L00ol0003oXjcMoj>/g@07oj>/g@03
o`000?nU/n;oYK?R00?oYK?R00?o0000ojFch_nU/n800onU/n800ol0003oY[SVojJhiP0=ojJhiP03
o`000?oooooooooo01oooooo00?o0000ooooooooool02_ooool000Oooooo00?o0000ooooooooool0
<_ooool00ol0003oY<KaojC6l@0=ojC6l@03o`000?nRb_GoX/[e00?oX/[e1Ol000000onRb_Go0000
o`000007o`000003oi_An_l0003o000000;o00000onRgO`4o`000004okWYmOl0003o__O_o`0000?o
dnKT00Co0000omgBcOoMd/gogM;=0_l000001?l0Clgo0000ocAA`_l00003ofm[_PGo00000onSOZ/5
o`0000;o]HBQ00?o0000olNBW_o7TYh01?l00002omVJT003o`000?o/Yh7o000000Co00000_mf8502
o`000003ohe1Jol0003o000000?oVU5c00?o0000oj=MOOnSGGd00ol000000onMJYKo0000ojAiX`02
ojAiX`03o`000?nYQ[3oZHJ`00?o00000onQS[l00ol0003oYI[:ojFJbP03ojFJbP03o`000?nWY=?o
YjCC00;oYjCC2?l00004oj>/g@03o`000?nU/n;oYK?R00?oYK?R00?o0000ojFch_nU/n800onU/n80
0ol0003oY[SVojJhiP0=ojJhiP03o`000?oooooooooo01oooooo00?o0000ooooooooool02_ooool0
00Oooooo00?o0000ooooooooool0<_ooool?o`000003ojC6lOl0003o000000Co00001_nWbo<00ol0
003oYM?gojGCm`07ojGCm`05o`000?nRgOcoX]gloj;Mo?l000000_nRgO`00ol0003o^NWeokWYm@03
okWYm@06o`000?oCi^CodnKTo`000?oCd=Ko00000ooMd/d4o`0000;o=5721?l00003oh]_[PCo0000
0_nQMj@00ol0003o]HBQokF4X@0Do`000003oh@^E_l0003o000000?o000000?oVU5co`000?nSGGd0
0_nSGGd00ol0003oZfj=oj]^S@02o`0000?oY7VS00Ko0000ojV6/?nYQ[3oZHJ`o`000?n/Tkd4o`00
00GoYI[:00?o0000ojNTdonWY=<01?nWY=<00ol0003oZ:gKojR]f`03ojR]f`co00001?nU/n800ol0
003oY[SVojJhiP0=ojJhiP03o`000?oooooooooo01oooooo00?o0000ooooooooool02_ooool000Oo
oooo00?o0000ooooooooool0<_ooool00ol0003oYlK`ojO6l00=ojO6l003o`000?nWbo?oYl_c00Wo
Yl_c00?o0000ojGCmonUdoL01OnUdoL00ol0003oYM?go`000003o`0000?o/mce00?o0000okWYmOl0
00000_l000001?o7gNWo0000om?Vi?l00003om?@eP03o`000?oMd/go000000;od[_31_l000000omV
F[7o0000oh]_[P02o`000004ohMUYOl0003oXGNToj5gY1co00000onO?dl3o`000003oj=MOOl0003o
Zfj=00;oZfj=00?o0000ok1oW_l000000_l00004ojV6/003o`000?n/Tkgo[9>m00;o[9>m1?l00000
0onUV/[o0000ojNTd`06ojNTd`03o`000?nX[M_oZ:gK00OoZ:gK00?o0000ojRdhOnX]>401?nX]>4F
o`00027ooooo00?o0000ooooooooool02_ooool000Kooooo00?o0000ooooooooool0=?ooool00ol0
003oYlK`ojO6l00<ojO6l003o`000?nWbo?oYl_c00[oYl_c00?o0000ojGCmol000001?l00002ojoB
lP03o`000?ncg?Go/mce00Go/mce00?o0000olOMjOo7gNT00oo7gNT00ol0003odm3Fom?@eP03om?@
eP;o000000God[_3o`000?l0003o0000o`0DX`02o`0000;oIUZa0_l00002ohMUY@oo00000_o5PXX0
1Ol0003of8j0omR>P?oHSX3o000000;ojII/00?o0000oo6C@ol000000_l000000onF=T_o0000oilo
C`03oiloC`03o`000?n]F6Oo[EQW00?o000000?oZfj=o`000?n`Oih00on`Oih3o`000003ojV6/?l0
003o[9>m00Co[9>m00Co0000ojfNb?n]W/So[Ik81_l00003ojNTd`03o`000?nX[M_oZ:gK00OoZ:gK
00?o0000ojRdhOnX]>401_nX]>401?l0003oZ;CQojRdhOl0000?ojRii@03o`000?oooooooooo01oo
oooo00?o0000ooooooooool02_ooool000Kooooo00?o0000ooooooooool0=?ooool00ol0003oYlK`
ojO6l00=ojO6l003o`000?nWbo?oYl_c00?oYl_c1Ol000000onWbo?o0000o`000008ojoBlP03o`00
0?ncg?Go000000;o00000_nme>`01Ol0003oamgYolOMjOo7gNWo000000;obLgM00Co0000om?@e_oC
d=Kodm3F1?l000000ooB^l?o0000olJY_002o`000004oa`b[?l0003o0000oee<YR?o00000_nO?dl0
1Ol0003o[EQWojeHIon]F6Oo000000;o]W>61?l00002ok1oWP03o`000?ncSJko/hf^00;o000000Go
[9>mo`000?l0003o[9>mo`000005ojfNb003o`000?n]Ym;o[JOB00;o[JOB1?l000000onX[M_o0000
o`000002o`0000?oZ:gK00?o0000ojRdhOnX]>401onX]>401?l0003oZ;CQojRdhOl0000>ojRii@03
o`000?oooooooooo023ooooo00?o0000ooooooooool02_ooool000Kooooo00?o0000ooooooooool0
=?ooool00ol0003oYlK`ojO6l009ojO6l0?o000000?oYlK`o`000?l000001?l00006ojc;l003o`00
0?n_d_;o[m;b00Oo[m;b0_l00006okgDk003o`000?o7gNWo000000CobLgM1?l00003olbmc1?o0000
3_mjdol00ol0003oKlWoofo9o`05ofo9o`ko00000_njQYd2o`0000Co/hf^00Co0000okBI_?ndVKco
]9Vl0_l000000on]W/So0000o`000002ojfNb003o`000?n]Ym;o[JOB00Go[JOB00?o0000ojb_f_n/
[mX00on/[mX4o`000003ojRdhOl0003o000000?o00001?nX]>42o`0000ooZ;WU00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0:ooooo`001_ooool00ol0003oooooooooo`0eooooo`04o`00
0?nWa_3oYlK`ojO6l0Oo00001?nZa^h00ol0003o[<_`ojc;l00:ojc;l003o`000?n_d_;o[m;b00;o
[m;b0ol000000onecNco0000okgDk007okgDk004o`000?o9cMgobLgMolW=g@Co00000_o<_L`5o`00
00;oR]gn00?o0000og[Coomjdol06_mjdol00ol0003oKlWoofo9o`0Bofo9o`Wo00000_ndVK`01?l0
003o]9VlokBI_?l00003ok>Sb0?o000000Co[JOBo`000?l0003o00000_n]Ym800ol0003o[:oJojb_
fP07ojb_fP03o`000?n[]N3oZkGP00CoZkGP1_l000001?nX^NGo0000o`000?l0000;ojRii@03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool0=Ooo
ool4o`0000coZ/K^00?o0000ojc;l?n/bo002On/bo000ol0003o[m;bo`000002o`0000Go]Lg/00?o
0000okgDk?nme>`00_nme>`2o`0000;o`<[R0ol000000oo9cMgo0000o`000003o`0000SoR]gn00?o
0000og[Coomjdol06?mjdol00ol0003oKlWoofo9o`0Gofo9o`03o`000?m[`OkoJl7n00;oJl7n1Ol0
0006ok>Sb003o`000?nbZm;o/Z_B00;o/Z_B0ol00009ojb_fP03o`000?n[]N3oZkGP00WoZkGP0_l0
0003ojZii0Oo00000onX^ND00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo0006
ooooo`03o`000?oooooooooo03Gooooo00?o0000oj[6k_nZa^h03OnZa^h00ol0003o[<_`ojc;l007
ojc;l0;o000000?o[<_`o`000?necN`02?necN`01Ol0003o_MC/o`000?l0003o`<[R00Oo00003_n:
gOh00ol0003oN]?oog[Co`0Gog[Co`03o`000?m_bOooKlWo01KoKlWo00?o0000of_1o_m[`Oh01om[
`Oh3o`000004okRWb?l0003o0000o`0000Oo/Z_B00?o0000ok2bf_n`/]X01Ol000000on/[m[o0000
oj^eh00:oj^eh004o`000?nZ^NCoZ[WTo`0000WoZ[WT1?l0000Tooooo`03o`000?oooooooooo00Wo
oooo0005ooooo`03o`000?oooooooooo03Oooooo00?o0000oj[6k_nZa^h03?nZa^h01?l0003o[<_`
ojc;l?n/bo06o`0000?o/<S/00?o0000okG=k?necN`02?necN`7o`0001?oR]gn00?o0000og[Coomj
dol05_mjdol00ol0003oKlWoofo9o`0Eofo9o`03o`000?m[`OkoJl7n00_oJl7n1?l00002okJ^dP?o
000000?o/Z_Bo`000?n`/]X01on`/]X2o`000003oj^eh?l0003o000000?o00001On[]N001?l0003o
Z[WTojZii?l0000<ojZii003o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool000Go
oooo00?o0000ooooooooool0=oooool00ol0003oZ/K^oj[6kP0=oj[6kP?o00002_n`b>`00ol0003o
]Lg/okG=k003okG=k0Ko00006On:gOh00ol0003oN]?oog[Co`0Eog[Co`03o`000?m_bOooKlWo01?o
KlWo0_l0000Bof_1oPCo000000?o]ZkBo`000?l000001?n`/]X00ol0003o/;;Jok2bfP02ok2bfP03
o`000?n^]n3o[[OP00Co[[OP1Ol00003ojZii0;o00002onZ^N@00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Wooooo0005ooooo`03o`000?oooooooooo03Sooooo00?o0000oj[6k_nZa^h0
1OnZa^h5o`0000;o[<G/00?o0000ok38k?n`b>`02on`b>`00ol0003o]Lg/o`000003o`0001ooR]gn
00?o0000og[Coomjdol04omjdol00ol0003oKlWoofo9o`0Cofo9o`03o`000?m[`OkoJl7n01KoJl7n
0ol00005ok:dfPCo00002on^]n000ol0003o[;_Tojbki002ojbki0So00000onZ^N@00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Wooooo0005ooooo`03o`000?oooooooooo03Sooooo00?o
0000oj[6k_nZa^h01Ol00008ojc5k003o`000?n`b>co/<S/00[o/<S/0ol00003oigSo@;o00007_n:
gOh00ol0003oN]?oog[Co`08og[Co`_o000000?oKlWoo`000?l000000_l0000?ofo9o`03o`000?m[
`OkoJl7n01[oJl7n1_l00002ok:dfP04o`000?n_^N3o[kWPojnih0Go00000_n^]n000ol0003o[;_T
ojbki005ojbki003o`000?n/^nCo[;_T00?o[;_T1?l0000Uooooo`03o`000?oooooooooo00Wooooo
0005ooooo`03o`000?oooooooooo03Wooooo0_l0000>ojc5k003o`000?n`b>co/<S/00Co/<S/1_l0
0007oigSo@;o00006on:gOh<o`0000[oEl_b00?o0000odNmlom7_O<00om7_O<9o`0000GoKlWo00?o
0000of_1o_m[`Oh06?m[`Oh3o`0000?oJk[m1Ol00009ojnih0?o00001on/^n@00ol0003o[;_Tojbk
i006ojbki003o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool000Gooooo00?o0000
ooooooooool0>Oooool00ol0003o[<G/ojc5k00>ojc5k003o`000?n`b>co/<S/00Ko00003?nMhod3
o`0001CoR]gn1?l00004og;Km003o`000?mGbo;oEl_b00ooEl_b00?o0000odNmlom7_O<03?m7_O<5
o`0001SoJl7n0ol00009of^jo@;o00000ona^n48o`0000Go[;cU1ol00004ojbki003o`000?oooooo
oooo02Gooooo00?o0000ooooooooool02?ooool000Cooooo00?o0000ooooooooool0>oooool00ol0
003o[<G/ojc5k00>ojc5k0Ko00004OnMhod2o`0000koR]gn1?l00009og;Km003o`000?mGbo;oEl_b
00goEl_b00?o0000odNmlom7_O<03_m7_O<2o`0000Co@k?f1?l0000@of_1oP;o00003_m[^_d3o`00
00Go/K_Q0ol00003ojjkh`Go00000_n/_>D00ol0003o[;cUo`000003o`0002Sooooo00?o0000oooo
ooooool02?ooool000Cooooo00?o0000ooooooooool0??ooool00ol0003o[<G/ojc5k008ojc5k0Wo
00005OnMhod2o`0000SoR]gn1?l0000<og;Km0?o000000?oEl_bo`000?l000003?l00004odNml`?o
00001om7_O<2o`0000[o@k?f1?l00009of_1oP?o00004om[^_d4o`0000?o/K_Q00?o0000ojjmiOn^
_ND00_l00004ojjkh`Go00000_n/_>D00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00So
oooo0004ooooo`03o`000?oooooooooo03cooooo00?o0000ojc5k?n/aN`01?n/aN`7o`0000;o[/?Y
0_l0000IoigSo@;o00000_n:gOh4o`0000_oL]_d1Ol000000olo`/_o0000o`000002o`0000Ko5:C1
2_ooool2o`6CaPWo00004?m3/oH4o`0000;oJl7n0ol0000Hof^jo@Oo00001_n^_ND5o`000003ojjk
hol0003o000002Wooooo00?o0000ooooooooool02?ooool000Cooooo00?o0000ooooooooool0?Ooo
ool00ol0003o[<G/ojc5k003o`000004ojk3jOl0003o0000o`0000;o[/?Y0ol0000LoigSo@Oo0000
1_mbfo@5o`0000?o?l;;0ol000001?o[aJko0000o`000?l00002onW7/PCo00004_ooool00omC003o
0000o`6=e002o`6=e0Co00003_m3/oH2o`0001goJk[m0ol00002ojjniPGo00001_n^_ND2o`0002[o
oooo00?o0000ooooooooool02?ooool000Cooooo00?o0000ooooooooool0?_ooool2o`000004ojk3
jOl0003o0000o`0000?o[/?Y0_l0000MoigSo@;o00001onBj_L:o`000003oco2bol0003o000000?o
00000_o[aJh3o`0000;ojLNb1?l0000Eooooo`04oe<00?l0003o0000o`0000;o0HgD1?l00004od>c
mPGo00001?m7[?P2o`0001goJk[m0_l00005ojjniPGo00000_n^_ND00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00Sooooo0004ooooo`03o`000?oooooooooo03kooooo0ol00004ojk3j@;o
00007?nMhod3o`0000WoT^[g0_l00004ogKSgPCo00000_oedJT00ol0003ok/^^onk;[P05o`000003
onW3[_l0003o000000Co00006?ooool00omC003o0000o`000003o`000003o`6=e?l0003o000000;o
00002om7[?P2o`0001GoJk[m1?l00004offen`03o`000?n^_^Ko[[kV00Oo[[kV0_l000000ooooooo
0000ooooo`0Xooooo`03o`000?oooooooooo00Sooooo0004ooooo`03o`000?oooooooooo03_ooooo
0ol00002ooooo`03o`000?n^`nWo[/?Y00Go00006OnMhod2o`0000[oT^[g0_l00003ogKSgPCo0000
0_oii:`01?l0003omM6YooGAZOl00002onk;[P03o`000?o[ajoo000000;o000000GojL>^o`000?o]
a:Wo0000oo?:Y@03o`0001[ooooo00?o0000o`b<hOl<S>401?l<S>42o`0000coAjch0_l0000>of^j
o@Go00002Om]]O/2o`0000So[[kV00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`08
ooooo`000oooool00ol0003oooooooooo`0iooooo`?o00001_ooool2o`0000Go[NGi1Ol0000BoigS
o@;o00002_nBj_L2o`0000CoM^?N1Ol00002ooWT[0?o00000_o^bjh02?l0003ojlN_on_7[ol0003o
j/B^o`000?oY`jko00000_o]a:T4o`0001[ooooo0_l000000ol0=K;o0000o`000004o`b<h@?o0000
2om7[?P2o`0000SoJk[m1?l0000@offen`Go00000_n^_^H01Ol0003ooooooooooooooooo000002Wo
oooo00?o0000ooooooooool01oooool000?ooooo00?o0000ooooooooool0=_ooool3o`0000Wooooo
00?o0000ojgUnOn]iOT02On]iOT5o`0000[oWN?m0ol0000:oi;Zm`;o00000_mfhmh4o`000004olOl
^ol0003ok_Rdo`0000;onNB/00Co0000oo;G/oobek?o00000_o^bjh00ol0003ojlN_o`000002o`00
0005onW3[_l0003ojKnZo`000?o]a:T01?l0000Kooooo`So00000ol<S>42o`0000_oAjch0_l00002
of^jo@Co00005_m]]O/00ol0003o[l3Vojo0iP02o`0000Gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`07ooooo`000oooool00ol0003oooooooooo`0cooooo`?o00002oooool00ol0
003o[NGiojgUn@0?ojgUn@Go00000onMhod2o`0000_oT^[g2Ol000001Oo7o;_o0000onkh]?o^n;Co
000000;onNB/00?o0000oo;G/oobek<00_l000001Oo^bjko0000on_7[ol0003ojLB_00;o00000_oY
_jX00ol0003okLBYo`000004o`0001[ooooo1Ol000000ol0Fl?o0000oaj=j`02oaj=j`;o000000?o
38cQo`000?l000002Ol00002odN/n0;o00006om]]O/2o`0000Sooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`07ooooo`000oooool00ol0003oooooooooo`0`ooooo`?o00003Oooool0
0ol0003o[NGiojgUn@0EojgUnA7o00001?nYmn/2o`00000<ol_ng?l0003oaobko`000?o^n;Co0000
oo?Y__l0003onNB/o`000?obek?o00000_o]c[D2o`000005on_7[ol0003o0000onS2[ol000000ooY
_jX2o`000004oo>jT?l0003o0000o`0001_ooooo0ol000001Ol0?;_o0000o`1Ue?l0Fl?o000000Ko
7Xg[00?o0000odjXn?m>Z?P02_m>Z?P00ol0003oKKGkoffen`0Joffen`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`07ooooo`000oooool00ol0003ooooo
ooooo`0/ooooo`Co00003oooool00ol0003o[NGiojgUn@0FojgUn@03o`000?n^koOo[^og00[o[^og
00?o0000ojWgjonYmn/01?nYmn/2o`000003ol_ng?l0003oaobk00?o00000oocjKh01?l0003ol]Nc
oo;G/ol00002ong>]@03o`000?oYbKGo000000?o000000Koi[f]o`000?oY_j[ojKnZo`000?o^^9T5
o`0001[ooooo0ol000001Ol0BLWo0000o`000?l0003o06GD00Co00000olNSN/2o`0000_oCZSh0_l0
000Koffen`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`07ooooo`000oooool00ol0003oooooooooo`0Yooooo`?o00004Oooool2o`0001So[NGi00?o0000
ojk_mon^koL02_n^koL00ol0003oZOO[ojWgj`04ojWgj`04o`000?o;o]cobokLol_ng0;o000000?o
ioW=o`000?l000000oocjKh2o`000004oo;G/ol0003okLjeo`0000;ojLVe0_l000001ooX`Zoo0000
onJm[Ol0003ojKnZo`000?oW]j801ol0000Iooooo`;o000000?o02B_o`000?l0BLT00ol000001?l0
JM[o06GDobV=kOlYSNd3o`0000;o7Xg[00?o0000odjXn?m>Z?P02_m>Z?P2o`0000goKKGk2?l00005
og2bn@03o`000?oooooooooo00Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07
ooooo`000_ooool00ol0003oooooooooo`0Wooooo`?o00004oooool00ol0003o[NGiojgUn@0FojgU
n@;o00002on^koL2o`0000CoZOO[0ol00004ol_ng004o`000?oWnLgoioW=o`0000?olnVn00Co0000
ongJ_oo]f[oo00000_o]c[D00ol0003ojLVeo`000002o`000005onS2[ol0003oi[f]onJm[Ol00000
0_oW]j801Ol0003ok[RIo`000?l0003okiIF00?o00006?ooool3o`000008o`0T[ol0003o0000o`19
bOl0003o2FcMo`000?l0JMX2o`0000Co:Hg]2_l00005odjXn003o`000?m]]O_oKKGk00;oKKGk2?l0
000>og2bn@03o`000?oooooooooo00Gooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`07ooooo`000_ooool00ol0003oooooooooo`0Tooooo`?o00005Oooool00ol0003o[NGiojgUn@0F
ojgUn@03o`000?n^koOo[^og00[o[^og00?o0000ojWgjonYmn/01?l00002olKgk003o`000?o;o]co
bokL00;o00000_oWnLd2o`0000;olnVn00Co0000ongJ_oo]f[ookMZo0_l000000oo]c[Go0000o`00
0002o`000003onG2]?l0003oi[f]00;oi[f]00Go0000onNgX_oW]j;o0000onjhV@03o`000003onnF
E_l0003oY2h000;o00005Oooool6o`000003o`YBc_l0003o04W900;o000000Co2FcMo`1Yf_l0003o
=8g^0_l00004obV=k@03o`000?mDYOOoE:Gg00CoE:Gg1Ol000000om>Z?So0000o`000002o`0001Oo
L;;i00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Ko
oooo0002ooooo`03o`000?oooooooooo027ooooo0ol0000Gooooo`03o`000?n]iOWo[NGi01Go[NGi
0_l0000<ojk_m`Co00001Oo6mn`02?l0003obokLo`000?l0003ogOCMo`000?oWnLgo00000_oZjLd0
0ol0003olnVno`000002ongJ_`05o`000?oXd;koj=2no`000?oYbKD00_l00002onG2]0;o000000Co
i[f]o`000?oR]ZSo00000_oW]j800ol0003oiJJ>o`000002o`000003onnFE_l0003o000000;o0000
4oooool5o`000004o`0e^Ol0003o0000o`YBcP;o000000Co8W;Qo`000?l0003o2FcM0ol00002ocB=
kP04o`000?lYSNgo:Hg]o`0000goE:Gg00?o0000og2bnOm`/_T05om`/_T00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool000;ooooo00?o0000oooo
ooooool07_ooool3o`0001Wooooo00?o0000ojgUnOn]iOT05On]iOT00ol0003o[^ogojk_m`07ojk_
m`Ko00001oo6mn`3o`0000?ogOCM0_l00004on[Yc@05o`000?o]f[ookMZoongJ_ol000000_oXd;h2
o`000004onO6]?l0003oiL:do`0000;oh[fb00Ko0000on:fZ?oR]ZSoh[JXo`000?oW]j82o`000003
onFVS_l0003o000000Oo00003oooool8o`000004o`0e^Ol0003o0000o`YBcP;o00000_lRL^47o`00
00;o=8g^1_l00009oeBUm`03o`000?m`/_WoL;;i01OoL;;i00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo0002ooooo`03o`000?oooooooooo01_o
oooo0ol0000Kooooo`03o`000?n]iOWo[NGi01Go[NGi00?o0000ojk_mon^koL02?l00004oko]lP03
o`000?o6mncoa_O/00Goa_O/0_l00004omgdg@;o00001OoZjLd01?l0003okMZoongJ_ol00002onS@
_P06o`000?oUbkco0000o`000?oU`[Co00000ooR_K800ol0003oh[JXon:fZ002on:fZ003o`000?oP
YiWoh:NI00;o000000?oj:>4o`000?l000002Ol00009ooooo`;o000000?o8`00o`000?l000000ol0
00001ol57j;o0000o`0e^Ol0003o;5c?o`000?l:D/h00_l00002ob9bh@;o000000Ko@Hg^o`000?l0
003o0000oc^=k_l00002ocB=kP04o`000?mJXoKoFZ?foeZSmPKo00001?mDYOL00ol0003oL;;iog2b
n@0;og2bn@So00001?m`/_T00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01_ooool000;ooooo00?o0000ooooooooool06?ooool3o`0001gooooo00?o0000
ojgUnOn]iOT02On]iOT@o`0000_o_ngb00?o0000olKgk?o6mn`01?o6mn`2o`0000GogOCM0_l00005
on[Yc@0=o`000?oVfl[o0000ongJ_ol0003oj=2no`000?oUbkco0000onG;_Ol0003oiL:do`000002
on:m/P03o`000?oM]Zoo000000?oh[JX0_l00002on2WV@[o000000?o/C8?o`000?l000002Ol00000
0olS003o0000o`000005o`000004o`DOX_l0003o0000o`0000;o;5c?0_l000000olgM=oo0000o`00
0002ob9bh@?o00000_m1SNh2o`000003oc^=k_l0003o000000Co00001_mJXoH2o`000003oeBUmol0
003o000000_o00003Omb/?L00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool01_ooool00003ooooool0003ooooo01Oooooo0ol0000Oooooo`go00003?nhho@0
0ol0003o_ngboko]lP0<oko]lP03o`000?o6mncoa_O/00;oa_O/0_l000000ooBkNOo0000omgdg@03
omgdg@03o`000?oOi]So000000Coj^W=00Go0000onKKb_oVfl[oi]_:o`000002onS@_P05o`000?oU
bkco0000o`000?oQa;/00_l00002on:m/P06o`000?oM]ZoogKJ_o`000?oR]ZSo00000_oKZJ800ol0
003oh:NIon2WV@0>o`000003oi@M7Ol0003o000000co000000?o1AnRo`000?l_AkX00_l00003obaL
c`03o`000?lgM=oo=gCO00?o00000_m9SN`3o`0000?o@Hg^1?l000000omMX_Go0000o`000004o`00
00GoFZ?f00?o0000og:`momb/?L05_mb/?L00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool01_ooool00003ooooool0003ooooo01Cooooo0ol0000Rooooo`03
o`000?nhhoCo^>?d01Go^>?d00?o0000oko]l_nokO803?nokO800ol0003oa_O/olKgk003o`0000?o
d^gW00Go0000omgdgOoMm=gogOCMo`000003omoVf004o`000?oZjLgoj^W=o`0000Coi]_:00Co0000
onS@__l0003oiL^l0ol000001_oQa;_o0000omjn^Ol0003oh[fbo`0000?ogKJ_0_l00003om^YXP04
o`000?oPYiWo0000omBFTPOo000000?o`fQRo`000?l000001_l00002oh4SAPOo000000Co9Ab?o`00
0?l0003o00000_l_AkX00ol0003o;5c?obaLc`02obaLc`;o00000_lgM=l2o`0000CoBHg/0ol00000
0om1SNko0000of2Ql`02of2Ql`Go00001?mMX_D2o`000003oeZSm_l0003o0000017o00001_mb/?L0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01_ooool0
0003ooooool0003ooooo017ooooo0ol0000Tooooo`03o`000?nhhoCo^>?d01Ko^>?d00?o0000oko]
l_nokO802onokO801?l0003oa_O/o`000?l00006om;]i`04o`000?oMm=gogOCMo`0000CognKH00?o
0000on[YcOl000001?oVflX01Ol0003oh];7o`000?l0003oiL^l00;o000000?ohLBko`000?oN_[T0
0_oN_[T00ol0003ogKJ_omff[`02omff[`03o`000?oGZj_o000000?ofjVR0_l00002omBFTP[o0000
00?oZU9Qo`000?l000002Ol000000omA:H;o0000o`000002od4lY@03o`000?l_Ak[o;dNj00;o0000
0ol/G<l00ol0003oCGSLo`000003ocMdg`?o00001?m9SN`3o`0000SoH:7c1?l00002oefRm@So0000
4Omc[oL00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
1_ooool00003ooooool0003ooooo00kooooo0ol0000Wooooo`03o`000?nhhoCo^>?d01Go^>?d00?o
0000oko]l_nokO803?nokO82o`0000Sod^gW00?o0000omgdgOl000001OoOi]P2o`0000Coi]_:00Go
0000on;BaooRd/Oo0000omo<aP04o`0000Cog[ji0_l00002omff[`07o`000?oGZj_oej^[omN[Zol0
003ofjVRo`000002om2JW@03o`000?oDUY;oe9JB01Co000000CoDBV2o`000?mP?iCo00000_m1?:D0
1_l0003o;dNjobm7^_l0003oCFG:o`0000;o;5c?00?o0000odehg?m=N=`00_l000001?lgM=oo0000
oeJ=jOmFSNT3o`0000CoBHg/1?l00009of2QlaKo00001Omc[oL00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00003ooooool0003ooooo00_ooooo
0ol0000Yooooo`03o`000?nhhoCo^>?d01Ko^>?d00?o0000oko]l_nokO802OnokO83o`0000[od^gW
0_l00005omoVf003o`000?oMfmCo000000?oi]_:00Co0000on;BaooRd/Oo00000_oOc<H2o`000003
on74^ol0003og[ji00;og[ji00Ko0000omVg]ooI]kOo0000omff[ol00004omN[Z`;o00000oo@VYd0
1?l0003oe9JBo`000?o4Q8l@o`000003oge:R?l0003o000000;oH3nD00Oo0000od4lYOl0003oFERf
o`000?l_Ak[o000000;oCFG:00?o0000obaLcol000001?m=N=`2o`0000GoEXgY0ol000000om9SNco
0000ofFOl@02ofFOl@Ko00001OmPXO<00ol0003oMJgeogF]m@0;ogF]m@go00001_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Gooooo00000ooooooo0000ooooo`08ooooo`?o0000
:oooool00ol0003o^>?dokSSm00FokSSm003o`000?nokO;o_ngb00Oo_ngb0ol00002olSUk003o`00
0?oBkNOod^gW00Ood^gW0_l00005omoVf007o`000?oMfmCogM_DomgKe?l0003oi]_:o`000002on;B
a`03o`000?oOc<Koglc600Go00000_oN_[T00ol0003ofKNgomVg]`02omVg]`;o00001?oGZj/01?l0
003ocIjWo`000?l00002om2JW@;o00001?o4Q8l;o`0000;oODZ80_l00002of0oU004o`000?m]E:Co
0000o`0000;oFERf0_l00003odeUbP;o00001Om=N=`2o`0000OoEXgY0ol00008ofFOl@Go000000?o
H:7co`000?me[OD05ome[OD00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool01Oooool00003ooooool0003ooooo00Gooooo0ol0000^ooooo`03o`000?nhhoCo
^>?d01Ko^>?d00?o0000oko]l_nokO800onokO84o`0000Gob>G/00?o0000om;]iooBkNL01OoBkNL2
o`000003omGRhOl0003ognKH00;ognKH0_l00004omgKe0;o00000_oRd/L00ol0003oglc6omo<aP03
o`000006om_5`ol0003ofL31o`000?oN_[Wo00001?oI]kL01?l0003odZfdo`000?l00002omN[Z`08
o`000?o=WZOocIjWolfNYol0003od9ZMo`000?o2RYT3o`000003olB4Sol0003o/G:=00;o/G:=1?l0
0002oi]ORP?o000000CoQ5NDo`000?mP?iCo00000_m]E:@00ol0003oFERfoeUH]P02oeUH]P03o`00
0?m=IL[oCFG:00;oCFG:0_l00005odehg0;o00002OmFSNT3o`0000[oIIoa2_l0000AogF]m@03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`0000?o
0000ooooooooool00_ooool3o`00033ooooo00?o0000okSSm?nhho@05_nhho@01?l0003o_ngboko]
l_nokO83o`0000Wob>G/00?o0000om;]iooBkNL00ooBkNL2o`0000?oeN;Q00Co0000omoVf?oOi]So
00001OoMfm@01Ol0003ofm;@o`000?oRd/Oo000000;oglc60ol000000ooKaL?o0000omW0`@02omW0
`@03o`000?oI]kOofKNg00;ofKNg00?o0000om:]]?oB[K@00_oB[K@2o`0000GocIjW0ol00003ol::
V@co00000on4Ei@2o`0000;oKEBT0_l00004oeUH]P03o`000?m=IL[oCFG:00;oCFG:00?o0000of=k
eOl000001?m=N=`00ol0003oIHcSo`000002o`0000KoEXgY00?o0000ofbMk_m/WNh01?l00008ofFO
l@03o`000?mh[??oN:cc00GoN:cc3Ol00005ogF]m@03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`05ooooo`0000?o0000ooooool000000_l0000cooooo`03
o`000?nhhoCo^>?d01Ko^>?d1?l0000;olSUk003o`000?oBkNOod^gW00;od^gW0_l00006omGRh@;o
00001OoMfm@01Ol0003ofm;@om_Bd?oKd]3o000000?oglc600Co0000omk9a?oKaL?o00001?oI`<42
o`0000;ofKNg00?o0000om:]]?oB[K@01?oB[K@2o`0000CocIjW00?o0000ol6@Xoo1T:<01?l00004
ok5jU`03o`000?nNJYKoWVZF00?oWVZF1?l000001?n;IJ;o0000ofeDY?l00002ogQV/@06o`000?mI
F;KoFERfo`000?mZKL?o00000om=ILX00ol0003oHg_Eof=ke@02o`0000;oCGSL00?o0000ofF<homU
S><00_mUS><2o`0000CoEXgY00?o0000ofbMk_m/WNh01?m/WNh5o`0000CoIIoa00?o0000ogR/lomh
[?<04Omh[?<7o`0000Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`00
0_l0000eooooo`03o`000?nhhoCo^>?d01;o^>?d1_l0000>olSUk003o`000?oBkNOod^gW00;o0000
1ooEh^42o`0000GogM_D00?o0000om_Bd?oKd]000_oKd]02o`000003omo<a_l0003og/W400;o0000
1?oI`<401_l0003oe;VoomBi_ol0003ofKNgo`0000KodZfd00Co0000olZR/?l0003o00000_o=WZL0
0ol0003o`I2Sol6@X`03ol6@X`Co000000Co/GZGo`000?nNJYKoWVZF1?l00004oh]UXP;o00000omh
I[400ol0003oFERfo`000003ofY]``03o`000?m=IL[o000000GoHg_E0_l000000om=N=co0000ofF<
h`04ofF<h`;o00000omFSNT00ol0003oK9g^ofbMkP08ofbMkPGo00006Omh[?<00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool000;ooooo00?o0000
ooooooooool0<Oooool00ol0003o^>?dokSSm00:okSSm0Wo00001?nngNl00ol0003ob>G/olSUk00=
olSUk0?o00002?oEh^400ol0003oe=SKo`000004omgKe003o`000?oKd]3ofm;@00;ofm;@00So0000
omW=c_oIcLko0000omk9a?l0003oflG3o`0000?ofL3100?o0000omBi_ooD^Kl00_oD^Kl2o`0000Go
dZfd00?o0000olZR/?o:X[000_o:X[02o`0000Ko`I2S00Co0000ok:2XOnbPZ7o/X:Q1?l00003oj5d
X@04o`000?n;IJ;oRfFRoh]UXP;o00001OmhI[400ol0003oJVg3ofY]``03ofY]``;o00001omSNmD2
o`0000OoIHcS1?l0000>ofbMkPKo00005Omh[?<00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool01Oooool000?ooooo00?o0000ooooooooool0<?ooool01?l0
003o^>?dokSSm?nhho@9o`0000go_]g_00?o0000olSUk?o8iN`03?o8iN`2o`0000WoeN;Q00Go0000
omCHfooDf=_oe=SKo`000002omgKe003o`000?oKd]3ofm;@00;ofm;@00?o0000omW=c_oIcLh00ol0
00000ooKaL?o0000omW0`@02omW0`@03o`000?oD^Kooe;Vo00?oe;Vo00Co0000olj`_?l0003o0000
0_oB[K@00ol0003obZ:`olZR/004olZR/0?o00001?o1T:<00ol0003o/X:Qok:2X@02ok:2X@03o`00
0?nQM:7oXGBQ00?oXGBQ1?l000000on@LZko0000ogQV/@03ogQV/@;o00001_mZKL<2o`0000OoHg_E
0_l00009ofF<h`?o00003Om/WNh00ol0003oOJW`ogfYl002ogfYl0Oo00003_mh[?<00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool000Cooooo0_l0
000_ooooo`Go00005_nngNl00ol0003ob>G/olSUk009olSUk0?o000000?obmgVo`000?oEh^401_oE
h^42o`0000Coe=SK00?o0000omgKe?l000001?oKd]000ol0003ofLg>omW=cP03o`000003omK7bol0
003o000000?ofL3100?o0000omBi_ooD^Kl00_oD^Kl00ol0003oc[2lolj`_002olj`_003o`000?oB
[KCo000000KobZ:`00?o0000oknF[OnoUZd01?l00005ok:2X@03o`000?nQM:7oXGBQ00Co00001On@
LZh01?l0003oN6JaogQV/Ol00002oh9f_@03o`000?mZKL?oJVg300?oJVg300?o0000ogQocOl00000
1_mSNmD01?l0003oLhcMo`000?l00007ofF<h`03o`000?mfW>WoMYcY00?o00002om/WNh00ol0003o
OJW`ogfYl008ogfYl0Oo00002?mh[?<00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool01?ooool000Kooooo00?o0000ooooooooool0;?ooool00ol0003o_]g_
okkMk`0HokkMk`03o`000?o8iNcob>G/00Kob>G/0ol00005ol_MiP03o`000?oEh^7oeN;Q00?oeN;Q
00?o0000omCHfooDf=/01?oDf=/2o`0000Cofm;@00?o0000omW=c_oIcLh00ol00002omK7b`05o`00
0?oC`/Wo0000omW0`Ol000001OoD^Kl00ol0003oc[2lolj`_003olj`_0;o00001Oo:X[000ol0003o
_iJ]oknF[@04oknF[@Wo00000onSOZ`00ol0003oT7:^oi1b[P03oi1b[P03o`000?mhI[7o000000Co
PWJm00Go0000ofY]`omZKL?oJVg3o`000003ogQoc@;o00000omSNmD00ol0003oLhcMog><g@02og><
g@;o00001OmUS><00ol0003oMYcYogJLj@03ogJLj@Co00001om/WNh00ol0003oOJW`ogfYl00?ogfY
l0Oo000000?oN:cco`000?ooool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Cooooo0007ooooo`03o`000?oooooooooo02_ooooo00?o0000okkMkonngNl05onngNl00ol0003o
b>G/olSUk004olSUk0?o00002?o;gNH01?l0003oeN;QomGRhOoEh^42o`0000Koe=SK00?o0000om?B
f?l000000ooKd]000ol0003ofLg>omW=cP03o`0000;oe/O;00Co0000om?2bOoC`/Wodl;90_l00004
omBi_`03o`000?o>/;coc[2l00Coc[2l00Co0000olNW^Ol0003o00000oo:X[000ol0003o_iJ]oknF
[@04oknF[@03o`000?nbRZco/XZ/00?o/XZ/00?o0000oj=n[?nSOZ`00onSOZ`00ol0003oT7:^oi1b
[P03oi1b[P;o00001_n2M[d00ol0003oJVg3o`000006ogQoc@04o`000?mSNmGoHg_Eo`0000KoLhcM
00?o0000ofF<homUS><00_mUS><00ol0003oMYcYogJLj@07ogJLj@Co00000om/WNh00ol0003oOJW`
ogfYl00FogfYl0?o00001oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo
0008ooooo`;o0000:oooool00ol0003o_]g_okkMk`0GokkMk`04o`000?o8iNcob>G/olSUk0?o0000
2oo;gNH01?l0003oeN;QomGRhOl00007omCHf`07o`000?oCd]Sodm;Hom?Bf?l0003ofm;@o`000002
omW=cP?o00000_oFal/00ol0003odl;9om?2b@02om?2b@03o`000?o?^lOo000000;oe;Vo00?o0000
olj`_?o>/;`01?o>/;`00ol0003oajNiolNW^@02olNW^@;o000000?obZ:`o`000?noUZd01OnoUZd0
0ol0003o/XZ/ok::[003ok::[003o`000?nSOZcoXgj/00CoXgj/00?o0000oi1b[_n@LZh00_l00000
0onEO[So0000oh9f_@05oh9f_@;o00002?mhOld00ol0003oHg_Eo`000007og><g@;o00000_mUS><0
0ol0003oMYcYogJLj@0;ogJLj@?o000000?oK9g^o`000?mmZO006?mmZO000ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool000[ooooo00?o0000oooo
ooooool0:?ooool00ol0003o_]g_okkMk`0GokkMk`Co00003oo;gNH2o`0000Koe=SK0_l00004om?B
f0?o000000CofLg>o`000?l0003oel[=0_oFal/00ol0003odl;9om?2b@02om?2b@07o`000?o?^lOo
ck_7olnkaol0003oe;Voo`000006olj`_003o`000?o7YkWoajNi00CoajNi1Ol00002oknF[@03o`00
0?nbRZco/XZ/00Co/XZ/00?o0000oj=n[?nSOZ`01?nSOZ`3o`0000CoUGjh00?o0000oh9f_On2M[d0
0_n2M[d00ol0003oRXC7o`000009ogQoc@;o00002OmcS=d3o`00013oMYcY1?l0000GogfYl003o`00
0?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`002ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?nngNoo_]g_01Go_]g_0ol0000Aol_MiP;o00001_oD
f=/00ol0003odm;Hom?Bf003om?Bf003o`000?oAcMKodLgF00?o000000Goel[=omK7booFal_oe/O;
o`000003om?2b@03o`000?o?^lOock_700?ock_70_l00005olj`_003o`000?o7YkWoajNi00GoajNi
00?o0000okfL]onmW;L00_nmW;L7o`0000;o/XZ/00Co0000oj=n[?nSOZcoXgj/1?l00007oiEn^004
o`000?n2M[goPWJmo`0000?oRXC700?o0000ogQocOmhOld01_mhOld00ol0003oPhkFo`00000:og><
g@;o00004?mfW>T00ol0003oPZO/oh:Wk005o`0001;oOJW`00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo000<ooooo`;o00009oooool00ol0003o
_]g_okkMk`0AokkMk`Co00000_o2f>X00ol0003obmgVol_MiP0=ol_MiP;o000000?obmKRo`000?oD
f=/00ooDf=/2o`0000Godm;H00Go0000om7=e_oAcMKo0000om3:e002o`0000?oe/O;00Go0000om?2
bOoC`/Wodl;9o`000006olnka`04o`000?o:]<Co0000o`0000?oc[2l00?o0000olNW^Oo7YkT01?o7
YkT00ol0003o_IbgokfL]`05okfL]`03o`000?nbT[Go/Y:e00;o/Y:e1_l00003ojF8]P03o`000?nE
O[SoUGjh00GoUGjh00?o0000oh9f_Ol000001On:Q<L00ol0003oN7o=ogQoc@04ogQoc@05o`000?n3
S]KoPhkFoh>>e_l000002OmcS=d00ol0003oP9[So`000002o`0000goMYcY00?o0000oh:Wk?n2Yn`0
1On2Yn`4o`0000koOJW`00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00?ooooo000>ooooo`03o`000?oooooooooo02?ooooo00?o0000okkMkonngNl03_nn
gNl4o`0000Ko`]SZ00?o0000ol_Mi_o;gNH02_o;gNH3o`0000CobmKR00Co0000omCHfooDf=_o0000
1_oCd]P01?l0003odLgFom7=e_l00002om3:e0;oclOC00?o0000omK7bol000001?oC`/T00ol0003o
ck_7olnka`03olnka`03o`000?o:]<Cob[C400;ob[C40_l000000oo>/;co0000olNW^@05olNW^@03
o`000?nmW;Oo_Ibg00Go_Ibg00?o0000ok:B]OnbT[D01?nbT[D00ol0003oYHRfojF8]P05ojF8]P03
o`000?nEO[SoUGjh00CoUGjh0_l00007ohZ4a`03o`000?mhOlgoN7o=00;oN7o=00?o0000oh>>e_n3
S]H00on3S]H2o`0000OoLhcM00?o0000oh2Jhon0V^<00_n0V^<2o`0000_oMYcY00?o0000oh:Wk?n2
Yn`02On2Yn`5o`0000[oOJW`00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00?ooooo000?ooooo`03o`000?oooooooooo02;ooooo00?o0000okkMkonngNl0
2_nngNl4o`0000[o`]SZ00?o0000ol_Mi_o;gNH02?o;gNH2o`0000OobmKR00?o0000omCHfol00000
1OoCd]P2o`0000;odLgF00?o0000om3:e?o@b]@00oo?am<3o`0000?odl;900?o0000olnkaoo?^lL0
0oo?^lL00ol0003ob[C4olZda005olZda0?o00001Oo7YkT00ol0003o_IbgokfL]`05okfL]`03o`00
0?nbT[Go/Y:e00Co/Y:e00?o0000ojF8]_nUR;H01OnUR;H01?l0003oUGjhoiEn^?nEO[P3o`000003
oiV:`_l0003oRXC700OoRXC700Go0000ogQocOmhOlgoN7o=o`000007oh>>eP03o`000?mcS=goLhcM
00?oLhcM00?o0000oh2Jhon0V^<01On0V^<3o`0000SoMYcY00?o0000oh:Wk?n2Yn`03_n2Yn`4o`00
00KoOJW`00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00?ooooo000@ooooo`;o00008_ooool00ol0003o_]g_okkMk`07okkMk`?o00003_o2f>X00ol0003o
bmgVol_MiP06ol_MiP;o00002Oo;e^82o`0000Godm;H00Go0000om7=e_oAcMKodLgFo`000002om3:
e0?oclOC00Oo0000olg3dOo=`m7ocL?Ao`000?oC`/Wo000000Kock_700?o0000olZda?o:]<@01Oo:
]<@00ol0003o`j_2ol>[`P03o`000003olNW^Ol0003o_Ibg00Ko_Ibg00?o0000ok:B]OnbT[D01Onb
T[D00ol0003oYHRfojF8]P05ojF8]P04o`000?nEO[So0000o`0000GoVH[200?o0000ohZ4aon:Q<L0
1_n:Q<L00ol0003oN7o=o`000009oh>>eP;o00000omcS=d00ol0003oP9[Soh2Jh`08oh2Jh`?o0000
1OmfW>T00ol0003oPZO/oh:Wk00Boh:Wk0Go000000?oOJW`o`000?ooool02oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00?ooooo000Booooo`03o`000?oooooooooo01oooooo00?o
0000okkMkonngNl00onngNl4o`0001;o`]SZ00?o0000ol_Mi_o;gNH00oo;gNH2o`0000[obmKR00Co
0000ol[@g_o:d=ko00000ooCd]P01Ol0003odLgFom7=e_oAcMKo000000;od<[D0oo?am<00ol0003o
cL?Aolg3d@03olg3d@;o00001Oo?^lL00ol0003ob[C4olZda005olZda003o`000?o3Zl;o`j_200Co
`j_21?l00005okfL]`03o`000?nbT[Go/Y:e00Ko/Y:e00?o0000ojF8]_nUR;H00onUR;H3o`0000So
VH[200?o0000ohZ4aon:Q<L01On:Q<L3o`0000_oPhkF00Co0000og><gOmcS=go00003On0V^<2o`00
00?oMYcY00?o0000oh:Wk?n2Yn`05on2Yn`2o`0000cooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`0Nooooo`03o`000?nngNoo000000?o
00005_o2f>X00ol0003obmgVol_MiP03o`0000[obmKR0_l00004ol[@gP03o`000?oCd]So000000?o
dLgF0_l000001Oo@b]CoclOColo7doo?am?o000000KocL?A00Co0000olZncol0003o00000oo?^lL0
0ol0003ob[C4olZda005olZda003o`000?o3Zl;o`j_200Go`j_200?o0000ok^R_onkX[l01?l00000
0onmW;Oo0000ok:B]@07ok:B]@03o`000?nUR;Ko000000?o00000_nVTKl00ol0003oVH[2oiV:`P06
oiV:`P03o`000?n:Q<OoRXC700CoRXC700Go0000oi2@d?n@T=3oT93@o`00000;oh>>eP;o00004?n0
V^<4o`0001[oPZO/00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00?ooooo000Dooooo`;o00007_ooool2o`0001[o`]SZ0ol0000;ol_FhP;o00001oo:d=h0
1?l0003odLgFom7=e_oAcMH2o`000005om3:e?o?am?oclOColo7dol000001_o=`m400ol0003ob[k?
olZnc`02olZnc`03o`000?o?^lOo000000Oob[C400?o0000ol>[`_o3Zl801Oo3Zl800ol0003o^j:o
ok^R_`05ok^R_`co00001onVTKl00ol0003oVH[2oiV:`P06oiV:`P03o`000?n:Q<OoRXC700;oRXC7
00?o0000oi2@d?n@T=000on@T=000ol0003oPhkFoh>>eP09oh>>eP;o00004_n0V^<3o`0001SoPZO/
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo
000Fooooo`03o`000?oooooooooo01_ooooo00?o0000ol;Hj_o2f>X06?o2f>X2o`0000cobmKR00?o
0000ol[@g_o:d=h01_o:d=h2olW=g005o`000?oAcMKo0000o`000?o@b]@00oo?am<00ol0003ocL?A
olg3d@04olg3d@03o`000?o:_/oob[k?00Cob[k?0_l00007olZda003o`000?o3Zl;o`j_200Go`j_2
00?o0000ok^R_onkX[l01_nkX[l00ol0003o/YVnok:I_P06ok:I_P03o`000?nVTKooYY6o00KoYY6o
00?o0000oiV:`_nIR/801_nIR/801Ol0003oRXC7ohZ4aon:Q<Oo000000OoT93@00?o0000oh>>e_n3
S]H01on3S]H00ol0003oRi[Moh^Jg@02o`00013oP9[S00?o0000ohVUion9YNL00ol0000Eoh:Wk003
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`00
5oooool00ol0003oooooooooo`0Jooooo`03o`000?o2f>[o`]SZ01Go`]SZ0ol000000oo2dnKo0000
ol_FhP09ol_FhP;o00001_o:d=h2o`0000CobLgL0_l000001Oo@b]CoclOColo7doo?am?o000000Ko
cL?A00?o0000olZncoo:_/l01Oo:_/l00ol0003oaKO<o`000002o`0000?ob[C400?o0000ol>[`_o3
Zl801_o3Zl800ol0003o^j:ook^R_`06ok^R_`03o`000?nbVKko/YVn00Ko/YVn00?o0000ojJA_onV
TKl01_nVTKl00ol0003oVH[2oiV:`P07oiV:`P03o`000?n:Q<Oo000000WoT93@00?o0000oh>>e_n3
S]H01On3S]H00ol0003oRi[Moh^Jg@03oh^Jg@;o00003On0V^<00ol0003oRJGWohVUi`04ohVUi`?o
00004_n2Yn`00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool001Sooooo0_l0000Kooooo`03o`000?o2f>[o`]SZ017o`]SZ0ol00005ol;CiP03o`00
0?o;e^;obmKR00KobmKR00?o0000ol[@g_o:d=h01Oo:d=h00ol0003obLgLolW=g003olW=g003olW;
fol0003o000000CoclOC1_o=`m400ol0003ob[k?olZnc`05olZnc`03o`000?o5]lcoaKO<00?oaKO<
0_l000000oo:]<Co0000ol>[`P06ol>[`P03o`000?nkX[oo^j:o00Oo^j:o00?o0000ok:I__nbVKh0
1_nbVKh00ol0003oYY6oojJA_`07ojJA_`03o`000?nIR/;oVH[200KoVH[20_l0000;oi2@d003o`00
0?n3S]KoPhkF00?oPhkF00?o0000oh^JgOn;V]d01_n;V]d2o`0000_oP9[S00?o0000ohVUion9YNL0
1on9YNL3o`0000ooPZO/00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00;ooooo000Jooooo`03o`000?oooooooooo01Sooooo00?o0000ol;Hj_o2f>X03_o2
f>X3o`0000Wo`]?V00?o0000ol_Fh_o;e^800oo;e^82o`0000Kob]3N0_l00004olW=g003o`000?o9
bm_o000000;ob<SJ00?o0000olo7doo?am<01_o=`m400ol0003ob[k?olZnc`05olZnc`03o`000?o5
]lcoaKO<00KoaKO<0ol00006ol>[`P03o`000?nkX[oo^j:o00Oo^j:o00?o0000ok:I__nbVKh01_nb
VKh00ol0003oYY6oojJA_`07ojJA_`03o`000?nIR/;oVH[200?oVH[20ol000000onLU<_o0000oi2@
d00;oi2@d005o`000?n3S]KoPhkFoh>>e_l000002on;V]d2o`0000SoP9[S00?o0000ohVUion9YNL0
2on9YNL4o`0000[oPZO/00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00;ooooo000Kooooo`03o`000?oooooooooo01Oooooo00?o0000ol;Hj_o2f>X02oo2
f>X3o`0000co`]?V00Co0000ol_Fh_o;e^;obmKR0_l00007ol[@gP03o`000?o9cMcobLgL00;obLgL
0_l000000oo9bm_o0000olS8fP02olS8fP?o00001Oo=`m400ol0003ob[k?olZnc`06olZnc`03o`00
0?o5]lcoaKO<00KoaKO<00?o0000ol2`bOo0/<T01?l00002ol>[`P03o`000?nkX[oo^j:o00Ko^j:o
00?o0000ok:I__nbVKh02?nbVKh00ol0003oYY6oojJA_`06ojJA_`03o`000?nIR/;oVH[200?o0000
1OnLU</00ol0003oT93@oi2@d00:oi2@d003o`000?n3S]Ko000000koRi[M0_l00006oh2Jh`03o`00
0?n9YNOoRJGW00ooRJGW0ol00007oh:Wk003o`000?oooooooooo017ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`02ooooo`007?ooool2o`0001Sooooo00?o0000ol;Hj_o2f>X02?o2
f>X2o`00013o`]?V00?o0000ol_Fh_l000002?o:d=h00ol0003obLgLolW=g002olW=g004o`000?o9
bm_o0000o`0000?ob<SJ00Go0000olK5f?o6aMSoa/GHo`000003olg3d@03o`000?o:_/oob[k?00Ko
b[k?00?o0000olFgc?o5]l`01_o5]l`00ol0003o`;39ol2`b@05ol2`b@Go00001_nkX[l00ol0003o
/YVnok:I_P08ok:I_P03o`000?nVTKooYY6o00GoYY6o1?l00009oibDb`03o`000?n@T=3oT93@00[o
T93@00?o0000oh^JgOn;V]d03on;V]d2o`0000?oP9[S00?o0000ohVUion9YNL04on9YNL3o`0000Co
PZO/00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o
oooo000Nooooo`03o`000?oooooooooo01Gooooo00?o0000ol;Hj_o2f>X01Oo2f>X3o`0001?o`]?V
00?o0000ol[@g_o:d=h01Oo:d=h2o`0000?obLgL0_l000000oo9bm_o0000o`000003olS8fP03o`00
0?o6aMSoa/GH00?oa/GH00?o0000olg3dOl000002?o:_/l00ol0003oaKO<olFgc006olFgc003o`00
0?o0/<Wo`;3900Oo`;3900Co0000okVXb?niZ<So^JS81Ol000000onkX[oo0000ok:I_P09ok:I_P03
o`000?nVTKooYY6o00Go00000_nWV/P00ol0003oW9C;oibDb`09oibDb`03o`000?n@T=3oT93@00Oo
T93@00Go0000oiFKeonEVmOoUI_Go`00000Aoh^Jg@;o000000?oP9[So`000?n9YNL05on9YNL3o`00
0003oh:Wk?l0003ooooo01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02oooo
o`007oooool2o`0001Gooooo00?o0000ol;Hj_o2f>X00_o2f>X3o`0001?o`]?V0_l000000oo2cnCo
0000ol[@gP05ol[@gP03o`000?o9cMcobLgL00;obLgL00Co0000olW;fol0003obL_K1?o8b=X00ol0
003oa/GHolK5f005olK5f0;o00001oo:_/l00ol0003oaKO<olFgc007olFgc003o`000?o0/<Wo`;39
00Oo`;3900?o0000okVXb?niZ<P01_niZ<P?o`0000SoYi[800?o0000oibDbonLU</02OnLU</00ol0
003oT93@oi2@d005oi2@d003o`000?nEVmOoUI_G00?oUI_G00?o0000oh^JgOn;V]d04?n;V]d00ol0
003oRJGWohVUi`0JohVUi`;o00005Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00;ooooo000Qooooo`03o`000?oooooooooo01?ooooo1?l0000Dol;CiP;o00001?o2cn@01?l0003o
b]3Nol[@g_o:d=h2o`0000CobLgL00Co0000olW;fol0003o00001?o8b=X00ol0003oa/GHolK5f005
olK5f003o`000?o4`=Koa<3F00?o00001?o:_/l00ol0003oaKO<olFgc006olFgc003o`000?o0/<Wo
`;3900Oo`;3900?o0000okVXb?niZ<P02?niZ<P00ol0003o/J77ok6Qa`08ok6Qa`03o`000?nWV/So
Yi[800SoYi[800?o0000oibDbonLU</02OnLU</00ol0003oT93@oi2@d003oi2@d0;o00001onEVmL0
0ol0003oRi[Moh^Jg@0?oh^Jg@04o`000?nAYN;o0000o`0001[oRJGW00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo000Rooooo`03o`000?oooooo
oooo01;ooooo00?o0000ol;Ci_o2dnH04_o2dnH3o`0000Oo`/oT00?o0000ol[@g_l000001?o9cM`5
o`0000Cob<SJ00?o0000olK5f?o6aMP01Oo6aMP00ol0003oa<3FolC0eP04olC0eP;o000000?ob[k?
o`000?o5]l`02?o5]l`00ol0003o`;39ol2`b@07ol2`b@03o`000?niZ<So^JS800So^JS800?o0000
ok6QaonaXLL02?naXLL00ol0003oYi[8ojNJb008ojNJb003o`000?nLU<_oW9C;00[oW9C;00Go0000
oi2@d?n@T=3oT93@o`00000:oiFKe`;o00003_n;V]d00ol0003oTJGRoi6UhP02oi6UhP;o00005on9
YNL00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00Ooo
ool002?ooooo0_l0000Booooo`03o`000?o2dnKo`]?V013o`]?V0_l0000;ol;?i0;o00000oo9cM`0
1?l0003obL_Ko`000?o9bm/5olS8fP03o`000?o6aMSoa/GH00Goa/GH00?o0000olC0e_o4`=H01oo4
`=H2o`0000SoaKO<00?o0000ol2`bOo0/<T02?o0/<T00ol0003o^JS8okVXb008okVXb003o`000?na
XLOo/J7700Wo/J7700?o0000ojNJb?nWV/P02?nWV/P00ol0003oW9C;oibDb`0:oibDb`03o`000?n@
T=3o000000goUI_G00?o0000oh^JgOn;V]d02_n;V]d00ol0003oTJGRoi6UhP05oi6UhP?o00005?n9
YNL00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Ooo
ool002Gooooo00?o0000ooooooooool04?ooool00ol0003o`]?Vol;CiP0=ol;CiP;o00002oo2cn@0
2_l0003o`/cRol;<h_o2c>;o0000olW=g?l0003obL_Ko`000?o9bm/5olS8fP03o`000?o6aMSoa/GH
00Goa/GH00?o0000olC0e_o4`=H02?o4`=H00ol0003o`K[Co`000002o`0000CoaKO<00?o0000ol2`
bOo0/<T02?o0/<T00ol0003o^JS8okVXb009okVXb003o`000?naXLOo/J7700Wo/J7700?o0000ojNJ
b?nWV/P02?nWV/P00ol0003oW9C;oibDb`0:oibDb`;o00003onEVmL00ol0003oRi[Moh^Jg@08oh^J
g@03o`000?nAYN;oTJGR00WoTJGR0_l0000AohVUi`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`01ooooo`009_ooool00ol0003oooooooooo`0@ooooo`03
o`000?o2dnKo`]?V00[o`]?V0_l0000:ol;?i0;o00001_o2c>801?l0003obL_Ko`000?o9bm/5olS8
fP03o`000?o6aMSoa/GH00Goa/GH00?o0000olC0e_o4`=H02?o4`=H00ol0003o`K[Col6jd`03ol6j
d`?o000000?oaKO<o`000?o0/<T02Oo0/<T00ol0003o^JS8okVXb009okVXb003o`000?naXLOo/J77
00Wo/J7700?o0000ojNJb?nWV/P02OnWV/P00ol0003oW9C;oibDb`06oibDb`?o000000?oWikCo`00
0?nEVmL03onEVmL2o`0000OoRi[M00?o0000oi6Uh_nAYN803?nAYN82o`0000ooRJGW00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo007ooooo000Wooooo`;o
00004?ooool00ol0003o`]?Vol;CiP08ol;CiP;o00002oo2cn@00ol0003o`/cRol;<hP05ol;<hP;o
`/_Q0_l00006olS8fPOoa/GH00?o0000olC0e_o4`=H02?o4`=H00ol0003o`K[Col6jd`07ol6jd`?o
00002Oo0/<T00ol0003o^JS8okVXb008okVXb003o`000?naXLOo/J7700[o/J7700?o0000ojNJb?nW
V/P02OnWV/P00ol0003oW9C;oibDb`03oibDb`?o00001OnOW]<00ol0003oUI_GoiFKe`0?oiFKe`03
o`000?n;V]goRi[M00?oRi[M00?o0000oi6Uh_nAYN803onAYN82o`0000coRJGW00?o0000oooooooo
ool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`00
0?oooooooooo00kooooo00?o0000ol;Ci_o2dnH01?o2dnH3o`0000_o`/oT0_l00005ol;<hP05o`00
0?o2bn7o`/_Qol;;hOl000000_o1b>000ol0003ob<SJolS8fP02olS8fPOoa/GH00?o0000olC0e_o4
`=H02?o4`=H00ol0003o`K[Col6jd`08ol6jd`03o`000?nl]=7o_;CA00Co00001Oo0/<T00ol0003o
^JS8okVXb008okVXb003o`000?naXLOo/J7700[o/J7700?o0000ojNJb?nWV/P02OnWV/P00ol0003o
W9C;oibDb`03o`0000WoWikC00?o0000oiFKeonEVmL03onEVmL01Ol0003oRi[Moh^JgOn;V]go0000
01CoTJGR0_l00009ohVUi`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`01ooooo`00:_ooool00ol0003oooooooooo`0=ooooo`03o`000?o2dnKo`]?V00;o
`]?V0_l0000<ol;?i0;o00001Oo2c>82o`0000;o`/_Q00?o`L[Qo`000?o1b>000oo1b>000ol0003o
b<SJolS8fP07olK5f003o`000?o4`=Koa<3F00Soa<3F00?o0000ol6jdoo1^]<02?o1^]<00ol0003o
_;CAokbdd@05okbdd@?o000000?o`;39o`000?niZ<P02_niZ<P00ol0003o/J77ok6Qa`0;ok6Qa`03
o`000?nWV/SoYi[800KoYi[81Ol0000=oinNd`03o`000?nEVmOoUI_G00ooUI_G00?o0000oh^JgOl0
00005onAYN83o`0000KoRJGW00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo007ooooo000[ooooo`;o00003_ooool01?l0003o`]?Vo`000?l0000<ol;?i0;o
00001Oo2c>82o`0000;o`/_Q0_l00006ol78h0?o00001_o6aMP00ol0003oa<3FolC0eP08olC0eP03
o`000?o1^]?o`K[C00Wo`K[C00?o0000okbddOnl]=402?nl]=45o`0000So^JS800?o0000ok6Qaona
XLL02onaXLL00ol0003oYi[8ojNJb006o`0000?oZ:;@00?o0000oinNdonOW]<03OnOW]<00ol0003o
UI_GoiFKe`0?oiFKe`03o`000?nAYN;oTJGR01WoTJGR0_l00003ohVUi`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002gooooo00?o0000ooooooooool0
3?ooool00ol0003o`/oTol;?i00:ol;?i0;o00001_o2c>801_l0003o`/_Qol;;hOl0003o`L[Qo`00
00Ko`LSP00Co0000ol36g_o0a]ko`<KN0_l00003olK5f003o`000?o4`=Koa<3F00Soa<3F00?o0000
ol6jdoo1^]<02Oo1^]<00ol0003o_;CAokbdd@0:okbdd@04o`000?ng[]3o]jk@okN^d0Ko00000_ni
Z<P00ol0003o/J77ok6Qa`04ok6Qa`[o00002_nXX]000ol0003oWikCoinNd`0=oinNd`03o`000?nE
VmOoUI_G00_oUI_G0_l00003oiVUgP03o`000?nAYN;oTJGR01WoTJGR0_l000000on9YNOo0000oooo
o`0Qooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo00cooooo00?o0000ol;?i?o2cn@01oo2cn@2o`0000Ko`/cR0_l000001?o2bn7o0000ol7:hOo1
b^46ol78h0;o00001_o0a]h00ol0003oa/GHo`00000;olC0eP03o`000?o1^]?o`K[C00So`K[C00?o
0000okbddOnl]=402_nl]=400ol0003o]jk@okN^d008okN^d0Wo00001on`Ym000ol0003oZ:;@ojRR
d00:ojRRd003o`000?nOW]?oWikC00goWikC00?o0000oiFKeonEVmL02_nEVmL00ol0003oVJGNoiVU
gP04oiVUgP;o00006onAYN800ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo0Ol0
0001ooooo`7ooooo000_ooooo`;o00003Oooool00ol0003o`/oTol;?i005ol;?i003o`000?o2c>;o
`/cR00Co`/cR0_l000001Oo2bn7o0000o`000?o1b^7o000000Ko`LSP00?o0000ol36g_o0a]h01_o0
a]h3o`0000[oa<3F00?o0000ol6jdoo1^]<02Oo1^]<00ol0003o_;CAokbdd@0:okbdd@03o`000?ng
[]3o]jk@00[o]jk@00?o0000ok2Wd?n`Ym002on`Ym000ol0003oZ:;@ojRRd00;ojRRd003o`000?nO
W]?oWikC00goWikC00?o0000oiFKeonEVmL01onEVmL2o`0000WoVJGN00?o0000oi6Uh_nAYN805_nA
YN800ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000a
ooooo`03o`000?oooooooooo00_ooooo00?o0000ol;?i?o2cn@00_o2cn@2o`0000Ko`/cR00Co0000
ol;;hOo2bn7o00000_o1b^47ol78h003o`000?o0a]ko`<KN00Ko`<KN00Co0000okk2g?nn`]co_/;L
0_l00007olC0eP03o`000?o1^]?o`K[C00Wo`K[C00?o0000okbddOnl]=402onl]=400ol0003o]jk@
okN^d00:okN^d003o`000?n`Ym3o/:O@00co/:O@00?o0000ojRRd?nXX]002_nXX]000ol0003oWikC
oinNd`0>oinNd`03o`000?nEVmOoUI_G00CoUI_G0_l0000<oiVUgP;o00005OnAYN800ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`7ooooo000booooo`03o`000?oo
oooooooo00_ooooo00Co0000ol;?i?l0003o00001_o2c>82o`000005ol;;hOl0003o`L[Qol7:hOl0
00001_o1b>02o`0000So`<KN00?o0000okk2g?nn`]`01?nn`]`2o`0000Coa<3F00?o0000ol6jdoo1
^]<02_o1^]<00ol0003o_;CAokbdd@0:okbdd@03o`000?ng[]3o]jk@00_o]jk@00?o0000ok2Wd?n`
Ym003?n`Ym000ol0003oZ:;@ojRRd00;ojRRd003o`000?nOW]?oWikC00koWikC00?o0000oiFKeonE
VmL00_nEVmL00ol0003oVJGNoiVUgP0>oiVUgP03o`000?nAYN;oTJGR017oTJGR00?o0000oooooooo
ool0:?ooool01Ol0003ooooooooooooooooo000000;ooooo000cooooo`;o00003?ooool00ol0003o
`/cRol;<hP04ol;<hP;o000000?o`/_Qo`000?l000000_o1b^47ol78h003o`000?o0a]ko`<KN00Oo
`<KN00?o0000okk2g?nn`]`01onn`]`2o`000003olC0e_l0003o`K[C00_o`K[C00?o0000okbddOnl
]=402onl]=400ol0003o]jk@okN^d00;okN^d003o`000?n`Ym3o/:O@00co/:O@00?o0000ojRRd?nX
X]003?nXX]000ol0003oWikCoinNd`0>oinNd`04o`000?nEVmOo0000o`0001;oVJGN0_l0000@oi6U
hP03o`000?oooooooooo02[ooooo00Co0000oooooooooooo00000_ooool003Gooooo00?o0000oooo
ooooool02_ooool00ol0003o`/cRol;<hP02ol;<hP04o`000?o2bn7o0000o`0000;o`L[Q00?o0000
ol78h?o1b>001?o1b>02o`0000Wo`<KN00?o0000okk2g?nn`]`02_nn`]`2o`0000co`K[C00?o0000
okbddOnl]=402onl]=400ol0003o]jk@okN^d00;okN^d003o`000?n`Ym3o/:O@00co/:O@00?o0000
ojRRd?nXX]003?nXX]000ol0003oWikCoinNd`0>oinNd`;o00005_nIYMh2o`0000goTJGR00?o0000
ooooooooool0;?ooool00ol0003oooooo`000002ooooo`00=_ooool00ol0003oooooooooo`0:oooo
o`06o`000?o2c>;o0000o`000?o2bn7o00000oo1b^47ol78h003o`000?o0a]ko`<KN00Oo`<KN0_l0
000=okk2g003o`000?nl_M[o000000;o00002?o1^]<00ol0003o_;CAokbdd@0;okbdd@03o`000?ng
[]3o]jk@00co]jk@00?o0000ok2Wd?n`Ym003?n`Ym000ol0003oZ:;@ojRRd00=ojRRd003o`000?nO
W]?oWikC00[oWikC0ol00003oj6WfP03o`000?nIYMkoVJGN01CoVJGN00?o0000oi6Uh_nAYN802OnA
YN800ol0003oooooooooo`0]ooooo`04o`000?ooooooooooo`00007ooooo000gooooo`;o00002ooo
ool01?l0003o`/_Qo`000?l00003ol7:h@Ko`LSP0_l00009ol36gP03o`000?nn`]co_/;L00co_/;L
00?o0000okbmf_nl_MX00onl_MX3o`0000Co`K[C00?o0000okbddOnl]=403?nl]=400ol0003o]jk@
okN^d00<okN^d003o`000?n`Ym3o/:O@00go/:O@00?o0000ojRRd?nXX]003?nXX]000ol0003oWikC
oinNd`07oinNd`?o00001onQYmX00ol0003oVJGNoiVUgP0DoiVUgP;o00002?nAYN800ol0003ooooo
ooooo`0_ooooo`03o`000?oooooo0000007ooooo000iooooo`03o`000?oooooooooo00Wooooo0_l0
0002ol7:h@Oo`LSP00?o0000ol36g_o0a]h02?o0a]h00ol0003o_/;Lokk2g00<okk2g003o`000?nl
_M[o_;gJ00Oo_;gJ0ol000000oo1^]?o0000okbdd@0=okbdd@03o`000?ng[]3o]jk@00_o]jk@00?o
0000ok2Wd?n`Ym003_n`Ym000ol0003oZ:;@ojRRd00=ojRRd003o`000?nOW]?oWikC00?oWikC0ol0
000;oj6WfP03o`000?nIYMkoVJGN01GoVJGN00?o0000oi6Uh_nAYN801?nAYN800ol0003ooooooooo
o`0aooooo`;o00000Oooool003[ooooo00?o0000ooooooooool02_ooool2o`0000Ko`LSP00?o0000
ol36g_o0a]h02?o0a]h00ol0003o_/;Lokk2g00<okk2g003o`000?nl_M[o_;gJ00_o_;gJ0ol0000<
okbdd@03o`000?ng[]3o]jk@00co]jk@00?o0000ok2Wd?n`Ym003_n`Ym000ol0003oZ:;@ojRRd00=
ojRRd003o`000?nOW]?oWikC00?o00003onQYmX00ol0003oVJGNoiVUgP0EoiVUgP;o00000onAYN80
0ol0003oooooooooo`0aooooo`?o00000Oooool003_ooooo0_l0000<ooooo`03o`000?o1b>3o`LSP
00;o`LSP00?o0000ol36g_o0a]h02?o0a]h00ol0003o_/;Lokk2g00<okk2g003o`000?nl_M[o_;gJ
00co_;gJ00?o0000okVhfOni^=T01Ol00007okbdd@03o`000?ng[]3o]jk@00co]jk@00?o0000ok2W
d?n`Ym003_n`Ym000ol0003oZ:;@ojRRd00;ojRRd0Go00004onQYmX00ol0003oVJGNoiVUgP0FoiVU
gP03o`000?nAYN;o0000033ooooo1?l00004ooooo`00?Oooool00ol0003oooooooooo`0:ooooo`03
o`000?o1b>3o`LSP00[o`<KN0_l0000>okk2g003o`000?nl_M[o_;gJ00co_;gJ00?o0000okVhfOni
^=T01_ni^=T5o`0000;o_;CA00?o0000okN^d?ng[]003?ng[]000ol0003o/:O@ok2Wd00>ok2Wd003
o`000?nXX]3oZ:;@00KoZ:;@1Ol00003ojRZf003o`000?nQYm[oXJOJ01?oXJOJ00?o0000oiVUg_nI
YMh05_nIYMh00ol0003oooooooooo`0[ooooo`Co00002?ooool003kooooo00?o0000ooooooooool0
2_ooool2o`0000Wo`<KN00?o0000okk2g?nn`]`03Onn`]`00ol0003o_;gJokbmfP0<okbmfP03o`00
0?ni^=Wo^KSI00co^KSI1_l0000;okN^d003o`000?n`Ym3o/:O@00oo/:O@00?o0000ojRRd?nXX]00
1Ol00009ojRZf003o`000?nQYm[oXJOJ01?oXJOJ00?o0000oiVUg_nIYMh04_nIYMh2o`0002_ooooo
1?l0000<ooooo`00?oooool2o`0000cooooo0_l00006ol36gP03o`000?nn`]co_/;L00go_/;L00?o
0000okbmf_nl_MX03Onl_MX00ol0003o^KSIokVhf@0=okVhf@03o`000?nd/mOo];?G00;o];?G2?l0
0003okN^d003o`000?n`Ym3o/:O@00Ko/:O@3?l0000?ojRZf003o`000?nQYm[oXJOJ01?oXJOJ00?o
0000oiVUg_nIYMh04?nIYMh00ol0003oooooooooo`0Wooooo`Co00004?ooool0047ooooo00?o0000
ooooooooool02oooool00ol0003o`<KNol36gP03ol36gPoo_/;L00?o0000okbmf_nl_MX03Onl_MX0
0ol0003o^KSIokVhf@0=okVhf@03o`000?nd/mOo];?G00_o];?G3?l00009ojj^e`03o`000?nXZ]So
Z:[H00ooZ:[H00?o0000oj6Wf_nQYmX05?nQYmX00ol0003oVJGNoiVUgP0=oiVUgP;o00009Oooool5
o`0001Cooooo0012ooooo`03o`000?oooooooooo00_ooooo0_l00002ol36gPoo_/;L00?o0000okbm
f_nl_MX03Onl_MX00ol0003o^KSIokVhf@0>okVhf@03o`000?nd/mOo];?G00ko];?G00?o0000ojj^
eon^[]L03on^[]L00ol0003oZ:[HojRZf00@ojRZf003o`000?nQYm[oXJOJ01CoXJOJ00?o0000oiVU
g_nIYMh02_nIYMh2o`0002?ooooo1?l0000Iooooo`00@oooool2o`0000gooooo0_l0000>okk2g003
o`000?nl_M[o_;gJ00ko_;gJ00?o0000okVhfOni^=T03_ni^=T00ol0003o];?GokBce`0>okBce`03
o`000?n^[]Oo[ZkG013o[ZkG00?o0000ojRZf?nXZ]P04?nXZ]P00ol0003oXJOJoj6WfP0Doj6WfP03
o`000?nIYMkoVJGN00OoVJGN0_l0000Qooooo`Co00007Oooool004Gooooo00?o0000ooooooooool0
3?ooool2o`0000_o_/;L00?o0000okbmf_nl_MX03_nl_MX00ol0003o^KSIokVhf@0>okVhf@03o`00
0?nd/mOo];?G00oo];?G00?o0000ojj^eon^[]L04?n^[]L00ol0003oZ:[HojRZf00@ojRZf003o`00
0?nQYm[oXJOJ01GoXJOJ00?o0000oiVUg_nIYMh01?nIYMh2o`0001oooooo1?l0000Qooooo`00A_oo
ool00ol0003oooooooooo`0=ooooo`?o00001onn`]`00ol0003o_;gJokbmfP0>okbmfP03o`000?ni
^=Wo^KSI00oo^KSI00?o0000okBceond/mL03ond/mL00ol0003o[ZkGojj^e`0@ojj^e`03o`000?nX
Z]SoZ:[H017oZ:[H00?o0000oj6Wf_nQYmX05OnQYmX00ol0003oVJGNoiVUgP02oiVUgP03o`000?oo
oooooooo01_ooooo1?l0000Uooooo`00Aoooool2o`00013ooooo0_l00004okk2g003o`000?nl_M[o
_;gJ00oo_;gJ00?o0000okVhfOni^=T03_ni^=T00ol0003o];?GokBce`0@okBce`03o`000?n^[]Oo
[ZkG013o[ZkG00?o0000ojRZf?nXZ]P04_nXZ]P00ol0003oXJOJoj6WfP0Eoj6WfP04o`000?nIYMko
0000o`0001[ooooo1?l0000Yooooo`00BOooool00ol0003oooooooooo`0?ooooo`;o000000?o_/;L
o`000?nl_MX04?nl_MX00ol0003o^KSIokVhf@0?okVhf@03o`000?nd/mOo];?G013o];?G00?o0000
ojj^eon^[]L04?n^[]L00ol0003oZ:[HojRZf00BojRZf003o`000?nQYm[oXJOJ01KoXJOJ00?o0000
ooooooooool05_ooool4o`0002gooooo001:ooooo`03o`000?oooooooooo013ooooo0ol0000@okbm
fP03o`000?ni^=Wo^KSI00oo^KSI00?o0000okBceond/mL04?nd/mL00ol0003o[ZkGojj^e`0Aojj^
e`03o`000?nXZ]SoZ:[H01;oZ:[H00?o0000oj6Wf_nQYmX04OnQYmX3o`0001Kooooo1?l0000aoooo
o`00Boooool2o`0001?ooooo0ol0000<okbmfP03o`000?ni^=Wo^KSI00oo^KSI00?o0000okBceond
/mL04Ond/mL00ol0003o[ZkGojj^e`0Aojj^e`03o`000?nXZ]SoZ:[H01;oZ:[H00?o0000oj6Wf_nQ
YmX03_nQYmX3o`0001Gooooo1?l0000eooooo`00COooool00ol0003oooooooooo`0Cooooo`?o0000
2?nl_MX00ol0003o^KSIokVhf@0@okVhf@03o`000?nd/mOo];?G013o];?G00?o0000ojj^eon^[]L0
4_n^[]L00ol0003oZ:[HojRZf00CojRZf003o`000?nQYm[oXJOJ00[oXJOJ0ol0000Dooooo`Co0000
>Oooool004kooooo00?o0000ooooooooool05Oooool3o`0000Go_;gJ00?o0000okVhfOni^=T04?ni
^=T00ol0003o];?GokBce`0@okBce`03o`000?n^[]Oo[ZkG01;o[ZkG00?o0000ojRZf?nXZ]P05?nX
Z]P00ol0003oXJOJoj6WfP06oj6WfP?o00004oooool4o`0003gooooo001?ooooo`;o00006?ooool3
o`000003okbmf_l0003o^KSI017o^KSI00?o0000okBceond/mL04Ond/mL00ol0003o[ZkGojj^e`0C
ojj^e`03o`000?nXZ]SoZ:[H01?oZ:[H00?o0000oj6Wf_nQYmX00onQYmX3o`00017ooooo1Ol00011
ooooo`00DOooool00ol0003oooooooooo`0Hooooo`?o00004Oni^=T00ol0003o];?GokBce`0AokBc
e`03o`000?n^[]Oo[ZkG01?o[ZkG00?o0000ojRZf?nXZ]P05?nXZ]P00ol0003oXJOJo`000002o`00
013ooooo1?l00016ooooo`00D_ooool00ol0003oooooooooo`0Jooooo`Go00002oni^=T00ol0003o
];?GokBce`0BokBce`03o`000?n^[]Oo[ZkG01?o[ZkG00?o0000ojRZf?nXZ]P04_nXZ]P4o`0000oo
oooo1?l0001:ooooo`00Doooool2o`0001kooooo1Ol00007okVhf@03o`000?nd/mOo];?G01;o];?G
00?o0000ojj^eon^[]L04on^[]L00ol0003oZ:[HojRZf00<ojRZf0Ko00003oooool4o`0004kooooo
001Eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool5o`0000;o^KSI00?o
0000okBceond/mL04_nd/mL00ol0003o[ZkGojj^e`0Cojj^e`03o`000?nXZ]SoZ:[H00OoZ:[H1Ol0
000Aooooo`Co0000D_ooool005Kooooo0_l0000Kooooo`03o`000?oooooooooo00Oooooo3Ol0000:
okBce`03o`000?n^[]Oo[ZkG01Co[ZkG00?o0000ojRZf?nXZ]P01_l0000Booooo`Co0000E_ooool0
05Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0DooooobCo00005?ooool4o`00
05[ooooo001Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool4o`0005ko
oooo001Jooooo`;o00005oooool00ol0003oooooooooo`14ooooo`Co0000H_ooool005cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`10ooooo`Co0000I_ooool005gooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0kooooo`Go0000J_ooool005kooooo0_l0000Coooo
o`03o`000?oooooooooo03Oooooo1?l0001_ooooo`00H?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03?ooooo1?l0001cooooo`00HOooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo033ooooo1?l0001gooooo`00H_ooool2o`0000kooooo00?o0000ooooooooool0;?oo
ool4o`0007_ooooo001Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool4
o`0007oooooo001Uooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool4o`00
08?ooooo001Vooooo`;o00002_ooool00ol0003oooooooooo`0Pooooo`Co0000Qoooool006Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`Co0000Roooool006Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`Co0000Soooool006[ooooo0_l00006
ooooo`03o`000?oooooooooo01Cooooo1?l0002Cooooo`00K?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00oooooo1Ol0002Gooooo`00KOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00_ooooo1?l0002Looooo`00K_ooool2o`0000;ooooo00?o0000ooooooooool0
1oooool4o`000:3ooooo001`ooooo`03o`000?oooooo000000Gooooo1?l0002Tooooo`00LOooool2
o`000003ooooool0003o000000;o0000Z?ooool007;ooooo0_l0002/ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {278.625, 0}} -> {0.00640388, -4.55792*^-6, \
0.00327173, 0.00327173}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["alternatively, one can specify the full path to the file", "Text"],

Cell[BoxData[
    \(mySurface = ShowSurface["\<Documents/3dxm/Costa.surf\>"]\)], "Input"],

Cell["\<\
Once a file is saved as a Mathematica graphis, it can be \
manipulated in any way just like normal Mathematica graphics.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[mySurface, 
      ViewPoint -> {\(-0.137\), \ \(-0.117\), \ 3.379}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99839 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00644899 1.01388 -0.0154905 1.01388 [
[ 0 0 0 0 ]
[ 1 .99839 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.53243 .075 m
.54036 0 L
s
.54036 0 m
0 .46607 L
s
0 .46607 m
.09853 .44862 L
s
.09853 .44862 m
.53243 .075 L
s
.90181 .5118 m
.46918 .87744 L
s
.46918 .87744 m
.4616 .99839 L
s
.4616 .99839 m
1 .54467 L
s
1 .54467 m
.90181 .5118 L
s
.53243 .075 m
.54036 0 L
s
.54036 0 m
1 .54467 L
s
1 .54467 m
.90181 .5118 L
s
.90181 .5118 m
.53243 .075 L
s
.09853 .44862 m
.46918 .87744 L
s
.46918 .87744 m
.4616 .99839 L
s
.4616 .99839 m
0 .46607 L
s
0 .46607 m
.09853 .44862 L
s
0 0 m
1 0 L
1 .99839 L
0 .99839 L
closepath
clip
newpath
.5 Mabswid
.58832 .66641 m .53859 .68093 L .54864 .74538 L p .723 .653 .779 r
F P
0 g
s
.54864 .74538 m .61545 .72538 L .58832 .66641 L p .723 .653 .779 r
F P
0 g
s
.48277 .74758 m .54864 .74538 L .53859 .68093 L p .705 .641 .782 r
F P
0 g
s
.53859 .68093 m .4894 .68205 L .48277 .74758 L p .705 .641 .782 r
F P
0 g
s
.42395 .73554 m .48277 .74758 L .4894 .68205 L p .689 .626 .78 r
F P
0 g
s
.4894 .68205 m .4454 .67256 L .42395 .73554 L p .689 .626 .78 r
F P
0 g
s
.37612 .71498 m .42395 .73554 L .4454 .67256 L p .676 .612 .776 r
F P
0 g
s
.63332 .63818 m .58832 .66641 L .61545 .72538 L p .74 .661 .772 r
F P
0 g
s
.61545 .72538 m .67614 .6871 L .63332 .63818 L p .74 .661 .772 r
F P
0 g
s
.4454 .67256 m .40945 .65668 L .37612 .71498 L p .676 .612 .776 r
F P
0 g
s
.34055 .69178 m .37612 .71498 L .40945 .65668 L p .666 .599 .77 r
F P
0 g
s
.66856 .59841 m .63332 .63818 L .67614 .6871 L p .754 .662 .759 r
F P
0 g
s
.67614 .6871 m .72399 .63358 L .66856 .59841 L p .754 .662 .759 r
F P
0 g
s
.40945 .65668 m .38269 .63895 L .34055 .69178 L p .666 .599 .77 r
F P
0 g
s
.31679 .67129 m .34055 .69178 L .38269 .63895 L p .659 .588 .764 r
F P
0 g
s
.38269 .63895 m .36472 .62339 L .31679 .67129 L p .659 .588 .764 r
F P
0 g
s
.30338 .65747 m .31679 .67129 L .36472 .62339 L p .654 .581 .76 r
F P
0 g
s
.36472 .62339 m .35458 .61289 L .30338 .65747 L p .654 .581 .76 r
F P
0 g
s
.29906 .65258 m .30338 .65747 L .35458 .61289 L p .652 .577 .758 r
F P
0 g
s
.35458 .61289 m .35135 .60915 L .29906 .65258 L p .652 .577 .758 r
F P
0 g
s
.34813 .6054 m .35135 .60915 L .29906 .65258 L p .651 .576 .757 r
F P
0 g
s
.29906 .65258 m .29485 .64759 L .34813 .6054 L p .651 .576 .757 r
F P
0 g
s
.33924 .59382 m .34813 .6054 L .29485 .64759 L p .649 .572 .754 r
F P
0 g
s
.29485 .64759 m .28311 .6323 L .33924 .59382 L p .649 .572 .754 r
F P
0 g
s
.69102 .55166 m .66856 .59841 L .72399 .63358 L p .765 .658 .744 r
F P
0 g
s
.72399 .63358 m .75482 .57084 L .69102 .55166 L p .765 .658 .744 r
F P
0 g
s
.3265 .57372 m .33924 .59382 L .28311 .6323 L p .646 .565 .75 r
F P
0 g
s
.28311 .6323 m .26628 .60578 L .3265 .57372 L p .646 .565 .75 r
F P
0 g
s
.31291 .54456 m .3265 .57372 L .26628 .60578 L p .642 .555 .741 r
F P
0 g
s
.26628 .60578 m .24849 .5671 L .31291 .54456 L p .642 .555 .741 r
F P
0 g
s
.70009 .50319 m .69102 .55166 L .75482 .57084 L p .77 .648 .727 r
F P
0 g
s
.75482 .57084 m .7678 .50597 L .70009 .50319 L p .77 .648 .727 r
F P
0 g
s
.30253 .50652 m .31291 .54456 L .24849 .5671 L p .638 .543 .731 r
F P
0 g
s
.24849 .5671 m .23512 .51657 L .30253 .50652 L p .638 .543 .731 r
F P
0 g
s
.29973 .4614 m .30253 .50652 L .23512 .51657 L p .636 .53 .717 r
F P
0 g
s
.23512 .51657 m .23191 .45628 L .29973 .4614 L p .636 .53 .717 r
F P
0 g
s
.69773 .45809 m .70009 .50319 L .7678 .50597 L p .771 .636 .712 r
F P
0 g
s
.7678 .50597 m .76539 .44566 L .69773 .45809 L p .771 .636 .712 r
F P
0 g
s
.30834 .41268 m .29973 .4614 L .23191 .45628 L p .638 .519 .701 r
F P
0 g
s
.23191 .45628 m .24407 .39102 L .30834 .41268 L p .638 .519 .701 r
F P
0 g
s
.6877 .4199 m .69773 .45809 L .76539 .44566 L p .769 .623 .698 r
F P
0 g
s
.76539 .44566 m .75264 .39483 L .6877 .4199 L p .769 .623 .698 r
F P
0 g
s
.33049 .36547 m .30834 .41268 L .24407 .39102 L p .644 .51 .685 r
F P
0 g
s
.24407 .39102 m .27433 .3275 L .33049 .36547 L p .644 .51 .685 r
F P
0 g
s
.67432 .39053 m .6877 .4199 L .75264 .39483 L p .765 .611 .688 r
F P
0 g
s
.75264 .39483 m .73522 .35575 L .67432 .39053 L p .765 .611 .688 r
F P
0 g
s
.66169 .37024 m .67432 .39053 L .73522 .35575 L p .761 .601 .68 r
F P
0 g
s
.73522 .35575 m .71857 .32886 L .66169 .37024 L p .761 .601 .68 r
F P
0 g
s
.36567 .32515 m .33049 .36547 L .27433 .3275 L p .654 .506 .67 r
F P
0 g
s
.27433 .3275 m .32207 .273 L .36567 .32515 L p .654 .506 .67 r
F P
0 g
s
.65284 .35852 m .66169 .37024 L .71857 .32886 L p .757 .594 .675 r
F P
0 g
s
.71857 .32886 m .70691 .31333 L .65284 .35852 L p .757 .594 .675 r
F P
0 g
s
.64962 .35472 m .65284 .35852 L .70691 .31333 L p .755 .591 .673 r
F P
0 g
s
.6984 .30327 m .70271 .30825 L .68176 .32659 L p .754 .589 .672 r
F P
0 g
s
.70691 .31333 m .68176 .32659 L .64962 .35472 L .755 .591 .673 r
F
.68176 .32659 m .64962 .35472 L p .64962 .35472 L .754 .589 .672 r
F P
0 g
s
.6984 .30327 m .68176 .32659 L .64962 .35472 L .754 .589 .672 r
F
.70691 .31333 m .70271 .30825 L .68176 .32659 L p .755 .591 .673 r
F P
0 g
s
.64962 .35472 m .6464 .35093 L .6984 .30327 L p .754 .589 .672 r
F P
0 g
s
.68176 .32659 m .64962 .35472 L p .64962 .35472 L .755 .591 .673 r
F P
0 g
s
.685 .28919 m .6984 .30327 L .6464 .35093 L p .752 .585 .669 r
F P
0 g
s
.6464 .35093 m .63627 .34028 L .685 .28919 L p .752 .585 .669 r
F P
0 g
s
.66118 .26829 m .685 .28919 L .63627 .34028 L p .748 .579 .665 r
F P
0 g
s
.41089 .29644 m .36567 .32515 L .32207 .273 L p .668 .508 .658 r
F P
0 g
s
.32207 .273 m .38316 .23386 L .41089 .29644 L p .668 .508 .658 r
F P
0 g
s
.63627 .34028 m .61827 .32449 L .66118 .26829 L p .748 .579 .665 r
F P
0 g
s
.62538 .24456 m .66118 .26829 L .61827 .32449 L p .741 .568 .66 r
F P
0 g
s
.61827 .32449 m .59138 .30645 L .62538 .24456 L p .741 .568 .66 r
F P
0 g
s
.57706 .22349 m .62538 .24456 L .59138 .30645 L p .731 .556 .654 r
F P
0 g
s
.46105 .28166 m .41089 .29644 L .38316 .23386 L p .685 .516 .651 r
F P
0 g
s
.38316 .23386 m .45075 .21335 L .46105 .28166 L p .685 .516 .651 r
F P
0 g
s
.57098 .62805 m .53269 .63874 L .53859 .68093 L p .727 .679 .803 r
F P
0 g
s
.53859 .68093 m .58832 .66641 L .57098 .62805 L p .727 .679 .803 r
F P
0 g
s
.4894 .68205 m .53859 .68093 L .53269 .63874 L p .702 .661 .807 r
F P
0 g
s
.53269 .63874 m .49466 .639 L .4894 .68205 L p .702 .661 .807 r
F P
0 g
s
.4454 .67256 m .4894 .68205 L .49466 .639 L p .68 .641 .804 r
F P
0 g
s
.60539 .60658 m .57098 .62805 L .58832 .66641 L p .752 .69 .792 r
F P
0 g
s
.58832 .66641 m .63332 .63818 L .60539 .60658 L p .752 .69 .792 r
F P
0 g
s
.59138 .30645 m .55515 .29026 L .57706 .22349 L p .731 .556 .654 r
F P
0 g
s
.5175 .21111 m .57706 .22349 L .55515 .29026 L p .718 .541 .65 r
F P
0 g
s
.49466 .639 m .46044 .631 L .4454 .67256 L p .68 .641 .804 r
F P
0 g
s
.40945 .65668 m .4454 .67256 L .46044 .631 L p .661 .62 .798 r
F P
0 g
s
.51073 .28055 m .46105 .28166 L .45075 .21335 L p .702 .528 .649 r
F P
0 g
s
.45075 .21335 m .5175 .21111 L .51073 .28055 L p .702 .528 .649 r
F P
0 g
s
.55515 .29026 m .51073 .28055 L .5175 .21111 L p .718 .541 .65 r
F P
0 g
s
.63217 .57612 m .60539 .60658 L .63332 .63818 L p .773 .692 .775 r
F P
0 g
s
.63332 .63818 m .66856 .59841 L .63217 .57612 L p .773 .692 .775 r
F P
0 g
s
.46044 .631 m .4324 .61812 L .40945 .65668 L p .661 .62 .798 r
F P
0 g
s
.38269 .63895 m .40945 .65668 L .4324 .61812 L p .647 .602 .789 r
F P
0 g
s
.4324 .61812 m .41142 .60387 L .38269 .63895 L p .647 .602 .789 r
F P
0 g
s
.36472 .62339 m .38269 .63895 L .41142 .60387 L p .638 .588 .782 r
F P
0 g
s
.41142 .60387 m .39729 .59142 L .36472 .62339 L p .638 .588 .782 r
F P
0 g
s
.35458 .61289 m .36472 .62339 L .39729 .59142 L p .632 .578 .776 r
F P
0 g
s
.64891 .54006 m .63217 .57612 L .66856 .59841 L p .787 .686 .753 r
F P
0 g
s
.66856 .59841 m .69102 .55166 L .64891 .54006 L p .787 .686 .753 r
F P
0 g
s
.39729 .59142 m .38923 .5831 L .35458 .61289 L p .632 .578 .776 r
F P
0 g
s
.35135 .60915 m .35458 .61289 L .38923 .5831 L p .628 .572 .772 r
F P
0 g
s
.38412 .57715 m .38668 .58013 L .35135 .60915 L p .628 .572 .772 r
F P
0 g
s
.35135 .60915 m .34813 .6054 L .38412 .57715 L p .628 .572 .772 r
F P
0 g
s
.38923 .5831 m .38668 .58013 L .35135 .60915 L p .628 .572 .772 r
F P
0 g
s
.3771 .56794 m .38412 .57715 L .34813 .6054 L p .625 .565 .767 r
F P
0 g
s
.34813 .6054 m .33924 .59382 L .3771 .56794 L p .625 .565 .767 r
F P
0 g
s
.36689 .55209 m .3771 .56794 L .33924 .59382 L p .62 .555 .76 r
F P
0 g
s
.33924 .59382 m .3265 .57372 L .36689 .55209 L p .62 .555 .76 r
F P
0 g
s
.35592 .52916 m .36689 .55209 L .3265 .57372 L p .614 .542 .75 r
F P
0 g
s
.3265 .57372 m .31291 .54456 L .35592 .52916 L p .614 .542 .75 r
F P
0 g
s
.65525 .50254 m .64891 .54006 L .69102 .55166 L p .794 .672 .729 r
F P
0 g
s
.69102 .55166 m .70009 .50319 L .65525 .50254 L p .794 .672 .729 r
F P
0 g
s
.34737 .49941 m .35592 .52916 L .31291 .54456 L p .609 .525 .734 r
F P
0 g
s
.31291 .54456 m .30253 .50652 L .34737 .49941 L p .609 .525 .734 r
F P
0 g
s
.65277 .46742 m .65525 .50254 L .70009 .50319 L p .795 .654 .707 r
F P
0 g
s
.70009 .50319 m .69773 .45809 L .65277 .46742 L p .795 .654 .707 r
F P
0 g
s
.34462 .46424 m .34737 .49941 L .30253 .50652 L p .606 .507 .715 r
F P
0 g
s
.30253 .50652 m .29973 .4614 L .34462 .46424 L p .606 .507 .715 r
F P
0 g
s
.35069 .42651 m .34462 .46424 L .29973 .4614 L p .608 .49 .693 r
F P
0 g
s
.29973 .4614 m .30834 .41268 L .35069 .42651 L p .608 .49 .693 r
F P
0 g
s
.64442 .43762 m .65277 .46742 L .69773 .45809 L p .792 .636 .689 r
F P
0 g
s
.69773 .45809 m .6877 .4199 L .64442 .43762 L p .792 .636 .689 r
F P
0 g
s
.36724 .39014 m .35069 .42651 L .30834 .41268 L p .616 .477 .67 r
F P
0 g
s
.30834 .41268 m .33049 .36547 L .36724 .39014 L p .616 .477 .67 r
F P
0 g
s
.63359 .41458 m .64442 .43762 L .6877 .4199 L p .786 .619 .674 r
F P
0 g
s
.6877 .4199 m .67432 .39053 L .63359 .41458 L p .786 .619 .674 r
F P
0 g
s
.62344 .39862 m .63359 .41458 L .67432 .39053 L p .78 .606 .664 r
F P
0 g
s
.67432 .39053 m .66169 .37024 L .62344 .39862 L p .78 .606 .664 r
F P
0 g
s
.39398 .35934 m .36724 .39014 L .33049 .36547 L p .63 .472 .649 r
F P
0 g
s
.33049 .36547 m .36567 .32515 L .39398 .35934 L p .63 .472 .649 r
F P
0 g
s
.61645 .38932 m .62344 .39862 L .66169 .37024 L p .775 .596 .657 r
F P
0 g
s
.66169 .37024 m .65284 .35852 L .61645 .38932 L p .775 .596 .657 r
F P
0 g
s
.61389 .38632 m .61645 .38932 L .65284 .35852 L p .772 .59 .653 r
F P
0 g
s
.65284 .35852 m .64962 .35472 L .61389 .38632 L p .772 .59 .653 r
F P
0 g
s
.6464 .35093 m .64962 .35472 L .61389 .38632 L p .772 .59 .653 r
F P
0 g
s
.61389 .38632 m .61134 .38331 L .6464 .35093 L p .772 .59 .653 r
F P
0 g
s
.63627 .34028 m .6464 .35093 L .61134 .38331 L p .768 .584 .649 r
F P
0 g
s
.42852 .3376 m .39398 .35934 L .36567 .32515 L p .651 .475 .633 r
F P
0 g
s
.36567 .32515 m .41089 .29644 L .42852 .3376 L p .651 .475 .633 r
F P
0 g
s
.61134 .38331 m .60328 .37491 L .63627 .34028 L p .768 .584 .649 r
F P
0 g
s
.61827 .32449 m .63627 .34028 L .60328 .37491 L p .762 .574 .643 r
F P
0 g
s
.60328 .37491 m .58914 .3623 L .61827 .32449 L p .762 .574 .643 r
F P
0 g
s
.59138 .30645 m .61827 .32449 L .58914 .3623 L p .753 .561 .636 r
F P
0 g
s
.46707 .32678 m .42852 .3376 L .41089 .29644 L p .675 .486 .623 r
F P
0 g
s
.41089 .29644 m .46105 .28166 L .46707 .32678 L p .675 .486 .623 r
F P
0 g
s
.58914 .3623 m .56807 .34785 L .59138 .30645 L p .753 .561 .636 r
F P
0 g
s
.55515 .29026 m .59138 .30645 L .56807 .34785 L p .739 .543 .628 r
F P
0 g
s
.5054 .32658 m .46707 .32678 L .46105 .28166 L p .699 .503 .619 r
F P
0 g
s
.46105 .28166 m .51073 .28055 L .5054 .32658 L p .699 .503 .619 r
F P
0 g
s
.56807 .34785 m .53987 .33474 L .55515 .29026 L p .739 .543 .628 r
F P
0 g
s
.51073 .28055 m .55515 .29026 L .53987 .33474 L p .721 .523 .622 r
F P
0 g
s
.53987 .33474 m .5054 .32658 L .51073 .28055 L p .721 .523 .622 r
F P
0 g
s
.56017 .60334 m .52964 .61138 L .53269 .63874 L p .73 .713 .834 r
F P
0 g
s
.53269 .63874 m .57098 .62805 L .56017 .60334 L p .73 .713 .834 r
F P
0 g
s
.49466 .639 m .53269 .63874 L .52964 .61138 L p .696 .688 .839 r
F P
0 g
s
.58745 .58656 m .56017 .60334 L .57098 .62805 L p .766 .729 .819 r
F P
0 g
s
.57098 .62805 m .60539 .60658 L .58745 .58656 L p .766 .729 .819 r
F P
0 g
s
.52964 .61138 m .49914 .61098 L .49466 .639 L p .696 .688 .839 r
F P
0 g
s
.46044 .631 m .49466 .639 L .49914 .61098 L p .664 .658 .834 r
F P
0 g
s
.6084 .56238 m .58745 .58656 L .60539 .60658 L p .795 .732 .794 r
F P
0 g
s
.60539 .60658 m .63217 .57612 L .6084 .56238 L p .795 .732 .794 r
F P
0 g
s
.49914 .61098 m .47153 .60375 L .46044 .631 L p .664 .658 .834 r
F P
0 g
s
.4324 .61812 m .46044 .631 L .47153 .60375 L p .639 .63 .825 r
F P
0 g
s
.47153 .60375 m .44866 .59262 L .4324 .61812 L p .639 .63 .825 r
F P
0 g
s
.41142 .60387 m .4324 .61812 L .44866 .59262 L p .621 .604 .812 r
F P
0 g
s
.62122 .53357 m .6084 .56238 L .63217 .57612 L p .816 .722 .762 r
F P
0 g
s
.63217 .57612 m .64891 .54006 L .62122 .53357 L p .816 .722 .762 r
F P
0 g
s
.44866 .59262 m .43137 .58056 L .41142 .60387 L p .621 .604 .812 r
F P
0 g
s
.39729 .59142 m .41142 .60387 L .43137 .58056 L p .608 .586 .803 r
F P
0 g
s
.43137 .58056 m .41969 .57004 L .39729 .59142 L p .608 .586 .803 r
F P
0 g
s
.38923 .5831 m .39729 .59142 L .41969 .57004 L p .6 .572 .794 r
F P
0 g
s
.41969 .57004 m .41298 .56305 L .38923 .5831 L p .6 .572 .794 r
F P
0 g
s
.38668 .58013 m .38923 .5831 L .41298 .56305 L p .596 .564 .788 r
F P
0 g
s
.4087 .55807 m .41084 .56056 L .38668 .58013 L p .596 .564 .788 r
F P
0 g
s
.38668 .58013 m .38412 .57715 L .4087 .55807 L p .596 .564 .788 r
F P
0 g
s
.41298 .56305 m .41084 .56056 L .38668 .58013 L p .596 .564 .788 r
F P
0 g
s
.40281 .55038 m .4087 .55807 L .38412 .57715 L p .591 .555 .783 r
F P
0 g
s
.38412 .57715 m .3771 .56794 L .40281 .55038 L p .591 .555 .783 r
F P
0 g
s
.62565 .50341 m .62122 .53357 L .64891 .54006 L p .825 .702 .729 r
F P
0 g
s
.64891 .54006 m .65525 .50254 L .62565 .50341 L p .825 .702 .729 r
F P
0 g
s
.39416 .53723 m .40281 .55038 L .3771 .56794 L p .584 .541 .773 r
F P
0 g
s
.3771 .56794 m .36689 .55209 L .39416 .53723 L p .584 .541 .773 r
F P
0 g
s
.38481 .51826 m .39416 .53723 L .36689 .55209 L p .577 .524 .759 r
F P
0 g
s
.36689 .55209 m .35592 .52916 L .38481 .51826 L p .577 .524 .759 r
F P
0 g
s
.37723 .49389 m .38481 .51826 L .35592 .52916 L p .568 .5 .738 r
F P
0 g
s
.35592 .52916 m .34737 .49941 L .37723 .49389 L p .568 .5 .738 r
F P
0 g
s
.62284 .475 m .62565 .50341 L .65525 .50254 L p .825 .677 .698 r
F P
0 g
s
.65525 .50254 m .65277 .46742 L .62284 .475 L p .825 .677 .698 r
F P
0 g
s
.37424 .46537 m .37723 .49389 L .34737 .49941 L p .564 .475 .713 r
F P
0 g
s
.34737 .49941 m .34462 .46424 L .37424 .46537 L p .564 .475 .713 r
F P
0 g
s
.37849 .43502 m .37424 .46537 L .34462 .46424 L p .566 .451 .681 r
F P
0 g
s
.34462 .46424 m .35069 .42651 L .37849 .43502 L p .566 .451 .681 r
F P
0 g
s
.61539 .45064 m .62284 .475 L .65277 .46742 L p .819 .651 .675 r
F P
0 g
s
.65277 .46742 m .64442 .43762 L .61539 .45064 L p .819 .651 .675 r
F P
0 g
s
.39119 .40596 m .37849 .43502 L .35069 .42651 L p .576 .433 .649 r
F P
0 g
s
.35069 .42651 m .36724 .39014 L .39119 .40596 L p .576 .433 .649 r
F P
0 g
s
.60613 .43163 m .61539 .45064 L .64442 .43762 L p .811 .628 .654 r
F P
0 g
s
.64442 .43762 m .63359 .41458 L .60613 .43163 L p .811 .628 .654 r
F P
0 g
s
.41212 .38152 m .39119 .40596 L .36724 .39014 L p .597 .425 .619 r
F P
0 g
s
.36724 .39014 m .39398 .35934 L .41212 .38152 L p .597 .425 .619 r
F P
0 g
s
.59752 .41841 m .60613 .43163 L .63359 .41458 L p .803 .61 .641 r
F P
0 g
s
.63359 .41458 m .62344 .39862 L .59752 .41841 L p .803 .61 .641 r
F P
0 g
s
.43948 .36459 m .41212 .38152 L .39398 .35934 L p .626 .429 .596 r
F P
0 g
s
.39398 .35934 m .42852 .3376 L .43948 .36459 L p .626 .429 .596 r
F P
0 g
s
.59165 .41067 m .59752 .41841 L .62344 .39862 L p .796 .598 .633 r
F P
0 g
s
.62344 .39862 m .61645 .38932 L .59165 .41067 L p .796 .598 .633 r
F P
0 g
s
.58951 .40816 m .59165 .41067 L .61645 .38932 L p .792 .589 .627 r
F P
0 g
s
.61645 .38932 m .61389 .38632 L .58951 .40816 L p .792 .589 .627 r
F P
0 g
s
.61134 .38331 m .61389 .38632 L .58951 .40816 L p .792 .589 .627 r
F P
0 g
s
.58951 .40816 m .58737 .40565 L .61134 .38331 L p .792 .589 .627 r
F P
0 g
s
.60328 .37491 m .61134 .38331 L .58737 .40565 L p .787 .581 .622 r
F P
0 g
s
.47018 .35652 m .43948 .36459 L .42852 .3376 L p .66 .445 .582 r
F P
0 g
s
.42852 .3376 m .46707 .32678 L .47018 .35652 L p .66 .445 .582 r
F P
0 g
s
.58737 .40565 m .58067 .39861 L .60328 .37491 L p .787 .581 .622 r
F P
0 g
s
.58914 .3623 m .60328 .37491 L .58067 .39861 L p .779 .568 .614 r
F P
0 g
s
.58067 .39861 m .56897 .38798 L .58914 .3623 L p .779 .568 .614 r
F P
0 g
s
.56807 .34785 m .58914 .3623 L .56897 .38798 L p .767 .55 .604 r
F P
0 g
s
.50087 .35702 m .47018 .35652 L .46707 .32678 L p .693 .47 .579 r
F P
0 g
s
.46707 .32678 m .5054 .32658 L .50087 .35702 L p .693 .47 .579 r
F P
0 g
s
.56897 .38798 m .55162 .37575 L .56807 .34785 L p .767 .55 .604 r
F P
0 g
s
.53987 .33474 m .56807 .34785 L .55162 .37575 L p .748 .525 .594 r
F P
0 g
s
.52865 .36443 m .50087 .35702 L .5054 .32658 L p .724 .499 .584 r
F P
0 g
s
.5054 .32658 m .53987 .33474 L .52865 .36443 L p .724 .499 .584 r
F P
0 g
s
.55162 .37575 m .52865 .36443 L .53987 .33474 L p .748 .525 .594 r
F P
0 g
s
.5762 .57428 m .55382 .58788 L .56017 .60334 L p .781 .782 .853 r
F P
0 g
s
.56017 .60334 m .58745 .58656 L .5762 .57428 L p .781 .782 .853 r
F P
0 g
s
.52964 .61138 m .56017 .60334 L .55382 .58788 L p .731 .757 .874 r
F P
0 g
s
.55382 .58788 m .52856 .59406 L .52964 .61138 L p .731 .757 .874 r
F P
0 g
s
.49914 .61098 m .52964 .61138 L .52856 .59406 L p .681 .72 .879 r
F P
0 g
s
.59321 .5544 m .5762 .57428 L .58745 .58656 L p .824 .786 .816 r
F P
0 g
s
.58745 .58656 m .6084 .56238 L .59321 .5544 L p .824 .786 .816 r
F P
0 g
s
.52856 .59406 m .50319 .59306 L .49914 .61098 L p .681 .72 .879 r
F P
0 g
s
.47153 .60375 m .49914 .61098 L .50319 .59306 L p .639 .677 .871 r
F P
0 g
s
.60332 .53052 m .59321 .5544 L .6084 .56238 L p .852 .77 .771 r
F P
0 g
s
.6084 .56238 m .62122 .53357 L .60332 .53052 L p .852 .77 .771 r
F P
0 g
s
.50319 .59306 m .47996 .58625 L .47153 .60375 L p .639 .677 .871 r
F P
0 g
s
.44866 .59262 m .47153 .60375 L .47996 .58625 L p .606 .637 .856 r
F P
0 g
s
.47996 .58625 m .4605 .57607 L .44866 .59262 L p .606 .637 .856 r
F P
0 g
s
.43137 .58056 m .44866 .59262 L .4605 .57607 L p .583 .606 .841 r
F P
0 g
s
.60629 .50536 m .60332 .53052 L .62122 .53357 L p .863 .739 .725 r
F P
0 g
s
.62122 .53357 m .62565 .50341 L .60629 .50536 L p .863 .739 .725 r
F P
0 g
s
.4605 .57607 m .44562 .56512 L .43137 .58056 L p .583 .606 .841 r
F P
0 g
s
.41969 .57004 m .43137 .58056 L .44562 .56512 L p .567 .579 .825 r
F P
0 g
s
.44562 .56512 m .43538 .55572 L .41969 .57004 L p .567 .579 .825 r
F P
0 g
s
.41298 .56305 m .41969 .57004 L .43538 .55572 L p .557 .562 .815 r
F P
0 g
s
.43538 .55572 m .42949 .54947 L .41298 .56305 L p .557 .562 .815 r
F P
0 g
s
.41084 .56056 m .41298 .56305 L .42949 .54947 L p .551 .551 .807 r
F P
0 g
s
.42569 .54504 m .42759 .54725 L .41084 .56056 L p .551 .551 .807 r
F P
0 g
s
.41084 .56056 m .4087 .55807 L .42569 .54504 L p .551 .551 .807 r
F P
0 g
s
.42949 .54947 m .42759 .54725 L .41084 .56056 L p .551 .551 .807 r
F P
0 g
s
.4204 .53827 m .42569 .54504 L .4087 .55807 L p .545 .54 .8 r
F P
0 g
s
.4087 .55807 m .40281 .55038 L .4204 .53827 L p .545 .54 .8 r
F P
0 g
s
.41264 .52669 m .4204 .53827 L .40281 .55038 L p .538 .524 .788 r
F P
0 g
s
.40281 .55038 m .39416 .53723 L .41264 .52669 L p .538 .524 .788 r
F P
0 g
s
.60316 .48139 m .60629 .50536 L .62565 .50341 L p .861 .702 .683 r
F P
0 g
s
.62565 .50341 m .62284 .475 L .60316 .48139 L p .861 .702 .683 r
F P
0 g
s
.40403 .51026 m .41264 .52669 L .39416 .53723 L p .525 .497 .768 r
F P
0 g
s
.39416 .53723 m .38481 .51826 L .40403 .51026 L p .525 .497 .768 r
F P
0 g
s
.39686 .48937 m .40403 .51026 L .38481 .51826 L p .514 .467 .742 r
F P
0 g
s
.38481 .51826 m .37723 .49389 L .39686 .48937 L p .514 .467 .742 r
F P
0 g
s
.3936 .46523 m .39686 .48937 L .37723 .49389 L p .506 .432 .707 r
F P
0 g
s
.37723 .49389 m .37424 .46537 L .3936 .46523 L p .506 .432 .707 r
F P
0 g
s
.39645 .43986 m .3936 .46523 L .37424 .46537 L p .506 .396 .663 r
F P
0 g
s
.37424 .46537 m .37849 .43502 L .39645 .43986 L p .506 .396 .663 r
F P
0 g
s
.59609 .46059 m .60316 .48139 L .62284 .475 L p .853 .667 .65 r
F P
0 g
s
.62284 .475 m .61539 .45064 L .59609 .46059 L p .853 .667 .65 r
F P
0 g
s
.40647 .41573 m .39645 .43986 L .37849 .43502 L p .519 .369 .617 r
F P
0 g
s
.37849 .43502 m .39119 .40596 L .40647 .41573 L p .519 .369 .617 r
F P
0 g
s
.42346 .39565 m .40647 .41573 L .39119 .40596 L p .547 .356 .574 r
F P
0 g
s
.39119 .40596 m .41212 .38152 L .42346 .39565 L p .547 .356 .574 r
F P
0 g
s
.58754 .44418 m .59609 .46059 L .61539 .45064 L p .841 .638 .628 r
F P
0 g
s
.61539 .45064 m .60613 .43163 L .58754 .44418 L p .841 .638 .628 r
F P
0 g
s
.44591 .38196 m .42346 .39565 L .41212 .38152 L p .589 .364 .542 r
F P
0 g
s
.41212 .38152 m .43948 .36459 L .44591 .38196 L p .589 .364 .542 r
F P
0 g
s
.47128 .37582 m .44591 .38196 L .43948 .36459 L p .637 .388 .525 r
F P
0 g
s
.43948 .36459 m .47018 .35652 L .47128 .37582 L p .637 .388 .525 r
F P
0 g
s
.57981 .43258 m .58754 .44418 L .60613 .43163 L p .829 .612 .609 r
F P
0 g
s
.60613 .43163 m .59752 .41841 L .57981 .43258 L p .829 .612 .609 r
F P
0 g
s
.57453 .42577 m .57981 .43258 L .59752 .41841 L p .821 .597 .599 r
F P
0 g
s
.59752 .41841 m .59165 .41067 L .57453 .42577 L p .821 .597 .599 r
F P
0 g
s
.49679 .37697 m .47128 .37582 L .47018 .35652 L p .685 .425 .524 r
F P
0 g
s
.47018 .35652 m .50087 .35702 L .49679 .37697 L p .685 .425 .524 r
F P
0 g
s
.57263 .42355 m .57453 .42577 L .59165 .41067 L p .815 .586 .592 r
F P
0 g
s
.59165 .41067 m .58951 .40816 L .57263 .42355 L p .815 .586 .592 r
F P
0 g
s
.58737 .40565 m .58951 .40816 L .57263 .42355 L p .815 .586 .592 r
F P
0 g
s
.57263 .42355 m .57073 .42132 L .58737 .40565 L p .815 .586 .592 r
F P
0 g
s
.58067 .39861 m .58737 .40565 L .57073 .42132 L p .809 .576 .585 r
F P
0 g
s
.57073 .42132 m .56485 .41501 L .58067 .39861 L p .809 .576 .585 r
F P
0 g
s
.56897 .38798 m .58067 .39861 L .56485 .41501 L p .799 .56 .576 r
F P
0 g
s
.52014 .384 m .49679 .37697 L .50087 .35702 L p .727 .466 .532 r
F P
0 g
s
.50087 .35702 m .52865 .36443 L .52014 .384 L p .727 .466 .532 r
F P
0 g
s
.56485 .41501 m .55459 .40551 L .56897 .38798 L p .799 .56 .576 r
F P
0 g
s
.55162 .37575 m .56897 .38798 L .55459 .40551 L p .781 .534 .562 r
F P
0 g
s
.53968 .3944 m .52014 .384 L .52865 .36443 L p .759 .503 .546 r
F P
0 g
s
.52865 .36443 m .55162 .37575 L .53968 .3944 L p .759 .503 .546 r
F P
0 g
s
.55459 .40551 m .53968 .3944 L .55162 .37575 L p .781 .534 .562 r
F P
0 g
s
.56955 .56725 m .55049 .57871 L .55382 .58788 L p .793 .851 .894 r
F P
0 g
s
.55382 .58788 m .5762 .57428 L .56955 .56725 L p .793 .851 .894 r
F P
0 g
s
.52856 .59406 m .55382 .58788 L .55049 .57871 L p .72 .813 .923 r
F P
0 g
s
.5839 .55031 m .56955 .56725 L .5762 .57428 L p .857 .856 .84 r
F P
0 g
s
.5762 .57428 m .59321 .5544 L .5839 .55031 L p .857 .856 .84 r
F P
0 g
s
.55049 .57871 m .52886 .58368 L .52856 .59406 L p .72 .813 .923 r
F P
0 g
s
.50319 .59306 m .52856 .59406 L .52886 .58368 L p .65 .757 .927 r
F P
0 g
s
.59219 .52983 m .5839 .55031 L .59321 .5544 L p .896 .831 .774 r
F P
0 g
s
.59321 .5544 m .60332 .53052 L .59219 .52983 L p .896 .831 .774 r
F P
0 g
s
.52886 .58368 m .50696 .58223 L .50319 .59306 L p .65 .757 .927 r
F P
0 g
s
.47996 .58625 m .50319 .59306 L .50696 .58223 L p .594 .696 .914 r
F P
0 g
s
.50696 .58223 m .48674 .57557 L .47996 .58625 L p .594 .696 .914 r
F P
0 g
s
.4605 .57607 m .47996 .58625 L .48674 .57557 L p .554 .642 .892 r
F P
0 g
s
.59413 .50806 m .59219 .52983 L .60332 .53052 L p .91 .784 .709 r
F P
0 g
s
.60332 .53052 m .60629 .50536 L .59413 .50806 L p .91 .784 .709 r
F P
0 g
s
.48674 .57557 m .46954 .56575 L .4605 .57607 L p .554 .642 .892 r
F P
0 g
s
.44562 .56512 m .4605 .57607 L .46954 .56575 L p .526 .598 .869 r
F P
0 g
s
.59062 .48714 m .59413 .50806 L .60629 .50536 L p .905 .731 .655 r
F P
0 g
s
.60629 .50536 m .60316 .48139 L .59062 .48714 L p .905 .731 .655 r
F P
0 g
s
.46954 .56575 m .45609 .55522 L .44562 .56512 L p .526 .598 .869 r
F P
0 g
s
.43538 .55572 m .44562 .56512 L .45609 .55522 L p .509 .567 .85 r
F P
0 g
s
.45609 .55522 m .44667 .54619 L .43538 .55572 L p .509 .567 .85 r
F P
0 g
s
.42949 .54947 m .43538 .55572 L .44667 .54619 L p .498 .546 .835 r
F P
0 g
s
.44667 .54619 m .44115 .54024 L .42949 .54947 L p .498 .546 .835 r
F P
0 g
s
.42759 .54725 m .42949 .54947 L .44115 .54024 L p .492 .532 .826 r
F P
0 g
s
.43756 .53605 m .43929 .5382 L .42759 .54725 L p .492 .532 .826 r
F P
0 g
s
.42759 .54725 m .42569 .54504 L .43756 .53605 L p .492 .532 .826 r
F P
0 g
s
.44115 .54024 m .43929 .5382 L .42759 .54725 L p .492 .532 .826 r
F P
0 g
s
.43251 .52968 m .43756 .53605 L .42569 .54504 L p .484 .518 .817 r
F P
0 g
s
.42569 .54504 m .4204 .53827 L .43251 .52968 L p .484 .518 .817 r
F P
0 g
s
.42499 .51896 m .43251 .52968 L .4204 .53827 L p .472 .496 .801 r
F P
0 g
s
.4204 .53827 m .41264 .52669 L .42499 .51896 L p .472 .496 .801 r
F P
0 g
s
.41582 .42135 m .4076 .4421 L .39645 .43986 L p .43 .274 .567 r
F P
0 g
s
.39645 .43986 m .40647 .41573 L .41582 .42135 L p .43 .274 .567 r
F P
0 g
s
.3936 .46523 m .39645 .43986 L .4076 .4421 L p .416 .317 .634 r
F P
0 g
s
.4076 .4421 m .40576 .46414 L .3936 .46523 L p .416 .317 .634 r
F P
0 g
s
.39686 .48937 m .3936 .46523 L .40576 .46414 L p .421 .369 .695 r
F P
0 g
s
.41656 .50397 m .42499 .51896 L .41264 .52669 L p .455 .463 .778 r
F P
0 g
s
.41264 .52669 m .40403 .51026 L .41656 .50397 L p .455 .463 .778 r
F P
0 g
s
.43016 .40424 m .41582 .42135 L .40647 .41573 L p .467 .253 .503 r
F P
0 g
s
.40647 .41573 m .42346 .39565 L .43016 .40424 L p .467 .253 .503 r
F P
0 g
s
.40576 .46414 m .40937 .48532 L .39686 .48937 L p .421 .369 .695 r
F P
0 g
s
.40403 .51026 m .39686 .48937 L .40937 .48532 L p .437 .42 .743 r
F P
0 g
s
.40937 .48532 m .41656 .50397 L .40403 .51026 L p .437 .42 .743 r
F P
0 g
s
.58351 .46867 m .59062 .48714 L .60316 .48139 L p .89 .682 .615 r
F P
0 g
s
.60316 .48139 m .59609 .46059 L .58351 .46867 L p .89 .682 .615 r
F P
0 g
s
.44927 .39273 m .43016 .40424 L .42346 .39565 L p .529 .265 .458 r
F P
0 g
s
.42346 .39565 m .44591 .38196 L .44927 .39273 L p .529 .265 .458 r
F P
0 g
s
.47099 .38786 m .44927 .39273 L .44591 .38196 L p .6 .304 .437 r
F P
0 g
s
.44591 .38196 m .47128 .37582 L .47099 .38786 L p .6 .304 .437 r
F P
0 g
s
.57513 .45377 m .58351 .46867 L .59609 .46059 L p .873 .642 .586 r
F P
0 g
s
.59609 .46059 m .58754 .44418 L .57513 .45377 L p .873 .642 .586 r
F P
0 g
s
.493 .38954 m .47099 .38786 L .47128 .37582 L p .67 .36 .44 r
F P
0 g
s
.47128 .37582 m .49679 .37697 L .493 .38954 L p .67 .36 .44 r
F P
0 g
s
.56763 .44306 m .57513 .45377 L .58754 .44418 L p .858 .613 .567 r
F P
0 g
s
.58754 .44418 m .57981 .43258 L .56763 .44306 L p .858 .613 .567 r
F P
0 g
s
.51331 .3965 m .493 .38954 L .49679 .37697 L p .727 .42 .459 r
F P
0 g
s
.49679 .37697 m .52014 .384 L .51331 .3965 L p .727 .42 .459 r
F P
0 g
s
.56259 .43667 m .56763 .44306 L .57981 .43258 L p .847 .593 .555 r
F P
0 g
s
.57981 .43258 m .57453 .42577 L .56259 .43667 L p .847 .593 .555 r
F P
0 g
s
.53058 .4066 m .51331 .3965 L .52014 .384 L p .77 .472 .483 r
F P
0 g
s
.52014 .384 m .53968 .3944 L .53058 .4066 L p .77 .472 .483 r
F P
0 g
s
.56086 .43452 m .56259 .43667 L .57453 .42577 L p .84 .579 .545 r
F P
0 g
s
.57453 .42577 m .57263 .42355 L .56086 .43452 L p .84 .579 .545 r
F P
0 g
s
.57073 .42132 m .57263 .42355 L .56086 .43452 L p .84 .579 .545 r
F P
0 g
s
.56086 .43452 m .559 .43246 L .57073 .42132 L p .84 .579 .545 r
F P
0 g
s
.56485 .41501 m .57073 .42132 L .559 .43246 L p .832 .567 .538 r
F P
0 g
s
.559 .43246 m .55348 .42647 L .56485 .41501 L p .832 .567 .538 r
F P
0 g
s
.55459 .40551 m .56485 .41501 L .55348 .42647 L p .819 .546 .525 r
F P
0 g
s
.56593 .56364 m .5491 .57372 L .55049 .57871 L p .787 .929 .928 r
F P
0 g
s
.55049 .57871 m .56955 .56725 L .56593 .56364 L p .787 .929 .928 r
F P
0 g
s
.52886 .58368 m .55049 .57871 L .5491 .57372 L p .68 .874 .972 r
F P
0 g
s
.54406 .41733 m .53058 .4066 L .53968 .3944 L p .8 .515 .506 r
F P
0 g
s
.53968 .3944 m .55459 .40551 L .54406 .41733 L p .8 .515 .506 r
F P
0 g
s
.57855 .54868 m .56593 .56364 L .56955 .56725 L p .882 .94 .849 r
F P
0 g
s
.56955 .56725 m .5839 .55031 L .57855 .54868 L p .882 .94 .849 r
F P
0 g
s
.55348 .42647 m .54406 .41733 L .55459 .40551 L p .819 .546 .525 r
F P
0 g
s
.5491 .57372 m .52996 .57797 L .52886 .58368 L p .68 .874 .972 r
F P
0 g
s
.50696 .58223 m .52886 .58368 L .52996 .57797 L p .584 .791 .978 r
F P
0 g
s
.5857 .53057 m .57855 .54868 L .5839 .55031 L p .942 .902 .755 r
F P
0 g
s
.5839 .55031 m .59219 .52983 L .5857 .53057 L p .942 .902 .755 r
F P
0 g
s
.52996 .57797 m .5105 .57634 L .50696 .58223 L p .584 .791 .978 r
F P
0 g
s
.48674 .57557 m .50696 .58223 L .5105 .57634 L p .513 .706 .958 r
F P
0 g
s
.58703 .51123 m .5857 .53057 L .59219 .52983 L p .963 .833 .667 r
F P
0 g
s
.59219 .52983 m .59413 .50806 L .58703 .51123 L p .963 .833 .667 r
F P
0 g
s
.5105 .57634 m .49241 .56975 L .48674 .57557 L p .513 .706 .958 r
F P
0 g
s
.46954 .56575 m .48674 .57557 L .49241 .56975 L p .471 .634 .925 r
F P
0 g
s
.5832 .49247 m .58703 .51123 L .59413 .50806 L p .953 .756 .601 r
F P
0 g
s
.59413 .50806 m .59062 .48714 L .5832 .49247 L p .953 .756 .601 r
F P
0 g
s
.4338 .40913 m .4212 .42426 L .41582 .42135 L p .342 .097 .39 r
F P
0 g
s
.41582 .42135 m .43016 .40424 L .4338 .40913 L p .342 .097 .39 r
F P
0 g
s
.4076 .4421 m .41582 .42135 L .4212 .42426 L p .287 .126 .481 r
F P
0 g
s
.49241 .56975 m .47676 .55995 L .46954 .56575 L p .471 .634 .925 r
F P
0 g
s
.45609 .55522 m .46954 .56575 L .47676 .55995 L p .447 .58 .894 r
F P
0 g
s
.4212 .42426 m .4141 .44267 L .4076 .4421 L p .287 .126 .481 r
F P
0 g
s
.40576 .46414 m .4076 .4421 L .4141 .44267 L p .275 .195 .581 r
F P
0 g
s
.45068 .39904 m .4338 .40913 L .43016 .40424 L p .429 .11 .321 r
F P
0 g
s
.43016 .40424 m .44927 .39273 L .45068 .39904 L p .429 .11 .321 r
F P
0 g
s
.4141 .44267 m .41285 .46237 L .40576 .46414 L p .275 .195 .581 r
F P
0 g
s
.40937 .48532 m .40576 .46414 L .41285 .46237 L p .292 .277 .67 r
F P
0 g
s
.46989 .39495 m .45068 .39904 L .44927 .39273 L p .535 .172 .297 r
F P
0 g
s
.44927 .39273 m .47099 .38786 L .46989 .39495 L p .535 .172 .297 r
F P
0 g
s
.47676 .55995 m .46418 .54927 L .45609 .55522 L p .447 .58 .894 r
F P
0 g
s
.44667 .54619 m .45609 .55522 L .46418 .54927 L p .431 .543 .869 r
F P
0 g
s
.5758 .47559 m .5832 .49247 L .59062 .48714 L p .928 .691 .559 r
F P
0 g
s
.59062 .48714 m .58351 .46867 L .5758 .47559 L p .928 .691 .559 r
F P
0 g
s
.41285 .46237 m .41677 .48149 L .40937 .48532 L p .292 .277 .67 r
F P
0 g
s
.41656 .50397 m .40937 .48532 L .41677 .48149 L p .327 .355 .737 r
F P
0 g
s
.46418 .54927 m .45502 .54006 L .44667 .54619 L p .431 .543 .869 r
F P
0 g
s
.44115 .54024 m .44667 .54619 L .45502 .54006 L p .421 .518 .852 r
F P
0 g
s
.48944 .39689 m .46989 .39495 L .47099 .38786 L p .639 .26 .311 r
F P
0 g
s
.47099 .38786 m .493 .38954 L .48944 .39689 L p .639 .26 .311 r
F P
0 g
s
.45502 .54006 m .44954 .53399 L .44115 .54024 L p .421 .518 .852 r
F P
0 g
s
.43929 .5382 m .44115 .54024 L .44954 .53399 L p .421 .519 .852 r
F P
0 g
s
.41677 .48149 m .42423 .49867 L .41656 .50397 L p .327 .355 .737 r
F P
0 g
s
.42499 .51896 m .41656 .50397 L .42423 .49867 L p .363 .418 .784 r
F P
0 g
s
.44591 .52976 m .44772 .53189 L .43929 .5382 L p .405 .487 .831 r
F P
0 g
s
.43929 .5382 m .43756 .53605 L .44591 .52976 L p .405 .487 .831 r
F P
0 g
s
.44954 .53399 m .44772 .53189 L .43929 .5382 L p .421 .519 .852 r
F P
0 g
s
.44074 .5234 m .44591 .52976 L .43756 .53605 L p .405 .488 .831 r
F P
0 g
s
.43756 .53605 m .43251 .52968 L .44074 .5234 L p .405 .488 .831 r
F P
0 g
s
.43298 .51288 m .44074 .5234 L .43251 .52968 L p .389 .461 .813 r
F P
0 g
s
.43251 .52968 m .42499 .51896 L .43298 .51288 L p .389 .461 .813 r
F P
0 g
s
.42423 .49867 m .43298 .51288 L .42499 .51896 L p .363 .418 .784 r
F P
0 g
s
.57583 .54861 m .5643 .56225 L .56593 .56364 L p .848 .998 .792 r
F P
0 g
s
.56593 .56364 m .57855 .54868 L .57583 .54861 L p .848 .998 .792 r
F P
0 g
s
.5491 .57372 m .56593 .56364 L .5643 .56225 L p .706 .98 .904 r
F P
0 g
s
.5643 .56225 m .54894 .57147 L .5491 .57372 L p .706 .98 .904 r
F P
0 g
s
.52996 .57797 m .5491 .57372 L .54894 .57147 L p .561 .904 .976 r
F P
0 g
s
.50761 .40387 m .48944 .39689 L .493 .38954 L p .722 .354 .352 r
F P
0 g
s
.493 .38954 m .51331 .3965 L .50761 .40387 L p .722 .354 .352 r
F P
0 g
s
.56709 .46156 m .5758 .47559 L .58351 .46867 L p .904 .641 .53 r
F P
0 g
s
.58351 .46867 m .57513 .45377 L .56709 .46156 L p .904 .641 .53 r
F P
0 g
s
.58236 .53215 m .57583 .54861 L .57855 .54868 L p .949 .954 .665 r
F P
0 g
s
.57855 .54868 m .5857 .53057 L .58236 .53215 L p .949 .954 .665 r
F P
0 g
s
.54894 .57147 m .53151 .5754 L .52996 .57797 L p .561 .904 .976 r
F P
0 g
s
.5105 .57634 m .52996 .57797 L .53151 .5754 L p .438 .794 .997 r
F P
0 g
s
.52331 .41405 m .50761 .40387 L .51331 .3965 L p .779 .432 .398 r
F P
0 g
s
.51331 .3965 m .53058 .4066 L .52331 .41405 L p .779 .432 .398 r
F P
0 g
s
.55935 .45111 m .56709 .46156 L .57513 .45377 L p .884 .605 .51 r
F P
0 g
s
.57513 .45377 m .56763 .44306 L .55935 .45111 L p .884 .605 .51 r
F P
0 g
s
.55418 .44475 m .55935 .45111 L .56763 .44306 L p .871 .581 .495 r
F P
0 g
s
.56763 .44306 m .56259 .43667 L .55418 .44475 L p .871 .581 .495 r
F P
0 g
s
.53592 .42502 m .52331 .41405 L .53058 .4066 L p .817 .49 .437 r
F P
0 g
s
.53058 .4066 m .54406 .41733 L .53592 .42502 L p .817 .49 .437 r
F P
0 g
s
.58339 .51451 m .58236 .53215 L .5857 .53057 L p .996 .865 .566 r
F P
0 g
s
.5857 .53057 m .58703 .51123 L .58339 .51451 L p .996 .865 .566 r
F P
0 g
s
.55238 .44262 m .55418 .44475 L .56259 .43667 L p .87 .583 .498 r
F P
0 g
s
.56259 .43667 m .56086 .43452 L .55238 .44262 L p .87 .583 .498 r
F P
0 g
s
.559 .43246 m .56086 .43452 L .55238 .44262 L p .853 .553 .48 r
F P
0 g
s
.55238 .44262 m .55056 .4405 L .559 .43246 L p .853 .553 .48 r
F P
0 g
s
.55348 .42647 m .559 .43246 L .55056 .4405 L p .855 .554 .478 r
F P
0 g
s
.53151 .5754 m .51374 .57378 L .5105 .57634 L p .438 .794 .997 r
F P
0 g
s
.49241 .56975 m .5105 .57634 L .51374 .57378 L p .37 .684 .979 r
F P
0 g
s
.54508 .43438 m .53592 .42502 L .54406 .41733 L p .84 .529 .462 r
F P
0 g
s
.54406 .41733 m .55348 .42647 L .54508 .43438 L p .84 .529 .462 r
F P
0 g
s
.55056 .4405 m .54508 .43438 L .55348 .42647 L p .855 .554 .478 r
F P
0 g
s
.43544 .41157 m .42392 .42538 L .4212 .42426 L p .115 0 .181 r
F P
0 g
s
.4212 .42426 m .4338 .40913 L .43544 .41157 L p .115 0 .181 r
F P
0 g
s
.4141 .44267 m .4212 .42426 L .42392 .42538 L p .049 0 .323 r
F P
0 g
s
.45084 .40235 m .43544 .41157 L .4338 .40913 L p .244 0 .086 r
F P
0 g
s
.4338 .40913 m .45068 .39904 L .45084 .40235 L p .244 0 .086 r
F P
0 g
s
.57944 .49738 m .58339 .51451 L .58703 .51123 L p .99 .764 .499 r
F P
0 g
s
.58703 .51123 m .5832 .49247 L .57944 .49738 L p .99 .764 .499 r
F P
0 g
s
.51374 .57378 m .49721 .56737 L .49241 .56975 L p .37 .684 .979 r
F P
0 g
s
.47676 .55995 m .49241 .56975 L .49721 .56737 L p .337 .596 .942 r
F P
0 g
s
.42392 .42538 m .41744 .44217 L .4141 .44267 L p .049 0 .323 r
F P
0 g
s
.41285 .46237 m .4141 .44267 L .41744 .44217 L p .041 0 .475 r
F P
0 g
s
.46834 .39864 m .45084 .40235 L .45068 .39904 L p .404 0 .053 r
F P
0 g
s
.45068 .39904 m .46989 .39495 L .46834 .39864 L p .404 0 .053 r
F P
0 g
s
.57477 .54937 m .56392 .56221 L .5643 .56225 L p .632 .886 .552 r
F P
0 g
s
.58099 .53398 m .57477 .54937 L .57583 .54861 L p .803 .869 .43 r
F P
0 g
s
.57583 .54861 m .58236 .53215 L .58111 .53382 L p .803 .869 .43 r
F P
0 g
s
.58201 .51758 m .58099 .53398 L .58236 .53215 L p .93 .807 .343 r
F P
0 g
s
.58099 .53398 m .58201 .51758 L .58195 .51895 L p 0 0 0 r
F P
0 g
s
.58099 .53398 m .58195 .51895 L .58167 .52358 L 0 0 0 r
F
.58167 .52358 m .58188 .52009 L .5819 .52016 L F
.5819 .52016 m .58093 .53282 L p .58099 .53398 L F P
0 g
s
.58195 .51895 m .5819 .52016 L p .58188 .52009 L 0 0 0 r
F P
0 g
s
.57839 .50527 m .5819 .52016 L .58201 .51758 L p .846 .575 .034 r
F P
0 g
s
.58201 .51758 m .57818 .50172 L .57831 .50393 L p .846 .575 .034 r
F P
0 g
s
.57831 .50393 m .57839 .50527 L p .57926 .50824 L .846 .575 .034 r
F P
0 g
s
.58201 .51758 m .57831 .50393 L .57926 .50824 L .846 .575 .034 r
F
.5806 .53509 m .581 .53411 L .58099 .53398 L .803 .869 .43 r
F
.57583 .54861 m .58111 .53382 L .5806 .53509 L F
.57477 .54937 m .5802 .53594 L p .58071 .53571 L 0 0 0 r
F P
0 g
s
.5802 .53594 m .58099 .53398 L .58071 .53571 L p 0 0 0 r
F P
0 g
s
.58111 .53382 m .58099 .53398 L p .581 .53411 L .803 .869 .43 r
F P
0 g
s
.58071 .53571 m .58119 .53166 L .58095 .53559 L 0 0 .232 r
F
.58088 .53677 m .58071 .53571 L p .58095 .53559 L F P
0 g
s
.58093 .53282 m .58071 .53571 L .58099 .53398 L p 0 0 0 r
F P
0 g
s
.58236 .53215 m .58339 .51451 L .58201 .51758 L p .93 .807 .343 r
F P
0 g
s
.58071 .53571 m .5819 .52016 L .58232 .5221 L p 0 0 .232 r
F P
0 g
s
.5819 .52016 m .57868 .50652 L p .57917 .50786 L 0 0 .238 r
F P
0 g
s
.57868 .50652 m .57839 .50527 L .57917 .50786 L p 0 0 .238 r
F P
0 g
s
.57917 .50786 m .58193 .5203 L p .58191 .52022 L 0 0 .238 r
F P
0 g
s
.5813 .51748 m .57917 .50786 L .58191 .52022 L 0 0 .238 r
F
.5819 .52016 m .5813 .51748 L .58191 .52022 L F
.58193 .5203 m .58232 .5221 L .5819 .52016 L p F P
0 g
s
.58232 .5221 m .57925 .50822 L p .57989 .50942 L 0 0 .406 r
F P
0 g
s
.57925 .50822 m .57917 .50786 L .57989 .50942 L p 0 0 .406 r
F P
0 g
s
.57319 .49758 m .57948 .50869 L p .57917 .50786 L .647 .245 0 r
F P
0 g
s
.57989 .50942 m .58277 .5233 L .58232 .5221 L p 0 0 .406 r
F P
0 g
s
.58277 .5233 m .57991 .5095 L p .58017 .50994 L 0 0 .476 r
F P
0 g
s
.57991 .5095 m .57989 .50942 L .58017 .50994 L p 0 0 .476 r
F P
0 g
s
.58011 .50983 m .58017 .50994 L .57989 .50942 L p 0 0 .415 r
F P
0 g
s
.57818 .50172 m .58201 .51758 L .58339 .51451 L p .977 .72 .312 r
F P
0 g
s
.57206 .4955 m .57917 .50786 L .57839 .50527 L p .801 .4 0 r
F P
0 g
s
.564 .48949 m .57349 .49814 L p .57319 .49758 L .758 .262 0 r
F P
0 g
s
.57521 .50105 m .57234 .49599 L .57319 .49758 L .647 .245 0 r
F
.57989 .50942 m .57324 .49766 L p .57362 .49826 L 0 0 .415 r
F P
0 g
s
.57324 .49766 m .57319 .49758 L .57362 .49826 L p 0 0 .415 r
F P
0 g
s
.57917 .50786 m .57266 .49654 L p .57521 .50105 L .647 .245 0 r
F P
0 g
s
.57266 .49654 m .57206 .4955 L p .57521 .50105 L .647 .245 0 r
F P
0 g
s
.57362 .49826 m .58011 .50983 L p .57989 .50942 L 0 0 .415 r
F P
0 g
s
.58017 .50994 m .57374 .49847 L p .57419 .49909 L 0 0 .476 r
F P
0 g
s
.57374 .49847 m .57362 .49826 L .57419 .49909 L p 0 0 .476 r
F P
0 g
s
.57419 .49909 m .57848 .50685 L p .57781 .50566 L 0 0 .476 r
F P
0 g
s
.57948 .50869 m .57989 .50942 L .57917 .50786 L p .647 .245 0 r
F P
0 g
s
.57839 .50527 m .57083 .49203 L .57206 .4955 L p .801 .4 0 r
F P
0 g
s
.58054 .51056 m .57419 .49909 L .57613 .5015 L p 0 .009 .578 r
F P
0 g
s
.56805 .49403 m .57558 .50099 L p .57419 .49909 L .598 .081 0 r
F P
0 g
s
.57558 .50099 m .57613 .5015 L .57419 .49909 L p .598 .081 0 r
F P
0 g
s
.5649 .49067 m .57409 .499 L p .57362 .49826 L .72 .216 0 r
F P
0 g
s
.57409 .499 m .57419 .49909 L .57362 .49826 L p .72 .216 0 r
F P
0 g
s
.57349 .49814 m .57362 .49826 L .57319 .49758 L p .758 .262 0 r
F P
0 g
s
.57206 .4955 m .57319 .49758 L p .57234 .49599 L .647 .245 0 r
F P
0 g
s
.58017 .50994 m .57781 .50566 L .58049 .51047 L 0 0 .476 r
F
.57848 .50685 m .58049 .51047 L p .57781 .50566 L F P
0 g
s
.58049 .51047 m .58054 .51056 L .58017 .50994 L p 0 0 .476 r
F P
0 g
s
.58232 .5221 m .58094 .53711 L .58088 .53677 L p 0 0 .232 r
F P
0 g
s
.58119 .53166 m .58232 .5221 L .58088 .53677 L 0 0 .232 r
F
.58071 .53571 m .5757 .54787 L p .57494 .54909 L 0 0 0 r
F P
0 g
s
.57477 .54937 m .57561 .54742 L .57494 .54909 L 0 0 0 r
F
.57561 .54742 m .58071 .53571 L .57494 .54909 L F
.57359 .55127 m .57583 .54861 L .57477 .54937 L p .632 .886 .552 r
F P
0 g
s
.5757 .54787 m .57464 .55044 L .57477 .54937 L p 0 0 0 r
F P
0 g
s
.5643 .56225 m .57359 .55127 L p .57477 .54937 L .632 .886 .552 r
F P
0 g
s
.57464 .55044 m .56555 .56103 L p .56392 .56221 L 0 0 0 r
F P
0 g
s
.56555 .56103 m .5641 .56272 L .56392 .56221 L p 0 0 0 r
F P
0 g
s
.54894 .57147 m .56183 .56373 L p .56392 .56221 L .434 .846 .674 r
F P
0 g
s
.56183 .56373 m .5643 .56225 L .56392 .56221 L p .434 .846 .674 r
F P
0 g
s
.54944 .5709 m .54894 .57147 L p .55148 .56991 L .434 .846 .674 r
F P
0 g
s
.54944 .5709 m .55022 .5712 L p .54782 .57169 L .04 0 0 r
F P
0 g
s
.53151 .5754 m .54894 .57147 L .54944 .5709 L p .292 .79 .811 r
F P
0 g
s
.53311 .5747 m .53151 .5754 L p .53446 .57466 L .292 .79 .811 r
F P
0 g
s
.54944 .5709 m .53311 .5747 L p .53446 .57466 L .292 .79 .811 r
F P
0 g
s
.53311 .5747 m .53454 .57497 L p .53203 .57473 L .118 0 0 r
F P
0 g
s
.51374 .57378 m .53151 .5754 L .53311 .5747 L p .181 .693 .896 r
F P
0 g
s
.51652 .57329 m .51374 .57378 L p .51745 .57395 L .181 .693 .896 r
F P
0 g
s
.53311 .5747 m .51652 .57329 L p .51745 .57395 L .181 .693 .896 r
F P
0 g
s
.51652 .57329 m .53311 .5747 L p .53203 .57473 L .118 0 0 r
F P
0 g
s
.51876 .57388 m .51652 .57329 L p .51873 .5735 L .118 0 0 r
F P
0 g
s
.53454 .57497 m .51876 .57388 L p .51873 .5735 L .118 0 0 r
F P
0 g
s
.51876 .57388 m .52037 .57481 L p .51877 .57416 L .395 0 0 r
F P
0 g
s
.51652 .57329 m .51876 .57388 L p .51577 .57276 L 0 .405 .745 r
F P
0 g
s
.50119 .56726 m .51652 .57329 L p .51577 .57276 L 0 .405 .745 r
F P
0 g
s
.50428 .56835 m .50119 .56726 L p .50377 .56823 L 0 .405 .745 r
F P
0 g
s
.51876 .57388 m .50428 .56835 L p .50377 .56823 L 0 .405 .745 r
F P
0 g
s
.50428 .56835 m .51876 .57388 L p .51877 .57416 L .395 0 0 r
F P
0 g
s
.51652 .57329 m .50119 .56726 L .49721 .56737 L p .131 .589 .923 r
F P
0 g
s
.49721 .56737 m .51374 .57378 L .51652 .57329 L p .131 .589 .923 r
F P
0 g
s
.50645 .56975 m .50428 .56835 L p .50547 .56883 L .395 0 0 r
F P
0 g
s
.52037 .57481 m .50645 .56975 L p .50547 .56883 L .395 0 0 r
F P
0 g
s
.50645 .56975 m .50773 .57083 L p .50705 .57032 L .495 0 0 r
F P
0 g
s
.50428 .56835 m .50645 .56975 L p .50466 .56843 L 0 .183 .639 r
F P
0 g
s
.49202 .55914 m .50428 .56835 L p .50466 .56843 L 0 .183 .639 r
F P
0 g
s
.49494 .56117 m .49202 .55914 L p .49349 .56022 L 0 .183 .639 r
F P
0 g
s
.50645 .56975 m .49494 .56117 L p .49349 .56022 L 0 .183 .639 r
F P
0 g
s
.49494 .56117 m .50645 .56975 L p .50705 .57032 L .495 0 0 r
F P
0 g
s
.50428 .56835 m .49202 .55914 L .48792 .55757 L p 0 .356 .802 r
F P
0 g
s
.49664 .56275 m .49494 .56117 L p .49533 .56146 L .495 0 0 r
F P
0 g
s
.50773 .57083 m .49664 .56275 L p .49533 .56146 L .495 0 0 r
F P
0 g
s
.48792 .55757 m .50119 .56726 L .50428 .56835 L p 0 .356 .802 r
F P
0 g
s
.49719 .56333 m .49664 .56275 L p .49672 .56281 L .567 .018 0 r
F P
0 g
s
.50815 .57123 m .49719 .56333 L p .49672 .56281 L .567 .018 0 r
F P
0 g
s
.49785 .56408 m .49719 .56333 L p .49737 .56346 L .609 .062 0 r
F P
0 g
s
.50865 .57174 m .49785 .56408 L p .49737 .56346 L .609 .062 0 r
F P
0 g
s
.48281 .55753 m .49721 .56737 L .50119 .56726 L p .135 .506 .91 r
F P
0 g
s
.50119 .56726 m .48792 .55757 L .48281 .55753 L p .135 .506 .91 r
F P
0 g
s
.51012 .57342 m .49973 .56653 L .49785 .56408 L p .674 .136 0 r
F P
0 g
s
.49785 .56408 m .49973 .56653 L p .49922 .56584 L 0 0 .446 r
F P
0 g
s
.49664 .56275 m .50773 .57083 L .50815 .57123 L p .567 .018 0 r
F P
0 g
s
.49719 .56333 m .50815 .57123 L .50865 .57174 L p .609 .062 0 r
F P
0 g
s
.49785 .56408 m .50865 .57174 L .51012 .57342 L p .674 .136 0 r
F P
0 g
s
.49044 .55408 m .49785 .56408 L p .49922 .56584 L 0 0 .446 r
F P
0 g
s
.49719 .56333 m .49785 .56408 L p .49776 .56396 L 0 0 .533 r
F P
0 g
s
.4895 .55294 m .49719 .56333 L p .49776 .56396 L 0 0 .533 r
F P
0 g
s
.49664 .56275 m .49719 .56333 L p .49708 .56319 L 0 .031 .576 r
F P
0 g
s
.48869 .55206 m .49664 .56275 L p .49708 .56319 L 0 .031 .576 r
F P
0 g
s
.49494 .56117 m .49664 .56275 L p .49584 .56176 L 0 .091 .63 r
F P
0 g
s
.4862 .54978 m .49494 .56117 L p .49584 .56176 L 0 .091 .63 r
F P
0 g
s
.53311 .5747 m .54944 .5709 L p .54782 .57169 L .04 0 0 r
F P
0 g
s
.56392 .56221 m .54944 .5709 L p .55148 .56991 L .434 .846 .674 r
F P
0 g
s
.41744 .44217 m .41648 .46024 L .41285 .46237 L p .041 0 .475 r
F P
0 g
s
.41677 .48149 m .41285 .46237 L .41648 .46024 L p .101 .142 .618 r
F P
0 g
s
.48619 .40064 m .46834 .39864 L .46989 .39495 L p .572 .104 .106 r
F P
0 g
s
.46989 .39495 m .48944 .39689 L .48619 .40064 L p .572 .104 .106 r
F P
0 g
s
.49721 .56737 m .48281 .55753 L .47676 .55995 L p .337 .596 .942 r
F P
0 g
s
.46418 .54927 m .47676 .55995 L .48281 .55753 L p .332 .539 .905 r
F P
0 g
s
.57173 .4818 m .57944 .49738 L .5832 .49247 L p .959 .683 .468 r
F P
0 g
s
.5832 .49247 m .5758 .47559 L .57173 .4818 L p .959 .683 .468 r
F P
0 g
s
.41648 .46024 m .4205 .47785 L .41677 .48149 L p .101 .142 .618 r
F P
0 g
s
.42423 .49867 m .41677 .48149 L .4205 .47785 L p .171 .264 .718 r
F P
0 g
s
.50278 .40755 m .48619 .40064 L .48944 .39689 L p .702 .257 .192 r
F P
0 g
s
.48944 .39689 m .50761 .40387 L .50278 .40755 L p .702 .257 .192 r
F P
0 g
s
.48281 .55753 m .47087 .5463 L .46418 .54927 L p .332 .539 .905 r
F P
0 g
s
.45502 .54006 m .46418 .54927 L .47087 .5463 L p .335 .505 .877 r
F P
0 g
s
.4205 .47785 m .42827 .49389 L .42423 .49867 L p .171 .264 .718 r
F P
0 g
s
.43298 .51288 m .42423 .49867 L .42827 .49389 L p .24 .357 .782 r
F P
0 g
s
.47087 .5463 m .46171 .53629 L .45502 .54006 L p .335 .505 .877 r
F P
0 g
s
.44954 .53399 m .45502 .54006 L .46171 .53629 L p .336 .484 .859 r
F P
0 g
s
.5623 .46837 m .57173 .4818 L .5758 .47559 L p .926 .626 .455 r
F P
0 g
s
.5758 .47559 m .56709 .46156 L .5623 .46837 L p .926 .626 .455 r
F P
0 g
s
.42827 .49389 m .43773 .50764 L .43298 .51288 L p .24 .357 .782 r
F P
0 g
s
.44074 .5234 m .43298 .51288 L .43773 .50764 L p .291 .417 .818 r
F P
0 g
s
.46171 .53629 m .45593 .52967 L .44954 .53399 L p .336 .484 .859 r
F P
0 g
s
.44772 .53189 m .44954 .53399 L .45593 .52967 L p .332 .471 .85 r
F P
0 g
s
.45201 .52509 m .45397 .52738 L .44772 .53189 L p .329 .467 .847 r
F P
0 g
s
.44772 .53189 m .44591 .52976 L .45201 .52509 L p .329 .467 .847 r
F P
0 g
s
.45593 .52967 m .45397 .52738 L .44772 .53189 L p .332 .471 .85 r
F P
0 g
s
.44632 .51833 m .45201 .52509 L .44591 .52976 L p .319 .452 .838 r
F P
0 g
s
.44591 .52976 m .44074 .5234 L .44632 .51833 L p .319 .452 .838 r
F P
0 g
s
.43773 .50764 m .44632 .51833 L .44074 .5234 L p .291 .417 .818 r
F P
0 g
s
.51722 .41791 m .50278 .40755 L .50761 .40387 L p .785 .379 .284 r
F P
0 g
s
.50761 .40387 m .52331 .41405 L .51722 .41791 L p .785 .379 .284 r
F P
0 g
s
.56392 .56221 m .57477 .54937 L .57464 .55044 L p 0 0 0 r
F P
0 g
s
.54944 .5709 m .56392 .56221 L .5641 .56272 L p 0 0 0 r
F P
0 g
s
.45033 .40376 m .43582 .41242 L .43544 .41157 L p 0 0 0 r
F P
0 g
s
.46528 .40057 m .45229 .40346 L p .45033 .40376 L 0 0 0 r
F P
0 g
s
.43544 .41157 m .44784 .40414 L p .45033 .40376 L 0 0 0 r
F P
0 g
s
.43582 .41242 m .44881 .40467 L p .44955 .40407 L .416 .834 .662 r
F P
0 g
s
.44881 .40467 m .45033 .40376 L .44955 .40407 L p .416 .834 .662 r
F P
0 g
s
.45229 .40346 m .44955 .40407 L .45033 .40376 L p 0 0 0 r
F P
0 g
s
.44784 .40414 m .45084 .40235 L .45033 .40376 L p 0 0 0 r
F P
0 g
s
.46672 .4002 m .45033 .40376 L .45084 .40235 L p .168 0 0 r
F P
0 g
s
.45084 .40235 m .46834 .39864 L .46672 .4002 L p .168 0 0 r
F P
0 g
s
.45033 .40376 m .46672 .4002 L .46566 .40048 L p 0 0 0 r
F P
0 g
s
.48114 .40215 m .46528 .40057 L .46672 .4002 L p .186 0 0 r
F P
0 g
s
.46672 .4002 m .48338 .40206 L .48219 .40211 L p .186 0 0 r
F P
0 g
s
.49349 .40749 m .48128 .40243 L p .48114 .40215 L .295 0 0 r
F P
0 g
s
.46672 .4002 m .48219 .40211 L .47757 .40167 L .186 0 0 r
F
.47757 .40167 m .48106 .402 L .48114 .40215 L F
.46528 .40057 m .48003 .40204 L p .47951 .40169 L .06 .611 .829 r
F P
0 g
s
.48003 .40204 m .48114 .40215 L .47951 .40169 L p .06 .611 .829 r
F P
0 g
s
.48128 .40243 m .47951 .40169 L .48114 .40215 L p .295 0 0 r
F P
0 g
s
.48338 .40206 m .46672 .4002 L .46834 .39864 L p .427 0 0 r
F P
0 g
s
.49568 .40837 m .48114 .40215 L .48338 .40206 L p .497 0 0 r
F P
0 g
s
.50334 .41575 m .4929 .40726 L p .49349 .40749 L .508 0 0 r
F P
0 g
s
.48114 .40215 m .49519 .40816 L p .48936 .4057 L .295 0 0 r
F P
0 g
s
.48936 .4057 m .49432 .4078 L .49349 .40749 L .295 0 0 r
F
.47951 .40169 m .49314 .40734 L p .49221 .4067 L 0 .411 .785 r
F P
0 g
s
.49314 .40734 m .49349 .40749 L .49221 .4067 L p 0 .411 .785 r
F P
0 g
s
.49519 .40816 m .49568 .40837 L p .48936 .4057 L .295 0 0 r
F P
0 g
s
.49221 .4067 m .48256 .40283 L p .48491 .40382 L 0 .411 .785 r
F P
0 g
s
.47854 .40122 m .49213 .40667 L p .49179 .4064 L 0 .462 .842 r
F P
0 g
s
.49213 .40667 m .49221 .4067 L .49179 .4064 L p 0 .462 .842 r
F P
0 g
s
.49469 .40871 m .50326 .41568 L .50279 .41527 L 0 .1 .571 r
F
.49425 .40836 m .50334 .41575 L p .49469 .40871 L F P
0 g
s
.49221 .4067 m .49425 .40836 L p .49469 .40871 L 0 .1 .571 r
F P
0 g
s
.50279 .41527 m .49189 .40649 L p .49221 .4067 L 0 .1 .571 r
F P
0 g
s
.50505 .41698 m .50334 .41575 L p .49935 .4124 L .508 0 0 r
F P
0 g
s
.49349 .40749 m .50383 .41598 L p .49935 .4124 L .508 0 0 r
F P
0 g
s
.50383 .41598 m .50505 .41698 L p .49935 .4124 L .508 0 0 r
F P
0 g
s
.49568 .40837 m .49349 .40749 L p .49432 .4078 L .295 0 0 r
F P
0 g
s
.49878 .40869 m .48338 .40206 L .48619 .40064 L p .638 .107 0 r
F P
0 g
s
.48338 .40206 m .49878 .40869 L .49568 .40837 L p .497 0 0 r
F P
0 g
s
.50505 .41698 m .49349 .40749 L .49568 .40837 L p .634 .081 0 r
F P
0 g
s
.50023 .41258 m .4898 .40465 L .49079 .40555 L p 0 .204 .701 r
F P
0 g
s
.49079 .40555 m .49128 .40601 L p .49215 .40664 L 0 .204 .701 r
F P
0 g
s
.4929 .40726 m .49221 .4067 L .49349 .40749 L p .508 0 0 r
F P
0 g
s
.49215 .40664 m .50023 .41258 L .49079 .40555 L 0 .204 .701 r
F
.50955 .42583 m .50233 .41496 L p .50279 .41527 L .754 .282 0 r
F P
0 g
s
.50233 .41496 m .5022 .41478 L p .50279 .41527 L .754 .282 0 r
F P
0 g
s
.49179 .4064 m .50259 .41512 L p .50213 .41466 L 0 .138 .621 r
F P
0 g
s
.50259 .41512 m .50279 .41527 L .50213 .41466 L p 0 .138 .621 r
F P
0 g
s
.50213 .41466 m .49804 .4114 L p .49707 .41062 L 0 .138 .621 r
F P
0 g
s
.49179 .4064 m .47821 .40103 L .47854 .40122 L p 0 .462 .842 r
F P
0 g
s
.47821 .40103 m .49179 .4064 L .49128 .40601 L p .011 .488 .871 r
F P
0 g
s
.49179 .4064 m .49707 .41062 L .49137 .40607 L 0 .138 .621 r
F
.49804 .4114 m .49137 .40607 L p .49707 .41062 L F P
0 g
s
.49137 .40607 m .49128 .40601 L .49179 .4064 L p 0 .138 .621 r
F P
0 g
s
.49189 .40649 m .49179 .4064 L .49221 .4067 L p 0 .1 .571 r
F P
0 g
s
.49128 .40601 m .50213 .41466 L .50023 .41258 L p 0 .204 .701 r
F P
0 g
s
.50695 .42245 m .50069 .41324 L p .50213 .41466 L .665 .213 0 r
F P
0 g
s
.50069 .41324 m .50023 .41258 L .50213 .41466 L p .665 .213 0 r
F P
0 g
s
.5022 .41478 m .50213 .41466 L .50279 .41527 L p .754 .282 0 r
F P
0 g
s
.50334 .41575 m .50279 .41527 L p .50326 .41568 L 0 .1 .571 r
F P
0 g
s
.47951 .40169 m .48491 .40382 L .47919 .40148 L 0 .411 .785 r
F
.48256 .40283 m .47919 .40148 L p .48491 .40382 L F P
0 g
s
.47919 .40148 m .47854 .40122 L .47951 .40169 L p 0 .411 .785 r
F P
0 g
s
.48219 .40211 m .48114 .40215 L p .48106 .402 L .186 0 0 r
F P
0 g
s
.47951 .40169 m .46576 .40052 L p .46559 .40054 L .06 .611 .829 r
F P
0 g
s
.46528 .40057 m .46952 .40091 L .46559 .40054 L .06 .611 .829 r
F
.46952 .40091 m .47951 .40169 L .46559 .40054 L F
.46566 .40048 m .46528 .40057 L p .46512 .40059 L 0 0 0 r
F P
0 g
s
.45033 .40376 m .46566 .40048 L .46245 .40118 L 0 0 0 r
F
.46576 .40052 m .46414 .40038 L .46528 .40057 L p .06 .611 .829 r
F P
0 g
s
.46245 .40118 m .46512 .40059 L .46528 .40057 L 0 0 0 r
F
.46414 .40038 m .45009 .40364 L p .44967 .40397 L .362 .831 .884 r
F P
0 g
s
.44955 .40407 m .45167 .40353 L .44967 .40397 L .362 .831 .884 r
F
.45167 .40353 m .46414 .40038 L .44967 .40397 L F
.45009 .40364 m .44881 .40393 L .44955 .40407 L p F P
0 g
s
.44955 .40407 m .43756 .41135 L p .43582 .41242 L .416 .834 .662 r
F P
0 g
s
.43756 .41135 m .43564 .41252 L .43582 .41242 L p .416 .834 .662 r
F P
0 g
s
.42392 .42538 m .43359 .41379 L p .43582 .41242 L 0 0 0 r
F P
0 g
s
.43359 .41379 m .43544 .41157 L .43582 .41242 L p 0 0 0 r
F P
0 g
s
.41744 .44217 m .42392 .42538 L .42498 .42545 L p 0 0 .046 r
F P
0 g
s
.42498 .42545 m .42511 .42498 L p .42422 .42726 L .681 .766 .28 r
F P
0 g
s
.4188 .44119 m .41744 .44217 L p .41868 .43943 L 0 0 .046 r
F P
0 g
s
.42498 .42545 m .4188 .44119 L p .41868 .43943 L 0 0 .046 r
F P
0 g
s
.41908 .44048 m .42498 .42545 L .42422 .42726 L .681 .766 .28 r
F
.4188 .44119 m .41908 .44049 L p .41908 .44048 L F P
0 g
s
.41908 .44049 m .42498 .42545 L p .41908 .44048 L .681 .766 .28 r
F P
0 g
s
.41785 .45809 m .4188 .44119 L p .4189 .44261 L 0 0 .036 r
F P
0 g
s
.42498 .42545 m .42392 .42538 L p .42594 .42319 L 0 0 0 r
F P
0 g
s
.41908 .4401 m .4188 .44119 L p .4195 .43939 L .681 .766 .28 r
F P
0 g
s
.42511 .42498 m .41908 .4401 L p .4195 .43939 L .681 .766 .28 r
F P
0 g
s
.41908 .4401 m .41884 .43913 L p .41876 .44062 L .849 .723 .198 r
F P
0 g
s
.4188 .44119 m .41908 .4401 L p .4189 .44261 L 0 0 .036 r
F P
0 g
s
.41648 .46024 m .41744 .44217 L .4188 .44119 L p 0 0 .29 r
F P
0 g
s
.41785 .45809 m .41648 .46024 L p .41692 .45659 L 0 0 .29 r
F P
0 g
s
.4188 .44119 m .41785 .45809 L p .41692 .45659 L 0 0 .29 r
F P
0 g
s
.41795 .45619 m .41785 .45809 L p .418 .45588 L 0 0 .036 r
F P
0 g
s
.418 .45588 m .41906 .44039 L .41795 .45619 L 0 0 .036 r
F
.41795 .45619 m .41751 .45471 L p .41791 .45641 L .732 .466 0 r
F P
0 g
s
.42152 .47175 m .42174 .47453 L p .42118 .47184 L 0 0 .321 r
F P
0 g
s
.41795 .45619 m .42152 .47175 L p .42118 .47184 L 0 0 .321 r
F P
0 g
s
.42152 .47175 m .41795 .45619 L p .41791 .45641 L .732 .466 0 r
F P
0 g
s
.42174 .47453 m .41785 .45809 L p .41859 .4593 L 0 0 .321 r
F P
0 g
s
.41785 .45809 m .41795 .45619 L p .41859 .4593 L 0 0 .321 r
F P
0 g
s
.42072 .46969 m .42152 .47175 L p .42122 .47049 L .732 .466 0 r
F P
0 g
s
.41751 .45471 m .42072 .46969 L p .42122 .47049 L .732 .466 0 r
F P
0 g
s
.41785 .45809 m .42174 .47453 L .4205 .47785 L p 0 0 .506 r
F P
0 g
s
.42072 .46969 m .41999 .46843 L p .42041 .46919 L .645 .25 0 r
F P
0 g
s
.42788 .48291 m .42913 .48575 L p .42828 .48412 L 0 0 .436 r
F P
0 g
s
.42072 .46969 m .42788 .48291 L p .42828 .48412 L 0 0 .436 r
F P
0 g
s
.42788 .48291 m .42072 .46969 L p .42041 .46919 L .645 .25 0 r
F P
0 g
s
.42152 .47175 m .42072 .46969 L p .42177 .47168 L 0 0 .436 r
F P
0 g
s
.42913 .48575 m .42152 .47175 L p .42177 .47168 L 0 0 .436 r
F P
0 g
s
.42675 .48118 m .42788 .48291 L p .42764 .48246 L .645 .25 0 r
F P
0 g
s
.41999 .46843 m .42675 .48118 L p .42764 .48246 L .645 .25 0 r
F P
0 g
s
.42152 .47175 m .42913 .48575 L .4296 .48952 L p 0 0 .57 r
F P
0 g
s
.42631 .48061 m .42675 .48118 L p .4267 .48109 L .713 .303 0 r
F P
0 g
s
.41971 .46801 m .42631 .48061 L p .4267 .48109 L .713 .303 0 r
F P
0 g
s
.42574 .47992 m .42631 .48061 L p .4262 .4804 L .749 .332 0 r
F P
0 g
s
.41934 .4675 m .42574 .47992 L p .4262 .4804 L .749 .332 0 r
F P
0 g
s
.4296 .48952 m .42174 .47453 L .42152 .47175 L p 0 0 .57 r
F P
0 g
s
.4205 .47785 m .41648 .46024 L .41785 .45809 L p 0 0 .506 r
F P
0 g
s
.41807 .46597 m .42379 .4779 L .42574 .47992 L p .802 .377 0 r
F P
0 g
s
.42574 .47992 m .42379 .4779 L p .42441 .47854 L 0 0 .502 r
F P
0 g
s
.42675 .48118 m .41999 .46843 L .41971 .46801 L p .713 .303 0 r
F P
0 g
s
.42631 .48061 m .41971 .46801 L .41934 .4675 L p .749 .332 0 r
F P
0 g
s
.42574 .47992 m .41934 .4675 L .41807 .46597 L p .802 .377 0 r
F P
0 g
s
.43506 .48944 m .42574 .47992 L p .42441 .47854 L 0 0 .502 r
F P
0 g
s
.42631 .48061 m .42574 .47992 L p .42584 .48003 L 0 .044 .568 r
F P
0 g
s
.43596 .49046 m .42631 .48061 L p .42584 .48003 L 0 .044 .568 r
F P
0 g
s
.42675 .48118 m .42631 .48061 L p .42644 .48075 L 0 .069 .599 r
F P
0 g
s
.43664 .49131 m .42675 .48118 L p .42644 .48075 L 0 .069 .599 r
F P
0 g
s
.42788 .48291 m .42675 .48118 L p .42763 .48215 L 0 .098 .634 r
F P
0 g
s
.43829 .49386 m .42788 .48291 L p .42763 .48215 L 0 .098 .634 r
F P
0 g
s
.41795 .45619 m .41908 .4401 L p .41876 .44062 L .849 .723 .198 r
F P
0 g
s
.41908 .4401 m .41906 .44038 L p .41906 .44039 L 0 0 .036 r
F P
0 g
s
.41906 .44038 m .41795 .45619 L p .41906 .44039 L 0 0 .036 r
F P
0 g
s
.43582 .41242 m .42498 .42545 L p .42594 .42319 L 0 0 0 r
F P
0 g
s
.5641 .56272 m .55022 .5712 L .54944 .5709 L p 0 0 0 r
F P
0 g
s
.55374 .45783 m .5623 .46837 L .56709 .46156 L p .902 .59 .445 r
F P
0 g
s
.56709 .46156 m .55935 .45111 L .55374 .45783 L p .902 .59 .445 r
F P
0 g
s
.58339 .51451 m .57944 .49738 L .57818 .50172 L p .977 .72 .312 r
F P
0 g
s
.5292 .42957 m .51722 .41791 L .52331 .41405 L p .831 .461 .354 r
F P
0 g
s
.52331 .41405 m .53592 .42502 L .5292 .42957 L p .831 .461 .354 r
F P
0 g
s
.54806 .4511 m .55374 .45783 L .55935 .45111 L p .888 .566 .434 r
F P
0 g
s
.55935 .45111 m .55418 .44475 L .54806 .4511 L p .888 .566 .434 r
F P
0 g
s
.55022 .5712 m .53454 .57497 L .53311 .5747 L p .04 0 0 r
F P
0 g
s
.53836 .4398 m .5292 .42957 L .53592 .42502 L p .856 .51 .396 r
F P
0 g
s
.53592 .42502 m .54508 .43438 L .53836 .4398 L p .856 .51 .396 r
F P
0 g
s
.5461 .44881 m .54806 .4511 L .55418 .44475 L p .881 .554 .427 r
F P
0 g
s
.55418 .44475 m .55238 .44262 L .5461 .44881 L p .881 .554 .427 r
F P
0 g
s
.55056 .4405 m .55238 .44262 L .5461 .44881 L p .878 .549 .424 r
F P
0 g
s
.5461 .44881 m .54414 .44651 L .55056 .4405 L p .878 .549 .424 r
F P
0 g
s
.54508 .43438 m .55056 .4405 L .54414 .44651 L p .871 .537 .416 r
F P
0 g
s
.54414 .44651 m .53836 .4398 L .54508 .43438 L p .871 .537 .416 r
F P
0 g
s
.46834 .39864 m .48619 .40064 L .48338 .40206 L p .427 0 0 r
F P
0 g
s
.57487 .55143 m .56453 .56344 L .5641 .56272 L p 0 0 .034 r
F P
0 g
s
.5641 .56272 m .57464 .55044 L .57487 .55143 L p 0 0 .034 r
F P
0 g
s
.55022 .5712 m .5641 .56272 L .56453 .56344 L p .119 0 0 r
F P
0 g
s
.56453 .56344 m .55095 .57176 L .55022 .5712 L p .119 0 0 r
F P
0 g
s
.53454 .57497 m .55022 .5712 L .55095 .57176 L p .239 0 0 r
F P
0 g
s
.57037 .48735 m .57818 .50172 L .57944 .49738 L p .966 .643 .328 r
F P
0 g
s
.57944 .49738 m .57173 .4818 L .57037 .48735 L p .966 .643 .328 r
F P
0 g
s
.48619 .40064 m .50278 .40755 L .49878 .40869 L p .638 .107 0 r
F P
0 g
s
.58094 .53711 m .57487 .55143 L .57464 .55044 L p 0 0 .146 r
F P
0 g
s
.57464 .55044 m .58071 .53571 L .58094 .53711 L p 0 0 .146 r
F P
0 g
s
.42827 .49389 m .4205 .47785 L .42174 .47453 L p 0 .14 .668 r
F P
0 g
s
.47087 .5463 m .48281 .55753 L .48792 .55757 L p .175 .461 .885 r
F P
0 g
s
.42498 .42545 m .43582 .41242 L .43564 .41252 L p .575 .838 .483 r
F P
0 g
s
.43564 .41252 m .42511 .42498 L .42498 .42545 L p .575 .838 .483 r
F P
0 g
s
.55095 .57176 m .53568 .5756 L .53454 .57497 L p .239 0 0 r
F P
0 g
s
.51876 .57388 m .53454 .57497 L .53568 .5756 L p .344 0 0 r
F P
0 g
s
.57514 .55209 m .56486 .56395 L .56453 .56344 L p .077 0 .151 r
F P
0 g
s
.56453 .56344 m .57487 .55143 L .57514 .55209 L p .077 0 .151 r
F P
0 g
s
.55095 .57176 m .56453 .56344 L .56486 .56395 L p .202 0 .022 r
F P
0 g
s
.56486 .56395 m .55144 .57224 L .55095 .57176 L p .202 0 .022 r
F P
0 g
s
.53568 .5756 m .55095 .57176 L .55144 .57224 L p .339 0 0 r
F P
0 g
s
.42174 .47453 m .4296 .48952 L .42827 .49389 L p 0 .14 .668 r
F P
0 g
s
.43773 .50764 m .42827 .49389 L .4296 .48952 L p .089 .285 .768 r
F P
0 g
s
.51209 .41906 m .49878 .40869 L .50278 .40755 L p .775 .307 .129 r
F P
0 g
s
.50278 .40755 m .51722 .41791 L .51209 .41906 L p .775 .307 .129 r
F P
0 g
s
.58126 .53804 m .57514 .55209 L .57487 .55143 L p 0 0 .289 r
F P
0 g
s
.57487 .55143 m .58094 .53711 L .58126 .53804 L p 0 0 .289 r
F P
0 g
s
.48792 .55757 m .4768 .54575 L .47087 .5463 L p .175 .461 .885 r
F P
0 g
s
.46171 .53629 m .47087 .5463 L .4768 .54575 L p .223 .448 .867 r
F P
0 g
s
.56014 .47474 m .57037 .48735 L .57173 .4818 L p .934 .593 .361 r
F P
0 g
s
.57173 .4818 m .5623 .46837 L .56014 .47474 L p .934 .593 .361 r
F P
0 g
s
.57522 .55232 m .56498 .56414 L .56486 .56395 L p .081 0 .154 r
F P
0 g
s
.56486 .56395 m .57514 .55209 L .57522 .55232 L p .081 0 .154 r
F P
0 g
s
.55144 .57224 m .56486 .56395 L .56498 .56414 L p .253 0 .085 r
F P
0 g
s
.56498 .56414 m .55161 .57239 L .55144 .57224 L p .253 0 .085 r
F P
0 g
s
.53642 .57617 m .55144 .57224 L .55161 .57239 L p .339 0 0 r
F P
0 g
s
.55144 .57224 m .53642 .57617 L .53568 .5756 L p .339 0 0 r
F P
0 g
s
.57537 .55261 m .56517 .5644 L .56498 .56414 L p .16 0 .231 r
F P
0 g
s
.56498 .56414 m .57522 .55232 L .57537 .55261 L p .16 0 .231 r
F P
0 g
s
.55161 .57239 m .56498 .56414 L .56517 .5644 L p .31 0 .155 r
F P
0 g
s
.52037 .57481 m .53568 .5756 L .53642 .57617 L p .467 0 0 r
F P
0 g
s
.53568 .5756 m .52037 .57481 L .51876 .57388 L p .344 0 0 r
F P
0 g
s
.56517 .5644 m .55183 .57262 L .55161 .57239 L p .31 0 .155 r
F P
0 g
s
.53666 .57637 m .55161 .57239 L .55183 .57262 L p .402 0 .017 r
F P
0 g
s
.55161 .57239 m .53666 .57637 L .53642 .57617 L p .339 0 0 r
F P
0 g
s
.4296 .48952 m .43987 .50266 L .43773 .50764 L p .089 .285 .768 r
F P
0 g
s
.44632 .51833 m .43773 .50764 L .43987 .50266 L p .186 .374 .817 r
F P
0 g
s
.44881 .40393 m .43521 .41222 L .43564 .41252 L p .606 .953 .834 r
F P
0 g
s
.43564 .41252 m .44955 .40407 L .44881 .40393 L p .606 .953 .834 r
F P
0 g
s
.42511 .42498 m .43564 .41252 L .43521 .41222 L p .783 .978 .704 r
F P
0 g
s
.58138 .53834 m .57522 .55232 L .57514 .55209 L p 0 0 .307 r
F P
0 g
s
.57514 .55209 m .58126 .53804 L .58138 .53834 L p 0 0 .307 r
F P
0 g
s
.4768 .54575 m .46766 .53436 L .46171 .53629 L p .223 .448 .867 r
F P
0 g
s
.45593 .52967 m .46171 .53629 L .46766 .53436 L p .255 .446 .856 r
F P
0 g
s
.57593 .55359 m .56571 .56519 L .56517 .5644 L p .234 0 .302 r
F P
0 g
s
.56517 .5644 m .57537 .55261 L .57593 .55359 L p .234 0 .302 r
F P
0 g
s
.55183 .57262 m .56517 .5644 L .56571 .56519 L p .317 0 .162 r
F P
0 g
s
.43521 .41222 m .42487 .42442 L .42511 .42498 L p .783 .978 .704 r
F P
0 g
s
.41908 .4401 m .42511 .42498 L .42487 .42442 L p .859 .897 .476 r
F P
0 g
s
.56571 .56519 m .55257 .57346 L .55183 .57262 L p .317 0 .162 r
F P
0 g
s
.53695 .57664 m .55183 .57262 L .55257 .57346 L p .458 .014 .105 r
F P
0 g
s
.55183 .57262 m .53695 .57664 L .53666 .57637 L p .402 0 .017 r
F P
0 g
s
.58155 .53872 m .57537 .55261 L .57522 .55232 L p .048 0 .347 r
F P
0 g
s
.57522 .55232 m .58138 .53834 L .58155 .53872 L p .048 0 .347 r
F P
0 g
s
.46766 .53436 m .46131 .52653 L .45593 .52967 L p .255 .446 .856 r
F P
0 g
s
.45397 .52738 m .45593 .52967 L .46131 .52653 L p .264 .441 .849 r
F P
0 g
s
.43987 .50266 m .44991 .51364 L .44632 .51833 L p .186 .374 .817 r
F P
0 g
s
.45201 .52509 m .44632 .51833 L .44991 .51364 L p .242 .419 .838 r
F P
0 g
s
.45673 .52118 m .45904 .52384 L .45397 .52738 L p .262 .437 .846 r
F P
0 g
s
.45397 .52738 m .45201 .52509 L .45673 .52118 L p .262 .437 .846 r
F P
0 g
s
.46131 .52653 m .45904 .52384 L .45397 .52738 L p .264 .441 .849 r
F P
0 g
s
.44991 .51364 m .45673 .52118 L .45201 .52509 L p .242 .419 .838 r
F P
0 g
s
.52324 .43149 m .51209 .41906 L .51722 .41791 L p .842 .433 .265 r
F P
0 g
s
.51722 .41791 m .5292 .42957 L .52324 .43149 L p .842 .433 .265 r
F P
0 g
s
.44955 .40407 m .46528 .40057 L .46414 .40038 L p .362 .831 .884 r
F P
0 g
s
.58277 .5233 m .58126 .53804 L .58094 .53711 L p 0 0 .368 r
F P
0 g
s
.58094 .53711 m .58232 .5221 L .58277 .5233 L p 0 0 .368 r
F P
0 g
s
.58215 .53989 m .57593 .55359 L .57537 .55261 L p .1 0 .385 r
F P
0 g
s
.57537 .55261 m .58155 .53872 L .58215 .53989 L p .1 0 .385 r
F P
0 g
s
.52134 .57555 m .53642 .57617 L .53666 .57637 L p .488 0 0 r
F P
0 g
s
.53642 .57617 m .52134 .57555 L .52037 .57481 L p .467 0 0 r
F P
0 g
s
.55012 .46406 m .56014 .47474 L .5623 .46837 L p .908 .565 .381 r
F P
0 g
s
.5623 .46837 m .55374 .45783 L .55012 .46406 L p .908 .565 .381 r
F P
0 g
s
.42487 .42442 m .41884 .43913 L .41908 .4401 L p .859 .897 .476 r
F P
0 g
s
.57083 .49203 m .57839 .50527 L .57818 .50172 L p .92 .548 .124 r
F P
0 g
s
.57818 .50172 m .57037 .48735 L .57083 .49203 L p .92 .548 .124 r
F P
0 g
s
.52166 .57583 m .53666 .57637 L .53695 .57664 L p .52 0 0 r
F P
0 g
s
.53666 .57637 m .52166 .57583 L .52134 .57555 L p .488 0 0 r
F P
0 g
s
.57712 .55539 m .56694 .56685 L .56571 .56519 L p .31 .064 .37 r
F P
0 g
s
.56571 .56519 m .57593 .55359 L .57712 .55539 L p .31 .064 .37 r
F P
0 g
s
.55257 .57346 m .56571 .56519 L .56694 .56685 L p .413 .079 .287 r
F P
0 g
s
.56694 .56685 m .55393 .57511 L .55257 .57346 L p .413 .079 .287 r
F P
0 g
s
.53786 .57754 m .55257 .57346 L .55393 .57511 L p .512 .1 .196 r
F P
0 g
s
.55257 .57346 m .53786 .57754 L .53695 .57664 L p .458 .014 .105 r
F P
0 g
s
.52204 .57617 m .53695 .57664 L .53786 .57754 L p .551 .034 0 r
F P
0 g
s
.53695 .57664 m .52204 .57617 L .52166 .57583 L p .52 0 0 r
F P
0 g
s
.58295 .5237 m .58138 .53834 L .58126 .53804 L p 0 0 .416 r
F P
0 g
s
.58126 .53804 m .58277 .5233 L .58295 .5237 L p 0 0 .416 r
F P
0 g
s
.53238 .44328 m .52324 .43149 L .5292 .42957 L p .869 .497 .34 r
F P
0 g
s
.5292 .42957 m .53836 .4398 L .53238 .44328 L p .869 .497 .34 r
F P
0 g
s
.44831 .40371 m .43487 .41195 L .43521 .41222 L p .683 .977 .895 r
F P
0 g
s
.43521 .41222 m .44881 .40393 L .44831 .40371 L p .683 .977 .895 r
F P
0 g
s
.42487 .42442 m .43521 .41222 L .43487 .41195 L p .832 .995 .759 r
F P
0 g
s
.54331 .4566 m .55012 .46406 L .55374 .45783 L p .895 .548 .383 r
F P
0 g
s
.55374 .45783 m .54806 .4511 L .54331 .4566 L p .895 .548 .383 r
F P
0 g
s
.50645 .56975 m .52037 .57481 L .52134 .57555 L p .525 0 0 r
F P
0 g
s
.43487 .41195 m .4246 .424 L .42487 .42442 L p .832 .995 .759 r
F P
0 g
s
.41884 .43913 m .42487 .42442 L .4246 .424 L p .925 .934 .572 r
F P
0 g
s
.58356 .54201 m .57712 .55539 L .57593 .55359 L p .227 .09 .476 r
F P
0 g
s
.57593 .55359 m .58215 .53989 L .58356 .54201 L p .227 .09 .476 r
F P
0 g
s
.58317 .52417 m .58155 .53872 L .58138 .53834 L p 0 0 .43 r
F P
0 g
s
.58138 .53834 m .58295 .5237 L .58317 .52417 L p 0 0 .43 r
F P
0 g
s
.541 .45394 m .54331 .4566 L .54806 .4511 L p .889 .539 .377 r
F P
0 g
s
.54806 .4511 m .5461 .44881 L .541 .45394 L p .889 .539 .377 r
F P
0 g
s
.53873 .45124 m .53238 .44328 L .53836 .4398 L p .88 .524 .368 r
F P
0 g
s
.53836 .4398 m .54414 .44651 L .53873 .45124 L p .88 .524 .368 r
F P
0 g
s
.54414 .44651 m .5461 .44881 L .541 .45394 L p .886 .535 .375 r
F P
0 g
s
.541 .45394 m .53873 .45124 L .54414 .44651 L p .886 .535 .375 r
F P
0 g
s
.4768 .54575 m .48792 .55757 L .49202 .55914 L p 0 .342 .821 r
F P
0 g
s
.46339 .40006 m .44831 .40371 L .44881 .40393 L p .49 .88 .964 r
F P
0 g
s
.44881 .40393 m .46414 .40038 L .46339 .40006 L p .49 .88 .964 r
F P
0 g
s
.58402 .52565 m .58215 .53989 L .58155 .53872 L p 0 0 .498 r
F P
0 g
s
.58155 .53872 m .58317 .52417 L .58402 .52565 L p 0 0 .498 r
F P
0 g
s
.41884 .43913 m .41751 .45471 L .41795 .45619 L p .849 .723 .198 r
F P
0 g
s
.44815 .40363 m .43475 .41184 L .43487 .41195 L p .686 .977 .896 r
F P
0 g
s
.43487 .41195 m .44831 .40371 L .44815 .40363 L p .686 .977 .896 r
F P
0 g
s
.4246 .424 m .43487 .41195 L .43475 .41184 L p .856 .997 .788 r
F P
0 g
s
.55393 .57511 m .5395 .57947 L .53786 .57754 L p .512 .1 .196 r
F P
0 g
s
.52321 .57736 m .53786 .57754 L .5395 .57947 L p .622 .158 .13 r
F P
0 g
s
.53786 .57754 m .52321 .57736 L .52204 .57617 L p .551 .034 0 r
F P
0 g
s
.4246 .424 m .41851 .43845 L .41884 .43913 L p .925 .934 .572 r
F P
0 g
s
.41751 .45471 m .41884 .43913 L .41851 .43845 L p .946 .797 .343 r
F P
0 g
s
.43475 .41184 m .42451 .42386 L .4246 .424 L p .856 .997 .788 r
F P
0 g
s
.41851 .43845 m .4246 .424 L .42451 .42386 L p .925 .937 .58 r
F P
0 g
s
.50773 .57083 m .52134 .57555 L .52166 .57583 L p .57 0 0 r
F P
0 g
s
.52134 .57555 m .50773 .57083 L .50645 .56975 L p .525 0 0 r
F P
0 g
s
.57935 .55827 m .56904 .56962 L .56694 .56685 L p .399 .174 .454 r
F P
0 g
s
.56694 .56685 m .57712 .55539 L .57935 .55827 L p .399 .174 .454 r
F P
0 g
s
.55393 .57511 m .56694 .56685 L .56904 .56962 L p .48 .177 .374 r
F P
0 g
s
.44793 .4035 m .43456 .41168 L .43475 .41184 L p .725 .976 .922 r
F P
0 g
s
.43475 .41184 m .44815 .40363 L .44793 .4035 L p .725 .976 .922 r
F P
0 g
s
.42451 .42386 m .43475 .41184 L .43456 .41168 L p .876 .99 .812 r
F P
0 g
s
.50798 .4184 m .49568 .40837 L .49878 .40869 L p .731 .206 0 r
F P
0 g
s
.49878 .40869 m .51209 .41906 L .50798 .4184 L p .731 .206 0 r
F P
0 g
s
.43456 .41168 m .42436 .42366 L .42451 .42386 L p .876 .99 .812 r
F P
0 g
s
.41839 .43824 m .42451 .42386 L .42436 .42366 L p .953 .944 .631 r
F P
0 g
s
.42451 .42386 m .41839 .43824 L .41851 .43845 L p .925 .937 .58 r
F P
0 g
s
.50815 .57123 m .52166 .57583 L .52204 .57617 L p .588 .016 0 r
F P
0 g
s
.52166 .57583 m .50815 .57123 L .50773 .57083 L p .57 0 0 r
F P
0 g
s
.56904 .56962 m .55612 .57802 L .55393 .57511 L p .48 .177 .374 r
F P
0 g
s
.5395 .57947 m .55393 .57511 L .55612 .57802 L p .572 .207 .311 r
F P
0 g
s
.46316 .39994 m .44815 .40363 L .44831 .40371 L p .512 .886 .971 r
F P
0 g
s
.44831 .40371 m .46339 .40006 L .46316 .39994 L p .512 .886 .971 r
F P
0 g
s
.44718 .40295 m .43401 .41117 L .43456 .41168 L p .753 .963 .935 r
F P
0 g
s
.43456 .41168 m .44793 .4035 L .44718 .40295 L p .753 .963 .935 r
F P
0 g
s
.42436 .42366 m .43456 .41168 L .43401 .41117 L p .878 .989 .814 r
F P
0 g
s
.58586 .52815 m .58356 .54201 L .58215 .53989 L p .133 .119 .575 r
F P
0 g
s
.58215 .53989 m .58402 .52565 L .58586 .52815 L p .133 .119 .575 r
F P
0 g
s
.43401 .41117 m .42379 .42296 L .42436 .42366 L p .878 .989 .814 r
F P
0 g
s
.41822 .43796 m .42436 .42366 L .42379 .42296 L p .966 .937 .67 r
F P
0 g
s
.42436 .42366 m .41822 .43796 L .41839 .43824 L p .953 .944 .631 r
F P
0 g
s
.47854 .40122 m .46339 .40006 L .46414 .40038 L p .211 .694 .931 r
F P
0 g
s
.46414 .40038 m .47951 .40169 L .47854 .40122 L p .211 .694 .931 r
F P
0 g
s
.46286 .39977 m .44793 .4035 L .44815 .40363 L p .544 .889 .983 r
F P
0 g
s
.44815 .40363 m .46316 .39994 L .46286 .39977 L p .544 .889 .983 r
F P
0 g
s
.50865 .57174 m .52204 .57617 L .52321 .57736 L p .647 .1 0 r
F P
0 g
s
.52204 .57617 m .50865 .57174 L .50815 .57123 L p .588 .016 0 r
F P
0 g
s
.43987 .50266 m .4296 .48952 L .42913 .48575 L p 0 .209 .734 r
F P
0 g
s
.5862 .54517 m .57935 .55827 L .57712 .55539 L p .333 .199 .544 r
F P
0 g
s
.57712 .55539 m .58356 .54201 L .5862 .54517 L p .333 .199 .544 r
F P
0 g
s
.56019 .48067 m .57083 .49203 L .57037 .48735 L p .922 .536 .246 r
F P
0 g
s
.57037 .48735 m .56014 .47474 L .56019 .48067 L p .922 .536 .246 r
F P
0 g
s
.41705 .45379 m .41851 .43845 L .41839 .43824 L p .96 .81 .374 r
F P
0 g
s
.41851 .43845 m .41705 .45379 L .41751 .45471 L p .946 .797 .343 r
F P
0 g
s
.46194 .39917 m .44718 .40295 L .44793 .4035 L p .572 .888 .99 r
F P
0 g
s
.44793 .4035 m .46286 .39977 L .46194 .39917 L p .572 .888 .99 r
F P
0 g
s
.58017 .50994 m .58295 .5237 L .58277 .5233 L p 0 0 .476 r
F P
0 g
s
.41688 .45348 m .41839 .43824 L .41822 .43796 L p .977 .82 .412 r
F P
0 g
s
.41839 .43824 m .41688 .45348 L .41705 .45379 L p .96 .81 .374 r
F P
0 g
s
.58054 .51056 m .58317 .52417 L .58295 .5237 L p 0 0 .518 r
F P
0 g
s
.58295 .5237 m .58017 .50994 L .58054 .51056 L p 0 0 .518 r
F P
0 g
s
.42072 .46969 m .41751 .45471 L .41705 .45379 L p .854 .564 .031 r
F P
0 g
s
.44581 .40175 m .43277 .40996 L .43401 .41117 L p .775 .938 .934 r
F P
0 g
s
.43401 .41117 m .44718 .40295 L .44581 .40175 L p .775 .938 .934 r
F P
0 g
s
.42379 .42296 m .43401 .41117 L .43277 .40996 L p .889 .951 .84 r
F P
0 g
s
.55612 .57802 m .5419 .58283 L .5395 .57947 L p .572 .207 .311 r
F P
0 g
s
.52515 .57978 m .5395 .57947 L .5419 .58283 L p .671 .262 .26 r
F P
0 g
s
.5395 .57947 m .52515 .57978 L .52321 .57736 L p .622 .158 .13 r
F P
0 g
s
.42379 .42296 m .41762 .43709 L .41822 .43796 L p .966 .937 .67 r
F P
0 g
s
.41665 .45312 m .41822 .43796 L .41762 .43709 L p .99 .827 .448 r
F P
0 g
s
.41822 .43796 m .41665 .45312 L .41688 .45348 L p .977 .82 .412 r
F P
0 g
s
.49202 .55914 m .48208 .54721 L .4768 .54575 L p 0 .342 .821 r
F P
0 g
s
.46766 .53436 m .4768 .54575 L .48208 .54721 L p .103 .37 .833 r
F P
0 g
s
.47821 .40103 m .46316 .39994 L .46339 .40006 L p .268 .717 .958 r
F P
0 g
s
.46339 .40006 m .47854 .40122 L .47821 .40103 L p .268 .717 .958 r
F P
0 g
s
.43277 .40996 m .42259 .42162 L .42379 .42296 L p .889 .951 .84 r
F P
0 g
s
.41762 .43709 m .42379 .42296 L .42259 .42162 L p .967 .918 .702 r
F P
0 g
s
.58181 .51243 m .58402 .52565 L .58317 .52417 L p 0 .022 .58 r
F P
0 g
s
.58317 .52417 m .58054 .51056 L .58181 .51243 L p 0 .022 .58 r
F P
0 g
s
.51012 .57342 m .52321 .57736 L .52515 .57978 L p .716 .215 .044 r
F P
0 g
s
.52321 .57736 m .51012 .57342 L .50865 .57174 L p .647 .1 0 r
F P
0 g
s
.47783 .4008 m .46286 .39977 L .46316 .39994 L p .286 .724 .965 r
F P
0 g
s
.46316 .39994 m .47821 .40103 L .47783 .4008 L p .286 .724 .965 r
F P
0 g
s
.46029 .3977 m .44581 .40175 L .44718 .40295 L p .629 .865 .987 r
F P
0 g
s
.44718 .40295 m .46194 .39917 L .46029 .3977 L p .629 .865 .987 r
F P
0 g
s
.51793 .43117 m .50798 .4184 L .51209 .41906 L p .848 .407 .17 r
F P
0 g
s
.51209 .41906 m .52324 .43149 L .51793 .43117 L p .848 .407 .17 r
F P
0 g
s
.58321 .56264 m .57255 .57409 L .56904 .56962 L p .485 .284 .532 r
F P
0 g
s
.56904 .56962 m .57935 .55827 L .58321 .56264 L p .485 .284 .532 r
F P
0 g
s
.55612 .57802 m .56904 .56962 L .57255 .57409 L p .549 .286 .469 r
F P
0 g
s
.58925 .53172 m .5862 .54517 L .58356 .54201 L p .277 .246 .643 r
F P
0 g
s
.58356 .54201 m .58586 .52815 L .58925 .53172 L p .277 .246 .643 r
F P
0 g
s
.47665 .3999 m .46194 .39917 L .46286 .39977 L p .359 .74 .988 r
F P
0 g
s
.46286 .39977 m .47783 .4008 L .47665 .3999 L p .359 .74 .988 r
F P
0 g
s
.42913 .48575 m .43981 .49787 L .43987 .50266 L p 0 .209 .734 r
F P
0 g
s
.44991 .51364 m .43987 .50266 L .43981 .49787 L p .089 .341 .814 r
F P
0 g
s
.41999 .46843 m .41705 .45379 L .41688 .45348 L p .895 .6 .095 r
F P
0 g
s
.41705 .45379 m .41999 .46843 L .42072 .46969 L p .854 .564 .031 r
F P
0 g
s
.57255 .57409 m .55947 .58282 L .55612 .57802 L p .549 .286 .469 r
F P
0 g
s
.5419 .58283 m .55612 .57802 L .55947 .58282 L p .624 .312 .421 r
F P
0 g
s
.42259 .42162 m .41618 .43543 L .41762 .43709 L p .967 .918 .702 r
F P
0 g
s
.4158 .45195 m .41762 .43709 L .41618 .43543 L p .999 .826 .533 r
F P
0 g
s
.41762 .43709 m .4158 .45195 L .41665 .45312 L p .99 .827 .448 r
F P
0 g
s
.48208 .54721 m .49202 .55914 L .49494 .56117 L p 0 .207 .725 r
F P
0 g
s
.41971 .46801 m .41688 .45348 L .41665 .45312 L p .909 .613 .121 r
F P
0 g
s
.41688 .45348 m .41971 .46801 L .41999 .46843 L p .895 .6 .095 r
F P
0 g
s
.58442 .51546 m .58586 .52815 L .58402 .52565 L p .033 .164 .669 r
F P
0 g
s
.58402 .52565 m .58181 .51243 L .58442 .51546 L p .033 .164 .669 r
F P
0 g
s
.59065 .54956 m .58321 .56264 L .57935 .55827 L p .432 .303 .604 r
F P
0 g
s
.57935 .55827 m .5862 .54517 L .59065 .54956 L p .432 .303 .604 r
F P
0 g
s
.49568 .40837 m .50798 .4184 L .50505 .41698 L p .634 .081 0 r
F P
0 g
s
.48208 .54721 m .47367 .53418 L .46766 .53436 L p .103 .37 .833 r
F P
0 g
s
.46131 .52653 m .46766 .53436 L .47367 .53418 L p .205 .413 .844 r
F P
0 g
s
.54831 .47056 m .56019 .48067 L .56014 .47474 L p .902 .537 .336 r
F P
0 g
s
.56014 .47474 m .55012 .46406 L .54831 .47056 L p .902 .537 .336 r
F P
0 g
s
.41934 .4675 m .41665 .45312 L .4158 .45195 L p .948 .646 .203 r
F P
0 g
s
.41665 .45312 m .41934 .4675 L .41971 .46801 L p .909 .613 .121 r
F P
0 g
s
.4436 .39944 m .43065 .40779 L .43277 .40996 L p .785 .89 .92 r
F P
0 g
s
.43277 .40996 m .44581 .40175 L .4436 .39944 L p .785 .89 .92 r
F P
0 g
s
.42259 .42162 m .43277 .40996 L .43065 .40779 L p .882 .907 .84 r
F P
0 g
s
.4747 .39797 m .46029 .3977 L .46194 .39917 L p .448 .746 .992 r
F P
0 g
s
.46194 .39917 m .47665 .3999 L .4747 .39797 L p .448 .746 .992 r
F P
0 g
s
.43981 .49787 m .4517 .50855 L .44991 .51364 L p .089 .341 .814 r
F P
0 g
s
.45673 .52118 m .44991 .51364 L .4517 .50855 L p .202 .408 .841 r
F P
0 g
s
.43065 .40779 m .42034 .41935 L .42259 .42162 L p .882 .907 .84 r
F P
0 g
s
.41618 .43543 m .42259 .42162 L .42034 .41935 L p .949 .878 .731 r
F P
0 g
s
.47367 .53418 m .46666 .52407 L .46131 .52653 L p .205 .413 .844 r
F P
0 g
s
.45904 .52384 m .46131 .52653 L .46666 .52407 L p .248 .433 .847 r
F P
0 g
s
.46074 .51717 m .46379 .52055 L .45904 .52384 L p .247 .431 .846 r
F P
0 g
s
.45904 .52384 m .45673 .52118 L .46074 .51717 L p .247 .431 .846 r
F P
0 g
s
.46666 .52407 m .46379 .52055 L .45904 .52384 L p .248 .433 .847 r
F P
0 g
s
.4517 .50855 m .46074 .51717 L .45673 .52118 L p .202 .408 .841 r
F P
0 g
s
.5419 .58283 m .52783 .58395 L .52515 .57978 L p .671 .262 .26 r
F P
0 g
s
.51244 .5767 m .52515 .57978 L .52783 .58395 L p .768 .333 .217 r
F P
0 g
s
.52515 .57978 m .51244 .5767 L .51012 .57342 L p .716 .215 .044 r
F P
0 g
s
.55947 .58282 m .54518 .58821 L .5419 .58283 L p .624 .312 .421 r
F P
0 g
s
.52783 .58395 m .5419 .58283 L .54518 .58821 L p .706 .357 .383 r
F P
0 g
s
.45787 .39495 m .4436 .39944 L .44581 .40175 L p .666 .83 .962 r
F P
0 g
s
.44581 .40175 m .46029 .3977 L .45787 .39495 L p .666 .83 .962 r
F P
0 g
s
.49128 .40601 m .47783 .4008 L .47821 .40103 L p .011 .488 .871 r
F P
0 g
s
.52635 .44484 m .51793 .43117 L .52324 .43149 L p .881 .5 .314 r
F P
0 g
s
.52324 .43149 m .53238 .44328 L .52635 .44484 L p .881 .5 .314 r
F P
0 g
s
.56168 .48548 m .57206 .4955 L .57083 .49203 L p .882 .448 .101 r
F P
0 g
s
.57083 .49203 m .56019 .48067 L .56168 .48548 L p .882 .448 .101 r
F P
0 g
s
.43981 .49787 m .42913 .48575 L .42788 .48291 L p 0 .147 .687 r
F P
0 g
s
.4898 .40465 m .47665 .3999 L .47783 .4008 L p .093 .524 .907 r
F P
0 g
s
.47783 .4008 m .49128 .40601 L .4898 .40465 L p .093 .524 .907 r
F P
0 g
s
.41618 .43543 m .41394 .44994 L .4158 .45195 L p .999 .826 .533 r
F P
0 g
s
.41807 .46597 m .4158 .45195 L .41394 .44994 L p .977 .678 .317 r
F P
0 g
s
.4158 .45195 m .41807 .46597 L .41934 .4675 L p .948 .646 .203 r
F P
0 g
s
.53927 .46215 m .54831 .47056 L .55012 .46406 L p .891 .537 .367 r
F P
0 g
s
.55012 .46406 m .54331 .4566 L .53927 .46215 L p .891 .537 .367 r
F P
0 g
s
.42034 .41935 m .41353 .43289 L .41618 .43543 L p .949 .878 .731 r
F P
0 g
s
.41394 .44994 m .41618 .43543 L .41353 .43289 L p .98 .804 .593 r
F P
0 g
s
.59479 .53633 m .59065 .54956 L .5862 .54517 L p .4 .352 .689 r
F P
0 g
s
.5862 .54517 m .58925 .53172 L .59479 .53633 L p .4 .352 .689 r
F P
0 g
s
.589 .51949 m .58925 .53172 L .58586 .52815 L p .227 .311 .741 r
F P
0 g
s
.58586 .52815 m .58442 .51546 L .589 .51949 L p .227 .311 .741 r
F P
0 g
s
.49973 .56653 m .51012 .57342 L .51244 .5767 L p .775 .268 0 r
F P
0 g
s
.57613 .5015 m .58181 .51243 L .58054 .51056 L p 0 .009 .578 r
F P
0 g
s
.53336 .45522 m .52635 .44484 L .53238 .44328 L p .887 .529 .362 r
F P
0 g
s
.53238 .44328 m .53873 .45124 L .53336 .45522 L p .887 .529 .362 r
F P
0 g
s
.58918 .56883 m .57783 .58066 L .57255 .57409 L p .547 .365 .587 r
F P
0 g
s
.57255 .57409 m .58321 .56264 L .58918 .56883 L p .547 .365 .587 r
F P
0 g
s
.55947 .58282 m .57255 .57409 L .57783 .58066 L p .596 .365 .536 r
F P
0 g
s
.49494 .56117 m .4862 .54978 L .48208 .54721 L p 0 .207 .725 r
F P
0 g
s
.53623 .45877 m .53927 .46215 L .54331 .4566 L p .889 .535 .368 r
F P
0 g
s
.54331 .4566 m .541 .45394 L .53623 .45877 L p .889 .535 .368 r
F P
0 g
s
.53873 .45124 m .541 .45394 L .53623 .45877 L p .888 .533 .367 r
F P
0 g
s
.53623 .45877 m .53336 .45522 L .53873 .45124 L p .888 .533 .367 r
F P
0 g
s
.57783 .58066 m .56426 .59001 L .55947 .58282 L p .596 .365 .536 r
F P
0 g
s
.54518 .58821 m .55947 .58282 L .56426 .59001 L p .658 .388 .501 r
F P
0 g
s
.47201 .39441 m .45787 .39495 L .46029 .3977 L p .527 .729 .967 r
F P
0 g
s
.46029 .3977 m .4747 .39797 L .47201 .39441 L p .527 .729 .967 r
F P
0 g
s
.48747 .40189 m .4747 .39797 L .47665 .3999 L p .231 .569 .939 r
F P
0 g
s
.47665 .3999 m .4898 .40465 L .48747 .40189 L p .231 .569 .939 r
F P
0 g
s
.5138 .42938 m .50505 .41698 L .50798 .4184 L p .843 .378 .06 r
F P
0 g
s
.50798 .4184 m .51793 .43117 L .5138 .42938 L p .843 .378 .06 r
F P
0 g
s
.59762 .55551 m .58918 .56883 L .58321 .56264 L p .512 .389 .649 r
F P
0 g
s
.58321 .56264 m .59065 .54956 L .59762 .55551 L p .512 .389 .649 r
F P
0 g
s
.44021 .39533 m .42711 .40402 L .43065 .40779 L p .782 .827 .888 r
F P
0 g
s
.43065 .40779 m .4436 .39944 L .44021 .39533 L p .782 .827 .888 r
F P
0 g
s
.42034 .41935 m .43065 .40779 L .42711 .40402 L p .858 .842 .827 r
F P
0 g
s
.47367 .53418 m .48208 .54721 L .4862 .54978 L p 0 .271 .775 r
F P
0 g
s
.42711 .40402 m .41645 .41568 L .42034 .41935 L p .858 .842 .827 r
F P
0 g
s
.41353 .43289 m .42034 .41935 L .41645 .41568 L p .911 .821 .744 r
F P
0 g
s
.54518 .58821 m .53115 .59043 L .52783 .58395 L p .706 .357 .383 r
F P
0 g
s
.51538 .58212 m .52783 .58395 L .53115 .59043 L p .792 .427 .368 r
F P
0 g
s
.52783 .58395 m .51538 .58212 L .51244 .5767 L p .768 .333 .217 r
F P
0 g
s
.58005 .50524 m .58442 .51546 L .58181 .51243 L p 0 .201 .729 r
F P
0 g
s
.58181 .51243 m .57613 .5015 L .58005 .50524 L p 0 .201 .729 r
F P
0 g
s
.49664 .56275 m .48869 .55206 L .4862 .54978 L p 0 .091 .63 r
F P
0 g
s
.45456 .39025 m .44021 .39533 L .4436 .39944 L p .689 .782 .922 r
F P
0 g
s
.4436 .39944 m .45787 .39495 L .45456 .39025 L p .689 .782 .922 r
F P
0 g
s
.56333 .48849 m .57319 .49758 L .57206 .4955 L p .817 .343 0 r
F P
0 g
s
.57206 .4955 m .56168 .48548 L .56333 .48849 L p .817 .343 0 r
F P
0 g
s
.41353 .43289 m .41053 .447 L .41394 .44994 L p .98 .804 .593 r
F P
0 g
s
.41544 .46347 m .41394 .44994 L .41053 .447 L p .972 .688 .431 r
F P
0 g
s
.41394 .44994 m .41544 .46347 L .41807 .46597 L p .977 .678 .317 r
F P
0 g
s
.56426 .59001 m .54957 .59634 L .54518 .58821 L p .658 .388 .501 r
F P
0 g
s
.53115 .59043 m .54518 .58821 L .54957 .59634 L p .724 .432 .483 r
F P
0 g
s
.42788 .48291 m .43829 .49386 L .43981 .49787 L p 0 .147 .687 r
F P
0 g
s
.49719 .56333 m .4895 .55294 L .48869 .55206 L p 0 .031 .576 r
F P
0 g
s
.50253 .57122 m .51244 .5767 L .51538 .58212 L p .853 .411 .162 r
F P
0 g
s
.51244 .5767 m .50253 .57122 L .49973 .56653 L p .775 .268 0 r
F P
0 g
s
.4517 .50855 m .43981 .49787 L .43829 .49386 L p .017 .337 .818 r
F P
0 g
s
.41645 .41568 m .40904 .42921 L .41353 .43289 L p .911 .821 .744 r
F P
0 g
s
.41053 .447 m .41353 .43289 L .40904 .42921 L p .94 .767 .639 r
F P
0 g
s
.42379 .4779 m .41807 .46597 L .41544 .46347 L p .876 .451 .037 r
F P
0 g
s
.5961 .52427 m .59479 .53633 L .58925 .53172 L p .383 .422 .778 r
F P
0 g
s
.58925 .53172 m .589 .51949 L .5961 .52427 L p .383 .422 .778 r
F P
0 g
s
.54864 .47731 m .56168 .48548 L .56019 .48067 L p .888 .504 .301 r
F P
0 g
s
.56019 .48067 m .54831 .47056 L .54864 .47731 L p .888 .504 .301 r
F P
0 g
s
.49785 .56408 m .49044 .55408 L p .48971 .55323 L 0 0 .533 r
F P
0 g
s
.49303 .5579 m .49044 .55408 L p .49163 .55567 L 0 0 .446 r
F P
0 g
s
.49973 .56653 m .49303 .5579 L p .49163 .55567 L 0 0 .446 r
F P
0 g
s
.49637 .56499 m .49303 .5579 L p .49572 .56167 L .716 .267 0 r
F P
0 g
s
.50253 .57122 m .49637 .56499 L p .49572 .56167 L .716 .267 0 r
F P
0 g
s
.49637 .56499 m .49924 .575 L p .49709 .56874 L .791 .476 0 r
F P
0 g
s
.49425 .56046 m .49637 .56499 L p .49709 .56874 L .791 .476 0 r
F P
0 g
s
.49303 .5579 m .49637 .56499 L p .49505 .5611 L 0 0 .468 r
F P
0 g
s
.49303 .5579 m .49973 .56653 L .50253 .57122 L p .716 .267 0 r
F P
0 g
s
.49109 .54935 m .49303 .5579 L p .49505 .5611 L 0 0 .468 r
F P
0 g
s
.49044 .55408 m .49303 .5579 L p .49249 .55645 L 0 .05 .615 r
F P
0 g
s
.48723 .54248 m .49044 .55408 L p .49249 .55645 L 0 .05 .615 r
F P
0 g
s
.49044 .55408 m .4895 .55294 L p .48971 .55323 L 0 0 .533 r
F P
0 g
s
.60304 .542 m .59762 .55551 L .59065 .54956 L p .493 .431 .716 r
F P
0 g
s
.59065 .54956 m .59479 .53633 L .60304 .542 L p .493 .431 .716 r
F P
0 g
s
.48451 .39708 m .47201 .39441 L .4747 .39797 L p .369 .591 .931 r
F P
0 g
s
.4747 .39797 m .48747 .40189 L .48451 .39708 L p .369 .591 .931 r
F P
0 g
s
.57319 .49758 m .56333 .48849 L .564 .48949 L p .758 .262 0 r
F P
0 g
s
.46865 .3886 m .45456 .39025 L .45787 .39495 L p .583 .7 .923 r
F P
0 g
s
.45787 .39495 m .47201 .39441 L .46865 .3886 L p .583 .7 .923 r
F P
0 g
s
.59792 .57731 m .58545 .58998 L .57783 .58066 L p .595 .43 .629 r
F P
0 g
s
.57783 .58066 m .58918 .56883 L .59792 .57731 L p .595 .43 .629 r
F P
0 g
s
.56426 .59001 m .57783 .58066 L .58545 .58998 L p .633 .43 .591 r
F P
0 g
s
.5113 .42755 m .50334 .41575 L .50505 .41698 L p .815 .339 0 r
F P
0 g
s
.50505 .41698 m .5138 .42938 L .5113 .42755 L p .815 .339 0 r
F P
0 g
s
.42675 .48118 m .43664 .49131 L .43829 .49386 L p 0 .098 .634 r
F P
0 g
s
.5865 .50975 m .589 .51949 L .58442 .51546 L p .172 .39 .834 r
F P
0 g
s
.58442 .51546 m .58005 .50524 L .5865 .50975 L p .172 .39 .834 r
F P
0 g
s
.58545 .58998 m .57086 .60028 L .56426 .59001 L p .633 .43 .591 r
F P
0 g
s
.54957 .59634 m .56426 .59001 L .57086 .60028 L p .679 .448 .565 r
F P
0 g
s
.57362 .49826 m .564 .48949 L .5649 .49067 L p .72 .216 0 r
F P
0 g
s
.52029 .4441 m .5138 .42938 L .51793 .43117 L p .897 .521 .311 r
F P
0 g
s
.51793 .43117 m .52635 .44484 L .52029 .4441 L p .897 .521 .311 r
F P
0 g
s
.4862 .54978 m .47972 .53605 L .47367 .53418 L p 0 .271 .775 r
F P
0 g
s
.46666 .52407 m .47367 .53418 L .47972 .53605 L p .171 .378 .825 r
F P
0 g
s
.49742 .40843 m .48747 .40189 L .4898 .40465 L p 0 .312 .802 r
F P
0 g
s
.4898 .40465 m .50023 .41258 L .49742 .40843 L p 0 .312 .802 r
F P
0 g
s
.42631 .48061 m .43596 .49046 L .43664 .49131 L p 0 .069 .599 r
F P
0 g
s
.43538 .38888 m .42178 .3982 L .42711 .40402 L p .771 .772 .854 r
F P
0 g
s
.42711 .40402 m .44021 .39533 L .43538 .38888 L p .771 .772 .854 r
F P
0 g
s
.41645 .41568 m .42711 .40402 L .42178 .3982 L p .83 .784 .808 r
F P
0 g
s
.60768 .56325 m .59792 .57731 L .58918 .56883 L p .57 .45 .677 r
F P
0 g
s
.58918 .56883 m .59762 .55551 L .60768 .56325 L p .57 .45 .677 r
F P
0 g
s
.57419 .49909 m .5649 .49067 L .56805 .49403 L p .598 .081 0 r
F P
0 g
s
.54957 .59634 m .53509 .59975 L .53115 .59043 L p .724 .432 .483 r
F P
0 g
s
.51864 .59014 m .53115 .59043 L .53509 .59975 L p .792 .492 .48 r
F P
0 g
s
.53115 .59043 m .51864 .59014 L .51538 .58212 L p .792 .427 .368 r
F P
0 g
s
.42178 .3982 m .41042 .41025 L .41645 .41568 L p .83 .784 .808 r
F P
0 g
s
.40904 .42921 m .41645 .41568 L .41042 .41025 L p .872 .768 .744 r
F P
0 g
s
.47972 .53605 m .4862 .54978 L .48869 .55206 L p 0 .19 .719 r
F P
0 g
s
.43829 .49386 m .45135 .50293 L .4517 .50855 L p .017 .337 .818 r
F P
0 g
s
.46074 .51717 m .4517 .50855 L .45135 .50293 L p .193 .422 .854 r
F P
0 g
s
.40904 .42921 m .40495 .4431 L .41053 .447 L p .94 .767 .639 r
F P
0 g
s
.41083 .46009 m .41053 .447 L .40495 .4431 L p .936 .678 .522 r
F P
0 g
s
.41053 .447 m .41083 .46009 L .41544 .46347 L p .972 .688 .431 r
F P
0 g
s
.42574 .47992 m .43506 .48944 L p .4357 .49019 L 0 .044 .568 r
F P
0 g
s
.4319 .48655 m .43506 .48944 L p .43362 .48797 L 0 0 .502 r
F P
0 g
s
.42379 .4779 m .4319 .48655 L p .43362 .48797 L 0 0 .502 r
F P
0 g
s
.41985 .47473 m .42567 .48249 L .4319 .48655 L p .634 .109 0 r
F P
0 g
s
.4319 .48655 m .42567 .48249 L p .42942 .48451 L 0 .344 .763 r
F P
0 g
s
.4319 .48655 m .42379 .4779 L .41985 .47473 L p .634 .109 0 r
F P
0 g
s
.44075 .49059 m .4319 .48655 L p .42942 .48451 L 0 .344 .763 r
F P
0 g
s
.43506 .48944 m .4319 .48655 L p .43329 .48736 L 0 .401 .842 r
F P
0 g
s
.4467 .49516 m .43506 .48944 L p .43329 .48736 L 0 .401 .842 r
F P
0 g
s
.43506 .48944 m .43596 .49046 L p .4357 .49019 L 0 .044 .568 r
F P
0 g
s
.50564 .57855 m .51538 .58212 L .51864 .59014 L p .874 .512 .359 r
F P
0 g
s
.51538 .58212 m .50564 .57855 L .50253 .57122 L p .853 .411 .162 r
F P
0 g
s
.41985 .47473 m .41544 .46347 L .41083 .46009 L p .914 .519 .225 r
F P
0 g
s
.41544 .46347 m .41985 .47473 L .42379 .4779 L p .876 .451 .037 r
F P
0 g
s
.45012 .38283 m .43538 .38888 L .44021 .39533 L p .698 .731 .876 r
F P
0 g
s
.44021 .39533 m .45456 .39025 L .45012 .38283 L p .698 .731 .876 r
F P
0 g
s
.57086 .60028 m .55526 .60778 L .54957 .59634 L p .679 .448 .565 r
F P
0 g
s
.53509 .59975 m .54957 .59634 L .55526 .60778 L p .731 .484 .555 r
F P
0 g
s
.47972 .53605 m .47322 .52222 L .46666 .52407 L p .171 .378 .825 r
F P
0 g
s
.46379 .52055 m .46666 .52407 L .47322 .52222 L p .302 .454 .847 r
F P
0 g
s
.5105 .4268 m .50279 .41527 L .50334 .41575 L p .78 .305 0 r
F P
0 g
s
.50334 .41575 m .5113 .42755 L .5105 .4268 L p .78 .305 0 r
F P
0 g
s
.46431 .51181 m .46921 .51666 L .46379 .52055 L p .305 .46 .851 r
F P
0 g
s
.46379 .52055 m .46074 .51717 L .46431 .51181 L p .305 .46 .851 r
F P
0 g
s
.47322 .52222 m .46921 .51666 L .46379 .52055 L p .302 .454 .847 r
F P
0 g
s
.45135 .50293 m .46431 .51181 L .46074 .51717 L p .193 .422 .854 r
F P
0 g
s
.53568 .46896 m .54864 .47731 L .54831 .47056 L p .878 .537 .402 r
F P
0 g
s
.54831 .47056 m .53927 .46215 L .53568 .46896 L p .878 .537 .402 r
F P
0 g
s
.60598 .52955 m .60304 .542 L .59479 .53633 L p .491 .493 .787 r
F P
0 g
s
.59479 .53633 m .5961 .52427 L .60598 .52955 L p .491 .493 .787 r
F P
0 g
s
.41042 .41025 m .40202 .42401 L .40904 .42921 L p .872 .768 .744 r
F P
0 g
s
.40495 .4431 m .40904 .42921 L .40202 .42401 L p .891 .724 .668 r
F P
0 g
s
.50279 .41527 m .5105 .4268 L .50955 .42583 L p .754 .282 0 r
F P
0 g
s
.45135 .50293 m .43829 .49386 L .43664 .49131 L p .01 .373 .84 r
F P
0 g
s
.57425 .49869 m .58005 .50524 L .57613 .5015 L p 0 .193 .675 r
F P
0 g
s
.57387 .49941 m .56805 .49403 L .57425 .49869 L p 0 .193 .675 r
F P
0 g
s
.56946 .49642 m .57425 .49869 L .56988 .49541 L p .487 0 0 r
F P
0 g
s
.56988 .49541 m .56805 .49403 L p .56946 .49642 L .487 0 0 r
F P
0 g
s
.56946 .49642 m .56772 .49681 L .56921 .49701 L p .248 0 0 r
F P
0 g
s
.57425 .49869 m .56946 .49642 L .57462 .49798 L p 0 .481 .799 r
F P
0 g
s
.5812 .49867 m .58157 .50007 L .56946 .49642 L p .248 0 0 r
F P
0 g
s
.56921 .49701 m .5812 .49867 L p .56946 .49642 L .248 0 0 r
F P
0 g
s
.57462 .49798 m .58157 .50007 L p .57425 .49869 L 0 .481 .799 r
F P
0 g
s
.57613 .5015 m .57387 .49941 L p .57425 .49869 L 0 .193 .675 r
F P
0 g
s
.48123 .38969 m .46865 .3886 L .47201 .39441 L p .471 .591 .892 r
F P
0 g
s
.47201 .39441 m .48451 .39708 L .48123 .38969 L p .471 .591 .892 r
F P
0 g
s
.61461 .54893 m .60768 .56325 L .59762 .55551 L p .56 .487 .73 r
F P
0 g
s
.59762 .55551 m .60304 .542 L .61461 .54893 L p .56 .487 .73 r
F P
0 g
s
.55059 .48241 m .56333 .48849 L .56168 .48548 L p .862 .448 .24 r
F P
0 g
s
.56168 .48548 m .54864 .47731 L .55059 .48241 L p .862 .448 .24 r
F P
0 g
s
.52678 .45853 m .52029 .4441 L .52635 .44484 L p .888 .555 .412 r
F P
0 g
s
.52635 .44484 m .53336 .45522 L .52678 .45853 L p .888 .555 .412 r
F P
0 g
s
.50213 .41466 m .50955 .42583 L .50695 .42245 L p .665 .213 0 r
F P
0 g
s
.48411 .53906 m .48869 .55206 L .4895 .55294 L p 0 .151 .689 r
F P
0 g
s
.48869 .55206 m .48411 .53906 L .47972 .53605 L p 0 .19 .719 r
F P
0 g
s
.49429 .4017 m .48451 .39708 L .48747 .40189 L p .177 .401 .842 r
F P
0 g
s
.48747 .40189 m .49742 .40843 L .49429 .4017 L p .177 .401 .842 r
F P
0 g
s
.59561 .51443 m .5961 .52427 L .589 .51949 L p .375 .509 .865 r
F P
0 g
s
.589 .51949 m .5865 .50975 L .59561 .51443 L p .375 .509 .865 r
F P
0 g
s
.46468 .37993 m .45012 .38283 L .45456 .39025 L p .62 .668 .875 r
F P
0 g
s
.45456 .39025 m .46865 .3886 L .46468 .37993 L p .62 .668 .875 r
F P
0 g
s
.53078 .46416 m .53568 .46896 L .53927 .46215 L p .88 .546 .415 r
F P
0 g
s
.53927 .46215 m .53623 .45877 L .53078 .46416 L p .88 .546 .415 r
F P
0 g
s
.49637 .56499 m .50253 .57122 L .50564 .57855 L p .89 .477 .068 r
F P
0 g
s
.61007 .58866 m .59594 .60265 L .58545 .58998 L p .631 .48 .659 r
F P
0 g
s
.58545 .58998 m .59792 .57731 L .61007 .58866 L p .631 .48 .659 r
F P
0 g
s
.57086 .60028 m .58545 .58998 L .59594 .60265 L p .658 .478 .63 r
F P
0 g
s
.53336 .45522 m .53623 .45877 L .53078 .46416 L p .883 .552 .418 r
F P
0 g
s
.53078 .46416 m .52678 .45853 L .53336 .45522 L p .883 .552 .418 r
F P
0 g
s
.59594 .60265 m .5798 .61435 L .57086 .60028 L p .658 .478 .63 r
F P
0 g
s
.55526 .60778 m .57086 .60028 L .5798 .61435 L p .693 .493 .613 r
F P
0 g
s
.48557 .54049 m .4895 .55294 L .49044 .55408 L p 0 .126 .671 r
F P
0 g
s
.4895 .55294 m .48557 .54049 L .48411 .53906 L p 0 .151 .689 r
F P
0 g
s
.55526 .60778 m .53977 .61251 L .53509 .59975 L p .731 .484 .555 r
F P
0 g
s
.52197 .60097 m .53509 .59975 L .53977 .61251 L p .781 .532 .56 r
F P
0 g
s
.53509 .59975 m .52197 .60097 L .51864 .59014 L p .792 .492 .48 r
F P
0 g
s
.51588 .44175 m .5113 .42755 L .5138 .42938 L p .919 .547 .3 r
F P
0 g
s
.5138 .42938 m .52029 .4441 L .51588 .44175 L p .919 .547 .3 r
F P
0 g
s
.62147 .57318 m .61007 .58866 L .59792 .57731 L p .614 .495 .694 r
F P
0 g
s
.59792 .57731 m .60768 .56325 L .62147 .57318 L p .614 .495 .694 r
F P
0 g
s
.49044 .55408 m .48723 .54248 L .48557 .54049 L p 0 .126 .671 r
F P
0 g
s
.50853 .5885 m .51864 .59014 L .52197 .60097 L p .856 .565 .495 r
F P
0 g
s
.51864 .59014 m .50853 .5885 L .50564 .57855 L p .874 .512 .359 r
F P
0 g
s
.4287 .37931 m .41408 .38961 L .42178 .3982 L p .756 .722 .821 r
F P
0 g
s
.42178 .3982 m .43538 .38888 L .4287 .37931 L p .756 .722 .821 r
F P
0 g
s
.41042 .41025 m .42178 .3982 L .41408 .38961 L p .802 .732 .787 r
F P
0 g
s
.44938 .49852 m .43664 .49131 L .43596 .49046 L p .025 .407 .857 r
F P
0 g
s
.43664 .49131 m .44938 .49852 L .45135 .50293 L p .01 .373 .84 r
F P
0 g
s
.40495 .4431 m .4037 .456 L .41083 .46009 L p .936 .678 .522 r
F P
0 g
s
.41337 .47087 m .41083 .46009 L .4037 .456 L p .9 .557 .387 r
F P
0 g
s
.41083 .46009 m .41337 .47087 L .41985 .47473 L p .914 .519 .225 r
F P
0 g
s
.40202 .42401 m .39665 .43816 L .40495 .4431 L p .891 .724 .668 r
F P
0 g
s
.4037 .456 m .40495 .4431 L .39665 .43816 L p .888 .658 .585 r
F P
0 g
s
.55168 .48417 m .564 .48949 L .56333 .48849 L p .834 .391 .175 r
F P
0 g
s
.56333 .48849 m .55059 .48241 L .55168 .48417 L p .834 .391 .175 r
F P
0 g
s
.41408 .38961 m .40161 .40251 L .41042 .41025 L p .802 .732 .787 r
F P
0 g
s
.40202 .42401 m .41042 .41025 L .40161 .40251 L p .833 .72 .74 r
F P
0 g
s
.5036 .41591 m .49742 .40843 L .50023 .41258 L p 0 0 .519 r
F P
0 g
s
.50211 .41533 m .50695 .42245 L .5036 .41591 L p 0 0 .519 r
F P
0 g
s
.50572 .42175 m .5036 .41591 L .50595 .42051 L p .805 .511 0 r
F P
0 g
s
.50595 .42051 m .50695 .42245 L p .50572 .42175 L .805 .511 0 r
F P
0 g
s
.50572 .42175 m .50555 .42398 L .50558 .42248 L p .737 .616 .049 r
F P
0 g
s
.5036 .41591 m .50572 .42175 L .50506 .41648 L p 0 0 .335 r
F P
0 g
s
.50587 .4104 m .50418 .40939 L .50572 .42175 L p .737 .616 .049 r
F P
0 g
s
.50558 .42248 m .50587 .4104 L p .50572 .42175 L .737 .616 .049 r
F P
0 g
s
.50506 .41648 m .50418 .40939 L p .5036 .41591 L 0 0 .335 r
F P
0 g
s
.50023 .41258 m .50211 .41533 L p .5036 .41591 L 0 0 .519 r
F P
0 g
s
.5798 .61435 m .56255 .62319 L .55526 .60778 L p .693 .493 .613 r
F P
0 g
s
.53977 .61251 m .55526 .60778 L .56255 .62319 L p .73 .52 .607 r
F P
0 g
s
.58343 .50334 m .5865 .50975 L .58005 .50524 L p .087 .47 .891 r
F P
0 g
s
.58005 .50524 m .57425 .49869 L .58343 .50334 L p .087 .47 .891 r
F P
0 g
s
.44829 .49697 m .43596 .49046 L .43506 .48944 L p .016 .411 .858 r
F P
0 g
s
.43596 .49046 m .44829 .49697 L .44938 .49852 L p .025 .407 .857 r
F P
0 g
s
.55327 .48621 m .5649 .49067 L .564 .48949 L p .811 .343 .113 r
F P
0 g
s
.564 .48949 m .55168 .48417 L .55327 .48621 L p .811 .343 .113 r
F P
0 g
s
.44437 .37204 m .4287 .37931 L .43538 .38888 L p .702 .691 .836 r
F P
0 g
s
.43538 .38888 m .45012 .38283 L .44437 .37204 L p .702 .691 .836 r
F P
0 g
s
.47322 .52222 m .47972 .53605 L .48411 .53906 L p .139 .318 .782 r
F P
0 g
s
.6191 .53549 m .61461 .54893 L .60304 .542 L p .565 .536 .782 r
F P
0 g
s
.60304 .542 m .60598 .52955 L .6191 .53549 L p .565 .536 .782 r
F P
0 g
s
.42567 .48249 m .41985 .47473 L .41337 .47087 L p .774 .266 0 r
F P
0 g
s
.63008 .55745 m .62147 .57318 L .60768 .56325 L p .609 .524 .733 r
F P
0 g
s
.60768 .56325 m .61461 .54893 L .63008 .55745 L p .609 .524 .733 r
F P
0 g
s
.40161 .40251 m .39188 .41699 L .40202 .42401 L p .833 .72 .74 r
F P
0 g
s
.39665 .43816 m .40202 .42401 L .39188 .41699 L p .846 .687 .685 r
F P
0 g
s
.47787 .37943 m .46468 .37993 L .46865 .3886 L p .54 .585 .849 r
F P
0 g
s
.46865 .3886 m .48123 .38969 L .47787 .37943 L p .54 .585 .849 r
F P
0 g
s
.5592 .49134 m .56805 .49403 L .5649 .49067 L p .729 .205 0 r
F P
0 g
s
.5649 .49067 m .55327 .48621 L .5592 .49134 L p .729 .205 0 r
F P
0 g
s
.43506 .48944 m .4467 .49516 L .44829 .49697 L p .016 .411 .858 r
F P
0 g
s
.60735 .51909 m .60598 .52955 L .5961 .52427 L p .504 .568 .854 r
F P
0 g
s
.5961 .52427 m .59561 .51443 L .60735 .51909 L p .504 .568 .854 r
F P
0 g
s
.49924 .575 m .50564 .57855 L .50853 .5885 L p .943 .606 .356 r
F P
0 g
s
.50564 .57855 m .49924 .575 L .49637 .56499 L p .89 .477 .068 r
F P
0 g
s
.49138 .39229 m .48123 .38969 L .48451 .39708 L p .347 .454 .827 r
F P
0 g
s
.48451 .39708 m .49429 .4017 L .49138 .39229 L p .347 .454 .827 r
F P
0 g
s
.51442 .44052 m .5105 .4268 L .5113 .42755 L p .935 .567 .279 r
F P
0 g
s
.5113 .42755 m .51588 .44175 L .51442 .44052 L p .935 .567 .279 r
F P
0 g
s
.46431 .51181 m .45135 .50293 L .44938 .49852 L p .216 .475 .888 r
F P
0 g
s
.49303 .5579 m .49109 .54935 L .48723 .54248 L p 0 .05 .615 r
F P
0 g
s
.62644 .60357 m .6101 .61955 L .59594 .60265 L p .657 .516 .68 r
F P
0 g
s
.59594 .60265 m .61007 .58866 L .62644 .60357 L p .657 .516 .68 r
F P
0 g
s
.5798 .61435 m .59594 .60265 L .6101 .61955 L p .676 .515 .66 r
F P
0 g
s
.6101 .61955 m .59164 .63309 L .5798 .61435 L p .676 .515 .66 r
F P
0 g
s
.56255 .62319 m .5798 .61435 L .59164 .63309 L p .7 .525 .648 r
F P
0 g
s
.51276 .43876 m .50955 .42583 L .5105 .4268 L p .94 .572 .248 r
F P
0 g
s
.5105 .4268 m .51442 .44052 L .51276 .43876 L p .94 .572 .248 r
F P
0 g
s
.56255 .62319 m .54544 .62932 L .53977 .61251 L p .73 .52 .607 r
F P
0 g
s
.52548 .61504 m .53977 .61251 L .54544 .62932 L p .765 .556 .614 r
F P
0 g
s
.53977 .61251 m .52548 .61504 L .52197 .60097 L p .781 .532 .56 r
F P
0 g
s
.53431 .4781 m .55059 .48241 L .54864 .47731 L p .855 .539 .453 r
F P
0 g
s
.54864 .47731 m .53568 .46896 L .53431 .4781 L p .855 .539 .453 r
F P
0 g
s
.45994 .36774 m .44437 .37204 L .45012 .38283 L p .644 .641 .832 r
F P
0 g
s
.45012 .38283 m .46468 .37993 L .45994 .36774 L p .644 .641 .832 r
F P
0 g
s
.51102 .601 m .52197 .60097 L .52548 .61504 L p .825 .587 .579 r
F P
0 g
s
.52197 .60097 m .51102 .601 L .50853 .5885 L p .856 .565 .495 r
F P
0 g
s
.63994 .58605 m .62644 .60357 L .61007 .58866 L p .645 .528 .706 r
F P
0 g
s
.61007 .58866 m .62147 .57318 L .63994 .58605 L p .645 .528 .706 r
F P
0 g
s
.50072 .40641 m .49429 .4017 L .49742 .40843 L p 0 .129 .666 r
F P
0 g
s
.49742 .40843 m .5036 .41591 L .50072 .40641 L p 0 .129 .666 r
F P
0 g
s
.50889 .4324 m .50695 .42245 L .50955 .42583 L p .93 .569 .152 r
F P
0 g
s
.50955 .42583 m .51276 .43876 L .50889 .4324 L p .93 .569 .152 r
F P
0 g
s
.59164 .63309 m .57205 .64364 L .56255 .62319 L p .7 .525 .648 r
F P
0 g
s
.54544 .62932 m .56255 .62319 L .57205 .64364 L p .726 .545 .646 r
F P
0 g
s
.51812 .45914 m .51588 .44175 L .52029 .4441 L p .882 .587 .482 r
F P
0 g
s
.52029 .4441 m .52678 .45853 L .51812 .45914 L p .882 .587 .482 r
F P
0 g
s
.39665 .43816 m .39377 .45138 L .4037 .456 L p .888 .658 .585 r
F P
0 g
s
.40423 .46681 m .4037 .456 L .39377 .45138 L p .862 .574 .5 r
F P
0 g
s
.4037 .456 m .40423 .46681 L .41337 .47087 L p .9 .557 .387 r
F P
0 g
s
.5948 .50736 m .59561 .51443 L .5865 .50975 L p .369 .61 .942 r
F P
0 g
s
.5865 .50975 m .58343 .50334 L .5948 .50736 L p .369 .61 .942 r
F P
0 g
s
.56805 .49403 m .5592 .49134 L .56946 .49642 L p .487 0 0 r
F P
0 g
s
.39188 .41699 m .38501 .4319 L .39665 .43816 L p .846 .687 .685 r
F P
0 g
s
.39377 .45138 m .39665 .43816 L .38501 .4319 L p .842 .639 .628 r
F P
0 g
s
.4319 .48655 m .44075 .49059 L p .44318 .49311 L 0 .401 .842 r
F P
0 g
s
.43047 .48603 m .44075 .49059 L p .43373 .48682 L 0 .344 .763 r
F P
0 g
s
.42567 .48249 m .43047 .48603 L p .43373 .48682 L 0 .344 .763 r
F P
0 g
s
.43047 .48603 m .41834 .48274 L p .42757 .48532 L .217 0 0 r
F P
0 g
s
.44075 .49059 m .43047 .48603 L p .43783 .48755 L .272 .652 .967 r
F P
0 g
s
.43221 .48662 m .43047 .48603 L p .42757 .48532 L .217 0 0 r
F P
0 g
s
.4463 .48932 m .44075 .49059 L p .43783 .48755 L .272 .652 .967 r
F P
0 g
s
.44075 .49059 m .4467 .49516 L p .44318 .49311 L 0 .401 .842 r
F P
0 g
s
.48411 .53906 m .48186 .5228 L .47322 .52222 L p .139 .318 .782 r
F P
0 g
s
.46921 .51666 m .47322 .52222 L .48186 .5228 L p .37 .476 .837 r
F P
0 g
s
.41966 .36584 m .40347 .37759 L .41408 .38961 L p .743 .682 .792 r
F P
0 g
s
.41408 .38961 m .4287 .37931 L .41966 .36584 L p .743 .682 .792 r
F P
0 g
s
.40161 .40251 m .41408 .38961 L .40347 .37759 L p .776 .69 .769 r
F P
0 g
s
.48186 .5228 m .48411 .53906 L .48557 .54049 L p .191 .291 .738 r
F P
0 g
s
.63605 .54244 m .63008 .55745 L .61461 .54893 L p .615 .56 .77 r
F P
0 g
s
.61461 .54893 m .6191 .53549 L .63605 .54244 L p .615 .56 .77 r
F P
0 g
s
.44938 .49852 m .46567 .50389 L .46431 .51181 L p .216 .475 .888 r
F P
0 g
s
.46921 .51666 m .46431 .51181 L .46567 .50389 L p .383 .501 .854 r
F P
0 g
s
.40347 .37759 m .38934 .39182 L .40161 .40251 L p .776 .69 .769 r
F P
0 g
s
.39188 .41699 m .40161 .40251 L .38934 .39182 L p .798 .681 .735 r
F P
0 g
s
.48186 .5228 m .477 .51075 L .46921 .51666 L p .37 .476 .837 r
F P
0 g
s
.46567 .50389 m .477 .51075 L .46921 .51666 L p .383 .501 .854 r
F P
0 g
s
.5012 .58699 m .50853 .5885 L .51102 .601 L p .908 .643 .525 r
F P
0 g
s
.50853 .5885 m .5012 .58699 L .49924 .575 L p .943 .606 .356 r
F P
0 g
s
.41646 .47842 m .41337 .47087 L .40423 .46681 L p .828 .404 .235 r
F P
0 g
s
.41337 .47087 m .41646 .47842 L .42567 .48249 L p .774 .266 0 r
F P
0 g
s
.49924 .575 m .49578 .57309 L .49425 .56046 L p .791 .476 0 r
F P
0 g
s
.49425 .56046 m .49578 .57309 L p .49487 .56386 L 0 0 .158 r
F P
0 g
s
.49637 .56499 m .49425 .56046 L p .49355 .55664 L 0 0 .468 r
F P
0 g
s
.49441 .55922 m .49425 .56046 L p .49487 .56386 L 0 0 .158 r
F P
0 g
s
.49425 .56046 m .49109 .54935 L p .49355 .55664 L 0 0 .468 r
F P
0 g
s
.65027 .56803 m .63994 .58605 L .62147 .57318 L p .643 .548 .732 r
F P
0 g
s
.62147 .57318 m .63008 .55745 L .65027 .56803 L p .643 .548 .732 r
F P
0 g
s
.62188 .52381 m .6191 .53549 L .60598 .52955 L p .582 .592 .828 r
F P
0 g
s
.60598 .52955 m .60735 .51909 L .62188 .52381 L p .582 .592 .828 r
F P
0 g
s
.43699 .35715 m .41966 .36584 L .4287 .37931 L p .703 .658 .802 r
F P
0 g
s
.4287 .37931 m .44437 .37204 L .43699 .35715 L p .703 .658 .802 r
F P
0 g
s
.62892 .64185 m .60726 .65775 L .59164 .63309 L p .688 .541 .681 r
F P
0 g
s
.59164 .63309 m .6101 .61955 L .62892 .64185 L p .688 .541 .681 r
F P
0 g
s
.57205 .64364 m .59164 .63309 L .60726 .65775 L p .704 .548 .673 r
F P
0 g
s
.64813 .62311 m .62892 .64185 L .6101 .61955 L p .675 .542 .695 r
F P
0 g
s
.6101 .61955 m .62644 .60357 L .64813 .62311 L p .675 .542 .695 r
F P
0 g
s
.57205 .64364 m .55245 .65103 L .54544 .62932 L p .726 .545 .646 r
F P
0 g
s
.52942 .63299 m .54544 .62932 L .55245 .65103 L p .749 .569 .651 r
F P
0 g
s
.54544 .62932 m .52942 .63299 L .52548 .61504 L p .765 .556 .614 r
F P
0 g
s
.4862 .5253 m .48557 .54049 L .48723 .54248 L p .21 .279 .716 r
F P
0 g
s
.48557 .54049 m .4862 .5253 L .48186 .5228 L p .191 .291 .738 r
F P
0 g
s
.46567 .50389 m .44938 .49852 L .44829 .49697 L p .335 .58 .932 r
F P
0 g
s
.48887 .38021 m .47787 .37943 L .48123 .38969 L p .461 .488 .8 r
F P
0 g
s
.48123 .38969 m .49138 .39229 L .48887 .38021 L p .461 .488 .8 r
F P
0 g
s
.47431 .3658 m .45994 .36774 L .46468 .37993 L p .589 .581 .811 r
F P
0 g
s
.46468 .37993 m .47787 .37943 L .47431 .3658 L p .589 .581 .811 r
F P
0 g
s
.52297 .47155 m .53431 .4781 L .53568 .46896 L p .85 .567 .507 r
F P
0 g
s
.53568 .46896 m .53078 .46416 L .52297 .47155 L p .85 .567 .507 r
F P
0 g
s
.51318 .6162 m .52548 .61504 L .52942 .63299 L p .794 .594 .632 r
F P
0 g
s
.52548 .61504 m .51318 .6162 L .51102 .601 L p .825 .587 .579 r
F P
0 g
s
.38934 .39182 m .37798 .40771 L .39188 .41699 L p .798 .681 .735 r
F P
0 g
s
.38501 .4319 m .39188 .41699 L .37798 .40771 L p .808 .657 .696 r
F P
0 g
s
.50695 .42245 m .50889 .4324 L .50572 .42175 L p .805 .511 0 r
F P
0 g
s
.52297 .47155 m .51812 .45914 L .52678 .45853 L p .858 .58 .515 r
F P
0 g
s
.52678 .45853 m .53078 .46416 L .52297 .47155 L p .858 .58 .515 r
F P
0 g
s
.53588 .48295 m .55168 .48417 L .55059 .48241 L p .829 .507 .445 r
F P
0 g
s
.55059 .48241 m .53431 .4781 L .53588 .48295 L p .829 .507 .445 r
F P
0 g
s
.60726 .65775 m .58436 .67028 L .57205 .64364 L p .704 .548 .673 r
F P
0 g
s
.55245 .65103 m .57205 .64364 L .58436 .67028 L p .721 .561 .672 r
F P
0 g
s
.66418 .60264 m .64813 .62311 L .62644 .60357 L p .668 .55 .711 r
F P
0 g
s
.62644 .60357 m .63994 .58605 L .66418 .60264 L p .668 .55 .711 r
F P
0 g
s
.49029 .53063 m .48723 .54248 L .49109 .54935 L p .186 .235 .681 r
F P
0 g
s
.48723 .54248 m .49029 .53063 L .4862 .5253 L p .21 .279 .716 r
F P
0 g
s
.46408 .49947 m .44829 .49697 L .4467 .49516 L p .382 .619 .945 r
F P
0 g
s
.44829 .49697 m .46408 .49947 L .46567 .50389 L p .335 .58 .932 r
F P
0 g
s
.58157 .50007 m .58343 .50334 L .57425 .49869 L p 0 .481 .799 r
F P
0 g
s
.60805 .51093 m .60735 .51909 L .59561 .51443 L p .525 .647 .911 r
F P
0 g
s
.59561 .51443 m .5948 .50736 L .60805 .51093 L p .525 .647 .911 r
F P
0 g
s
.49874 .39479 m .49138 .39229 L .49429 .4017 L p .204 .28 .72 r
F P
0 g
s
.49429 .4017 m .50072 .40641 L .49874 .39479 L p .204 .28 .72 r
F P
0 g
s
.4542 .35136 m .43699 .35715 L .44437 .37204 L p .662 .622 .798 r
F P
0 g
s
.44437 .37204 m .45994 .36774 L .4542 .35136 L p .662 .622 .798 r
F P
0 g
s
.54032 .48799 m .55327 .48621 L .55168 .48417 L p .798 .433 .366 r
F P
0 g
s
.55168 .48417 m .53588 .48295 L .54032 .48799 L p .798 .433 .366 r
F P
0 g
s
.50246 .60072 m .51102 .601 L .51318 .6162 L p .856 .641 .61 r
F P
0 g
s
.51102 .601 m .50246 .60072 L .5012 .58699 L p .908 .643 .525 r
F P
0 g
s
.51378 .45707 m .51442 .44052 L .51588 .44175 L p .896 .624 .517 r
F P
0 g
s
.51588 .44175 m .51812 .45914 L .51378 .45707 L p .896 .624 .517 r
F P
0 g
s
.43047 .48603 m .42567 .48249 L .41646 .47842 L p .502 0 0 r
F P
0 g
s
.38501 .4319 m .38059 .44602 L .39377 .45138 L p .842 .639 .628 r
F P
0 g
s
.39244 .46269 m .39377 .45138 L .38059 .44602 L p .821 .581 .576 r
F P
0 g
s
.39377 .45138 m .39244 .46269 L .40423 .46681 L p .862 .574 .5 r
F P
0 g
s
.65771 .55081 m .65027 .56803 L .63008 .55745 L p .648 .573 .757 r
F P
0 g
s
.63008 .55745 m .63605 .54244 L .65771 .55081 L p .648 .573 .757 r
F P
0 g
s
.58436 .67028 m .56147 .67919 L .55245 .65103 L p .721 .561 .672 r
F P
0 g
s
.53407 .65573 m .55245 .65103 L .56147 .67919 L p .736 .577 .677 r
F P
0 g
s
.55245 .65103 m .53407 .65573 L .52942 .63299 L p .749 .569 .651 r
F P
0 g
s
.65366 .67101 m .62783 .69008 L .60726 .65775 L p .696 .559 .696 r
F P
0 g
s
.60726 .65775 m .62892 .64185 L .65366 .67101 L p .696 .559 .696 r
F P
0 g
s
.58436 .67028 m .60726 .65775 L .62783 .69008 L p .706 .563 .691 r
F P
0 g
s
.49578 .57309 m .49924 .575 L .5012 .58699 L p .984 .7 .369 r
F P
0 g
s
.67671 .6487 m .65366 .67101 L .62892 .64185 L p .688 .559 .704 r
F P
0 g
s
.62892 .64185 m .64813 .62311 L .67671 .6487 L p .688 .559 .704 r
F P
0 g
s
.67661 .58159 m .66418 .60264 L .63994 .58605 L p .667 .563 .729 r
F P
0 g
s
.63994 .58605 m .65027 .56803 L .67661 .58159 L p .667 .563 .729 r
F P
0 g
s
.51542 .63493 m .52942 .63299 L .53407 .65573 L p .768 .595 .664 r
F P
0 g
s
.52942 .63299 m .51542 .63493 L .51318 .6162 L p .794 .594 .632 r
F P
0 g
s
.37798 .40771 m .36944 .42396 L .38501 .4319 L p .808 .657 .696 r
F P
0 g
s
.38059 .44602 m .38501 .4319 L .36944 .42396 L p .803 .623 .657 r
F P
0 g
s
.45963 .49482 m .4467 .49516 L .44075 .49059 L p .397 .654 .962 r
F P
0 g
s
.4467 .49516 m .45963 .49482 L .46408 .49947 L p .382 .619 .945 r
F P
0 g
s
.62783 .69008 m .60047 .70504 L .58436 .67028 L p .706 .563 .691 r
F P
0 g
s
.56147 .67919 m .58436 .67028 L .60047 .70504 L p .717 .571 .69 r
F P
0 g
s
.63996 .52913 m .63605 .54244 L .6191 .53549 L p .629 .599 .8 r
F P
0 g
s
.6191 .53549 m .62188 .52381 L .63996 .52913 L p .629 .599 .8 r
F P
0 g
s
.55363 .49392 m .5592 .49134 L .55327 .48621 L p .704 .261 .196 r
F P
0 g
s
.55327 .48621 m .54032 .48799 L .55363 .49392 L p .704 .261 .196 r
F P
0 g
s
.40508 .47486 m .40423 .46681 L .39244 .46269 L p .816 .484 .427 r
F P
0 g
s
.40423 .46681 m .40508 .47486 L .41646 .47842 L p .828 .404 .235 r
F P
0 g
s
.50967 .45211 m .51276 .43876 L .51442 .44052 L p .935 .671 .512 r
F P
0 g
s
.51442 .44052 m .51378 .45707 L .50967 .45211 L p .935 .671 .512 r
F P
0 g
s
.69595 .62421 m .67671 .6487 L .64813 .62311 L p .683 .564 .715 r
F P
0 g
s
.64813 .62311 m .66418 .60264 L .69595 .62421 L p .683 .564 .715 r
F P
0 g
s
.40766 .34753 m .38914 .36118 L .40347 .37759 L p .732 .651 .769 r
F P
0 g
s
.40347 .37759 m .41966 .36584 L .40766 .34753 L p .732 .651 .769 r
F P
0 g
s
.38934 .39182 m .40347 .37759 L .38914 .36118 L p .755 .657 .753 r
F P
0 g
s
.38914 .36118 m .3728 .37743 L .38934 .39182 L p .755 .657 .753 r
F P
0 g
s
.37798 .40771 m .38934 .39182 L .3728 .37743 L p .771 .651 .73 r
F P
0 g
s
.68634 .70942 m .65497 .73258 L .62783 .69008 L p .701 .571 .705 r
F P
0 g
s
.62783 .69008 m .65366 .67101 L .68634 .70942 L p .701 .571 .705 r
F P
0 g
s
.60047 .70504 m .62783 .69008 L .65497 .73258 L p .707 .573 .702 r
F P
0 g
s
.60047 .70504 m .57323 .71583 L .56147 .67919 L p .717 .571 .69 r
F P
0 g
s
.53999 .68493 m .56147 .67919 L .57323 .71583 L p .726 .582 .693 r
F P
0 g
s
.56147 .67919 m .53999 .68493 L .53407 .65573 L p .736 .577 .677 r
F P
0 g
s
.50328 .61661 m .51318 .6162 L .51542 .63493 L p .813 .63 .655 r
F P
0 g
s
.51318 .6162 m .50328 .61661 L .50246 .60072 L p .856 .641 .61 r
F P
0 g
s
.65497 .73258 m .6218 .75079 L .60047 .70504 L p .707 .573 .702 r
F P
0 g
s
.57323 .71583 m .60047 .70504 L .6218 .75079 L p .713 .578 .702 r
F P
0 g
s
.49386 .54484 m .49109 .54935 L .49425 .56046 L p 0 .056 .575 r
F P
0 g
s
.49109 .54935 m .49386 .54484 L .49029 .53063 L p .186 .235 .681 r
F P
0 g
s
.50418 .40939 m .50072 .40641 L .5036 .41591 L p 0 0 .335 r
F P
0 g
s
.71442 .68235 m .68634 .70942 L .65366 .67101 L p .696 .571 .71 r
F P
0 g
s
.65366 .67101 m .67671 .6487 L .71442 .68235 L p .696 .571 .71 r
F P
0 g
s
.51794 .65829 m .53407 .65573 L .53999 .68493 L p .748 .594 .685 r
F P
0 g
s
.53407 .65573 m .51794 .65829 L .51542 .63493 L p .768 .595 .664 r
F P
0 g
s
.6218 .75079 m .58869 .76381 L .57323 .71583 L p .713 .578 .702 r
F P
0 g
s
.48668 .36529 m .47431 .3658 L .47787 .37943 L p .54 .515 .777 r
F P
0 g
s
.47787 .37943 m .48887 .38021 L .48668 .36529 L p .54 .515 .777 r
F P
0 g
s
.62357 .51436 m .62188 .52381 L .60735 .51909 L p .605 .645 .863 r
F P
0 g
s
.60735 .51909 m .60805 .51093 L .62357 .51436 L p .605 .645 .863 r
F P
0 g
s
.42735 .33705 m .40766 .34753 L .41966 .36584 L p .704 .633 .775 r
F P
0 g
s
.41966 .36584 m .43699 .35715 L .42735 .33705 L p .704 .633 .775 r
F P
0 g
s
.5061 .43826 m .50889 .4324 L .51276 .43876 L p .99 .762 .498 r
F P
0 g
s
.51276 .43876 m .50967 .45211 L .5061 .43826 L p .99 .762 .498 r
F P
0 g
s
.58869 .76381 m .55765 .77213 L .54765 .72271 L p .718 .584 .704 r
F P
0 g
s
.54765 .72271 m .57323 .71583 L .58869 .76381 L p .718 .584 .704 r
F P
0 g
s
.57323 .71583 m .54765 .72271 L .53999 .68493 L p .726 .582 .693 r
F P
0 g
s
.59451 .50279 m .5948 .50736 L .58343 .50334 L p .347 .696 .983 r
F P
0 g
s
.58343 .50334 m .58157 .50007 L .59451 .50279 L p .347 .696 .983 r
F P
0 g
s
.47032 .34813 m .4542 .35136 L .45994 .36774 L p .625 .579 .783 r
F P
0 g
s
.45994 .36774 m .47431 .3658 L .47032 .34813 L p .625 .579 .783 r
F P
0 g
s
.49632 .58633 m .5012 .58699 L .50246 .60072 L p .94 .714 .569 r
F P
0 g
s
.5012 .58699 m .49632 .58633 L .49578 .57309 L p .984 .7 .369 r
F P
0 g
s
.3728 .37743 m .35935 .39536 L .37798 .40771 L p .771 .651 .73 r
F P
0 g
s
.36944 .42396 m .37798 .40771 L .35935 .39536 L p .776 .634 .704 r
F P
0 g
s
.68565 .56141 m .67661 .58159 L .65027 .56803 L p .671 .58 .745 r
F P
0 g
s
.65027 .56803 m .65771 .55081 L .68565 .56141 L p .671 .58 .745 r
F P
0 g
s
.71103 .59916 m .69595 .62421 L .66418 .60264 L p .683 .573 .726 r
F P
0 g
s
.66418 .60264 m .67661 .58159 L .71103 .59916 L p .683 .573 .726 r
F P
0 g
s
.55765 .77213 m .5302 .77655 L .52496 .72636 L p .722 .59 .707 r
F P
0 g
s
.52496 .72636 m .54765 .72271 L .55765 .77213 L p .722 .59 .707 r
F P
0 g
s
.73789 .65268 m .71442 .68235 L .67671 .6487 L p .693 .574 .717 r
F P
0 g
s
.67671 .6487 m .69595 .62421 L .73789 .65268 L p .693 .574 .717 r
F P
0 g
s
.52096 .68802 m .53999 .68493 L .54765 .72271 L p .732 .592 .699 r
F P
0 g
s
.53999 .68493 m .52096 .68802 L .51794 .65829 L p .748 .594 .685 r
F P
0 g
s
.477 .51075 m .48186 .5228 L .4862 .5253 L p .373 .437 .799 r
F P
0 g
s
.49747 .38128 m .48887 .38021 L .49138 .39229 L p .389 .386 .735 r
F P
0 g
s
.49138 .39229 m .49874 .39479 L .49747 .38128 L p .389 .386 .735 r
F P
0 g
s
.41834 .48274 m .41646 .47842 L .40508 .47486 L p .723 .238 .094 r
F P
0 g
s
.41646 .47842 m .41834 .48274 L .43047 .48603 L p .502 0 0 r
F P
0 g
s
.50397 .63567 m .51542 .63493 L .51794 .65829 L p .779 .618 .681 r
F P
0 g
s
.51542 .63493 m .50397 .63567 L .50328 .61661 L p .813 .63 .655 r
F P
0 g
s
.66265 .53544 m .65771 .55081 L .63605 .54244 L p .659 .598 .776 r
F P
0 g
s
.63605 .54244 m .63996 .52913 L .66265 .53544 L p .659 .598 .776 r
F P
0 g
s
.54765 .72271 m .52496 .72636 L .52096 .68802 L p .732 .592 .699 r
F P
0 g
s
.36944 .42396 m .36355 .43957 L .38059 .44602 L p .803 .623 .657 r
F P
0 g
s
.37786 .45841 m .38059 .44602 L .36355 .43957 L p .788 .584 .625 r
F P
0 g
s
.38059 .44602 m .37786 .45841 L .39244 .46269 L p .821 .581 .576 r
F P
0 g
s
.5302 .77655 m .50776 .77816 L .50641 .72782 L p .725 .595 .711 r
F P
0 g
s
.50641 .72782 m .52496 .72636 L .5302 .77655 L p .725 .595 .711 r
F P
0 g
s
.56772 .49681 m .56946 .49642 L .5592 .49134 L p .578 .064 0 r
F P
0 g
s
.5592 .49134 m .55363 .49392 L .56772 .49681 L p .578 .064 0 r
F P
0 g
s
.477 .51075 m .46567 .50389 L .46408 .49947 L p .436 .561 .882 r
F P
0 g
s
.44075 .49059 m .4463 .48932 L .45963 .49482 L p .397 .654 .962 r
F P
0 g
s
.39179 .47166 m .39244 .46269 L .37786 .45841 L p .789 .524 .536 r
F P
0 g
s
.39244 .46269 m .39179 .47166 L .40508 .47486 L p .816 .484 .427 r
F P
0 g
s
.44708 .32986 m .42735 .33705 L .43699 .35715 L p .676 .609 .772 r
F P
0 g
s
.43699 .35715 m .4542 .35136 L .44708 .32986 L p .676 .609 .772 r
F P
0 g
s
.49634 .6006 m .50246 .60072 L .50328 .61661 L p .874 .686 .645 r
F P
0 g
s
.50246 .60072 m .49634 .6006 L .49632 .58633 L p .94 .714 .569 r
F P
0 g
s
.50776 .77816 m .49105 .77828 L .49265 .72793 L p .726 .599 .714 r
F P
0 g
s
.49265 .72793 m .50641 .72782 L .50776 .77816 L p .726 .599 .714 r
F P
0 g
s
.50461 .65934 m .51794 .65829 L .52096 .68802 L p .754 .608 .696 r
F P
0 g
s
.51794 .65829 m .50461 .65934 L .50397 .63567 L p .779 .618 .681 r
F P
0 g
s
.35935 .39536 m .3491 .41385 L .36944 .42396 L p .776 .634 .704 r
F P
0 g
s
.36355 .43957 m .36944 .42396 L .3491 .41385 L p .773 .611 .678 r
F P
0 g
s
.52496 .72636 m .50641 .72782 L .50539 .68928 L p .737 .6 .705 r
F P
0 g
s
.50539 .68928 m .52096 .68802 L .52496 .72636 L p .737 .6 .705 r
F P
0 g
s
.75622 .62217 m .73789 .65268 L .69595 .62421 L p .693 .579 .723 r
F P
0 g
s
.69595 .62421 m .71103 .59916 L .75622 .62217 L p .693 .579 .723 r
F P
0 g
s
.49425 .56046 m .49441 .55922 L .49386 .54484 L p 0 .056 .575 r
F P
0 g
s
.52096 .68802 m .50539 .68928 L .50461 .65934 L p .754 .608 .696 r
F P
0 g
s
.4862 .5253 m .49996 .49271 L p .477 .51075 L .373 .437 .799 r
F P
0 g
s
.4862 .5253 m .49029 .53063 L p .50028 .49224 L .507 .424 .696 r
F P
0 g
s
.50438 .53305 m .49763 .5278 L .50041 .49247 L p .511 .403 .668 r
F P
0 g
s
.53588 .48295 m .53431 .4781 L p .50017 .49204 L .783 .611 .668 r
F P
0 g
s
.50017 .49204 m .50018 .49205 L .53588 .48295 L .783 .611 .668 r
F
.50012 .49206 m .50013 .49207 L .53588 .48295 L F
.5002 .49214 m .53588 .48295 L p .50007 .49208 L F P
0 g
s
.51812 .45914 m .52297 .47155 L .5042 .48814 L p .759 .569 .64 r
F P
0 g
s
.45963 .49482 m .46405 .48859 L .4685 .48894 L p .65 .688 .873 r
F P
0 g
s
.46494 .48961 m .46127 .4827 L .46406 .48051 L p .647 .724 .905 r
F P
0 g
s
.46406 .48051 m .46635 .47871 L p .46571 .48365 L .647 .724 .905 r
F P
0 g
s
.46571 .48365 m .46494 .48961 L .46406 .48051 L .647 .724 .905 r
F
.4685 .48894 m .49889 .49132 L p .47107 .4938 L .65 .688 .873 r
F P
0 g
s
.47107 .4938 m .45963 .49482 L .4685 .48894 L .65 .688 .873 r
F
.53431 .4781 m .5042 .48814 L .50015 .49172 L .783 .611 .668 r
F
.477 .51075 m .49996 .49271 L .49986 .49201 L .373 .437 .799 r
F
.49986 .49197 m .49983 .49199 L p .49986 .49201 L F P
0 g
s
.51378 .45707 m .49979 .49149 L p .50233 .45592 L .89 .75 .7 r
F P
0 g
s
.49983 .49199 m .477 .51075 L p .49983 .49203 L .373 .437 .799 r
F P
0 g
s
.46408 .49947 m .49964 .49164 L p .477 .51075 L .436 .561 .882 r
F P
0 g
s
.49986 .49197 m .49986 .49197 L .49997 .49188 L .373 .437 .799 r
F
.51812 .45914 m .5042 .48814 L .49997 .49188 L .759 .569 .64 r
F
.49997 .49188 m .49986 .49197 L p .49997 .49188 L .373 .437 .799 r
F P
0 g
s
.49982 .49168 m .49979 .49174 L .49979 .49149 L .759 .569 .64 r
F
.49986 .49197 m .477 .51075 L p .49979 .49174 L .436 .561 .882 r
F P
0 g
s
.46635 .47871 m .49822 .49124 L p .46494 .48961 L .647 .724 .905 r
F P
0 g
s
.49945 .49233 m .49974 .49161 L p .49979 .49174 L .759 .569 .64 r
F P
0 g
s
.477 .51075 m .49964 .49164 L .49979 .49174 L .436 .561 .882 r
F
.49997 .49188 m .49986 .49197 L p .49979 .49174 L F P
0 g
s
.49979 .49174 m .49997 .49188 L .49945 .49233 L .759 .569 .64 r
F
.49889 .49132 m .49953 .49137 L p .49954 .49153 L .65 .688 .873 r
F P
0 g
s
.51812 .45914 m .49997 .49188 L .49982 .49168 L .759 .569 .64 r
F
.49966 .48967 m .50233 .45592 L p .49979 .49149 L .89 .75 .7 r
F P
0 g
s
.51378 .45707 m .51812 .45914 L p .49982 .49168 L .759 .569 .64 r
F P
0 g
s
.49979 .49149 m .51378 .45707 L p .49982 .49168 L .759 .569 .64 r
F P
0 g
s
.49953 .49137 m .50049 .49145 L p .49968 .49152 L .65 .688 .873 r
F P
0 g
s
.49968 .49152 m .49954 .49153 L .49953 .49137 L .65 .688 .873 r
F
.49979 .49149 m .49976 .49159 L p .49966 .48967 L .89 .75 .7 r
F P
0 g
s
.49973 .49162 m .46408 .49947 L p .49954 .49153 L .65 .688 .873 r
F P
0 g
s
.49976 .49159 m .49945 .49233 L .49953 .49137 L p .89 .75 .7 r
F P
0 g
s
.49953 .49137 m .49966 .48967 L p .49976 .49159 L .89 .75 .7 r
F P
0 g
s
.49954 .49153 m .45963 .49482 L .49889 .49132 L .65 .688 .873 r
F
.46408 .49947 m .45963 .49482 L p .49954 .49153 L F P
0 g
s
.49822 .49124 m .4986 .49139 L p .49945 .49233 L .647 .724 .905 r
F P
0 g
s
.49983 .49203 m .49986 .49201 L .49983 .49199 L .373 .437 .799 r
F
.49983 .49203 m .49983 .49199 L .49983 .49199 L F
.53588 .48295 m .50023 .49213 L p .53589 .49519 L .695 .407 .482 r
F P
0 g
s
.50023 .49213 m .5002 .49214 L p .50023 .49215 L .695 .407 .482 r
F P
0 g
s
.50023 .49213 m .50023 .49215 L .53589 .49519 L .695 .407 .482 r
F
.50023 .49215 m .50138 .49249 L .50162 .49226 L F
.5042 .48814 m .49997 .49188 L p .49997 .49188 L .759 .569 .64 r
F P
0 g
s
.53431 .4781 m .50015 .49172 L .5002 .49173 L .783 .611 .668 r
F
.53431 .4781 m .50008 .49178 L .50013 .49181 L F
.5042 .48814 m .49997 .49188 L p .49997 .49188 L F P
0 g
s
.53431 .4781 m .49997 .49188 L .50007 .49208 L .783 .611 .668 r
F
.50233 .45592 m .50967 .45211 L .51378 .45707 L p .89 .75 .7 r
F P
0 g
s
.50138 .49249 m .53589 .49519 L p .50162 .49226 L .695 .407 .482 r
F P
0 g
s
.53589 .49519 m .54032 .48799 L .53588 .48295 L p .695 .407 .482 r
F P
0 g
s
.54032 .48799 m .53589 .49519 L .55316 .49656 L p .688 .375 .441 r
F P
0 g
s
.54058 .50221 m .53692 .49432 L .50145 .49152 L p .688 .431 .529 r
F P
0 g
s
.50145 .49152 m .50049 .49145 L p .50128 .49166 L .688 .431 .529 r
F P
0 g
s
.50138 .49249 m .50145 .49152 L p .50128 .49166 L .891 .75 .7 r
F P
0 g
s
.50049 .49145 m .5012 .49176 L p .50128 .49166 L .688 .431 .529 r
F P
0 g
s
.50119 .49173 m .5012 .49176 L p .50128 .49166 L .891 .75 .7 r
F P
0 g
s
.5012 .49176 m .50138 .49249 L p .50128 .49166 L .891 .75 .7 r
F P
0 g
s
.5355 .50658 m .54058 .50221 L p .50128 .49166 L .688 .431 .529 r
F P
0 g
s
.5012 .49176 m .5355 .50658 L p .50128 .49166 L .688 .431 .529 r
F P
0 g
s
.50128 .49166 m .54058 .50221 L .50145 .49152 L .688 .431 .529 r
F
.49256 .45634 m .50119 .49173 L p .50424 .45607 L .891 .75 .7 r
F P
0 g
s
.50145 .49152 m .50424 .45607 L p .50119 .49173 L .891 .75 .7 r
F P
0 g
s
.50096 .49245 m .50138 .49249 L p .50023 .49215 L .695 .407 .482 r
F P
0 g
s
.5002 .49214 m .50024 .49216 L .50023 .49215 L .695 .407 .482 r
F
.50024 .49216 m .50096 .49245 L .50023 .49215 L F
.50041 .49247 m .50041 .49241 L p .50062 .49285 L .511 .403 .668 r
F P
0 g
s
.50041 .49241 m .50049 .49145 L p .50057 .49228 L .511 .403 .668 r
F P
0 g
s
.50041 .49241 m .50028 .49224 L .50039 .49243 L .507 .424 .696 r
F
.50029 .49223 m .50028 .49224 L .50041 .49241 L F
.50028 .49224 m .49029 .53063 L .50041 .49247 L F
.5002 .49214 m .4862 .5253 L p .50028 .49224 L F P
0 g
s
.49996 .49271 m .5002 .49214 L p .49986 .49197 L .373 .437 .799 r
F P
0 g
s
.5002 .49214 m .49945 .49233 L p .50096 .49245 L .695 .407 .482 r
F P
0 g
s
.49945 .49233 m .49945 .49233 L .50026 .4924 L p .695 .407 .482 r
F P
0 g
s
.50026 .4924 m .50096 .49245 L p .49945 .49233 L .695 .407 .482 r
F P
0 g
s
.50057 .49227 m .50138 .49249 L .50041 .49241 L .647 .724 .905 r
F
.50138 .49249 m .50057 .49242 L p .50138 .49249 L F P
0 g
s
.50057 .49242 m .50041 .49241 L p .50138 .49249 L .647 .724 .905 r
F P
0 g
s
.50049 .49145 m .50067 .49221 L p .50057 .49227 L .511 .403 .668 r
F P
0 g
s
.50064 .4922 m .50067 .49221 L p .50057 .49227 L .647 .724 .905 r
F P
0 g
s
.50067 .49221 m .50138 .49249 L p .50057 .49227 L .647 .724 .905 r
F P
0 g
s
.5093 .5289 m .50438 .53305 L p .50057 .49227 L .511 .403 .668 r
F P
0 g
s
.50067 .49221 m .5093 .5289 L p .50057 .49227 L .511 .403 .668 r
F P
0 g
s
.50057 .49228 m .50058 .49241 L .50046 .49241 L .511 .403 .668 r
F
.50057 .49228 m .50046 .49241 L .50041 .49241 L F
.50041 .49241 m .50049 .49145 L p .50029 .49223 L .507 .424 .696 r
F P
0 g
s
.49974 .49161 m .49979 .49149 L p .49979 .49174 L .759 .569 .64 r
F P
0 g
s
.49982 .49168 m .49997 .49188 L .49979 .49174 L .759 .569 .64 r
F
.5002 .49173 m .50015 .49172 L .50008 .49178 L .783 .611 .668 r
F
.50049 .49145 m .49997 .49188 L p .49997 .49188 L .373 .437 .799 r
F P
0 g
s
.49964 .49164 m .50049 .49145 L .49997 .49188 L p .436 .561 .882 r
F P
0 g
s
.50013 .49181 m .50008 .49178 L .49997 .49188 L .783 .611 .668 r
F
.50049 .49145 m .49973 .49162 L p .49954 .49153 L .65 .688 .873 r
F P
0 g
s
.50049 .49145 m .5002 .49214 L p .50028 .49224 L .507 .424 .696 r
F P
0 g
s
.50017 .49204 m .50012 .49206 L .50018 .49205 L .783 .611 .668 r
F
.50012 .49206 m .50007 .49208 L .50013 .49207 L F
.5002 .49214 m .50049 .49145 L p .49986 .49197 L .373 .437 .799 r
F P
0 g
s
.5093 .5289 m .50067 .49221 L p .52081 .51594 L .439 .224 .489 r
F P
0 g
s
.50067 .49221 m .50049 .49145 L .50093 .49198 L p .439 .224 .489 r
F P
0 g
s
.46854 .47448 m .48104 .46945 L .50093 .49198 L p .775 .689 .769 r
F P
0 g
s
.50093 .49198 m .50138 .49249 L p .5008 .49217 L .775 .689 .769 r
F P
0 g
s
.5008 .49217 m .50067 .49221 L .50093 .49198 L .439 .224 .489 r
F
.46854 .47448 m .50093 .49198 L .5008 .49217 L .775 .689 .769 r
F
.50093 .49198 m .50103 .4921 L p .5008 .49217 L .439 .224 .489 r
F P
0 g
s
.50138 .49249 m .50067 .49221 L p .5008 .49217 L .775 .689 .769 r
F P
0 g
s
.50103 .4921 m .52081 .51594 L p .50067 .49221 L .439 .224 .489 r
F P
0 g
s
.50071 .49212 m .5008 .49217 L .50064 .4922 L .775 .689 .769 r
F
.50067 .49221 m .50064 .4922 L p .5008 .49217 L F P
0 g
s
.46635 .47871 m .46854 .47448 L p .50071 .49212 L .775 .689 .769 r
F P
0 g
s
.49997 .49188 m .49993 .49191 L p .50001 .49195 L .783 .611 .668 r
F P
0 g
s
.49993 .49191 m .49945 .49233 L p .50001 .49195 L .783 .611 .668 r
F P
0 g
s
.50007 .49208 m .50001 .49195 L .49945 .49233 L .783 .611 .668 r
F
.49945 .49233 m .49997 .49188 L .49945 .49233 L .759 .569 .64 r
F
.49997 .49188 m .49945 .49233 L p .49997 .49188 L F P
0 g
s
.50064 .4922 m .46635 .47871 L p .50071 .49212 L .775 .689 .769 r
F P
0 g
s
.5355 .50658 m .5013 .4918 L p .52081 .51594 L .519 .239 .43 r
F P
0 g
s
.5012 .49176 m .50049 .49145 L p .50114 .49188 L .519 .239 .43 r
F P
0 g
s
.49256 .45634 m .48781 .45803 L p .50114 .49188 L .746 .686 .794 r
F P
0 g
s
.50138 .49249 m .5012 .49176 L p .50114 .49188 L .746 .686 .794 r
F P
0 g
s
.5012 .49176 m .49256 .45634 L p .50114 .49188 L .746 .686 .794 r
F P
0 g
s
.50049 .49145 m .50093 .49198 L p .50114 .49188 L .519 .239 .43 r
F P
0 g
s
.5013 .4918 m .5012 .49176 L p .50114 .49188 L .519 .239 .43 r
F P
0 g
s
.50093 .49198 m .50138 .49249 L p .50114 .49188 L .746 .686 .794 r
F P
0 g
s
.50093 .49198 m .52081 .51594 L p .5013 .4918 L .519 .239 .43 r
F P
0 g
s
.50078 .49181 m .50093 .49198 L p .50093 .49136 L .746 .686 .794 r
F P
0 g
s
.50093 .49136 m .50093 .49198 L .50114 .49188 L .746 .686 .794 r
F
.48781 .45803 m .48104 .46945 L .50078 .49181 L p F P
0 g
s
.48781 .45803 m .50078 .49181 L .50093 .49136 L .746 .686 .794 r
F
.50058 .49241 m .50061 .49269 L .50052 .49257 L .511 .403 .668 r
F
.50058 .49241 m .50052 .49257 L .50041 .49241 L F
.50061 .49269 m .50062 .49285 L .50041 .49241 L F
.49945 .49233 m .5002 .49214 L p .50007 .49208 L .783 .611 .668 r
F P
0 g
s
.4986 .49139 m .50064 .4922 L p .49945 .49233 L .647 .724 .905 r
F P
0 g
s
.50041 .49241 m .49945 .49233 L p .50064 .4922 L .647 .724 .905 r
F P
0 g
s
.50041 .49247 m .50041 .49241 L p .50039 .49243 L .507 .424 .696 r
F P
0 g
s
.50041 .49241 m .50041 .49241 L p .50039 .49243 L .507 .424 .696 r
F P
0 g
s
.49945 .49233 m .49945 .49233 L p .4986 .49139 L .647 .724 .905 r
F P
0 g
s
.49945 .49233 m .46494 .48961 L p .49822 .49124 L .647 .724 .905 r
F P
0 g
s
.53431 .4781 m .52297 .47155 L .5042 .48814 L p .783 .611 .668 r
F P
0 g
s
.50062 .49285 m .50438 .53305 L .50041 .49247 L .511 .403 .668 r
F
.49029 .53063 m .49762 .5278 L .50041 .49247 L p .507 .424 .696 r
F P
0 g
s
.49105 .77828 m .48081 .77786 L .48419 .72762 L p .726 .601 .717 r
F P
0 g
s
.48419 .72762 m .49265 .72793 L .49105 .77828 L p .726 .601 .717 r
F P
0 g
s
.64231 .51813 m .63996 .52913 L .62188 .52381 L p .648 .632 .821 r
F P
0 g
s
.62188 .52381 m .62357 .51436 L .64231 .51813 L p .648 .632 .821 r
F P
0 g
s
.72193 .57508 m .71103 .59916 L .67661 .58159 L p .685 .583 .735 r
F P
0 g
s
.67661 .58159 m .68565 .56141 L .72193 .57508 L p .685 .583 .735 r
F P
0 g
s
.48081 .77786 m .4779 .7779 L .48186 .72772 L p .73 .606 .719 r
F P
0 g
s
.48186 .72772 m .47956 .72735 L .47954 .72758 L p .73 .607 .72 r
F P
0 g
s
.47954 .72758 m .47503 .77748 L p .48186 .72772 L .73 .607 .72 r
F P
0 g
s
.48186 .72772 m .47954 .72758 L .48186 .72772 L .73 .607 .72 r
F
.48186 .72772 m .48419 .72762 L .48418 .72786 L p .73 .606 .719 r
F P
0 g
s
.48418 .72786 m .48081 .77786 L p .48186 .72772 L .73 .606 .719 r
F P
0 g
s
.48186 .72772 m .48418 .72786 L .48186 .72772 L .73 .606 .719 r
F
.60859 .50512 m .60805 .51093 L .5948 .50736 L p .549 .714 .949 r
F P
0 g
s
.5948 .50736 m .59451 .50279 L .60859 .50512 L p .549 .714 .949 r
F P
0 g
s
.47503 .77748 m .4779 .7779 L .48186 .72772 L p .73 .607 .72 r
F P
0 g
s
.46483 .77649 m .47503 .77748 L .47956 .72735 L p .725 .604 .722 r
F P
0 g
s
.49601 .61675 m .50328 .61661 L .50397 .63567 L p .822 .658 .679 r
F P
0 g
s
.50328 .61661 m .49601 .61675 L .49634 .6006 L p .874 .686 .645 r
F P
0 g
s
.50641 .72782 m .49265 .72793 L .49389 .68944 L p .738 .607 .711 r
F P
0 g
s
.49389 .68944 m .50539 .68928 L .50641 .72782 L p .738 .607 .711 r
F P
0 g
s
.69167 .54322 m .68565 .56141 L .65771 .55081 L p .678 .596 .756 r
F P
0 g
s
.65771 .55081 m .66265 .53544 L .69167 .54322 L p .678 .596 .756 r
F P
0 g
s
.44828 .77409 m .46483 .77649 L .47113 .72658 L p .725 .606 .724 r
F P
0 g
s
.47956 .72735 m .47113 .72658 L .46483 .77649 L p .725 .604 .722 r
F P
0 g
s
.50364 .39628 m .49874 .39479 L .50072 .40641 L p .043 .08 .575 r
F P
0 g
s
.50072 .40641 m .50418 .40939 L .50364 .39628 L p .043 .08 .575 r
F P
0 g
s
.50555 .42398 m .50572 .42175 L .50889 .4324 L p .993 .812 .437 r
F P
0 g
s
.50889 .4324 m .5061 .43826 L .50555 .42398 L p .993 .812 .437 r
F P
0 g
s
.37005 .33917 m .35084 .35823 L .3728 .37743 L p .738 .632 .741 r
F P
0 g
s
.3728 .37743 m .38914 .36118 L .37005 .33917 L p .738 .632 .741 r
F P
0 g
s
.35935 .39536 m .3728 .37743 L .35084 .35823 L p .749 .628 .726 r
F P
0 g
s
.49554 .63594 m .50397 .63567 L .50461 .65934 L p .785 .636 .697 r
F P
0 g
s
.50397 .63567 m .49554 .63594 L .49601 .61675 L p .822 .658 .679 r
F P
0 g
s
.39179 .32307 m .37005 .33917 L .38914 .36118 L p .723 .628 .751 r
F P
0 g
s
.38914 .36118 m .40766 .34753 L .39179 .32307 L p .723 .628 .751 r
F P
0 g
s
.50539 .68928 m .49389 .68944 L .49479 .65954 L p .758 .619 .706 r
F P
0 g
s
.49479 .65954 m .50461 .65934 L .50539 .68928 L p .758 .619 .706 r
F P
0 g
s
.48442 .34668 m .47032 .34813 L .47431 .3658 L p .596 .537 .759 r
F P
0 g
s
.47431 .3658 m .48668 .36529 L .48442 .34668 L p .596 .537 .759 r
F P
0 g
s
.49265 .72793 m .48419 .72762 L .48676 .68922 L p .739 .611 .716 r
F P
0 g
s
.48676 .68922 m .49389 .68944 L .49265 .72793 L p .739 .611 .716 r
F P
0 g
s
.40538 .48026 m .40508 .47486 L .39179 .47166 L p .76 .401 .375 r
F P
0 g
s
.40508 .47486 m .40538 .48026 L .41834 .48274 L p .723 .238 .094 r
F P
0 g
s
.42625 .7694 m .44828 .77409 L .45748 .72474 L p .723 .608 .728 r
F P
0 g
s
.47113 .72658 m .45748 .72474 L .44828 .77409 L p .725 .606 .724 r
F P
0 g
s
.50461 .65934 m .49479 .65954 L .49554 .63594 L p .785 .636 .697 r
F P
0 g
s
.4941 .57281 m .49578 .57309 L .49632 .58633 L p .994 .78 .413 r
F P
0 g
s
.49578 .57309 m .4941 .57281 L .49441 .55922 L p 0 0 .158 r
F P
0 g
s
.76954 .59291 m .75622 .62217 L .71103 .59916 L p .695 .585 .728 r
F P
0 g
s
.71103 .59916 m .72193 .57508 L .76954 .59291 L p .695 .585 .728 r
F P
0 g
s
.35084 .35823 m .33485 .37912 L .35935 .39536 L p .749 .628 .726 r
F P
0 g
s
.3491 .41385 m .35935 .39536 L .33485 .37912 L p .753 .617 .709 r
F P
0 g
s
.48419 .72762 m .48186 .72772 L .48488 .68936 L p .748 .621 .719 r
F P
0 g
s
.48488 .68936 m .48676 .68922 L .48419 .72762 L p .748 .621 .719 r
F P
0 g
s
.46559 .32547 m .44708 .32986 L .4542 .35136 L p .652 .58 .761 r
F P
0 g
s
.4542 .35136 m .47032 .34813 L .46559 .32547 L p .652 .58 .761 r
F P
0 g
s
.3491 .41385 m .34177 .43158 L .36355 .43957 L p .773 .611 .678 r
F P
0 g
s
.35972 .45345 m .36355 .43957 L .34177 .43158 L p .762 .585 .658 r
F P
0 g
s
.36355 .43957 m .35972 .45345 L .37786 .45841 L p .788 .584 .625 r
F P
0 g
s
.47956 .72735 m .48186 .72772 L .48488 .68936 L p .747 .623 .721 r
F P
0 g
s
.66568 .52257 m .66265 .53544 L .63996 .52913 L p .672 .62 .788 r
F P
0 g
s
.63996 .52913 m .64231 .51813 L .66568 .52257 L p .672 .62 .788 r
F P
0 g
s
.49664 .3655 m .48668 .36529 L .48887 .38021 L p .504 .456 .737 r
F P
0 g
s
.48887 .38021 m .49747 .38128 L .49664 .3655 L p .504 .456 .737 r
F P
0 g
s
.41482 .31049 m .39179 .32307 L .40766 .34753 L p .705 .616 .755 r
F P
0 g
s
.40766 .34753 m .42735 .33705 L .41482 .31049 L p .705 .616 .755 r
F P
0 g
s
.37624 .46851 m .37786 .45841 L .35972 .45345 L p .766 .548 .602 r
F P
0 g
s
.37786 .45841 m .37624 .46851 L .39179 .47166 L p .789 .524 .536 r
F P
0 g
s
.47113 .72658 m .47956 .72735 L .48305 .68904 L p .738 .617 .724 r
F P
0 g
s
.48488 .68936 m .48305 .68904 L .47956 .72735 L p .747 .623 .721 r
F P
0 g
s
.41834 .48274 m .41872 .48486 L .43221 .48662 L p .217 0 0 r
F P
0 g
s
.43221 .48662 m .41872 .48486 L p .42641 .48556 L .262 .719 .953 r
F P
0 g
s
.43047 .48603 m .43221 .48662 L p .44187 .48839 L .272 .652 .967 r
F P
0 g
s
.43209 .48607 m .43221 .48662 L p .42641 .48556 L .262 .719 .953 r
F P
0 g
s
.43221 .48662 m .4463 .48932 L p .44187 .48839 L .272 .652 .967 r
F P
0 g
s
.39962 .76121 m .42625 .7694 L .43924 .72092 L p .72 .608 .731 r
F P
0 g
s
.45748 .72474 m .43924 .72092 L .42625 .7694 L p .723 .608 .728 r
F P
0 g
s
.62463 .50739 m .62357 .51436 L .60805 .51093 L p .63 .686 .884 r
F P
0 g
s
.60805 .51093 m .60859 .50512 L .62463 .50739 L p .63 .686 .884 r
F P
0 g
s
.49389 .68944 m .48676 .68922 L .48876 .65939 L p .758 .626 .714 r
F P
0 g
s
.48876 .65939 m .49479 .65954 L .49389 .68944 L p .758 .626 .714 r
F P
0 g
s
.72916 .55332 m .72193 .57508 L .68565 .56141 L p .69 .593 .742 r
F P
0 g
s
.68565 .56141 m .69167 .54322 L .72916 .55332 L p .69 .593 .742 r
F P
0 g
s
.49346 .58632 m .49632 .58633 L .49634 .6006 L p .953 .768 .616 r
F P
0 g
s
.49632 .58633 m .49346 .58632 L .4941 .57281 L p .994 .78 .413 r
F P
0 g
s
.45748 .72474 m .47113 .72658 L .47593 .68847 L p .737 .62 .728 r
F P
0 g
s
.48305 .68904 m .47593 .68847 L .47113 .72658 L p .738 .617 .724 r
F P
0 g
s
.49762 .5278 m .49029 .53063 L .49386 .54484 L p .423 .358 .681 r
F P
0 g
s
.49479 .65954 m .48876 .65939 L .49038 .63585 L p .787 .648 .709 r
F P
0 g
s
.49038 .63585 m .49554 .63594 L .49479 .65954 L p .787 .648 .709 r
F P
0 g
s
.48676 .68922 m .48488 .68936 L .48723 .65957 L p .775 .645 .718 r
F P
0 g
s
.48723 .65957 m .48876 .65939 L .48676 .68922 L p .775 .645 .718 r
F P
0 g
s
.33485 .37912 m .32254 .40062 L .3491 .41385 L p .753 .617 .709 r
F P
0 g
s
.34177 .43158 m .3491 .41385 L .32254 .40062 L p .75 .602 .693 r
F P
0 g
s
.49262 .60064 m .49634 .6006 L .49601 .61675 L p .88 .718 .676 r
F P
0 g
s
.49634 .6006 m .49262 .60064 L .49346 .58632 L p .953 .768 .616 r
F P
0 g
s
.48305 .68904 m .48488 .68936 L .48723 .65957 L p .775 .648 .722 r
F P
0 g
s
.49554 .63594 m .49038 .63585 L .4916 .61672 L p .827 .678 .698 r
F P
0 g
s
.4916 .61672 m .49601 .61675 L .49554 .63594 L p .827 .678 .698 r
F P
0 g
s
.49601 .61675 m .4916 .61672 L .49262 .60064 L p .88 .718 .676 r
F P
0 g
s
.36996 .74856 m .39962 .76121 L .41715 .71434 L p .716 .607 .734 r
F P
0 g
s
.43924 .72092 m .41715 .71434 L .39962 .76121 L p .72 .608 .731 r
F P
0 g
s
.77839 .56652 m .76954 .59291 L .72193 .57508 L p .697 .59 .732 r
F P
0 g
s
.72193 .57508 m .72916 .55332 L .77839 .56652 L p .697 .59 .732 r
F P
0 g
s
.43924 .72092 m .45748 .72474 L .46451 .68703 L p .734 .623 .734 r
F P
0 g
s
.47593 .68847 m .46451 .68703 L .45748 .72474 L p .737 .62 .728 r
F P
0 g
s
.47593 .68847 m .48305 .68904 L .48574 .65929 L p .758 .636 .727 r
F P
0 g
s
.48723 .65957 m .48574 .65929 L .48305 .68904 L p .775 .648 .722 r
F P
0 g
s
.69531 .52812 m .69167 .54322 L .66265 .53544 L p .686 .609 .763 r
F P
0 g
s
.66265 .53544 m .66568 .52257 L .69531 .52812 L p .686 .609 .763 r
F P
0 g
s
.39128 .47811 m .39179 .47166 L .37624 .46851 L p .754 .477 .513 r
F P
0 g
s
.39179 .47166 m .39128 .47811 L .40538 .48026 L p .76 .401 .375 r
F P
0 g
s
.43789 .30165 m .41482 .31049 L .42735 .33705 L p .687 .6 .753 r
F P
0 g
s
.42735 .33705 m .44708 .32986 L .43789 .30165 L p .687 .6 .753 r
F P
0 g
s
.64375 .51 m .64231 .51813 L .62357 .51436 L p .665 .657 .832 r
F P
0 g
s
.62357 .51436 m .62463 .50739 L .64375 .51 L p .665 .657 .832 r
F P
0 g
s
.59468 .50018 m .59451 .50279 L .58157 .50007 L p .323 .74 .977 r
F P
0 g
s
.5812 .49867 m .56772 .49681 L p .57369 .49766 L .521 .002 0 r
F P
0 g
s
.58157 .50007 m .5812 .49867 L p .59234 .50016 L .323 .74 .977 r
F P
0 g
s
.58146 .49878 m .5812 .49867 L p .57369 .49766 L .521 .002 0 r
F P
0 g
s
.5812 .49867 m .59468 .50018 L p .59234 .50016 L .323 .74 .977 r
F P
0 g
s
.48876 .65939 m .48723 .65957 L .48909 .63607 L p .813 .678 .715 r
F P
0 g
s
.48909 .63607 m .49038 .63585 L .48876 .65939 L p .813 .678 .715 r
F P
0 g
s
.50363 .38205 m .49747 .38128 L .49874 .39479 L p .333 .298 .67 r
F P
0 g
s
.49874 .39479 m .50364 .39628 L .50363 .38205 L p .333 .298 .67 r
F P
0 g
s
.46405 .48859 m .45963 .49482 L .4463 .48932 L p .61 .711 .917 r
F P
0 g
s
.46451 .68703 m .47593 .68847 L .47972 .6589 L p .756 .641 .735 r
F P
0 g
s
.48574 .65929 m .47972 .6589 L .47593 .68847 L p .758 .636 .727 r
F P
0 g
s
.48574 .65929 m .48723 .65957 L .48909 .63607 L p .812 .682 .72 r
F P
0 g
s
.55316 .49656 m .55363 .49392 L .54032 .48799 L p .688 .375 .441 r
F P
0 g
s
.41872 .48486 m .41834 .48274 L .40538 .48026 L p .622 .112 .017 r
F P
0 g
s
.34177 .43158 m .33693 .44741 L .35972 .45345 L p .762 .585 .658 r
F P
0 g
s
.35745 .46495 m .35972 .45345 L .33693 .44741 L p .747 .562 .644 r
F P
0 g
s
.35972 .45345 m .35745 .46495 L .37624 .46851 L p .766 .548 .602 r
F P
0 g
s
.33894 .73082 m .36996 .74856 L .39261 .70409 L p .71 .603 .735 r
F P
0 g
s
.41715 .71434 m .39261 .70409 L .36996 .74856 L p .716 .607 .734 r
F P
0 g
s
.47972 .6589 m .48574 .65929 L .48783 .63583 L p .786 .665 .73 r
F P
0 g
s
.48909 .63607 m .48783 .63583 L .48574 .65929 L p .812 .682 .72 r
F P
0 g
s
.49038 .63585 m .48909 .63607 L .49059 .61704 L p .874 .731 .7 r
F P
0 g
s
.49059 .61704 m .4916 .61672 L .49038 .63585 L p .874 .731 .7 r
F P
0 g
s
.73356 .53527 m .72916 .55332 L .69167 .54322 L p .695 .601 .746 r
F P
0 g
s
.69167 .54322 m .69531 .52812 L .73356 .53527 L p .695 .601 .746 r
F P
0 g
s
.41715 .71434 m .43924 .72092 L .44915 .68402 L p .729 .624 .74 r
F P
0 g
s
.46451 .68703 m .44915 .68402 L .43924 .72092 L p .734 .623 .734 r
F P
0 g
s
.32254 .40062 m .31365 .42124 L .34177 .43158 L p .75 .602 .693 r
F P
0 g
s
.33693 .44741 m .34177 .43158 L .31365 .42124 L p .743 .586 .68 r
F P
0 g
s
.49627 .54502 m .49386 .54484 L .49441 .55922 L p .222 .183 .6 r
F P
0 g
s
.49386 .54484 m .49627 .54502 L .49762 .5278 L p .423 .358 .681 r
F P
0 g
s
.48185 .32326 m .46559 .32547 L .47032 .34813 L p .634 .553 .746 r
F P
0 g
s
.47032 .34813 m .48442 .34668 L .48185 .32326 L p .634 .553 .746 r
F P
0 g
s
.48783 .63583 m .48909 .63607 L .49059 .61704 L p .874 .74 .711 r
F P
0 g
s
.4916 .61672 m .49059 .61704 L .49186 .60093 L p .95 .798 .656 r
F P
0 g
s
.49186 .60093 m .49262 .60064 L .4916 .61672 L p .95 .798 .656 r
F P
0 g
s
.66732 .513 m .66568 .52257 L .64231 .51813 L p .683 .635 .795 r
F P
0 g
s
.64231 .51813 m .64375 .51 L .66732 .513 L p .683 .635 .795 r
F P
0 g
s
.3449 .31 m .32184 .33273 L .35084 .35823 L p .727 .614 .732 r
F P
0 g
s
.35084 .35823 m .37005 .33917 L .3449 .31 L p .727 .614 .732 r
F P
0 g
s
.33485 .37912 m .35084 .35823 L .32184 .33273 L p .733 .612 .723 r
F P
0 g
s
.49595 .3464 m .48442 .34668 L .48668 .36529 L p .576 .502 .734 r
F P
0 g
s
.48668 .36529 m .49664 .3655 L .49595 .3464 L p .576 .502 .734 r
F P
0 g
s
.60902 .50163 m .60859 .50512 L .59451 .50279 L p .57 .755 .965 r
F P
0 g
s
.59451 .50279 m .59468 .50018 L .60902 .50163 L p .57 .755 .965 r
F P
0 g
s
.78364 .54461 m .77839 .56652 L .72916 .55332 L p .7 .595 .735 r
F P
0 g
s
.72916 .55332 m .73356 .53527 L .78364 .54461 L p .7 .595 .735 r
F P
0 g
s
.32184 .33273 m .30269 .3577 L .33485 .37912 L p .733 .612 .723 r
F P
0 g
s
.32254 .40062 m .33485 .37912 L .30269 .3577 L p .735 .605 .712 r
F P
0 g
s
.44915 .68402 m .46451 .68703 L .46994 .65783 L p .751 .645 .744 r
F P
0 g
s
.47972 .6589 m .46994 .65783 L .46451 .68703 L p .756 .641 .735 r
F P
0 g
s
.37084 .29061 m .3449 .31 L .37005 .33917 L p .717 .612 .738 r
F P
0 g
s
.37005 .33917 m .39179 .32307 L .37084 .29061 L p .717 .612 .738 r
F P
0 g
s
.37521 .47597 m .37624 .46851 L .35745 .46495 L p .743 .519 .59 r
F P
0 g
s
.37624 .46851 m .37521 .47597 L .39128 .47811 L p .754 .477 .513 r
F P
0 g
s
.49262 .60064 m .49186 .60093 L .49298 .58666 L p .997 .842 .506 r
F P
0 g
s
.49298 .58666 m .49346 .58632 L .49262 .60064 L p .997 .842 .506 r
F P
0 g
s
.50369 .43862 m .5061 .43826 L .50746 .44353 L p .912 .77 .69 r
F P
0 g
s
.50585 .44351 m .50369 .43862 L .50746 .44353 L .912 .77 .69 r
F
.50967 .45211 m .50233 .45592 L .50369 .43862 L p F P
0 g
s
.5061 .43826 m .50369 .43862 L .50484 .42393 L p .975 .828 .635 r
F P
0 g
s
.50561 .43877 m .50325 .43832 L .50106 .44344 L p .912 .77 .69 r
F P
0 g
s
.50106 .44344 m .49749 .45178 L p .50268 .44346 L .912 .77 .69 r
F P
0 g
s
.50268 .44346 m .50561 .43877 L .50106 .44344 L .912 .77 .69 r
F
.50746 .44353 m .50967 .45211 L p .50585 .44351 L F P
0 g
s
.48783 .63583 m .48266 .63562 L .47972 .6589 L p .786 .665 .73 r
F P
0 g
s
.48266 .63562 m .48783 .63583 L .48962 .61679 L p .825 .706 .733 r
F P
0 g
s
.49059 .61704 m .48962 .61679 L .48783 .63583 L p .874 .74 .711 r
F P
0 g
s
.49511 .55963 m .49441 .55922 L .4941 .57281 L p 0 0 .401 r
F P
0 g
s
.49441 .55922 m .49511 .55963 L .49627 .54502 L p .222 .183 .6 r
F P
0 g
s
.46994 .65783 m .47972 .6589 L .48266 .63562 L p .782 .673 .743 r
F P
0 g
s
.49346 .58632 m .49298 .58666 L .49404 .57319 L p .743 .634 .072 r
F P
0 g
s
.49404 .57319 m .4941 .57281 L .49346 .58632 L p .743 .634 .072 r
F P
0 g
s
.48962 .61679 m .49059 .61704 L .49186 .60093 L p .95 .811 .672 r
F P
0 g
s
.4941 .57281 m .49404 .57319 L .49511 .55963 L p 0 0 .401 r
F P
0 g
s
.30868 .70776 m .33894 .73082 L .36699 .68954 L p .704 .597 .734 r
F P
0 g
s
.39261 .70409 m .36699 .68954 L .33894 .73082 L p .71 .603 .735 r
F P
0 g
s
.45956 .29609 m .43789 .30165 L .44708 .32986 L p .672 .582 .746 r
F P
0 g
s
.44708 .32986 m .46559 .32547 L .45956 .29609 L p .672 .582 .746 r
F P
0 g
s
.69725 .51685 m .69531 .52812 L .66568 .52257 L p .693 .618 .767 r
F P
0 g
s
.66568 .52257 m .66732 .513 L .69725 .51685 L p .693 .618 .767 r
F P
0 g
s
.40522 .48341 m .40538 .48026 L .39128 .47811 L p .71 .343 .352 r
F P
0 g
s
.40538 .48026 m .40522 .48341 L .41872 .48486 L p .622 .112 .017 r
F P
0 g
s
.39261 .70409 m .41715 .71434 L .43053 .67871 L p .721 .621 .745 r
F P
0 g
s
.44915 .68402 m .43053 .67871 L .41715 .71434 L p .729 .624 .74 r
F P
0 g
s
.30269 .3577 m .28778 .38323 L .32254 .40062 L p .735 .605 .712 r
F P
0 g
s
.31365 .42124 m .32254 .40062 L .28778 .38323 L p .734 .596 .703 r
F P
0 g
s
.49186 .60093 m .49113 .60079 L .48962 .61679 L p .95 .811 .672 r
F P
0 g
s
.49113 .60079 m .49186 .60093 L .49298 .58666 L p .994 .864 .53 r
F P
0 g
s
.62516 .50316 m .62463 .50739 L .60859 .50512 L p .647 .71 .893 r
F P
0 g
s
.60859 .50512 m .60902 .50163 L .62516 .50316 L p .647 .71 .893 r
F P
0 g
s
.3984 .27546 m .37084 .29061 L .39179 .32307 L p .705 .604 .741 r
F P
0 g
s
.39179 .32307 m .41482 .31049 L .3984 .27546 L p .705 .604 .741 r
F P
0 g
s
.48962 .61679 m .48519 .61676 L .48266 .63562 L p .825 .706 .733 r
F P
0 g
s
.48519 .61676 m .48962 .61679 L .49113 .60079 L p .879 .762 .73 r
F P
0 g
s
.31365 .42124 m .30778 .43984 L .33693 .44741 L p .743 .586 .68 r
F P
0 g
s
.33401 .46068 m .33693 .44741 L .30778 .43984 L p .733 .571 .672 r
F P
0 g
s
.33693 .44741 m .33401 .46068 L .35745 .46495 L p .747 .562 .644 r
F P
0 g
s
.56783 .49771 m .56772 .49681 L .55363 .49392 L p .646 .249 .277 r
F P
0 g
s
.55363 .49392 m .55316 .49656 L .56783 .49771 L p .646 .249 .277 r
F P
0 g
s
.73585 .52172 m .73356 .53527 L .69531 .52812 L p .699 .606 .749 r
F P
0 g
s
.69531 .52812 m .69725 .51685 L .73585 .52172 L p .699 .606 .749 r
F P
0 g
s
.50396 .36584 m .49664 .3655 L .49747 .38128 L p .483 .413 .701 r
F P
0 g
s
.49747 .38128 m .50363 .38205 L .50396 .36584 L p .483 .413 .701 r
F P
0 g
s
.49298 .58666 m .49254 .58658 L .49113 .60079 L p .994 .864 .53 r
F P
0 g
s
.49254 .58658 m .49298 .58666 L .49404 .57319 L p .727 .657 .103 r
F P
0 g
s
.44677 .48722 m .4463 .48932 L .43221 .48662 L p .517 .758 .984 r
F P
0 g
s
.4463 .48932 m .44677 .48722 L .4525 .48768 L p .61 .711 .917 r
F P
0 g
s
.44765 .48826 m .4473 .4861 L .45208 .48494 L p .63 .74 .927 r
F P
0 g
s
.45208 .48494 m .46127 .4827 L p .4523 .48636 L .63 .74 .927 r
F P
0 g
s
.4523 .48636 m .44765 .48826 L .45208 .48494 L .63 .74 .927 r
F
.4525 .48768 m .46405 .48859 L p .45272 .48905 L .61 .711 .917 r
F P
0 g
s
.45272 .48905 m .4463 .48932 L .4525 .48768 L .61 .711 .917 r
F
.48266 .63562 m .47425 .63485 L .46994 .65783 L p .782 .673 .743 r
F P
0 g
s
.47425 .63485 m .48266 .63562 L .48519 .61676 L p .819 .717 .753 r
F P
0 g
s
.35607 .47346 m .35745 .46495 L .33401 .46068 L p .732 .543 .636 r
F P
0 g
s
.35745 .46495 m .35607 .47346 L .37521 .47597 L p .743 .519 .59 r
F P
0 g
s
.50652 .39683 m .50364 .39628 L .50418 .40939 L p 0 0 .449 r
F P
0 g
s
.50418 .40939 m .50587 .4104 L .50652 .39683 L p 0 0 .449 r
F P
0 g
s
.43053 .67871 m .44915 .68402 L .45672 .65554 L p .742 .647 .754 r
F P
0 g
s
.46994 .65783 m .45672 .65554 L .44915 .68402 L p .751 .645 .744 r
F P
0 g
s
.64437 .50497 m .64375 .51 L .62463 .50739 L p .676 .672 .838 r
F P
0 g
s
.62463 .50739 m .62516 .50316 L .64437 .50497 L p .676 .672 .838 r
F P
0 g
s
.78646 .5281 m .78364 .54461 L .73356 .53527 L p .703 .598 .736 r
F P
0 g
s
.73356 .53527 m .73585 .52172 L .78646 .5281 L p .703 .598 .736 r
F P
0 g
s
.49113 .60079 m .48738 .60096 L .48519 .61676 L p .879 .762 .73 r
F P
0 g
s
.48738 .60096 m .49113 .60079 L .49254 .58658 L p .95 .845 .705 r
F P
0 g
s
.28778 .38323 m .27709 .40774 L .31365 .42124 L p .734 .596 .703 r
F P
0 g
s
.30778 .43984 m .31365 .42124 L .27709 .40774 L p .729 .586 .695 r
F P
0 g
s
.28104 .67988 m .30868 .70776 L .3419 .67063 L p .698 .589 .73 r
F P
0 g
s
.36699 .68954 m .3419 .67063 L .30868 .70776 L p .704 .597 .734 r
F P
0 g
s
.39087 .48201 m .39128 .47811 L .37521 .47597 L p .724 .444 .502 r
F P
0 g
s
.39128 .47811 m .39087 .48201 L .40522 .48341 L p .71 .343 .352 r
F P
0 g
s
.49404 .57319 m .49402 .57323 L .49254 .58658 L p .727 .657 .103 r
F P
0 g
s
.49402 .57323 m .49404 .57319 L .49511 .55963 L p 0 0 .365 r
F P
0 g
s
.45672 .65554 m .46994 .65783 L .47425 .63485 L p .775 .68 .759 r
F P
0 g
s
.66806 .50708 m .66732 .513 L .64375 .51 L p .691 .643 .797 r
F P
0 g
s
.64375 .51 m .64437 .50497 L .66806 .50708 L p .691 .643 .797 r
F P
0 g
s
.36699 .68954 m .39261 .70409 L .4098 .67035 L p .711 .615 .747 r
F P
0 g
s
.43053 .67871 m .4098 .67035 L .39261 .70409 L p .721 .621 .745 r
F P
0 g
s
.49511 .55963 m .49583 .5599 L .49402 .57323 L p 0 0 .365 r
F P
0 g
s
.49583 .5599 m .49511 .55963 L .49627 .54502 L p .234 .157 .561 r
F P
0 g
s
.56772 .49681 m .56783 .49771 L .58146 .49878 L p .521 .002 0 r
F P
0 g
s
.42589 .26459 m .3984 .27546 L .41482 .31049 L p .694 .594 .74 r
F P
0 g
s
.41482 .31049 m .43789 .30165 L .42589 .26459 L p .694 .594 .74 r
F P
0 g
s
.49254 .58658 m .48961 .58713 L .48738 .60096 L p .95 .845 .705 r
F P
0 g
s
.48961 .58713 m .49254 .58658 L .49402 .57323 L p .97 .908 .559 r
F P
0 g
s
.69812 .5098 m .69725 .51685 L .66732 .513 L p .698 .623 .769 r
F P
0 g
s
.66732 .513 m .66806 .50708 L .69812 .5098 L p .698 .623 .769 r
F P
0 g
s
.43221 .48662 m .43209 .48607 L .44364 .48698 L p .517 .758 .984 r
F P
0 g
s
.44363 .48709 m .43221 .48662 L .44364 .48698 L .517 .758 .984 r
F
.43298 .48711 m .43299 .48657 L .44368 .48622 L p .538 .78 .987 r
F P
0 g
s
.44368 .48622 m .4473 .4861 L p .44367 .48635 L .538 .78 .987 r
F P
0 g
s
.44367 .48635 m .43298 .48711 L .44368 .48622 L .538 .78 .987 r
F
.44364 .48698 m .44677 .48722 L p .44363 .48709 L .517 .758 .984 r
F P
0 g
s
.37471 .48051 m .37521 .47597 L .35607 .47346 L p .724 .497 .582 r
F P
0 g
s
.37521 .47597 m .37471 .48051 L .39087 .48201 L p .724 .444 .502 r
F P
0 g
s
.30778 .43984 m .30427 .45524 L .33401 .46068 L p .733 .571 .672 r
F P
0 g
s
.33244 .47054 m .33401 .46068 L .30427 .45524 L p .724 .56 .667 r
F P
0 g
s
.33401 .46068 m .33244 .47054 L .35607 .47346 L p .732 .543 .636 r
F P
0 g
s
.4953 .32254 m .48185 .32326 L .48442 .34668 L p .624 .532 .73 r
F P
0 g
s
.48442 .34668 m .49595 .3464 L .4953 .32254 L p .624 .532 .73 r
F P
0 g
s
.48519 .61676 m .47787 .61648 L .47425 .63485 L p .819 .717 .753 r
F P
0 g
s
.47787 .61648 m .48519 .61676 L .48738 .60096 L p .87 .783 .762 r
F P
0 g
s
.49627 .54502 m .49862 .54602 L .49583 .5599 L p .234 .157 .561 r
F P
0 g
s
.49862 .54602 m .49627 .54502 L .49763 .5278 L p .432 .326 .634 r
F P
0 g
s
.27709 .40774 m .27007 .42986 L .30778 .43984 L p .729 .586 .695 r
F P
0 g
s
.30427 .45524 m .30778 .43984 L .27007 .42986 L p .723 .577 .69 r
F P
0 g
s
.73688 .51332 m .73585 .52172 L .69725 .51685 L p .702 .609 .749 r
F P
0 g
s
.69725 .51685 m .69812 .5098 L .73688 .51332 L p .702 .609 .749 r
F P
0 g
s
.595 .49985 m .59468 .50018 L .5812 .49867 L p .147 0 0 r
F P
0 g
s
.5812 .49867 m .58146 .49878 L .595 .49985 L p .147 0 0 r
F P
0 g
s
.25741 .64847 m .28104 .67988 L .31905 .64765 L p .694 .581 .724 r
F P
0 g
s
.3419 .67063 m .31905 .64765 L .28104 .67988 L p .698 .589 .73 r
F P
0 g
s
.7877 .51791 m .78646 .5281 L .73585 .52172 L p .704 .6 .737 r
F P
0 g
s
.73585 .52172 m .73688 .51332 L .7877 .51791 L p .704 .6 .737 r
F P
0 g
s
.47878 .29322 m .45956 .29609 L .46559 .32547 L p .661 .565 .736 r
F P
0 g
s
.46559 .32547 m .48185 .32326 L .47878 .29322 L p .661 .565 .736 r
F P
0 g
s
.50484 .42393 m .50555 .42398 L .50596 .43456 L p .975 .828 .635 r
F P
0 g
s
.50578 .43457 m .50484 .42393 L .50596 .43456 L .975 .828 .635 r
F
.50677 .42408 m .50606 .42416 L .50398 .43465 L p .975 .828 .634 r
F P
0 g
s
.50398 .43465 m .50325 .43832 L p .50416 .43464 L .975 .828 .634 r
F P
0 g
s
.50416 .43464 m .50677 .42408 L .50398 .43465 L .975 .828 .634 r
F
.50596 .43456 m .5061 .43826 L p .50578 .43457 L .975 .828 .635 r
F P
0 g
s
.60936 .50098 m .60902 .50163 L .59468 .50018 L p .36 .766 .983 r
F P
0 g
s
.59468 .50018 m .595 .49985 L .60936 .50098 L p .36 .766 .983 r
F P
0 g
s
.28347 .29884 m .26012 .32913 L .30269 .3577 L p .722 .601 .721 r
F P
0 g
s
.30269 .3577 m .32184 .33273 L .28347 .29884 L p .722 .601 .721 r
F P
0 g
s
.28778 .38323 m .30269 .3577 L .26012 .32913 L p .724 .597 .715 r
F P
0 g
s
.49402 .57323 m .4922 .57448 L .48961 .58713 L p .97 .908 .559 r
F P
0 g
s
.4922 .57448 m .49402 .57323 L .49583 .5599 L p 0 0 0 r
F P
0 g
s
.41845 .485 m .41872 .48486 L .40522 .48341 L p .242 0 0 r
F P
0 g
s
.41872 .48486 m .41845 .485 L .43209 .48607 L p .262 .719 .953 r
F P
0 g
s
.49763 .5278 m .50438 .53305 L .49862 .54602 L p .432 .326 .634 r
F P
0 g
s
.31155 .27119 m .28347 .29884 L .32184 .33273 L p .718 .603 .726 r
F P
0 g
s
.32184 .33273 m .3449 .31 L .31155 .27119 L p .718 .603 .726 r
F P
0 g
s
.26012 .32913 m .24204 .3602 L .28778 .38323 L p .724 .597 .715 r
F P
0 g
s
.27709 .40774 m .28778 .38323 L .24204 .3602 L p .723 .592 .709 r
F P
0 g
s
.35548 .47872 m .35607 .47346 L .33244 .47054 L p .72 .53 .633 r
F P
0 g
s
.35607 .47346 m .35548 .47872 L .37471 .48051 L p .724 .497 .582 r
F P
0 g
s
.62559 .50225 m .62516 .50316 L .60902 .50163 L p .584 .766 .966 r
F P
0 g
s
.60902 .50163 m .60936 .50098 L .62559 .50225 L p .584 .766 .966 r
F P
0 g
s
.4098 .67035 m .43053 .67871 L .44083 .65139 L p .729 .643 .762 r
F P
0 g
s
.45672 .65554 m .44083 .65139 L .43053 .67871 L p .742 .647 .754 r
F P
0 g
s
.50736 .38241 m .50363 .38205 L .50364 .39628 L p .306 .247 .626 r
F P
0 g
s
.50364 .39628 m .50652 .39683 L .50736 .38241 L p .306 .247 .626 r
F P
0 g
s
.50443 .34649 m .49595 .3464 L .49664 .3655 L p .567 .478 .713 r
F P
0 g
s
.49664 .3655 m .50396 .36584 L .50443 .34649 L p .567 .478 .713 r
F P
0 g
s
.64476 .50376 m .64437 .50497 L .62516 .50316 L p .657 .713 .889 r
F P
0 g
s
.62516 .50316 m .62559 .50225 L .64476 .50376 L p .657 .713 .889 r
F P
0 g
s
.78821 .51504 m .7877 .51791 L .73688 .51332 L p .704 .603 .741 r
F P
0 g
s
.66846 .50562 m .66806 .50708 L .64437 .50497 L p .686 .666 .825 r
F P
0 g
s
.64437 .50497 m .64476 .50376 L .66846 .50562 L p .686 .666 .825 r
F P
0 g
s
.73688 .51332 m .73734 .51104 L .78821 .51504 L p .704 .603 .741 r
F P
0 g
s
.73734 .51104 m .73688 .51332 L .69812 .5098 L p .702 .617 .759 r
F P
0 g
s
.47425 .63485 m .46279 .63336 L .45672 .65554 L p .775 .68 .759 r
F P
0 g
s
.46279 .63336 m .47425 .63485 L .47787 .61648 L p .807 .729 .778 r
F P
0 g
s
.69855 .50799 m .69812 .5098 L .66806 .50708 L p .696 .637 .786 r
F P
0 g
s
.66806 .50708 m .66846 .50562 L .69855 .50799 L p .696 .637 .786 r
F P
0 g
s
.69812 .5098 m .69855 .50799 L .73734 .51104 L p .702 .617 .759 r
F P
0 g
s
.27007 .42986 m .26587 .44817 L .30427 .45524 L p .723 .577 .69 r
F P
0 g
s
.30245 .46675 m .30427 .45524 L .26587 .44817 L p .718 .57 .687 r
F P
0 g
s
.30427 .45524 m .30245 .46675 L .33244 .47054 L p .724 .56 .667 r
F P
0 g
s
.24204 .3602 m .22903 .38994 L .27709 .40774 L p .723 .592 .709 r
F P
0 g
s
.27007 .42986 m .27709 .40774 L .22903 .38994 L p .72 .586 .705 r
F P
0 g
s
.23891 .61509 m .25741 .64847 L .29963 .62166 L p .693 .574 .717 r
F P
0 g
s
.31905 .64765 m .29963 .62166 L .25741 .64847 L p .694 .581 .724 r
F P
0 g
s
.4049 .48393 m .40522 .48341 L .39087 .48201 L p .575 .084 .051 r
F P
0 g
s
.40522 .48341 m .4049 .48393 L .41845 .485 L p .242 0 0 r
F P
0 g
s
.3419 .67063 m .36699 .68954 L .3881 .65845 L p .7 .604 .745 r
F P
0 g
s
.4098 .67035 m .3881 .65845 L .36699 .68954 L p .711 .615 .747 r
F P
0 g
s
.78929 .51125 m .78925 .51415 L .73838 .51015 L p .705 .604 .741 r
F P
0 g
s
.34309 .24752 m .31155 .27119 L .3449 .31 L p .713 .601 .73 r
F P
0 g
s
.3449 .31 m .37084 .29061 L .34309 .24752 L p .713 .601 .73 r
F P
0 g
s
.73838 .51015 m .73838 .50783 L .78929 .51125 L p .705 .604 .741 r
F P
0 g
s
.73838 .50783 m .73838 .51015 L .69959 .5071 L p .703 .618 .759 r
F P
0 g
s
.33176 .47663 m .33244 .47054 L .30245 .46675 L p .717 .552 .665 r
F P
0 g
s
.33244 .47054 m .33176 .47663 L .35548 .47872 L p .72 .53 .633 r
F P
0 g
s
.44083 .65139 m .45672 .65554 L .46279 .63336 L p .761 .682 .775 r
F P
0 g
s
.78996 .50099 m .78929 .51125 L .73838 .50783 L p .707 .602 .737 r
F P
0 g
s
.69959 .5071 m .69955 .50525 L .73838 .50783 L p .703 .618 .759 r
F P
0 g
s
.69955 .50525 m .69959 .5071 L .6695 .50474 L p .698 .639 .786 r
F P
0 g
s
.45174 .25777 m .42589 .26459 L .43789 .30165 L p .685 .583 .735 r
F P
0 g
s
.43789 .30165 m .45956 .29609 L .45174 .25777 L p .685 .583 .735 r
F P
0 g
s
.39053 .4828 m .39087 .48201 L .37471 .48051 L p .676 .317 .356 r
F P
0 g
s
.39087 .48201 m .39053 .4828 L .4049 .48393 L p .575 .084 .051 r
F P
0 g
s
.48738 .60096 m .48112 .60136 L .47787 .61648 L p .87 .783 .762 r
F P
0 g
s
.48112 .60136 m .48738 .60096 L .48961 .58713 L p .932 .877 .759 r
F P
0 g
s
.6695 .50474 m .66943 .50324 L .69955 .50525 L p .698 .639 .786 r
F P
0 g
s
.66943 .50324 m .6695 .50474 L .6458 .50287 L p .689 .668 .825 r
F P
0 g
s
.22903 .38994 m .22051 .4167 L .27007 .42986 L p .72 .586 .705 r
F P
0 g
s
.26587 .44817 m .27007 .42986 L .22051 .4167 L p .717 .581 .702 r
F P
0 g
s
.73838 .50783 m .73895 .49939 L .78996 .50099 L p .707 .602 .737 r
F P
0 g
s
.73895 .49939 m .73838 .50783 L .69955 .50525 L p .707 .613 .75 r
F P
0 g
s
.6458 .50287 m .64572 .50162 L .66943 .50324 L p .689 .668 .825 r
F P
0 g
s
.64572 .50162 m .6458 .50287 L .62663 .50137 L p .663 .717 .888 r
F P
0 g
s
.62663 .50137 m .62647 .50041 L .64572 .50162 L p .663 .717 .888 r
F P
0 g
s
.62647 .50041 m .62663 .50137 L .61041 .50009 L p .594 .774 .966 r
F P
0 g
s
.61041 .50009 m .61031 .4994 L .62647 .50041 L p .594 .774 .966 r
F P
0 g
s
.61031 .4994 m .61041 .50009 L .59604 .49896 L p .38 .781 .985 r
F P
0 g
s
.59604 .49896 m .59595 .49859 L .61031 .4994 L p .38 .781 .985 r
F P
0 g
s
.59595 .49859 m .59604 .49896 L .5825 .4979 L p .121 0 0 r
F P
0 g
s
.37429 .48153 m .37471 .48051 L .35548 .47872 L p .705 .432 .51 r
F P
0 g
s
.37471 .48051 m .37429 .48153 L .39053 .4828 L p .676 .317 .356 r
F P
0 g
s
.69955 .50525 m .70007 .49816 L .73895 .49939 L p .707 .613 .75 r
F P
0 g
s
.70007 .49816 m .69955 .50525 L .66943 .50324 L p .707 .63 .77 r
F P
0 g
s
.5825 .4979 m .58242 .49798 L .59595 .49859 L p .121 0 0 r
F P
0 g
s
.58242 .49798 m .5825 .4979 L .56887 .49683 L p .5 0 0 r
F P
0 g
s
.49568 .56273 m .50056 .55294 L p .49689 .56042 L 0 0 .053 r
F P
0 g
s
.49568 .56273 m .4922 .57448 L p .49462 .56476 L 0 0 0 r
F P
0 g
s
.48826 .57768 m .4922 .57448 L .49568 .56273 L p 0 0 0 r
F P
0 g
s
.49266 .56906 m .49568 .56273 L p .49689 .56042 L 0 0 .053 r
F P
0 g
s
.49583 .5599 m .49568 .56273 L p .49462 .56476 L 0 0 0 r
F P
0 g
s
.49568 .56273 m .49583 .5599 L .49862 .54602 L p .061 0 .378 r
F P
0 g
s
.56887 .49683 m .56886 .49772 L .58242 .49798 L p .5 0 0 r
F P
0 g
s
.56886 .49772 m .56887 .49683 L .5542 .49567 L p .627 .235 .28 r
F P
0 g
s
.22577 .58167 m .23891 .61509 L .28452 .59397 L p .694 .57 .711 r
F P
0 g
s
.29963 .62166 m .28452 .59397 L .23891 .61509 L p .693 .574 .717 r
F P
0 g
s
.5542 .49567 m .55455 .49839 L .56886 .49772 L p .627 .235 .28 r
F P
0 g
s
.55455 .49839 m .5542 .49567 L .53692 .49432 L p .667 .367 .454 r
F P
0 g
s
.26587 .44817 m .26374 .46191 L .30245 .46675 L p .718 .57 .687 r
F P
0 g
s
.30164 .47392 m .30245 .46675 L .26374 .46191 L p .713 .566 .686 r
F P
0 g
s
.30245 .46675 m .30164 .47392 L .33176 .47663 L p .717 .552 .665 r
F P
0 g
s
.53692 .49432 m .54058 .50221 L .55455 .49839 L p .667 .367 .454 r
F P
0 g
s
.66943 .50324 m .66994 .49728 L .70007 .49816 L p .707 .63 .77 r
F P
0 g
s
.66994 .49728 m .66943 .50324 L .64572 .50162 L p .704 .655 .799 r
F P
0 g
s
.3551 .48002 m .35548 .47872 L .33176 .47663 L p .711 .498 .599 r
F P
0 g
s
.35548 .47872 m .3551 .48002 L .37429 .48153 L p .705 .432 .51 r
F P
0 g
s
.22051 .4167 m .21556 .43887 L .26587 .44817 L p .717 .581 .702 r
F P
0 g
s
.26374 .46191 m .26587 .44817 L .21556 .43887 L p .713 .577 .7 r
F P
0 g
s
.46127 .4827 m .46494 .48961 L .44765 .48826 L p .63 .74 .927 r
F P
0 g
s
.4473 .4861 m .44765 .48826 L .43298 .48711 L p .538 .78 .987 r
F P
0 g
s
.64572 .50162 m .64623 .49657 L .66994 .49728 L p .704 .655 .799 r
F P
0 g
s
.64623 .49657 m .64572 .50162 L .62647 .50041 L p .699 .692 .84 r
F P
0 g
s
.79023 .48421 m .78996 .50099 L .73895 .49939 L p .71 .604 .737 r
F P
0 g
s
.43174 .48701 m .41934 .48604 L p .43299 .48657 L .289 .742 .957 r
F P
0 g
s
.41934 .48604 m .41942 .4862 L .43299 .48657 L p .289 .742 .957 r
F P
0 g
s
.43066 .48685 m .43299 .48657 L .4315 .48653 L p .102 0 0 r
F P
0 g
s
.4315 .48653 m .41942 .4862 L p .43066 .48685 L .102 0 0 r
F P
0 g
s
.42455 .4896 m .43066 .48685 L .42536 .48744 L p .22 0 0 r
F P
0 g
s
.42536 .48744 m .41826 .48823 L p .42455 .4896 L .22 0 0 r
F P
0 g
s
.42079 .49398 m .4237 .49187 L p .42455 .4896 L 0 0 0 r
F P
0 g
s
.43066 .48685 m .42455 .4896 L .42919 .4874 L p .215 .732 .712 r
F P
0 g
s
.41942 .4862 m .41826 .48823 L .43066 .48685 L p .102 0 0 r
F P
0 g
s
.42919 .4874 m .43115 .48647 L p .43066 .48685 L .215 .732 .712 r
F P
0 g
s
.4237 .49187 m .43115 .48647 L .42455 .4896 L p 0 0 0 r
F P
0 g
s
.43299 .48657 m .43066 .48685 L .43773 .48489 L p .373 .798 .972 r
F P
0 g
s
.43773 .48489 m .4414 .48388 L p .43299 .48657 L .373 .798 .972 r
F P
0 g
s
.43299 .48657 m .43298 .48711 L .43174 .48701 L p .289 .742 .957 r
F P
0 g
s
.33137 .47815 m .33176 .47663 L .30164 .47392 L p .712 .533 .645 r
F P
0 g
s
.33176 .47663 m .33137 .47815 L .3551 .48002 L p .711 .498 .599 r
F P
0 g
s
.50592 .41026 m .50587 .4104 L .50555 .42398 L p .984 .846 .463 r
F P
0 g
s
.50555 .42398 m .50484 .42393 L .50592 .41026 L p .984 .846 .463 r
F P
0 g
s
.41942 .4862 m .41934 .48604 L .40579 .48497 L p .214 0 0 r
F P
0 g
s
.37655 .22893 m .34309 .24752 L .37084 .29061 L p .706 .597 .731 r
F P
0 g
s
.37084 .29061 m .3984 .27546 L .37655 .22893 L p .706 .597 .731 r
F P
0 g
s
.40589 .48553 m .40579 .48497 L .39142 .48384 L p .559 .067 .043 r
F P
0 g
s
.40579 .48497 m .40589 .48553 L .41942 .4862 L p .214 0 0 r
F P
0 g
s
.21748 .5503 m .22577 .58167 L .2738 .56633 L p .697 .568 .706 r
F P
0 g
s
.28452 .59397 m .2738 .56633 L .22577 .58167 L p .694 .57 .711 r
F P
0 g
s
.39152 .48467 m .39142 .48384 L .37518 .48256 L p .668 .307 .352 r
F P
0 g
s
.39142 .48384 m .39152 .48467 L .40589 .48553 L p .559 .067 .043 r
F P
0 g
s
.37534 .48362 m .37518 .48256 L .35599 .48105 L p .699 .426 .507 r
F P
0 g
s
.37518 .48256 m .37534 .48362 L .39152 .48467 L p .668 .307 .352 r
F P
0 g
s
.62647 .50041 m .627 .49616 L .64623 .49657 L p .699 .692 .84 r
F P
0 g
s
.627 .49616 m .62647 .50041 L .61031 .4994 L p .682 .742 .897 r
F P
0 g
s
.21556 .43887 m .21297 .45554 L .26374 .46191 L p .713 .577 .7 r
F P
0 g
s
.26281 .47041 m .26374 .46191 L .21297 .45554 L p .711 .574 .7 r
F P
0 g
s
.26374 .46191 m .26281 .47041 L .30164 .47392 L p .713 .566 .686 r
F P
0 g
s
.35608 .48239 m .35599 .48105 L .33226 .47919 L p .709 .496 .598 r
F P
0 g
s
.35599 .48105 m .35608 .48239 L .37534 .48362 L p .699 .426 .507 r
F P
0 g
s
.30124 .47578 m .30164 .47392 L .26281 .47041 L p .711 .556 .676 r
F P
0 g
s
.30164 .47392 m .30124 .47578 L .33137 .47815 L p .712 .533 .645 r
F P
0 g
s
.73895 .49939 m .73927 .48561 L .79023 .48421 L p .71 .604 .737 r
F P
0 g
s
.73927 .48561 m .73895 .49939 L .70007 .49816 L p .712 .617 .75 r
F P
0 g
s
.33234 .48074 m .33226 .47919 L .30213 .47682 L p .71 .531 .645 r
F P
0 g
s
.33226 .47919 m .33234 .48074 L .35608 .48239 L p .709 .496 .598 r
F P
0 g
s
.5084 .36617 m .50396 .36584 L .50363 .38205 L p .475 .389 .679 r
F P
0 g
s
.50363 .38205 m .50736 .38241 L .5084 .36617 L p .475 .389 .679 r
F P
0 g
s
.30219 .47871 m .30213 .47682 L .26327 .47376 L p .71 .555 .676 r
F P
0 g
s
.30213 .47682 m .30219 .47871 L .33234 .48074 L p .71 .531 .645 r
F P
0 g
s
.2132 .52256 m .21748 .5503 L .26716 .54036 L p .7 .568 .702 r
F P
0 g
s
.2738 .56633 m .26716 .54036 L .21748 .5503 L p .697 .568 .706 r
F P
0 g
s
.26281 .47041 m .26237 .47273 L .30124 .47578 L p .711 .556 .676 r
F P
0 g
s
.31905 .64765 m .3419 .67063 L .36697 .64268 L p .691 .591 .739 r
F P
0 g
s
.3881 .65845 m .36697 .64268 L .3419 .67063 L p .7 .604 .745 r
F P
0 g
s
.21297 .45554 m .21187 .46582 L .26281 .47041 L p .711 .574 .7 r
F P
0 g
s
.26237 .47273 m .26281 .47041 L .21187 .46582 L p .709 .569 .695 r
F P
0 g
s
.61031 .4994 m .61087 .4959 L .627 .49616 L p .682 .742 .897 r
F P
0 g
s
.61087 .4959 m .61031 .4994 L .59595 .49859 L p .628 .812 .971 r
F P
0 g
s
.2633 .47612 m .26327 .47376 L .2123 .46976 L p .709 .569 .695 r
F P
0 g
s
.26327 .47376 m .2633 .47612 L .30219 .47871 L p .71 .555 .676 r
F P
0 g
s
.21175 .49989 m .2132 .52256 L .26383 .51735 L p .704 .569 .7 r
F P
0 g
s
.26716 .54036 m .26383 .51735 L .2132 .52256 L p .7 .568 .702 r
F P
0 g
s
.21187 .46582 m .2114 .46872 L .26237 .47273 L p .709 .569 .695 r
F P
0 g
s
.30173 .48593 m .30219 .47871 L .2633 .47612 L p .708 .561 .686 r
F P
0 g
s
.30219 .47871 m .30173 .48593 L .33188 .48687 L p .708 .544 .664 r
F P
0 g
s
.33188 .48687 m .33234 .48074 L .30219 .47871 L p .708 .544 .664 r
F P
0 g
s
.2123 .46976 m .2123 .47269 L .2633 .47612 L p .709 .569 .695 r
F P
0 g
s
.26283 .48466 m .2633 .47612 L .2123 .47269 L p .708 .572 .699 r
F P
0 g
s
.2633 .47612 m .26283 .48466 L .30173 .48593 L p .708 .561 .686 r
F P
0 g
s
.21178 .48302 m .21175 .49989 L .26268 .49857 L p .706 .57 .699 r
F P
0 g
s
.26383 .51735 m .26268 .49857 L .21175 .49989 L p .704 .569 .7 r
F P
0 g
s
.33234 .48074 m .33188 .48687 L .3556 .48767 L p .707 .519 .631 r
F P
0 g
s
.3556 .48767 m .35608 .48239 L .33234 .48074 L p .707 .519 .631 r
F P
0 g
s
.70007 .49816 m .70039 .48669 L .73927 .48561 L p .712 .617 .75 r
F P
0 g
s
.70039 .48669 m .70007 .49816 L .66994 .49728 L p .715 .637 .769 r
F P
0 g
s
.4945 .29219 m .47878 .29322 L .48185 .32326 L p .655 .552 .726 r
F P
0 g
s
.48185 .32326 m .4953 .32254 L .4945 .29219 L p .655 .552 .726 r
F P
0 g
s
.2123 .47269 m .21178 .48302 L .26283 .48466 L p .708 .572 .699 r
F P
0 g
s
.26268 .49857 m .26283 .48466 L .21178 .48302 L p .706 .57 .699 r
F P
0 g
s
.35608 .48239 m .3556 .48767 L .37484 .48818 L p .703 .478 .58 r
F P
0 g
s
.37484 .48818 m .37534 .48362 L .35608 .48239 L p .703 .478 .58 r
F P
0 g
s
.59595 .49859 m .59669 .49601 L .61087 .4959 L p .628 .812 .971 r
F P
0 g
s
.59669 .49601 m .59595 .49859 L .58242 .49798 L p .408 .829 .965 r
F P
0 g
s
.37534 .48362 m .37484 .48818 L .39097 .48858 L p .691 .414 .498 r
F P
0 g
s
.39097 .48858 m .39152 .48467 L .37534 .48362 L p .691 .414 .498 r
F P
0 g
s
.26283 .48466 m .26268 .49857 L .30153 .49759 L p .705 .559 .686 r
F P
0 g
s
.30153 .49759 m .30173 .48593 L .26283 .48466 L p .705 .559 .686 r
F P
0 g
s
.3881 .65845 m .4098 .67035 L .42294 .6447 L p .713 .632 .766 r
F P
0 g
s
.44083 .65139 m .42294 .6447 L .4098 .67035 L p .729 .643 .762 r
F P
0 g
s
.5052 .32261 m .4953 .32254 L .49595 .3464 L p .619 .518 .717 r
F P
0 g
s
.49595 .3464 m .50443 .34649 L .5052 .32261 L p .619 .518 .717 r
F P
0 g
s
.39152 .48467 m .39097 .48858 L .40516 .48865 L p .655 .294 .348 r
F P
0 g
s
.40516 .48865 m .40589 .48553 L .39152 .48467 L p .655 .294 .348 r
F P
0 g
s
.48961 .58713 m .48448 .58854 L .48112 .60136 L p .932 .877 .759 r
F P
0 g
s
.48448 .58854 m .48961 .58713 L .4922 .57448 L p .938 .96 .665 r
F P
0 g
s
.47787 .61648 m .46785 .6158 L .46279 .63336 L p .807 .729 .778 r
F P
0 g
s
.46785 .6158 m .47787 .61648 L .48112 .60136 L p .848 .798 .802 r
F P
0 g
s
.66994 .49728 m .67032 .48754 L .70039 .48669 L p .715 .637 .769 r
F P
0 g
s
.67032 .48754 m .66994 .49728 L .64623 .49657 L p .718 .665 .797 r
F P
0 g
s
.30173 .48593 m .30153 .49759 L .33159 .49688 L p .703 .541 .665 r
F P
0 g
s
.33159 .49688 m .33188 .48687 L .30173 .48593 L p .703 .541 .665 r
F P
0 g
s
.49749 .45178 m .50424 .45607 L .50561 .43877 L p .912 .77 .69 r
F P
0 g
s
.50424 .45607 m .49749 .45178 L .49256 .45634 L p .891 .75 .7 r
F P
0 g
s
.26268 .49857 m .26383 .51735 L .30232 .51342 L p .701 .556 .687 r
F P
0 g
s
.30232 .51342 m .30153 .49759 L .26268 .49857 L p .701 .556 .687 r
F P
0 g
s
.78911 .46161 m .79023 .48421 L .73927 .48561 L p .714 .606 .736 r
F P
0 g
s
.50699 .39668 m .50652 .39683 L .50587 .4104 L p 0 0 0 r
F P
0 g
s
.50587 .4104 m .50592 .41026 L .50699 .39668 L p 0 0 0 r
F P
0 g
s
.58242 .49798 m .58359 .49669 L .59669 .49601 L p .408 .829 .965 r
F P
0 g
s
.58359 .49669 m .58242 .49798 L .56886 .49772 L p .162 0 0 r
F P
0 g
s
.40589 .48553 m .40516 .48865 L .41826 .48823 L p .528 .031 .02 r
F P
0 g
s
.41826 .48823 m .41942 .4862 L .40589 .48553 L p .528 .031 .02 r
F P
0 g
s
.47469 .25423 m .45174 .25777 L .45956 .29609 L p .679 .573 .729 r
F P
0 g
s
.45956 .29609 m .47878 .29322 L .47469 .25423 L p .679 .573 .729 r
F P
0 g
s
.41003 .21567 m .37655 .22893 L .3984 .27546 L p .699 .591 .731 r
F P
0 g
s
.3984 .27546 m .42589 .26459 L .41003 .21567 L p .699 .591 .731 r
F P
0 g
s
.49862 .54602 m .50056 .55294 L .49568 .56273 L p .061 0 .378 r
F P
0 g
s
.50056 .55294 m .49862 .54602 L .50438 .53305 L p .251 .096 .467 r
F P
0 g
s
.33188 .48687 m .33159 .49688 L .35526 .49633 L p .7 .513 .632 r
F P
0 g
s
.35526 .49633 m .3556 .48767 L .33188 .48687 L p .7 .513 .632 r
F P
0 g
s
.29963 .62166 m .31905 .64765 L .3477 .62346 L p .685 .577 .729 r
F P
0 g
s
.36697 .64268 m .3477 .62346 L .31905 .64765 L p .691 .591 .739 r
F P
0 g
s
.26383 .51735 m .26716 .54036 L .30493 .53283 L p .695 .554 .691 r
F P
0 g
s
.30493 .53283 m .30232 .51342 L .26383 .51735 L p .695 .554 .691 r
F P
0 g
s
.64623 .49657 m .64664 .48828 L .67032 .48754 L p .718 .665 .797 r
F P
0 g
s
.64664 .48828 m .64623 .49657 L .627 .49616 L p .72 .707 .837 r
F P
0 g
s
.73927 .48561 m .73834 .46698 L .78911 .46161 L p .714 .606 .736 r
F P
0 g
s
.73834 .46698 m .73927 .48561 L .70039 .48669 L p .718 .621 .748 r
F P
0 g
s
.50325 .43832 m .50561 .43877 L .50677 .42408 L p .975 .828 .634 r
F P
0 g
s
.50963 .34681 m .50443 .34649 L .50396 .36584 L p .563 .464 .7 r
F P
0 g
s
.50396 .36584 m .5084 .36617 L .50963 .34681 L p .563 .464 .7 r
F P
0 g
s
.30153 .49759 m .30232 .51342 L .33203 .51053 L p .696 .537 .667 r
F P
0 g
s
.33203 .51053 m .33159 .49688 L .30153 .49759 L p .696 .537 .667 r
F P
0 g
s
.42294 .6447 m .44083 .65139 L .44886 .63037 L p .739 .674 .787 r
F P
0 g
s
.46279 .63336 m .44886 .63037 L .44083 .65139 L p .761 .682 .775 r
F P
0 g
s
.5712 .49844 m .56045 .50194 L p .56827 .49965 L .178 0 0 r
F P
0 g
s
.5712 .49844 m .58359 .49669 L p .57376 .49738 L .162 0 0 r
F P
0 g
s
.58686 .49375 m .58359 .49669 L .5712 .49844 L p 0 0 0 r
F P
0 g
s
.57731 .497 m .5712 .49844 L p .56827 .49965 L .178 0 0 r
F P
0 g
s
.56886 .49772 m .5712 .49844 L p .57376 .49738 L .162 0 0 r
F P
0 g
s
.5712 .49844 m .56886 .49772 L .55455 .49839 L p .476 .027 .104 r
F P
0 g
s
.3556 .48767 m .35526 .49633 L .37423 .49575 L p .691 .471 .584 r
F P
0 g
s
.37423 .49575 m .37484 .48818 L .3556 .48767 L p .691 .471 .584 r
F P
0 g
s
.44886 .63037 m .46279 .63336 L .46785 .6158 L p .784 .73 .803 r
F P
0 g
s
.26716 .54036 m .2738 .56633 L .31026 .55479 L p .689 .554 .697 r
F P
0 g
s
.31026 .55479 m .30493 .53283 L .26716 .54036 L p .689 .554 .697 r
F P
0 g
s
.50813 .38225 m .50736 .38241 L .50652 .39683 L p 0 0 .44 r
F P
0 g
s
.50652 .39683 m .50699 .39668 L .50813 .38225 L p 0 0 .44 r
F P
0 g
s
.28452 .59397 m .29963 .62166 L .3315 .60153 L p .682 .566 .717 r
F P
0 g
s
.3477 .62346 m .3315 .60153 L .29963 .62166 L p .685 .577 .729 r
F P
0 g
s
.70039 .48669 m .69976 .47109 L .73834 .46698 L p .718 .621 .748 r
F P
0 g
s
.69976 .47109 m .70039 .48669 L .67032 .48754 L p .725 .642 .766 r
F P
0 g
s
.627 .49616 m .62766 .48908 L .64664 .48828 L p .72 .707 .837 r
F P
0 g
s
.62766 .48908 m .627 .49616 L .61087 .4959 L p .717 .768 .893 r
F P
0 g
s
.50606 .42416 m .50677 .42408 L .50785 .41041 L p .984 .846 .462 r
F P
0 g
s
.4414 .48388 m .4473 .4861 L .43299 .48657 L p .373 .798 .972 r
F P
0 g
s
.2738 .56633 m .28452 .59397 L .31894 .57819 L p .684 .558 .706 r
F P
0 g
s
.31894 .57819 m .31026 .55479 L .2738 .56633 L p .684 .558 .706 r
F P
0 g
s
.3315 .60153 m .31894 .57819 L .28452 .59397 L p .682 .566 .717 r
F P
0 g
s
.37484 .48818 m .37423 .49575 L .38993 .49508 L p .673 .403 .505 r
F P
0 g
s
.38993 .49508 m .39097 .48858 L .37484 .48818 L p .673 .403 .505 r
F P
0 g
s
.78521 .43389 m .78911 .46161 L .73834 .46698 L p .718 .608 .733 r
F P
0 g
s
.33159 .49688 m .33203 .51053 L .35523 .50816 L p .687 .507 .637 r
F P
0 g
s
.35523 .50816 m .35526 .49633 L .33159 .49688 L p .687 .507 .637 r
F P
0 g
s
.50788 .41063 m .50785 .41041 L .50892 .39683 L p 0 0 0 r
F P
0 g
s
.50785 .41041 m .50788 .41063 L .50606 .42416 L p .984 .846 .462 r
F P
0 g
s
.36697 .64268 m .3881 .65845 L .40417 .63493 L p .695 .614 .762 r
F P
0 g
s
.42294 .6447 m .40417 .63493 L .3881 .65845 L p .713 .632 .766 r
F P
0 g
s
.44148 .20725 m .41003 .21567 L .42589 .26459 L p .694 .584 .728 r
F P
0 g
s
.42589 .26459 m .45174 .25777 L .44148 .20725 L p .694 .584 .728 r
F P
0 g
s
.50612 .29221 m .4945 .29219 L .4953 .32254 L p .652 .544 .719 r
F P
0 g
s
.4953 .32254 m .5052 .32261 L .50612 .29221 L p .652 .544 .719 r
F P
0 g
s
.30232 .51342 m .30493 .53283 L .33393 .52711 L p .686 .533 .673 r
F P
0 g
s
.33393 .52711 m .33203 .51053 L .30232 .51342 L p .686 .533 .673 r
F P
0 g
s
.50941 .36595 m .5084 .36617 L .50736 .38241 L p .31 .241 .615 r
F P
0 g
s
.50736 .38241 m .50813 .38225 L .50941 .36595 L p .31 .241 .615 r
F P
0 g
s
.4922 .57448 m .48826 .57768 L .48448 .58854 L p .938 .96 .665 r
F P
0 g
s
.67032 .48754 m .66999 .47423 L .69976 .47109 L p .725 .642 .766 r
F P
0 g
s
.66999 .47423 m .67032 .48754 L .64664 .48828 L p .735 .675 .792 r
F P
0 g
s
.55455 .49839 m .56045 .50194 L .5712 .49844 L p .476 .027 .104 r
F P
0 g
s
.56045 .50194 m .55455 .49839 L .54058 .50221 L p .531 .154 .271 r
F P
0 g
s
.61087 .4959 m .61196 .49004 L .62766 .48908 L p .717 .768 .893 r
F P
0 g
s
.61196 .49004 m .61087 .4959 L .59669 .49601 L p .689 .854 .961 r
F P
0 g
s
.51128 .32293 m .5052 .32261 L .50443 .34649 L p .617 .51 .709 r
F P
0 g
s
.50443 .34649 m .50963 .34681 L .51128 .32293 L p .617 .51 .709 r
F P
0 g
s
.49346 .25291 m .47469 .25423 L .47878 .29322 L p .676 .566 .723 r
F P
0 g
s
.47878 .29322 m .4945 .29219 L .49346 .25291 L p .676 .566 .723 r
F P
0 g
s
.50937 .39709 m .50892 .39683 L .51006 .38241 L p 0 0 .441 r
F P
0 g
s
.50892 .39683 m .50937 .39709 L .50788 .41063 L p 0 0 0 r
F P
0 g
s
.73834 .46698 m .73527 .44408 L .78521 .43389 L p .718 .608 .733 r
F P
0 g
s
.73527 .44408 m .73834 .46698 L .69976 .47109 L p .725 .623 .744 r
F P
0 g
s
.48112 .60136 m .47228 .60184 L .46785 .6158 L p .848 .798 .802 r
F P
0 g
s
.47228 .60184 m .48112 .60136 L .48448 .58854 L p .892 .895 .824 r
F P
0 g
s
.39097 .48858 m .38993 .49508 L .40338 .49399 L p .628 .284 .369 r
F P
0 g
s
.40338 .49399 m .40516 .48865 L .39097 .48858 L p .628 .284 .369 r
F P
0 g
s
.4473 .4861 m .4414 .48388 L .44788 .48017 L p .588 .869 .994 r
F P
0 g
s
.44788 .48017 m .46127 .4827 L .4473 .4861 L p .588 .869 .994 r
F P
0 g
s
.51093 .34667 m .50963 .34681 L .5084 .36617 L p .484 .392 .675 r
F P
0 g
s
.5084 .36617 m .50941 .36595 L .51093 .34667 L p .484 .392 .675 r
F P
0 g
s
.51079 .38269 m .51006 .38241 L .51135 .36611 L p .311 .241 .615 r
F P
0 g
s
.51006 .38241 m .51079 .38269 L .50937 .39709 L p 0 0 .441 r
F P
0 g
s
.35526 .49633 m .35523 .50816 L .37368 .50613 L p .672 .461 .591 r
F P
0 g
s
.37368 .50613 m .37423 .49575 L .35526 .49633 L p .672 .461 .591 r
F P
0 g
s
.30493 .53283 m .31026 .55479 L .33806 .54606 L p .676 .534 .683 r
F P
0 g
s
.33806 .54606 m .33393 .52711 L .30493 .53283 L p .676 .534 .683 r
F P
0 g
s
.64664 .48828 m .64676 .4769 L .66999 .47423 L p .735 .675 .792 r
F P
0 g
s
.64676 .4769 m .64664 .48828 L .62766 .48908 L p .747 .722 .829 r
F P
0 g
s
.59669 .49601 m .59849 .49151 L .61196 .49004 L p .689 .854 .961 r
F P
0 g
s
.59849 .49151 m .59669 .49601 L .58359 .49669 L p .542 .908 .959 r
F P
0 g
s
.46931 .20285 m .44148 .20725 L .45174 .25777 L p .691 .579 .725 r
F P
0 g
s
.45174 .25777 m .47469 .25423 L .46931 .20285 L p .691 .579 .725 r
F P
0 g
s
.50971 .4101 m .50788 .41063 L .50937 .39709 L p 0 0 .406 r
F P
0 g
s
.50621 .42231 m .50606 .42416 L .50626 .42267 L p .725 .669 .119 r
F P
0 g
s
.50626 .42267 m .50788 .41063 L p .50621 .42231 L .725 .669 .119 r
F P
0 g
s
.50788 .41063 m .50971 .4101 L .50621 .42231 L p .725 .669 .119 r
F P
0 g
s
.50925 .41725 m .50621 .42231 L .50771 .41709 L p 0 0 .05 r
F P
0 g
s
.50771 .41709 m .50971 .4101 L p .50925 .41725 L 0 0 .05 r
F P
0 g
s
.51325 .41501 m .51088 .41741 L p .50925 .41725 L 0 0 0 r
F P
0 g
s
.50621 .42231 m .50925 .41725 L .50612 .42169 L p .738 .838 .388 r
F P
0 g
s
.50612 .42169 m .5048 .42356 L p .50621 .42231 L .738 .838 .388 r
F P
0 g
s
.51088 .41741 m .5048 .42356 L .50925 .41725 L p 0 0 0 r
F P
0 g
s
.51232 .36647 m .51135 .36611 L .51287 .34682 L p .485 .392 .675 r
F P
0 g
s
.51135 .36611 m .51232 .36647 L .51079 .38269 L p .311 .241 .615 r
F P
0 g
s
.69976 .47109 m .69733 .45191 L .73527 .44408 L p .725 .623 .744 r
F P
0 g
s
.69733 .45191 m .69976 .47109 L .66999 .47423 L p .737 .647 .759 r
F P
0 g
s
.3477 .62346 m .36697 .64268 L .38592 .62169 L p .679 .593 .751 r
F P
0 g
s
.40417 .63493 m .38592 .62169 L .36697 .64268 L p .695 .614 .762 r
F P
0 g
s
.51232 .39708 m .50937 .39709 L .51079 .38269 L p .309 .229 .602 r
F P
0 g
s
.50937 .39709 m .51232 .39708 L .50971 .4101 L p 0 0 .406 r
F P
0 g
s
.33203 .51053 m .33393 .52711 L .35633 .52272 L p .672 .502 .647 r
F P
0 g
s
.35633 .52272 m .35523 .50816 L .33203 .51053 L p .672 .502 .647 r
F P
0 g
s
.51332 .29256 m .50612 .29221 L .5052 .32261 L p .652 .539 .714 r
F P
0 g
s
.5052 .32261 m .51128 .32293 L .51332 .29256 L p .652 .539 .714 r
F P
0 g
s
.50606 .42416 m .50621 .42231 L .50132 .4327 L p .982 .884 .529 r
F P
0 g
s
.50132 .4327 m .50325 .43832 L .50606 .42416 L p .982 .884 .529 r
F P
0 g
s
.40516 .48865 m .40338 .49399 L .41501 .49224 L p .509 .058 .116 r
F P
0 g
s
.41501 .49224 m .41826 .48823 L .40516 .48865 L p .509 .058 .116 r
F P
0 g
s
.50438 .53305 m .50551 .54748 L .50056 .55294 L p .251 .096 .467 r
F P
0 g
s
.50551 .54748 m .50438 .53305 L .5093 .5289 L p .286 .107 .454 r
F P
0 g
s
.51282 .3228 m .51128 .32293 L .50963 .34681 L p .582 .477 .7 r
F P
0 g
s
.50963 .34681 m .51093 .34667 L .51282 .3228 L p .582 .477 .7 r
F P
0 g
s
.77733 .40242 m .78521 .43389 L .73527 .44408 L p .721 .607 .729 r
F P
0 g
s
.40417 .63493 m .42294 .6447 L .43305 .62524 L p .713 .656 .792 r
F P
0 g
s
.44886 .63037 m .43305 .62524 L .42294 .6447 L p .739 .674 .787 r
F P
0 g
s
.51456 .38293 m .51079 .38269 L .51232 .36647 L p .476 .379 .665 r
F P
0 g
s
.51079 .38269 m .51456 .38293 L .51232 .39708 L p .309 .229 .602 r
F P
0 g
s
.50738 .25293 m .49346 .25291 L .4945 .29219 L p .674 .561 .719 r
F P
0 g
s
.4945 .29219 m .50612 .29221 L .50738 .25293 L p .674 .561 .719 r
F P
0 g
s
.46785 .6158 m .45541 .61408 L .44886 .63037 L p .784 .73 .803 r
F P
0 g
s
.45541 .61408 m .46785 .6158 L .47228 .60184 L p .81 .797 .84 r
F P
0 g
s
.31026 .55479 m .31894 .57819 L .34509 .56629 L p .668 .539 .698 r
F P
0 g
s
.34509 .56629 m .33806 .54606 L .31026 .55479 L p .668 .539 .698 r
F P
0 g
s
.51287 .34682 m .51414 .34715 L .51232 .36647 L p .485 .392 .675 r
F P
0 g
s
.51677 .36681 m .51232 .36647 L .51414 .34715 L p .564 .457 .691 r
F P
0 g
s
.51232 .36647 m .51677 .36681 L .51456 .38293 L p .476 .379 .665 r
F P
0 g
s
.51414 .34715 m .51287 .34682 L .51475 .32295 L p .582 .477 .7 r
F P
0 g
s
.50325 .43832 m .50132 .4327 L .49636 .43877 L p .972 .911 .688 r
F P
0 g
s
.49636 .43877 m .49749 .45178 L .50325 .43832 L p .972 .911 .688 r
F P
0 g
s
.37423 .49575 m .37368 .50613 L .38849 .50421 L p .644 .392 .523 r
F P
0 g
s
.38849 .50421 m .38993 .49508 L .37423 .49575 L p .644 .392 .523 r
F P
0 g
s
.43305 .62524 m .44886 .63037 L .45541 .61408 L p .75 .717 .821 r
F P
0 g
s
.3315 .60153 m .3477 .62346 L .36939 .60528 L p .669 .571 .735 r
F P
0 g
s
.38592 .62169 m .36939 .60528 L .3477 .62346 L p .679 .593 .751 r
F P
0 g
s
.73527 .44408 m .72891 .41815 L .77733 .40242 L p .721 .607 .729 r
F P
0 g
s
.72891 .41815 m .73527 .44408 L .69733 .45191 L p .731 .622 .737 r
F P
0 g
s
.51475 .32295 m .51625 .3233 L .51414 .34715 L p .582 .477 .7 r
F P
0 g
s
.51934 .34759 m .51414 .34715 L .51625 .3233 L p .618 .506 .704 r
F P
0 g
s
.51414 .34715 m .51934 .34759 L .51677 .36681 L p .564 .457 .691 r
F P
0 g
s
.51521 .29246 m .51332 .29256 L .51128 .32293 L p .632 .52 .709 r
F P
0 g
s
.51128 .32293 m .51282 .3228 L .51521 .29246 L p .632 .52 .709 r
F P
0 g
s
.62766 .48908 m .62828 .47932 L .64676 .4769 L p .747 .722 .829 r
F P
0 g
s
.62828 .47932 m .62766 .48908 L .61196 .49004 L p .761 .79 .877 r
F P
0 g
s
.54058 .50221 m .55397 .50621 L .56045 .50194 L p .531 .154 .271 r
F P
0 g
s
.55397 .50621 m .54058 .50221 L .5355 .50658 L p .511 .153 .296 r
F P
0 g
s
.31894 .57819 m .3315 .60153 L .35558 .58644 L p .666 .552 .717 r
F P
0 g
s
.35558 .58644 m .34509 .56629 L .31894 .57819 L p .666 .552 .717 r
F P
0 g
s
.49207 .20131 m .46931 .20285 L .47469 .25423 L p .689 .574 .721 r
F P
0 g
s
.47469 .25423 m .49346 .25291 L .49207 .20131 L p .689 .574 .721 r
F P
0 g
s
.66999 .47423 m .66823 .458 L .69733 .45191 L p .737 .647 .759 r
F P
0 g
s
.66823 .458 m .66999 .47423 L .64676 .4769 L p .753 .681 .781 r
F P
0 g
s
.49709 .56343 m .49266 .56906 L p .49463 .56503 L 0 0 .053 r
F P
0 g
s
.50056 .55294 m .49709 .56343 L p .49463 .56503 L 0 0 .053 r
F P
0 g
s
.49709 .56343 m .5003 .56072 L p .49883 .5623 L 0 0 0 r
F P
0 g
s
.49266 .56906 m .49709 .56343 L p .49373 .56712 L 0 0 0 r
F P
0 g
s
.49568 .56273 m .49266 .56906 L p .49146 .57123 L 0 0 0 r
F P
0 g
s
.48517 .57649 m .49266 .56906 L p .49373 .56712 L 0 0 0 r
F P
0 g
s
.48517 .57649 m .48097 .58227 L p .48444 .57834 L .702 .934 .623 r
F P
0 g
s
.49266 .56906 m .48517 .57649 L p .48444 .57834 L .702 .934 .623 r
F P
0 g
s
.48868 .57317 m .48517 .57649 L p .48713 .57435 L 0 0 0 r
F P
0 g
s
.49709 .56343 m .48868 .57317 L p .48713 .57435 L 0 0 0 r
F P
0 g
s
.49266 .56906 m .48826 .57768 L p .49146 .57123 L 0 0 0 r
F P
0 g
s
.48097 .58227 m .48826 .57768 L .49266 .56906 L p .702 .934 .623 r
F P
0 g
s
.49095 .57164 m .48868 .57317 L p .48933 .57248 L 0 0 0 r
F P
0 g
s
.5003 .56072 m .49095 .57164 L p .48933 .57248 L 0 0 0 r
F P
0 g
s
.49095 .57164 m .49173 .57122 L p .49152 .57135 L 0 0 0 r
F P
0 g
s
.48868 .57317 m .49095 .57164 L p .48971 .5724 L 0 0 0 r
F P
0 g
s
.48868 .57317 m .49709 .56343 L p .49883 .5623 L 0 0 0 r
F P
0 g
s
.47659 .58035 m .48868 .57317 L p .48971 .5724 L 0 0 0 r
F P
0 g
s
.47659 .58035 m .47383 .58236 L p .47558 .58128 L .469 .867 .688 r
F P
0 g
s
.48868 .57317 m .47659 .58035 L p .47558 .58128 L .469 .867 .688 r
F P
0 g
s
.4783 .57948 m .47659 .58035 L p .47714 .58002 L 0 0 0 r
F P
0 g
s
.49095 .57164 m .4783 .57948 L p .47714 .58002 L 0 0 0 r
F P
0 g
s
.47887 .57925 m .4783 .57948 L p .4784 .57942 L 0 0 0 r
F P
0 g
s
.49173 .57122 m .47887 .57925 L p .4784 .57942 L 0 0 0 r
F P
0 g
s
.47383 .58236 m .48517 .57649 L p .48577 .57498 L .469 .867 .688 r
F P
0 g
s
.48517 .57649 m .48868 .57317 L p .48577 .57498 L .469 .867 .688 r
F P
0 g
s
.47935 .57909 m .47887 .57925 L p .479 .57917 L 0 0 0 r
F P
0 g
s
.49238 .57091 m .47935 .57909 L p .479 .57917 L 0 0 0 r
F P
0 g
s
.47935 .57909 m .48078 .57873 L p .48038 .57884 L 0 0 0 r
F P
0 g
s
.47887 .57925 m .47935 .57909 L p .47926 .57911 L 0 0 0 r
F P
0 g
s
.4783 .57948 m .49095 .57164 L p .49152 .57135 L 0 0 0 r
F P
0 g
s
.47887 .57925 m .49173 .57122 L .49238 .57091 L p 0 0 0 r
F P
0 g
s
.46334 .58328 m .4783 .57948 L p .4787 .57929 L 0 0 0 r
F P
0 g
s
.4783 .57948 m .46624 .58254 L p .46205 .58374 L .26 .766 .755 r
F P
0 g
s
.46624 .58254 m .46334 .58328 L .46305 .58338 L p .26 .766 .755 r
F P
0 g
s
.46305 .58338 m .46205 .58374 L p .46624 .58254 L .26 .766 .755 r
F P
0 g
s
.46989 .58158 m .46374 .58319 L .46337 .58327 L 0 0 0 r
F
.47887 .57925 m .46869 .5819 L p .46989 .58158 L F P
0 g
s
.46869 .5819 m .46374 .58319 L p .46989 .58158 L 0 0 0 r
F P
0 g
s
.46374 .58319 m .46869 .5819 L p .47926 .57911 L 0 0 0 r
F P
0 g
s
.46869 .5819 m .47887 .57925 L p .47926 .57911 L 0 0 0 r
F P
0 g
s
.47926 .57911 m .46869 .5819 L .47926 .57911 L 0 0 0 r
F
.48038 .57884 m .46617 .58258 L .47613 .57994 L F
.46409 .58312 m .46691 .58238 L p .46617 .58258 L F P
0 g
s
.46691 .58238 m .47613 .57994 L p .46617 .58258 L 0 0 0 r
F P
0 g
s
.47613 .57994 m .47935 .57909 L p .47958 .57903 L 0 0 0 r
F P
0 g
s
.48038 .57884 m .47613 .57994 L .47958 .57903 L 0 0 0 r
F
.46374 .58319 m .46334 .58328 L p .46337 .58327 L F P
0 g
s
.46409 .58312 m .46374 .58319 L p .46384 .58316 L 0 0 0 r
F P
0 g
s
.47935 .57909 m .46409 .58312 L p .46384 .58316 L 0 0 0 r
F P
0 g
s
.46205 .58374 m .47659 .58035 L p .47724 .57976 L .26 .766 .755 r
F P
0 g
s
.46511 .58302 m .46409 .58312 L p .46479 .58294 L 0 0 0 r
F P
0 g
s
.48078 .57873 m .46511 .58302 L p .46479 .58294 L 0 0 0 r
F P
0 g
s
.45985 .58498 m .47383 .58236 L .47659 .58035 L p .433 .873 .882 r
F P
0 g
s
.47659 .58035 m .46205 .58374 L .45985 .58498 L p .433 .873 .882 r
F P
0 g
s
.46511 .58302 m .46678 .58322 L p .46565 .58316 L .187 0 0 r
F P
0 g
s
.46409 .58312 m .46511 .58302 L p .46483 .58301 L 0 .567 .724 r
F P
0 g
s
.44787 .58228 m .46409 .58312 L p .46483 .58301 L 0 .567 .724 r
F P
0 g
s
.4486 .58229 m .44787 .58228 L p .44859 .58231 L 0 .567 .724 r
F P
0 g
s
.46511 .58302 m .4486 .58229 L p .44859 .58231 L 0 .567 .724 r
F P
0 g
s
.44764 .58229 m .46374 .58319 L p .46405 .58312 L .026 .596 .761 r
F P
0 g
s
.46334 .58328 m .44734 .58233 L .44641 .58255 L p .16 .688 .864 r
F P
0 g
s
.44734 .58233 m .46334 .58328 L .46374 .58319 L p .091 .643 .814 r
F P
0 g
s
.46374 .58319 m .44764 .58229 L .44734 .58233 L p .091 .643 .814 r
F P
0 g
s
.46409 .58312 m .44787 .58228 L .44764 .58229 L p .026 .596 .761 r
F P
0 g
s
.44966 .58265 m .4486 .58229 L p .45019 .58237 L .187 0 0 r
F P
0 g
s
.46678 .58322 m .44966 .58265 L p .45019 .58237 L .187 0 0 r
F P
0 g
s
.44465 .5834 m .45985 .58498 L .46205 .58374 L p .345 .782 .965 r
F P
0 g
s
.46205 .58374 m .44641 .58255 L .44465 .5834 L p .345 .782 .965 r
F P
0 g
s
.44641 .58255 m .46205 .58374 L .46334 .58328 L p .16 .688 .864 r
F P
0 g
s
.44966 .58265 m .45087 .58384 L p .44893 .58303 L .489 0 0 r
F P
0 g
s
.4486 .58229 m .44966 .58265 L p .44863 .58226 L .299 0 0 r
F P
0 g
s
.4486 .58229 m .46511 .58302 L p .46565 .58316 L .187 0 0 r
F P
0 g
s
.43141 .57646 m .44641 .58255 L .44734 .58233 L p .092 .564 .907 r
F P
0 g
s
.44734 .58233 m .43212 .57624 L .43141 .57646 L p .092 .564 .907 r
F P
0 g
s
.43212 .57624 m .44734 .58233 L .44764 .58229 L p 0 .492 .84 r
F P
0 g
s
.44764 .58229 m .43232 .57621 L .43212 .57624 L p 0 .492 .84 r
F P
0 g
s
.43232 .57621 m .44764 .58229 L .44787 .58228 L p 0 .412 .754 r
F P
0 g
s
.44787 .58228 m .43246 .57623 L .43232 .57621 L p 0 .412 .754 r
F P
0 g
s
.43246 .57623 m .44787 .58228 L .4486 .58229 L p 0 .413 .751 r
F P
0 g
s
.43289 .57627 m .43246 .57623 L p .43294 .5764 L 0 .413 .751 r
F P
0 g
s
.4486 .58229 m .43289 .57627 L p .43294 .5764 L 0 .413 .751 r
F P
0 g
s
.43289 .57627 m .43345 .57659 L p .4328 .57605 L 0 .12 .597 r
F P
0 g
s
.41981 .56537 m .43289 .57627 L p .4328 .57605 L 0 .12 .597 r
F P
0 g
s
.43345 .57659 m .44966 .58265 L p .44893 .58303 L .489 0 0 r
F P
0 g
s
.43289 .57627 m .4486 .58229 L p .44863 .58226 L .299 0 0 r
F P
0 g
s
.46374 .58319 m .46409 .58312 L p .46405 .58312 L .026 .596 .761 r
F P
0 g
s
.4783 .57948 m .47887 .57925 L p .4787 .57929 L 0 0 0 r
F P
0 g
s
.47659 .58035 m .4783 .57948 L p .47724 .57976 L .26 .766 .755 r
F P
0 g
s
.58359 .49669 m .58686 .49375 L .59849 .49151 L p .542 .908 .959 r
F P
0 g
s
.36939 .60528 m .35558 .58644 L .3315 .60153 L p .669 .571 .735 r
F P
0 g
s
.51625 .3233 m .51475 .32295 L .51714 .29261 L p .632 .52 .709 r
F P
0 g
s
.51594 .25333 m .50738 .25293 L .50612 .29221 L p .674 .558 .716 r
F P
0 g
s
.50612 .29221 m .51332 .29256 L .51594 .25333 L p .674 .558 .716 r
F P
0 g
s
.41826 .48823 m .41501 .49224 L .42455 .4896 L p .22 0 0 r
F P
0 g
s
.48448 .58854 m .47662 .59071 L .47228 .60184 L p .892 .895 .824 r
F P
0 g
s
.47662 .59071 m .48448 .58854 L .48826 .57768 L p .887 .988 .799 r
F P
0 g
s
.51714 .29261 m .519 .29298 L .51625 .3233 L p .632 .52 .709 r
F P
0 g
s
.52233 .32385 m .51625 .3233 L .519 .29298 L p .652 .537 .71 r
F P
0 g
s
.51625 .3233 m .52233 .32385 L .51934 .34759 L p .618 .506 .704 r
F P
0 g
s
.33393 .52711 m .33806 .54606 L .35927 .53943 L p .656 .503 .664 r
F P
0 g
s
.35927 .53943 m .35633 .52272 L .33393 .52711 L p .656 .503 .664 r
F P
0 g
s
.46127 .4827 m .44788 .48017 L .44968 .47857 L p .737 .88 .946 r
F P
0 g
s
.44968 .47857 m .46635 .47871 L .46127 .4827 L p .737 .88 .946 r
F P
0 g
s
.35523 .50816 m .35633 .52272 L .37382 .51909 L p .648 .455 .609 r
F P
0 g
s
.37382 .51909 m .37368 .50613 L .35523 .50816 L p .648 .455 .609 r
F P
0 g
s
.76458 .36876 m .77733 .40242 L .72891 .41815 L p .723 .605 .724 r
F P
0 g
s
.5183 .25326 m .51594 .25333 L .51332 .29256 L p .664 .548 .714 r
F P
0 g
s
.51332 .29256 m .51521 .29246 L .5183 .25326 L p .664 .548 .714 r
F P
0 g
s
.50902 .20128 m .49207 .20131 L .49346 .25291 L p .688 .571 .719 r
F P
0 g
s
.49346 .25291 m .50738 .25293 L .50902 .20128 L p .688 .571 .719 r
F P
0 g
s
.69733 .45191 m .69221 .43013 L .72891 .41815 L p .731 .622 .737 r
F P
0 g
s
.69221 .43013 m .69733 .45191 L .66823 .458 L p .747 .645 .748 r
F P
0 g
s
.52414 .36758 m .51677 .36681 L .51934 .34759 L p .571 .452 .679 r
F P
0 g
s
.51677 .36681 m .52414 .36758 L .52086 .38317 L p .488 .373 .648 r
F P
0 g
s
.52086 .38317 m .51456 .38293 L .51677 .36681 L p .488 .373 .648 r
F P
0 g
s
.52781 .34874 m .51934 .34759 L .52233 .32385 L p .621 .502 .696 r
F P
0 g
s
.51934 .34759 m .52781 .34874 L .52414 .36758 L p .571 .452 .679 r
F P
0 g
s
.519 .29298 m .51714 .29261 L .52023 .25341 L p .664 .548 .714 r
F P
0 g
s
.38592 .62169 m .40417 .63493 L .41646 .61723 L p .685 .628 .786 r
F P
0 g
s
.43305 .62524 m .41646 .61723 L .40417 .63493 L p .713 .656 .792 r
F P
0 g
s
.5093 .5289 m .50749 .54609 L .50551 .54748 L p .286 .107 .454 r
F P
0 g
s
.50749 .54609 m .5093 .5289 L .51404 .52766 L p .285 .082 .419 r
F P
0 g
s
.52081 .51594 m .51404 .52766 L .5093 .5289 L p .439 .224 .489 r
F P
0 g
s
.51456 .38293 m .52086 .38317 L .51747 .3965 L p .342 .23 .579 r
F P
0 g
s
.51747 .3965 m .51232 .39708 L .51456 .38293 L p .342 .23 .579 r
F P
0 g
s
.38993 .49508 m .38849 .50421 L .40051 .50201 L p .588 .281 .416 r
F P
0 g
s
.40051 .50201 m .40338 .49399 L .38993 .49508 L p .588 .281 .416 r
F P
0 g
s
.52023 .25341 m .52256 .25382 L .519 .29298 L p .664 .548 .714 r
F P
0 g
s
.52618 .29368 m .519 .29298 L .52256 .25382 L p .674 .557 .714 r
F P
0 g
s
.519 .29298 m .52618 .29368 L .52233 .32385 L p .652 .537 .71 r
F P
0 g
s
.53219 .32522 m .52233 .32385 L .52618 .29368 L p .654 .534 .706 r
F P
0 g
s
.52233 .32385 m .53219 .32522 L .52781 .34874 L p .621 .502 .696 r
F P
0 g
s
.61196 .49004 m .61345 .48171 L .62828 .47932 L p .761 .79 .877 r
F P
0 g
s
.61345 .48171 m .61196 .49004 L .59849 .49151 L p .766 .883 .93 r
F P
0 g
s
.49749 .45178 m .49636 .43877 L .49437 .44041 L p .911 .896 .8 r
F P
0 g
s
.49437 .44041 m .49256 .45634 L .49749 .45178 L p .911 .896 .8 r
F P
0 g
s
.64676 .4769 m .64576 .46285 L .66823 .458 L p .753 .681 .781 r
F P
0 g
s
.64576 .46285 m .64676 .4769 L .62828 .47932 L p .776 .729 .809 r
F P
0 g
s
.72891 .41815 m .71845 .39045 L .76458 .36876 L p .723 .605 .724 r
F P
0 g
s
.71845 .39045 m .72891 .41815 L .69221 .43013 L p .735 .618 .728 r
F P
0 g
s
.51941 .20176 m .50902 .20128 L .50738 .25293 L p .688 .57 .717 r
F P
0 g
s
.50738 .25293 m .51594 .25333 L .51941 .20176 L p .688 .57 .717 r
F P
0 g
s
.51232 .39708 m .51747 .3965 L .51367 .40796 L p .064 0 .412 r
F P
0 g
s
.51367 .40796 m .50971 .4101 L .51232 .39708 L p .064 0 .412 r
F P
0 g
s
.5355 .50658 m .55216 .50806 L .55397 .50621 L p .511 .153 .296 r
F P
0 g
s
.55216 .50806 m .5355 .50658 L .5333 .51125 L p .475 .122 .287 r
F P
0 g
s
.52081 .51594 m .5333 .51125 L .5355 .50658 L p .519 .239 .43 r
F P
0 g
s
.52256 .25382 m .53109 .25469 L .52618 .29368 L p .674 .557 .714 r
F P
0 g
s
.53772 .29535 m .52618 .29368 L .53109 .25469 L p .675 .555 .711 r
F P
0 g
s
.52618 .29368 m .53772 .29535 L .53219 .32522 L p .654 .534 .706 r
F P
0 g
s
.5707 .50076 m .57731 .497 L p .5731 .49823 L .178 0 0 r
F P
0 g
s
.56045 .50194 m .5707 .50076 L p .5731 .49823 L .178 0 0 r
F P
0 g
s
.5707 .50076 m .56727 .50372 L p .56902 .50255 L 0 0 0 r
F P
0 g
s
.57731 .497 m .5707 .50076 L p .57481 .49809 L 0 0 0 r
F P
0 g
s
.5712 .49844 m .57731 .497 L p .5801 .49577 L 0 0 0 r
F P
0 g
s
.58525 .4913 m .57731 .497 L p .57481 .49809 L 0 0 0 r
F P
0 g
s
.57731 .497 m .58686 .49375 L p .5801 .49577 L 0 0 0 r
F P
0 g
s
.592 .48776 m .58686 .49375 L .57731 .497 L p .51 .9 .748 r
F P
0 g
s
.58525 .4913 m .592 .48776 L p .58763 .4905 L .51 .9 .748 r
F P
0 g
s
.57731 .497 m .58525 .4913 L p .58763 .4905 L .51 .9 .748 r
F P
0 g
s
.58109 .49451 m .58525 .4913 L p .58286 .49285 L 0 0 0 r
F P
0 g
s
.5707 .50076 m .58109 .49451 L p .58286 .49285 L 0 0 0 r
F P
0 g
s
.579 .49669 m .58109 .49451 L p .58032 .49502 L 0 0 0 r
F P
0 g
s
.56727 .50372 m .579 .49669 L p .58032 .49502 L 0 0 0 r
F P
0 g
s
.579 .49669 m .57839 .49745 L p .57854 .49727 L 0 0 0 r
F P
0 g
s
.58109 .49451 m .5707 .50076 L p .56902 .50255 L 0 0 0 r
F P
0 g
s
.58961 .48413 m .58109 .49451 L p .57992 .4956 L 0 0 0 r
F P
0 g
s
.58961 .48413 m .59234 .48146 L p .59101 .483 L .639 .9 .581 r
F P
0 g
s
.58109 .49451 m .58961 .48413 L p .59101 .483 L .639 .9 .581 r
F P
0 g
s
.58829 .48584 m .58961 .48413 L p .58921 .48461 L 0 0 0 r
F P
0 g
s
.579 .49669 m .58829 .48584 L p .58921 .48461 L 0 0 0 r
F P
0 g
s
.58109 .49451 m .579 .49669 L p .57992 .4956 L 0 0 0 r
F P
0 g
s
.58791 .48643 m .58829 .48584 L p .58821 .48593 L 0 0 0 r
F P
0 g
s
.57839 .49745 m .58791 .48643 L p .58821 .48593 L 0 0 0 r
F P
0 g
s
.58762 .48691 m .58791 .48643 L p .58781 .48653 L 0 0 0 r
F P
0 g
s
.57792 .4981 m .58762 .48691 L p .58781 .48653 L 0 0 0 r
F P
0 g
s
.59234 .48146 m .58525 .4913 L p .5833 .49195 L .639 .9 .581 r
F P
0 g
s
.58525 .4913 m .58109 .49451 L p .5833 .49195 L .639 .9 .581 r
F P
0 g
s
.58687 .48842 m .58762 .48691 L p .58703 .48762 L 0 0 0 r
F P
0 g
s
.57668 .50009 m .58687 .48842 L p .58703 .48762 L 0 0 0 r
F P
0 g
s
.59712 .47813 m .592 .48776 L .58525 .4913 L p .788 .995 .777 r
F P
0 g
s
.58525 .4913 m .59234 .48146 L .59712 .47813 L p .788 .995 .777 r
F P
0 g
s
.58687 .48842 m .58607 .49099 L p .5866 .48973 L 0 0 0 r
F P
0 g
s
.58762 .48691 m .58687 .48842 L p .58703 .48804 L 0 0 0 r
F P
0 g
s
.58829 .48584 m .579 .49669 L p .57854 .49727 L 0 0 0 r
F P
0 g
s
.58791 .48643 m .57839 .49745 L .57792 .4981 L p 0 0 0 r
F P
0 g
s
.58762 .48691 m .57792 .4981 L .57668 .50009 L p 0 0 0 r
F P
0 g
s
.59366 .47279 m .58762 .48691 L p .58703 .48804 L 0 0 0 r
F P
0 g
s
.58791 .48643 m .58762 .48691 L p .58765 .48684 L .664 .771 .296 r
F P
0 g
s
.59382 .47242 m .58791 .48643 L p .58765 .48684 L .664 .771 .296 r
F P
0 g
s
.58829 .48584 m .58791 .48643 L p .58797 .48626 L .691 .794 .325 r
F P
0 g
s
.59404 .47198 m .58829 .48584 L p .58797 .48626 L .691 .794 .325 r
F P
0 g
s
.58791 .48643 m .59382 .47242 L .59404 .47198 L p .691 .794 .325 r
F P
0 g
s
.59366 .47279 m .59382 .47242 L p .59379 .47251 L .664 .771 .296 r
F P
0 g
s
.58762 .48691 m .59366 .47279 L p .59379 .47251 L .664 .771 .296 r
F P
0 g
s
.59324 .47393 m .59366 .47279 L p .59337 .47345 L 0 0 0 r
F P
0 g
s
.58687 .48842 m .59324 .47393 L p .59337 .47345 L 0 0 0 r
F P
0 g
s
.59487 .47063 m .58961 .48413 L p .58872 .48485 L .774 .867 .432 r
F P
0 g
s
.58961 .48413 m .59487 .47063 L .59674 .46842 L p .875 .944 .58 r
F P
0 g
s
.58829 .48584 m .59404 .47198 L .59487 .47063 L p .774 .867 .432 r
F P
0 g
s
.58961 .48413 m .58829 .48584 L p .58872 .48485 L .774 .867 .432 r
F P
0 g
s
.5929 .47583 m .59324 .47393 L p .59252 .47563 L 0 0 0 r
F P
0 g
s
.58607 .49099 m .5929 .47583 L p .59252 .47563 L 0 0 0 r
F P
0 g
s
.59674 .46842 m .59234 .48146 L .58961 .48413 L p .875 .944 .58 r
F P
0 g
s
.5929 .47583 m .59323 .47851 L p .59342 .47611 L 0 0 .193 r
F P
0 g
s
.59324 .47393 m .5929 .47583 L p .59302 .4747 L 0 0 0 r
F P
0 g
s
.59324 .47393 m .58687 .48842 L p .5866 .48973 L 0 0 0 r
F P
0 g
s
.59485 .45771 m .59324 .47393 L p .59302 .4747 L 0 0 0 r
F P
0 g
s
.59366 .47279 m .59324 .47393 L p .59327 .47364 L .818 .736 .211 r
F P
0 g
s
.5951 .45686 m .59366 .47279 L p .59327 .47364 L .818 .736 .211 r
F P
0 g
s
.5952 .45659 m .59382 .47242 L .59366 .47279 L p .848 .759 .247 r
F P
0 g
s
.59366 .47279 m .5951 .45686 L .5952 .45659 L p .848 .759 .247 r
F P
0 g
s
.59485 .45771 m .5951 .45686 L p .59503 .45757 L .818 .736 .211 r
F P
0 g
s
.59324 .47393 m .59485 .45771 L p .59503 .45757 L .818 .736 .211 r
F P
0 g
s
.59479 .45903 m .59485 .45771 L p .59468 .4593 L 0 0 0 r
F P
0 g
s
.5929 .47583 m .59479 .45903 L p .59468 .4593 L 0 0 0 r
F P
0 g
s
.59588 .45522 m .59487 .47063 L .59404 .47198 L p .921 .824 .364 r
F P
0 g
s
.59404 .47198 m .59535 .45626 L .59588 .45522 L p .921 .824 .364 r
F P
0 g
s
.59535 .45626 m .59404 .47198 L .59382 .47242 L p .887 .793 .305 r
F P
0 g
s
.59382 .47242 m .5952 .45659 L .59535 .45626 L p .887 .793 .305 r
F P
0 g
s
.59479 .45903 m .59541 .46073 L p .59494 .45866 L 0 0 .265 r
F P
0 g
s
.59485 .45771 m .59479 .45903 L p .59457 .45794 L .781 .523 0 r
F P
0 g
s
.59119 .44136 m .59485 .45771 L p .59457 .45794 L .781 .523 0 r
F P
0 g
s
.59117 .44217 m .59119 .44136 L p .59145 .44262 L .781 .523 0 r
F P
0 g
s
.59479 .45903 m .59117 .44217 L p .59145 .44262 L .781 .523 0 r
F P
0 g
s
.59485 .45771 m .59119 .44136 L .59136 .44081 L p .885 .617 .098 r
F P
0 g
s
.59541 .46073 m .5917 .44307 L .59117 .44217 L p 0 0 .265 r
F P
0 g
s
.59117 .44217 m .5917 .44307 L p .59079 .44156 L 0 0 .409 r
F P
0 g
s
.58215 .42719 m .59117 .44217 L p .59079 .44156 L 0 0 .409 r
F P
0 g
s
.58215 .42719 m .56872 .41582 L .56929 .41565 L p .671 .133 0 r
F P
0 g
s
.56872 .41582 m .58215 .42719 L p .58085 .42604 L .485 0 0 r
F P
0 g
s
.53797 .40747 m .55426 .40893 L .55352 .40921 L p .345 0 0 r
F P
0 g
s
.55352 .40921 m .53694 .40789 L .53797 .40747 L p .345 0 0 r
F P
0 g
s
.53694 .40789 m .55352 .40921 L .55327 .40925 L p .217 0 0 r
F P
0 g
s
.55327 .40925 m .55246 .40936 L p .54781 .40892 L .217 0 0 r
F P
0 g
s
.54781 .40892 m .53694 .40789 L .55327 .40925 L .217 0 0 r
F
.53872 .4071 m .52368 .4101 L .5254 .40884 L p .222 0 0 r
F P
0 g
s
.52368 .4101 m .53872 .4071 L .53832 .40731 L p .155 0 0 r
F P
0 g
s
.53832 .40731 m .52311 .41046 L .52368 .4101 L p .155 0 0 r
F P
0 g
s
.52311 .41046 m .53832 .40731 L .53797 .40747 L p .112 0 0 r
F P
0 g
s
.53797 .40747 m .52264 .41073 L .52311 .41046 L p .112 0 0 r
F P
0 g
s
.52264 .41073 m .53797 .40747 L .53694 .40789 L p .039 0 0 r
F P
0 g
s
.5048 .42356 m .51268 .41559 L p .51097 .41697 L .534 .839 .522 r
F P
0 g
s
.51268 .41559 m .51325 .41501 L .51097 .41697 L p .534 .839 .522 r
F P
0 g
s
.51097 .41697 m .50158 .42678 L .5048 .42356 L p .534 .839 .522 r
F P
0 g
s
.50158 .42678 m .51087 .41708 L p .5102 .41755 L .627 .924 .661 r
F P
0 g
s
.51087 .41708 m .51097 .41697 L .5102 .41755 L p .627 .924 .661 r
F P
0 g
s
.5102 .41755 m .50044 .4277 L .50158 .42678 L p .627 .924 .661 r
F P
0 g
s
.50044 .4277 m .51006 .41769 L p .50954 .41798 L .657 .947 .706 r
F P
0 g
s
.51006 .41769 m .5102 .41755 L .50954 .41798 L p .657 .947 .706 r
F P
0 g
s
.52264 .41073 m .50964 .41793 L p .5102 .41755 L 0 0 0 r
F P
0 g
s
.52311 .41046 m .51042 .41742 L p .51097 .41697 L 0 0 0 r
F P
0 g
s
.50954 .41798 m .49948 .4284 L .50044 .4277 L p .657 .947 .706 r
F P
0 g
s
.49948 .4284 m .50954 .41798 L .50757 .41911 L p .699 .976 .777 r
F P
0 g
s
.52368 .4101 m .52311 .41046 L p .5183 .41304 L 0 0 0 r
F P
0 g
s
.51097 .41697 m .51955 .41233 L p .5183 .41304 L 0 0 0 r
F P
0 g
s
.51955 .41233 m .52368 .4101 L p .5183 .41304 L 0 0 0 r
F P
0 g
s
.51346 .41578 m .508 .41887 L .50954 .41798 L 0 0 0 r
F
.53694 .40789 m .5216 .41134 L p .52264 .41073 L .039 0 0 r
F P
0 g
s
.52264 .41073 m .51438 .41525 L .52298 .41053 L 0 0 0 r
F
.51456 .41515 m .52311 .41046 L p .51438 .41525 L F P
0 g
s
.50954 .41798 m .52182 .41119 L p .5212 .41143 L 0 0 0 r
F P
0 g
s
.52182 .41119 m .52264 .41073 L .5212 .41143 L p 0 0 0 r
F P
0 g
s
.5212 .41143 m .51217 .41652 L p .51346 .41578 L 0 0 0 r
F P
0 g
s
.51097 .41697 m .51325 .41501 L p .52138 .41118 L 0 0 0 r
F P
0 g
s
.52368 .4101 m .52181 .41111 L p .52138 .41118 L 0 0 0 r
F P
0 g
s
.52181 .41111 m .51097 .41697 L p .52138 .41118 L 0 0 0 r
F P
0 g
s
.5102 .41755 m .51456 .41515 L p .51438 .41525 L 0 0 0 r
F P
0 g
s
.51217 .41652 m .50871 .41847 L p .51344 .4158 L 0 0 0 r
F P
0 g
s
.51217 .41652 m .51344 .4158 L .51346 .41578 L 0 0 0 r
F
.50871 .41847 m .508 .41887 L p .51346 .41578 L F P
0 g
s
.508 .41887 m .50757 .41911 L .50954 .41798 L p 0 0 0 r
F P
0 g
s
.50964 .41793 m .50954 .41798 L .5102 .41755 L p 0 0 0 r
F P
0 g
s
.51042 .41742 m .5102 .41755 L .51097 .41697 L p 0 0 0 r
F P
0 g
s
.5254 .40884 m .51325 .41501 L .51678 .41104 L p .064 0 0 r
F P
0 g
s
.51325 .41501 m .5254 .40884 L .52368 .4101 L p 0 0 0 r
F P
0 g
s
.50757 .41911 m .51901 .41267 L p .51882 .41216 L .474 .887 .769 r
F P
0 g
s
.51901 .41267 m .5212 .41143 L .51882 .41216 L p .474 .887 .769 r
F P
0 g
s
.5216 .41134 m .5212 .41143 L .52264 .41073 L p .039 0 0 r
F P
0 g
s
.52311 .41046 m .52264 .41073 L p .52298 .41053 L 0 0 0 r
F P
0 g
s
.5212 .41143 m .53694 .40789 L .53608 .40806 L p 0 0 0 r
F P
0 g
s
.53608 .40806 m .53526 .40823 L p .53512 .40828 L 0 0 0 r
F P
0 g
s
.53217 .40894 m .5212 .41143 L .53608 .40806 L 0 0 0 r
F
.55246 .40936 m .53526 .40823 L .53694 .40789 L p .217 0 0 r
F P
0 g
s
.53919 .4084 m .53545 .40817 L .53526 .40823 L .009 .583 .755 r
F
.53423 .4081 m .53526 .40823 L p .53545 .40817 L F P
0 g
s
.53526 .40823 m .53217 .40894 L .53512 .40828 L 0 0 0 r
F
.53306 .40794 m .51857 .41149 L p .51873 .41193 L .322 .809 .846 r
F P
0 g
s
.52222 .41115 m .51873 .41193 L .51882 .41216 L .322 .809 .846 r
F
.53306 .40794 m .51873 .41193 L .52222 .41115 L F
.50925 .41725 m .51678 .41104 L .51325 .41501 L p 0 0 0 r
F P
0 g
s
.51857 .41149 m .51555 .41223 L .51882 .41216 L p .322 .809 .846 r
F P
0 g
s
.52442 .4107 m .52019 .41183 L .5212 .41143 L 0 0 0 r
F
.53526 .40823 m .52595 .41046 L p .52442 .4107 L F P
0 g
s
.52595 .41046 m .52019 .41183 L p .52442 .4107 L 0 0 0 r
F P
0 g
s
.52019 .41183 m .51882 .41216 L .5212 .41143 L p 0 0 0 r
F P
0 g
s
.55125 .40891 m .53306 .40794 L .53423 .4081 L p .009 .583 .755 r
F P
0 g
s
.55125 .40891 m .53423 .4081 L .53919 .4084 L .009 .583 .755 r
F
.53526 .40823 m .55246 .40936 L .55125 .40891 L p F P
0 g
s
.56872 .41582 m .55246 .40936 L .55352 .40921 L p .476 0 0 r
F P
0 g
s
.56872 .41582 m .5665 .41485 L .56855 .41566 L .476 0 0 r
F
.55246 .40936 m .56588 .41469 L p .56828 .41557 L .264 0 0 r
F P
0 g
s
.56588 .41469 m .56872 .41582 L .56828 .41557 L p .264 0 0 r
F P
0 g
s
.58085 .42604 m .56975 .4168 L .56872 .41582 L .485 0 0 r
F
.59152 .44039 m .58285 .4261 L .58332 .42553 L p .917 .521 .151 r
F P
0 g
s
.58285 .4261 m .59152 .44039 L .59141 .44063 L p .915 .517 .141 r
F P
0 g
s
.59141 .44063 m .5827 .42628 L .58285 .4261 L p .915 .517 .141 r
F P
0 g
s
.57005 .41518 m .58285 .4261 L .5827 .42628 L p .791 .294 0 r
F P
0 g
s
.5827 .42628 m .56985 .41532 L .57005 .41518 L p .791 .294 0 r
F P
0 g
s
.56985 .41532 m .5827 .42628 L .5826 .42642 L p .751 .233 0 r
F P
0 g
s
.5826 .42642 m .56971 .4154 L .56985 .41532 L p .751 .233 0 r
F P
0 g
s
.56971 .4154 m .5826 .42642 L .58237 .42675 L p .748 .228 0 r
F P
0 g
s
.58237 .42675 m .56929 .41565 L .56971 .4154 L p .748 .228 0 r
F P
0 g
s
.56929 .41565 m .58237 .42675 L .58215 .42719 L p .671 .133 0 r
F P
0 g
s
.58351 .42686 m .57137 .41671 L p .56828 .41557 L 0 .283 .768 r
F P
0 g
s
.55352 .40921 m .56797 .41511 L p .56855 .41566 L .476 0 0 r
F P
0 g
s
.5665 .41485 m .55352 .40921 L .56855 .41566 L .476 0 0 r
F
.56797 .41511 m .56929 .41565 L .56872 .41582 L p F P
0 g
s
.55573 .4081 m .57076 .41463 L .57005 .41518 L p .657 .136 0 r
F P
0 g
s
.57005 .41518 m .55479 .40866 L .55573 .4081 L p .657 .136 0 r
F P
0 g
s
.55479 .40866 m .57005 .41518 L .56985 .41532 L p .634 .094 0 r
F P
0 g
s
.56985 .41532 m .55449 .40882 L .55479 .40866 L p .634 .094 0 r
F P
0 g
s
.55449 .40882 m .56985 .41532 L .56971 .4154 L p .607 .051 0 r
F P
0 g
s
.56971 .4154 m .55426 .40893 L .55449 .40882 L p .607 .051 0 r
F P
0 g
s
.55426 .40893 m .56971 .4154 L .56929 .41565 L p .588 .024 0 r
F P
0 g
s
.56929 .41565 m .55352 .40921 L .55426 .40893 L p .588 .024 0 r
F P
0 g
s
.57137 .41671 m .56844 .41426 L .56828 .41557 L p 0 .283 .768 r
F P
0 g
s
.56828 .41557 m .55125 .40891 L .55215 .40924 L p .264 0 0 r
F P
0 g
s
.55215 .40924 m .55246 .40936 L p .55544 .41053 L .264 0 0 r
F P
0 g
s
.56828 .41557 m .55215 .40924 L .55544 .41053 L .264 0 0 r
F
.56828 .41557 m .56872 .41582 L p .56975 .4168 L .485 0 0 r
F P
0 g
s
.58215 .42719 m .58239 .42734 L p .58085 .42604 L .485 0 0 r
F P
0 g
s
.58239 .42734 m .58071 .42594 L p .58085 .42604 L .485 0 0 r
F P
0 g
s
.58071 .42594 m .56828 .41557 L p .58085 .42604 L .485 0 0 r
F P
0 g
s
.58215 .42719 m .58222 .42705 L p .5831 .42804 L .791 .366 0 r
F P
0 g
s
.58222 .42705 m .58237 .42675 L p .58277 .42745 L .791 .366 0 r
F P
0 g
s
.5831 .42804 m .58222 .42705 L .58277 .42745 L .791 .366 0 r
F
.59117 .44217 m .58215 .42719 L p .5831 .42804 L F P
0 g
s
.58239 .42734 m .58215 .42719 L p .59155 .44281 L 0 0 .409 r
F P
0 g
s
.5917 .44307 m .59155 .44282 L p .59155 .44281 L 0 0 .409 r
F P
0 g
s
.59155 .44282 m .58239 .42734 L p .59155 .44281 L 0 0 .409 r
F P
0 g
s
.59494 .45866 m .59127 .4426 L .59479 .45903 L 0 0 .265 r
F
.59117 .44217 m .59126 .4426 L p .59127 .4426 L F P
0 g
s
.59126 .4426 m .59479 .45903 L p .59127 .4426 L 0 0 .265 r
F P
0 g
s
.59479 .45903 m .5929 .47583 L p .59342 .47611 L 0 0 .193 r
F P
0 g
s
.33806 .54606 m .34509 .56629 L .36491 .55729 L p .644 .513 .688 r
F P
0 g
s
.36491 .55729 m .35927 .53943 L .33806 .54606 L p .644 .513 .688 r
F P
0 g
s
.52236 .20174 m .51941 .20176 L .51594 .25333 L p .683 .565 .716 r
F P
0 g
s
.51594 .25333 m .5183 .25326 L .52236 .20174 L p .683 .565 .716 r
F P
0 g
s
.51404 .52766 m .52081 .51594 L .5279 .52499 L p .453 .204 .445 r
F P
0 g
s
.5333 .51125 m .52081 .51594 L .5279 .52499 L p .47 .207 .433 r
F P
0 g
s
.52256 .25382 m .52023 .25341 L .5243 .2019 L p .683 .565 .716 r
F P
0 g
s
.47228 .60184 m .46094 .60168 L .45541 .61408 L p .81 .797 .84 r
F P
0 g
s
.46094 .60168 m .47228 .60184 L .47662 .59071 L p .829 .883 .882 r
F P
0 g
s
.74637 .33499 m .76458 .36876 L .71845 .39045 L p .723 .599 .718 r
F P
0 g
s
.43115 .48647 m .4414 .48388 L .43066 .48685 L p .215 .732 .712 r
F P
0 g
s
.5243 .2019 m .52721 .20235 L .52256 .25382 L p .683 .565 .716 r
F P
0 g
s
.53109 .25469 m .52256 .25382 L .52721 .20235 L p .688 .569 .716 r
F P
0 g
s
.41646 .61723 m .43305 .62524 L .44106 .61053 L p .709 .688 .828 r
F P
0 g
s
.45541 .61408 m .44106 .61053 L .43305 .62524 L p .75 .717 .821 r
F P
0 g
s
.66823 .458 m .66425 .43936 L .69221 .43013 L p .747 .645 .748 r
F P
0 g
s
.66425 .43936 m .66823 .458 L .64576 .46285 L p .769 .678 .762 r
F P
0 g
s
.36939 .60528 m .38592 .62169 L .40018 .60608 L p .661 .594 .77 r
F P
0 g
s
.41646 .61723 m .40018 .60608 L .38592 .62169 L p .685 .628 .786 r
F P
0 g
s
.54552 .3279 m .53219 .32522 L .53772 .29535 L p .658 .531 .699 r
F P
0 g
s
.53219 .32522 m .54552 .3279 L .53935 .35072 L p .628 .498 .685 r
F P
0 g
s
.53935 .35072 m .52781 .34874 L .53219 .32522 L p .628 .498 .685 r
F P
0 g
s
.37368 .50613 m .37382 .51909 L .38732 .51594 L p .61 .388 .555 r
F P
0 g
s
.38732 .51594 m .38849 .50421 L .37368 .50613 L p .61 .388 .555 r
F P
0 g
s
.46635 .47871 m .44968 .47857 L .45095 .47716 L p .786 .864 .907 r
F P
0 g
s
.45095 .47716 m .46854 .47448 L .46635 .47871 L p .786 .864 .907 r
F P
0 g
s
.50971 .4101 m .51367 .40796 L .50925 .41725 L p 0 0 .05 r
F P
0 g
s
.52721 .20235 m .53756 .20342 L .53109 .25469 L p .688 .569 .716 r
F P
0 g
s
.5449 .25671 m .53109 .25469 L .53756 .20342 L p .688 .568 .714 r
F P
0 g
s
.53109 .25469 m .5449 .25671 L .53772 .29535 L p .675 .555 .711 r
F P
0 g
s
.55322 .29867 m .53772 .29535 L .5449 .25671 L p .677 .553 .707 r
F P
0 g
s
.53772 .29535 m .55322 .29867 L .54552 .3279 L p .658 .531 .699 r
F P
0 g
s
.52781 .34874 m .53935 .35072 L .53422 .36889 L p .583 .447 .662 r
F P
0 g
s
.53422 .36889 m .52414 .36758 L .52781 .34874 L p .583 .447 .662 r
F P
0 g
s
.35633 .52272 m .35927 .53943 L .37546 .5342 L p .626 .459 .637 r
F P
0 g
s
.37546 .5342 m .37382 .51909 L .35633 .52272 L p .626 .459 .637 r
F P
0 g
s
.44106 .61053 m .45541 .61408 L .46094 .60168 L p .757 .773 .866 r
F P
0 g
s
.69221 .43013 m .68371 .4068 L .71845 .39045 L p .735 .618 .728 r
F P
0 g
s
.68371 .4068 m .69221 .43013 L .66425 .43936 L p .753 .637 .732 r
F P
0 g
s
.34509 .56629 m .35558 .58644 L .37363 .57522 L p .64 .532 .716 r
F P
0 g
s
.37363 .57522 m .36491 .55729 L .34509 .56629 L p .64 .532 .716 r
F P
0 g
s
.49709 .56343 m .50056 .55294 L .50551 .54748 L p .008 0 .162 r
F P
0 g
s
.40338 .49399 m .40051 .50201 L .40991 .49941 L p .476 .101 .248 r
F P
0 g
s
.40991 .49941 m .41501 .49224 L .40338 .49399 L p .476 .101 .248 r
F P
0 g
s
.48826 .57768 m .48097 .58227 L .47662 .59071 L p .887 .988 .799 r
F P
0 g
s
.59849 .49151 m .60141 .4845 L .61345 .48171 L p .766 .883 .93 r
F P
0 g
s
.60141 .4845 m .59849 .49151 L .58686 .49375 L p .712 .968 .934 r
F P
0 g
s
.49256 .45634 m .49437 .44041 L .49266 .44154 L p .87 .872 .836 r
F P
0 g
s
.49266 .44154 m .48781 .45803 L .49256 .45634 L p .87 .872 .836 r
F P
0 g
s
.71845 .39045 m .70355 .36255 L .74637 .33499 L p .723 .599 .718 r
F P
0 g
s
.70355 .36255 m .71845 .39045 L .68371 .4068 L p .735 .608 .717 r
F P
0 g
s
.53756 .20342 m .55434 .20599 L .5449 .25671 L p .688 .568 .714 r
F P
0 g
s
.56334 .2608 m .5449 .25671 L .55434 .20599 L p .69 .567 .712 r
F P
0 g
s
.5449 .25671 m .56334 .2608 L .55322 .29867 L p .677 .553 .707 r
F P
0 g
s
.62828 .47932 m .62822 .46702 L .64576 .46285 L p .776 .729 .809 r
F P
0 g
s
.62822 .46702 m .62828 .47932 L .61345 .48171 L p .806 .797 .844 r
F P
0 g
s
.35558 .58644 m .36939 .60528 L .38559 .59182 L p .646 .561 .745 r
F P
0 g
s
.40018 .60608 m .38559 .59182 L .36939 .60528 L p .661 .594 .77 r
F P
0 g
s
.52414 .36758 m .53422 .36889 L .52975 .3835 L p .514 .371 .623 r
F P
0 g
s
.52975 .3835 m .52086 .38317 L .52414 .36758 L p .514 .371 .623 r
F P
0 g
s
.51404 .52766 m .5092 .54519 L .50749 .54609 L p .285 .082 .419 r
F P
0 g
s
.5092 .54519 m .51404 .52766 L .52295 .53006 L p .281 .023 .333 r
F P
0 g
s
.5279 .52499 m .52295 .53006 L .51404 .52766 L p .453 .204 .445 r
F P
0 g
s
.48104 .46945 m .46854 .47448 L .46817 .46603 L p .82 .846 .868 r
F P
0 g
s
.46817 .46603 m .47394 .4619 L .48104 .46945 L p .82 .846 .868 r
F P
0 g
s
.48104 .46945 m .48781 .45803 L .47889 .45688 L p .829 .847 .86 r
F P
0 g
s
.47889 .45688 m .47394 .4619 L .48104 .46945 L p .829 .847 .86 r
F P
0 g
s
.38559 .59182 m .37363 .57522 L .35558 .58644 L p .646 .561 .745 r
F P
0 g
s
.7229 .30307 m .74637 .33499 L .70355 .36255 L p .72 .592 .712 r
F P
0 g
s
.5333 .51125 m .55088 .50969 L .55216 .50806 L p .475 .122 .287 r
F P
0 g
s
.55088 .50969 m .5333 .51125 L .53366 .52094 L p .384 .046 .263 r
F P
0 g
s
.5279 .52499 m .53366 .52094 L .5333 .51125 L p .47 .207 .433 r
F P
0 g
s
.572 .30437 m .55322 .29867 L .56334 .2608 L p .682 .552 .702 r
F P
0 g
s
.55322 .29867 m .572 .30437 L .56152 .33251 L p .665 .53 .69 r
F P
0 g
s
.56152 .33251 m .54552 .3279 L .55322 .29867 L p .665 .53 .69 r
F P
0 g
s
.55434 .20599 m .57667 .21092 L .56334 .2608 L p .69 .567 .712 r
F P
0 g
s
.58565 .26773 m .56334 .2608 L .57667 .21092 L p .692 .567 .709 r
F P
0 g
s
.56334 .2608 m .58565 .26773 L .572 .30437 L p .682 .552 .702 r
F P
0 g
s
.5048 .42356 m .50132 .4327 L .50621 .42231 L p .738 .838 .388 r
F P
0 g
s
.54552 .3279 m .56152 .33251 L .55338 .35429 L p .641 .497 .672 r
F P
0 g
s
.55338 .35429 m .53935 .35072 L .54552 .3279 L p .641 .497 .672 r
F P
0 g
s
.52086 .38317 m .52975 .3835 L .52538 .39532 L p .407 .248 .551 r
F P
0 g
s
.52538 .39532 m .51747 .3965 L .52086 .38317 L p .407 .248 .551 r
F P
0 g
s
.5707 .50076 m .56045 .50194 L .55397 .50621 L p .256 0 .007 r
F P
0 g
s
.64576 .46285 m .64293 .44659 L .66425 .43936 L p .769 .678 .762 r
F P
0 g
s
.64293 .44659 m .64576 .46285 L .62822 .46702 L p .8 .722 .779 r
F P
0 g
s
.70355 .36255 m .68423 .33623 L .7229 .30307 L p .72 .592 .712 r
F P
0 g
s
.68423 .33623 m .70355 .36255 L .67129 .3834 L p .73 .596 .706 r
F P
0 g
s
.68371 .4068 m .67129 .3834 L .70355 .36255 L p .735 .608 .717 r
F P
0 g
s
.69528 .27459 m .7229 .30307 L .68423 .33623 L p .715 .584 .707 r
F P
0 g
s
.57667 .21092 m .60363 .21948 L .58565 .26773 L p .692 .567 .709 r
F P
0 g
s
.40018 .60608 m .41646 .61723 L .42576 .60426 L p .668 .645 .818 r
F P
0 g
s
.44106 .61053 m .42576 .60426 L .41646 .61723 L p .709 .688 .828 r
F P
0 g
s
.61041 .27841 m .58565 .26773 L .60363 .21948 L p .696 .568 .706 r
F P
0 g
s
.58565 .26773 m .61041 .27841 L .59289 .31316 L p .689 .554 .697 r
F P
0 g
s
.59289 .31316 m .572 .30437 L .58565 .26773 L p .689 .554 .697 r
F P
0 g
s
.67129 .3834 m .68371 .4068 L .65736 .41934 L p .752 .621 .714 r
F P
0 g
s
.66425 .43936 m .65736 .41934 L .68371 .4068 L p .753 .637 .732 r
F P
0 g
s
.46854 .47448 m .45095 .47716 L .45341 .47288 L p .815 .879 .892 r
F P
0 g
s
.45341 .47288 m .46817 .46603 L .46854 .47448 L p .815 .879 .892 r
F P
0 g
s
.35927 .53943 m .36491 .55729 L .3796 .55056 L p .609 .475 .674 r
F P
0 g
s
.3796 .55056 m .37546 .5342 L .35927 .53943 L p .609 .475 .674 r
F P
0 g
s
.38849 .50421 m .38732 .51594 L .39751 .513 L p .544 .289 .479 r
F P
0 g
s
.39751 .513 m .40051 .50201 L .38849 .50421 L p .544 .289 .479 r
F P
0 g
s
.65736 .41934 m .66425 .43936 L .64293 .44659 L p .778 .663 .737 r
F P
0 g
s
.4414 .48388 m .43115 .48647 L .43458 .48401 L p .566 .937 .895 r
F P
0 g
s
.43458 .48401 m .44788 .48017 L .4414 .48388 L p .566 .937 .895 r
F P
0 g
s
.53935 .35072 m .55338 .35429 L .54674 .37133 L p .606 .449 .643 r
F P
0 g
s
.54674 .37133 m .53422 .36889 L .53935 .35072 L p .606 .449 .643 r
F P
0 g
s
.572 .30437 m .59289 .31316 L .57953 .3397 L p .677 .534 .682 r
F P
0 g
s
.57953 .3397 m .56152 .33251 L .572 .30437 L p .677 .534 .682 r
F P
0 g
s
.60363 .21948 m .6336 .23261 L .61041 .27841 L p .696 .568 .706 r
F P
0 g
s
.66487 .25092 m .69528 .27459 L .6614 .31282 L p .709 .576 .704 r
F P
0 g
s
.68423 .33623 m .6614 .31282 L .69528 .27459 L p .715 .584 .707 r
F P
0 g
s
.47662 .59071 m .46578 .59255 L .46094 .60168 L p .829 .883 .882 r
F P
0 g
s
.46578 .59255 m .47662 .59071 L .48097 .58227 L p .809 .968 .905 r
F P
0 g
s
.48781 .45803 m .49266 .44154 L .48769 .4436 L p .85 .882 .862 r
F P
0 g
s
.48769 .4436 m .47889 .45688 L .48781 .45803 L p .85 .882 .862 r
F P
0 g
s
.6336 .23261 m .66487 .25092 L .63621 .29343 L p .702 .571 .704 r
F P
0 g
s
.63621 .29343 m .61041 .27841 L .6336 .23261 L p .702 .571 .704 r
F P
0 g
s
.61041 .27841 m .63621 .29343 L .61471 .32552 L p .698 .56 .694 r
F P
0 g
s
.61471 .32552 m .59289 .31316 L .61041 .27841 L p .698 .56 .694 r
F P
0 g
s
.58686 .49375 m .592 .48776 L .60141 .4845 L p .712 .968 .934 r
F P
0 g
s
.6614 .31282 m .68423 .33623 L .65518 .36126 L p .721 .582 .698 r
F P
0 g
s
.67129 .3834 m .65518 .36126 L .68423 .33623 L p .73 .596 .706 r
F P
0 g
s
.37382 .51909 m .37546 .5342 L .38751 .52999 L p .578 .398 .601 r
F P
0 g
s
.38751 .52999 m .38732 .51594 L .37382 .51909 L p .578 .398 .601 r
F P
0 g
s
.6614 .31282 m .63621 .29343 L .66487 .25092 L p .709 .576 .704 r
F P
0 g
s
.41501 .49224 m .40991 .49941 L .41664 .49657 L p .255 0 0 r
F P
0 g
s
.41664 .49657 m .42455 .4896 L .41501 .49224 L p .255 0 0 r
F P
0 g
s
.61345 .48171 m .61468 .47081 L .62822 .46702 L p .806 .797 .844 r
F P
0 g
s
.61468 .47081 m .61345 .48171 L .60141 .4845 L p .837 .884 .876 r
F P
0 g
s
.51747 .3965 m .52538 .39532 L .521 .40451 L p .239 .051 .412 r
F P
0 g
s
.521 .40451 m .51367 .40796 L .51747 .3965 L p .239 .051 .412 r
F P
0 g
s
.63621 .29343 m .6614 .31282 L .63591 .34171 L p .71 .569 .694 r
F P
0 g
s
.63591 .34171 m .61471 .32552 L .63621 .29343 L p .71 .569 .694 r
F P
0 g
s
.65518 .36126 m .63591 .34171 L .6614 .31282 L p .721 .582 .698 r
F P
0 g
s
.50551 .54748 m .5003 .56072 L .49709 .56343 L p .008 0 .162 r
F P
0 g
s
.5003 .56072 m .50551 .54748 L .50749 .54609 L p .084 0 .199 r
F P
0 g
s
.56152 .33251 m .57953 .3397 L .56928 .36001 L p .661 .504 .66 r
F P
0 g
s
.56928 .36001 m .55338 .35429 L .56152 .33251 L p .661 .504 .66 r
F P
0 g
s
.42576 .60426 m .44106 .61053 L .44745 .59978 L p .697 .727 .873 r
F P
0 g
s
.46094 .60168 m .44745 .59978 L .44106 .61053 L p .757 .773 .866 r
F P
0 g
s
.59289 .31316 m .61471 .32552 L .5984 .34995 L p .694 .543 .678 r
F P
0 g
s
.5984 .34995 m .57953 .3397 L .59289 .31316 L p .694 .543 .678 r
F P
0 g
s
.65518 .36126 m .67129 .3834 L .64698 .39924 L p .744 .601 .698 r
F P
0 g
s
.65736 .41934 m .64698 .39924 L .67129 .3834 L p .752 .621 .714 r
F P
0 g
s
.44745 .59978 m .46094 .60168 L .46578 .59255 L p .751 .84 .919 r
F P
0 g
s
.53422 .36889 m .54674 .37133 L .54116 .38451 L p .556 .379 .597 r
F P
0 g
s
.54116 .38451 m .52975 .3835 L .53422 .36889 L p .556 .379 .597 r
F P
0 g
s
.50132 .4327 m .5048 .42356 L .50158 .42678 L p .863 .98 .684 r
F P
0 g
s
.50158 .42678 m .49636 .43877 L .50132 .4327 L p .863 .98 .684 r
F P
0 g
s
.38559 .59182 m .40018 .60608 L .41082 .59474 L p .633 .596 .794 r
F P
0 g
s
.42576 .60426 m .41082 .59474 L .40018 .60608 L p .668 .645 .818 r
F P
0 g
s
.36491 .55729 m .37363 .57522 L .38693 .56696 L p .603 .505 .716 r
F P
0 g
s
.38693 .56696 m .3796 .55056 L .36491 .55729 L p .603 .505 .716 r
F P
0 g
s
.62822 .46702 m .62667 .45251 L .64293 .44659 L p .8 .722 .779 r
F P
0 g
s
.62667 .45251 m .62822 .46702 L .61468 .47081 L p .839 .781 .796 r
F P
0 g
s
.61471 .32552 m .63591 .34171 L .6167 .3636 L p .712 .558 .678 r
F P
0 g
s
.6167 .3636 m .5984 .34995 L .61471 .32552 L p .712 .558 .678 r
F P
0 g
s
.64698 .39924 m .65736 .41934 L .6374 .42906 L p .776 .639 .71 r
F P
0 g
s
.64293 .44659 m .6374 .42906 L .65736 .41934 L p .778 .663 .737 r
F P
0 g
s
.55397 .50621 m .56727 .50372 L .5707 .50076 L p .256 0 .007 r
F P
0 g
s
.56727 .50372 m .55397 .50621 L .55216 .50806 L p .28 0 .074 r
F P
0 g
s
.63591 .34171 m .65518 .36126 L .63323 .38029 L p .73 .579 .685 r
F P
0 g
s
.64698 .39924 m .63323 .38029 L .65518 .36126 L p .744 .601 .698 r
F P
0 g
s
.50749 .54609 m .50144 .55999 L .5003 .56072 L p .084 0 .199 r
F P
0 g
s
.50144 .55999 m .50749 .54609 L .5092 .54519 L p .106 0 .205 r
F P
0 g
s
.37363 .57522 m .38559 .59182 L .3975 .58209 L p .611 .546 .757 r
F P
0 g
s
.3975 .58209 m .38693 .56696 L .37363 .57522 L p .611 .546 .757 r
F P
0 g
s
.41082 .59474 m .3975 .58209 L .38559 .59182 L p .633 .596 .794 r
F P
0 g
s
.6374 .42906 m .64293 .44659 L .62667 .45251 L p .812 .699 .741 r
F P
0 g
s
.63323 .38029 m .6167 .3636 L .63591 .34171 L p .73 .579 .685 r
F P
0 g
s
.55338 .35429 m .56928 .36001 L .56117 .37557 L p .639 .461 .626 r
F P
0 g
s
.56117 .37557 m .54674 .37133 L .55338 .35429 L p .639 .461 .626 r
F P
0 g
s
.57953 .3397 m .5984 .34995 L .58594 .36855 L p .687 .519 .653 r
F P
0 g
s
.58594 .36855 m .56928 .36001 L .57953 .3397 L p .687 .519 .653 r
F P
0 g
s
.40051 .50201 m .39751 .513 L .40484 .51011 L p .431 .141 .369 r
F P
0 g
s
.40484 .51011 m .40991 .49941 L .40051 .50201 L p .431 .141 .369 r
F P
0 g
s
.44788 .48017 m .43458 .48401 L .43557 .4831 L p .701 .972 .926 r
F P
0 g
s
.43557 .4831 m .44968 .47857 L .44788 .48017 L p .701 .972 .926 r
F P
0 g
s
.51367 .40796 m .521 .40451 L .51678 .41104 L p 0 0 .159 r
F P
0 g
s
.51678 .41104 m .50925 .41725 L .51367 .40796 L p 0 0 .159 r
F P
0 g
s
.37546 .5342 m .3796 .55056 L .39026 .54547 L p .556 .423 .655 r
F P
0 g
s
.39026 .54547 m .38751 .52999 L .37546 .5342 L p .556 .423 .655 r
F P
0 g
s
.60141 .4845 m .60447 .47448 L .61468 .47081 L p .837 .884 .876 r
F P
0 g
s
.60447 .47448 m .60141 .4845 L .592 .48776 L p .848 .972 .874 r
F P
0 g
s
.55216 .50806 m .56627 .5048 L .56727 .50372 L p .28 0 .074 r
F P
0 g
s
.56627 .5048 m .55216 .50806 L .55088 .50969 L p .282 0 .093 r
F P
0 g
s
.52975 .3835 m .54116 .38451 L .53627 .39446 L p .487 .279 .522 r
F P
0 g
s
.53627 .39446 m .52538 .39532 L .52975 .3835 L p .487 .279 .522 r
F P
0 g
s
.5092 .54519 m .5024 .55945 L .50144 .55999 L p .106 0 .205 r
F P
0 g
s
.5024 .55945 m .5092 .54519 L .51416 .54385 L p .138 0 .195 r
F P
0 g
s
.52295 .53006 m .51416 .54385 L .5092 .54519 L p .281 .023 .333 r
F P
0 g
s
.42455 .4896 m .41664 .49657 L .42079 .49398 L p 0 0 0 r
F P
0 g
s
.38732 .51594 m .38751 .52999 L .39608 .52655 L p .504 .311 .551 r
F P
0 g
s
.39608 .52655 m .39751 .513 L .38732 .51594 L p .504 .311 .551 r
F P
0 g
s
.63323 .38029 m .64698 .39924 L .62877 .41128 L p .764 .607 .684 r
F P
0 g
s
.6374 .42906 m .62877 .41128 L .64698 .39924 L p .776 .639 .71 r
F P
0 g
s
.48097 .58227 m .47015 .58622 L .46578 .59255 L p .809 .968 .905 r
F P
0 g
s
.47015 .58622 m .48097 .58227 L .48517 .57649 L p .688 .981 .849 r
F P
0 g
s
.41082 .59474 m .42576 .60426 L .43286 .59505 L p .639 .664 .858 r
F P
0 g
s
.44745 .59978 m .43286 .59505 L .42576 .60426 L p .697 .727 .873 r
F P
0 g
s
.49636 .43877 m .50158 .42678 L .50044 .4277 L p .88 .992 .79 r
F P
0 g
s
.50044 .4277 m .49437 .44041 L .49636 .43877 L p .88 .992 .79 r
F P
0 g
s
.5984 .34995 m .6167 .3636 L .60227 .38011 L p .716 .543 .654 r
F P
0 g
s
.60227 .38011 m .58594 .36855 L .5984 .34995 L p .716 .543 .654 r
F P
0 g
s
.44968 .47857 m .43557 .4831 L .43633 .48233 L p .741 .973 .927 r
F P
0 g
s
.43633 .48233 m .45095 .47716 L .44968 .47857 L p .741 .973 .927 r
F P
0 g
s
.52295 .53006 m .5279 .52499 L .53308 .53184 L p .412 .14 .388 r
F P
0 g
s
.53366 .52094 m .5279 .52499 L .53308 .53184 L p .416 .141 .385 r
F P
0 g
s
.55088 .50969 m .56551 .50572 L .56627 .5048 L p .282 0 .093 r
F P
0 g
s
.56551 .50572 m .55088 .50969 L .54842 .51468 L p .263 0 .115 r
F P
0 g
s
.53366 .52094 m .54842 .51468 L .55088 .50969 L p .384 .046 .263 r
F P
0 g
s
.51416 .54385 m .52295 .53006 L .52957 .53502 L p .324 .037 .313 r
F P
0 g
s
.53308 .53184 m .52957 .53502 L .52295 .53006 L p .412 .14 .388 r
F P
0 g
s
.6167 .3636 m .63323 .38029 L .61685 .39462 L p .743 .574 .665 r
F P
0 g
s
.62877 .41128 m .61685 .39462 L .63323 .38029 L p .764 .607 .684 r
F P
0 g
s
.54674 .37133 m .56117 .37557 L .55472 .3872 L p .61 .403 .576 r
F P
0 g
s
.55472 .3872 m .54116 .38451 L .54674 .37133 L p .61 .403 .576 r
F P
0 g
s
.54842 .51468 m .53366 .52094 L .53677 .52889 L p .353 .043 .294 r
F P
0 g
s
.53308 .53184 m .53677 .52889 L .53366 .52094 L p .416 .141 .385 r
F P
0 g
s
.61685 .39462 m .60227 .38011 L .6167 .3636 L p .743 .574 .665 r
F P
0 g
s
.56928 .36001 m .58594 .36855 L .57654 .38243 L p .679 .485 .618 r
F P
0 g
s
.57654 .38243 m .56117 .37557 L .56928 .36001 L p .679 .485 .618 r
F P
0 g
s
.61468 .47081 m .61457 .45748 L .62667 .45251 L p .839 .781 .796 r
F P
0 g
s
.61457 .45748 m .61468 .47081 L .60447 .47448 L p .886 .853 .804 r
F P
0 g
s
.62877 .41128 m .6374 .42906 L .62262 .43658 L p .809 .662 .7 r
F P
0 g
s
.62667 .45251 m .62262 .43658 L .6374 .42906 L p .812 .699 .741 r
F P
0 g
s
.46578 .59255 m .45258 .59236 L .44745 .59978 L p .751 .84 .919 r
F P
0 g
s
.45258 .59236 m .46578 .59255 L .47015 .58622 L p .711 .905 .964 r
F P
0 g
s
.43286 .59505 m .44745 .59978 L .45258 .59236 L p .668 .77 .926 r
F P
0 g
s
.49437 .44041 m .50044 .4277 L .49948 .4284 L p .877 .988 .82 r
F P
0 g
s
.49948 .4284 m .49266 .44154 L .49437 .44041 L p .877 .988 .82 r
F P
0 g
s
.45095 .47716 m .43633 .48233 L .43821 .47994 L p .786 .971 .915 r
F P
0 g
s
.43821 .47994 m .45341 .47288 L .45095 .47716 L p .786 .971 .915 r
F P
0 g
s
.3796 .55056 m .38693 .56696 L .39639 .56105 L p .549 .466 .714 r
F P
0 g
s
.39639 .56105 m .39026 .54547 L .3796 .55056 L p .549 .466 .714 r
F P
0 g
s
.62262 .43658 m .62667 .45251 L .61457 .45748 L p .855 .744 .739 r
F P
0 g
s
.3975 .58209 m .41082 .59474 L .41856 .58685 L p .591 .594 .823 r
F P
0 g
s
.43286 .59505 m .41856 .58685 L .41082 .59474 L p .639 .664 .858 r
F P
0 g
s
.52538 .39532 m .53627 .39446 L .53188 .4016 L p .39 .132 .398 r
F P
0 g
s
.53188 .4016 m .521 .40451 L .52538 .39532 L p .39 .132 .398 r
F P
0 g
s
.47394 .4619 m .46817 .46603 L .46505 .4596 L p .836 .915 .889 r
F P
0 g
s
.46505 .4596 m .46874 .45661 L .47394 .4619 L p .836 .915 .889 r
F P
0 g
s
.47394 .4619 m .47889 .45688 L .47226 .45345 L p .84 .915 .886 r
F P
0 g
s
.47226 .45345 m .46874 .45661 L .47394 .4619 L p .84 .915 .886 r
F P
0 g
s
.40991 .49941 m .40484 .51011 L .4096 .5075 L p .242 0 .207 r
F P
0 g
s
.4096 .5075 m .41664 .49657 L .40991 .49941 L p .242 0 .207 r
F P
0 g
s
.49266 .44154 m .49948 .4284 L .49657 .43009 L p .861 .979 .855 r
F P
0 g
s
.49657 .43009 m .48769 .4436 L .49266 .44154 L p .861 .979 .855 r
F P
0 g
s
.46817 .46603 m .45341 .47288 L .45428 .46696 L p .832 .92 .894 r
F P
0 g
s
.45428 .46696 m .46505 .4596 L .46817 .46603 L p .832 .92 .894 r
F P
0 g
s
.592 .48776 m .59712 .47813 L .60447 .47448 L p .848 .972 .874 r
F P
0 g
s
.38693 .56696 m .3975 .58209 L .40603 .57525 L p .56 .524 .773 r
F P
0 g
s
.40603 .57525 m .39639 .56105 L .38693 .56696 L p .56 .524 .773 r
F P
0 g
s
.47889 .45688 m .48769 .4436 L .48109 .44406 L p .845 .921 .883 r
F P
0 g
s
.48109 .44406 m .47226 .45345 L .47889 .45688 L p .845 .921 .883 r
F P
0 g
s
.41856 .58685 m .40603 .57525 L .3975 .58209 L p .591 .594 .823 r
F P
0 g
s
.58594 .36855 m .60227 .38011 L .59152 .39239 L p .721 .521 .62 r
F P
0 g
s
.59152 .39239 m .57654 .38243 L .58594 .36855 L p .721 .521 .62 r
F P
0 g
s
.43115 .48647 m .4215 .49347 L p .42287 .49223 L .422 .816 .59 r
F P
0 g
s
.42287 .49223 m .43458 .48401 L .43115 .48647 L p .422 .816 .59 r
F P
0 g
s
.43458 .48401 m .423 .49214 L p .42349 .49161 L .572 .914 .696 r
F P
0 g
s
.423 .49214 m .42287 .49223 L .42349 .49161 L p .572 .914 .696 r
F P
0 g
s
.42349 .49161 m .43557 .4831 L .43458 .48401 L p .572 .914 .696 r
F P
0 g
s
.43557 .4831 m .42366 .49149 L p .42396 .49109 L .622 .941 .729 r
F P
0 g
s
.42366 .49149 m .42349 .49161 L .42396 .49109 L p .622 .941 .729 r
F P
0 g
s
.41402 .50363 m .42332 .49182 L p .42287 .49223 L 0 0 0 r
F P
0 g
s
.41431 .50326 m .4204 .49553 L .41411 .50352 L 0 0 0 r
F
.42029 .49567 m .41402 .50363 L p .4204 .49553 L F P
0 g
s
.42349 .49161 m .42029 .49567 L p .4204 .49553 L 0 0 0 r
F P
0 g
s
.41431 .50326 m .42389 .49118 L p .42349 .49161 L 0 0 0 r
F P
0 g
s
.41364 .50409 m .41402 .50363 L p .41753 .49911 L 0 0 0 r
F P
0 g
s
.42287 .49223 m .41665 .50023 L p .41753 .49911 L 0 0 0 r
F P
0 g
s
.41665 .50023 m .41364 .50409 L p .41753 .49911 L 0 0 0 r
F P
0 g
s
.4215 .49347 m .42079 .49398 L .42287 .49223 L p .422 .816 .59 r
F P
0 g
s
.41364 .50409 m .42287 .49223 L .42079 .49398 L p 0 0 0 r
F P
0 g
s
.41505 .5021 m .42176 .49375 L p .42098 .49477 L .576 .83 .464 r
F P
0 g
s
.42097 .49479 m .42098 .49477 L .42098 .49477 L .576 .83 .464 r
F
.41505 .5021 m .42098 .49477 L .42097 .49479 L F
.40876 .51734 m .41471 .50293 L p .41431 .50326 L 0 0 0 r
F P
0 g
s
.41471 .50293 m .41489 .50248 L p .41431 .50326 L 0 0 0 r
F P
0 g
s
.42396 .49109 m .41491 .5025 L p .41505 .5021 L .576 .83 .464 r
F P
0 g
s
.41491 .5025 m .41431 .50326 L .41505 .5021 L p .576 .83 .464 r
F P
0 g
s
.42079 .49398 m .41232 .50542 L .41364 .50409 L p 0 0 0 r
F P
0 g
s
.41364 .50409 m .40796 .51875 L .40804 .51864 L p 0 0 .007 r
F P
0 g
s
.40804 .51864 m .40818 .51844 L p .40864 .51722 L 0 0 .007 r
F P
0 g
s
.40864 .51722 m .41364 .50409 L .40804 .51864 L 0 0 .007 r
F
.40818 .51844 m .41402 .50363 L .41364 .50409 L p F P
0 g
s
.41402 .50363 m .40818 .51844 L .40834 .51816 L p 0 0 0 r
F P
0 g
s
.41402 .50363 m .41431 .50326 L p .41411 .50352 L 0 0 0 r
F P
0 g
s
.40834 .51816 m .41431 .50326 L .41402 .50363 L p 0 0 0 r
F P
0 g
s
.40723 .53409 m .40876 .51734 L .40834 .51816 L p 0 0 .159 r
F P
0 g
s
.40876 .51734 m .40723 .53409 L .40724 .5339 L p 0 0 .003 r
F P
0 g
s
.40772 .52851 m .40876 .51734 L .40724 .5339 L 0 0 .003 r
F
.40674 .53504 m .41062 .5512 L .41074 .55107 L p 0 0 .481 r
F P
0 g
s
.41074 .55107 m .40688 .53482 L .40674 .53504 L p 0 0 .481 r
F P
0 g
s
.40688 .53482 m .41074 .55107 L .41079 .55099 L p 0 0 .437 r
F P
0 g
s
.41079 .55099 m .40698 .53464 L .40688 .53482 L p 0 0 .437 r
F P
0 g
s
.40698 .53464 m .41079 .55099 L .41095 .55073 L p 0 0 .41 r
F P
0 g
s
.41095 .55073 m .40723 .53409 L .40698 .53464 L p 0 0 .41 r
F P
0 g
s
.40723 .53409 m .41095 .55073 L .41097 .55049 L p 0 0 .252 r
F P
0 g
s
.41097 .55049 m .41097 .55041 L p .41042 .54802 L 0 0 .252 r
F P
0 g
s
.41042 .54802 m .40723 .53409 L .41097 .55049 L 0 0 .252 r
F
.40834 .51816 m .40698 .53464 L .40723 .53409 L p 0 0 .159 r
F P
0 g
s
.41097 .55041 m .40728 .53328 L .40723 .53409 L p 0 0 .252 r
F P
0 g
s
.41045 .55023 m .40714 .53461 L p .40725 .53361 L .814 .544 0 r
F P
0 g
s
.40788 .53647 m .40725 .53361 L .40728 .53328 L .814 .544 0 r
F
.41045 .55023 m .40725 .53361 L .40788 .53647 L F
.40713 .51975 m .4062 .53572 L .40674 .53504 L p 0 0 .324 r
F P
0 g
s
.40674 .53504 m .40796 .51875 L .40713 .51975 L p 0 0 .324 r
F P
0 g
s
.40796 .51875 m .40674 .53504 L .40688 .53482 L p 0 0 .24 r
F P
0 g
s
.40688 .53482 m .40818 .51844 L .40796 .51875 L p 0 0 .24 r
F P
0 g
s
.40818 .51844 m .40688 .53482 L .40698 .53464 L p 0 0 .221 r
F P
0 g
s
.40698 .53464 m .40834 .51816 L .40818 .51844 L p 0 0 .221 r
F P
0 g
s
.40714 .53461 m .40666 .53233 L .40728 .53328 L p .814 .544 0 r
F P
0 g
s
.40728 .53328 m .40772 .52851 L .40735 .53266 L 0 0 .003 r
F
.40724 .5339 m .40728 .53328 L p .40735 .53266 L F P
0 g
s
.40834 .51816 m .40876 .51734 L p .40864 .51744 L 0 0 0 r
F P
0 g
s
.4101 .51376 m .40834 .51816 L p .41113 .51133 L 0 0 0 r
F P
0 g
s
.40713 .51975 m .41232 .50542 L .4096 .5075 L p .001 0 .231 r
F P
0 g
s
.41232 .50542 m .40713 .51975 L .40796 .51875 L p 0 0 .09 r
F P
0 g
s
.40796 .51875 m .41364 .50409 L .41232 .50542 L p 0 0 .09 r
F P
0 g
s
.40666 .53233 m .40875 .5141 L .40893 .5151 L p .846 .747 .23 r
F P
0 g
s
.40876 .51734 m .41113 .51133 L .40864 .51744 L 0 0 0 r
F
.41431 .50326 m .4101 .51376 L p .41113 .51133 L F P
0 g
s
.41505 .5021 m .40956 .5154 L p .40909 .51598 L .668 .771 .293 r
F P
0 g
s
.40956 .5154 m .40876 .51734 L .40909 .51598 L p .668 .771 .293 r
F P
0 g
s
.40909 .51598 m .40876 .51734 L p .40896 .51719 L 0 0 .003 r
F P
0 g
s
.40896 .51718 m .40909 .51598 L p .40896 .51719 L 0 0 .003 r
F P
0 g
s
.40728 .53328 m .40896 .51718 L p .40876 .51734 L 0 0 .003 r
F P
0 g
s
.40849 .51999 m .40882 .5163 L .40909 .51598 L .846 .747 .23 r
F
.40893 .5151 m .40909 .51598 L p .40882 .5163 L F P
0 g
s
.40666 .53233 m .40893 .5151 L .40849 .51999 L .846 .747 .23 r
F
.40909 .51598 m .41528 .50144 L p .41526 .5015 L .668 .771 .293 r
F P
0 g
s
.41389 .50475 m .41526 .5015 L .41515 .50181 L .668 .771 .293 r
F
.40909 .51598 m .41526 .5015 L .41389 .50475 L F
.41378 .50507 m .41515 .50181 L .41505 .5021 L F
.40909 .51598 m .41515 .50181 L .41378 .50507 L F
.41232 .50542 m .42079 .49398 L .41664 .49657 L p 0 0 0 r
F P
0 g
s
.41528 .50144 m .41585 .50012 L .41505 .5021 L p .668 .771 .293 r
F P
0 g
s
.41489 .50248 m .41505 .5021 L .41431 .50326 L p 0 0 0 r
F P
0 g
s
.42389 .49118 m .42396 .49109 L .42349 .49161 L p 0 0 0 r
F P
0 g
s
.42098 .49477 m .42486 .48989 L .42396 .49109 L .576 .83 .464 r
F
.42176 .49375 m .42486 .48989 L p .42098 .49477 L F P
0 g
s
.42486 .48989 m .42519 .48949 L .42396 .49109 L p .576 .83 .464 r
F P
0 g
s
.42332 .49182 m .42349 .49161 L .42287 .49223 L p 0 0 0 r
F P
0 g
s
.51416 .54385 m .5053 .55826 L .5024 .55945 L p .138 0 .195 r
F P
0 g
s
.5053 .55826 m .51416 .54385 L .52074 .54461 L p .207 0 .198 r
F P
0 g
s
.52957 .53502 m .52074 .54461 L .51416 .54385 L p .324 .037 .313 r
F P
0 g
s
.61685 .39462 m .62877 .41128 L .61537 .42041 L p .791 .616 .663 r
F P
0 g
s
.62262 .43658 m .61537 .42041 L .62877 .41128 L p .809 .662 .7 r
F P
0 g
s
.38751 .52999 m .39026 .54547 L .39758 .54167 L p .477 .35 .628 r
F P
0 g
s
.39758 .54167 m .39608 .52655 L .38751 .52999 L p .477 .35 .628 r
F P
0 g
s
.49095 .57164 m .5003 .56072 L .50144 .55999 L p 0 0 0 r
F P
0 g
s
.39751 .513 m .39608 .52655 L .40181 .52368 L p .391 .187 .48 r
F P
0 g
s
.40181 .52368 m .40484 .51011 L .39751 .513 L p .391 .187 .48 r
F P
0 g
s
.48517 .57649 m .47383 .58236 L .47015 .58622 L p .688 .981 .849 r
F P
0 g
s
.54116 .38451 m .55472 .3872 L .54954 .3955 L p .571 .322 .5 r
F P
0 g
s
.54954 .3955 m .53627 .39446 L .54116 .38451 L p .571 .322 .5 r
F P
0 g
s
.54842 .51468 m .56363 .50861 L .56551 .50572 L p .263 0 .115 r
F P
0 g
s
.56363 .50861 m .54842 .51468 L .54754 .5218 L p .25 0 .17 r
F P
0 g
s
.53677 .52889 m .54754 .5218 L .54842 .51468 L p .353 .043 .294 r
F P
0 g
s
.56117 .37557 m .57654 .38243 L .56937 .39257 L p .668 .44 .566 r
F P
0 g
s
.56937 .39257 m .55472 .3872 L .56117 .37557 L p .668 .44 .566 r
F P
0 g
s
.60227 .38011 m .61685 .39462 L .60484 .40527 L p .76 .566 .635 r
F P
0 g
s
.60484 .40527 m .59152 .39239 L .60227 .38011 L p .76 .566 .635 r
F P
0 g
s
.61537 .42041 m .60484 .40527 L .61685 .39462 L p .791 .616 .663 r
F P
0 g
s
.50144 .55999 m .49173 .57122 L .49095 .57164 L p 0 0 0 r
F P
0 g
s
.49173 .57122 m .50144 .55999 L .5024 .55945 L p 0 0 0 r
F P
0 g
s
.41856 .58685 m .43286 .59505 L .43817 .58893 L p .59 .682 .905 r
F P
0 g
s
.45258 .59236 m .43817 .58893 L .43286 .59505 L p .668 .77 .926 r
F P
0 g
s
.60447 .47448 m .60597 .46174 L .61457 .45748 L p .886 .853 .804 r
F P
0 g
s
.60597 .46174 m .60447 .47448 L .59712 .47813 L p .928 .926 .786 r
F P
0 g
s
.61537 .42041 m .62262 .43658 L .61191 .44253 L p .85 .688 .682 r
F P
0 g
s
.61457 .45748 m .61191 .44253 L .62262 .43658 L p .855 .744 .739 r
F P
0 g
s
.579 .49669 m .56727 .50372 L .56627 .5048 L p 0 0 0 r
F P
0 g
s
.5024 .55945 m .49238 .57091 L .49173 .57122 L p 0 0 0 r
F P
0 g
s
.49238 .57091 m .5024 .55945 L .5053 .55826 L p .011 0 0 r
F P
0 g
s
.521 .40451 m .53188 .4016 L .52818 .40622 L p .25 0 .201 r
F P
0 g
s
.52818 .40622 m .51678 .41104 L .521 .40451 L p .25 0 .201 r
F P
0 g
s
.45341 .47288 m .43821 .47994 L .44003 .47595 L p .826 .965 .896 r
F P
0 g
s
.44003 .47595 m .45428 .46696 L .45341 .47288 L p .826 .965 .896 r
F P
0 g
s
.47015 .58622 m .4567 .58763 L .45258 .59236 L p .711 .905 .964 r
F P
0 g
s
.4567 .58763 m .47015 .58622 L .47383 .58236 L p .605 .929 .964 r
F P
0 g
s
.61191 .44253 m .61457 .45748 L .60597 .46174 L p .906 .794 .726 r
F P
0 g
s
.43817 .58893 m .45258 .59236 L .4567 .58763 L p .605 .809 .978 r
F P
0 g
s
.39026 .54547 m .39639 .56105 L .40277 .55696 L p .471 .411 .708 r
F P
0 g
s
.40277 .55696 m .39758 .54167 L .39026 .54547 L p .471 .411 .708 r
F P
0 g
s
.56627 .5048 m .57839 .49745 L .579 .49669 L p 0 0 0 r
F P
0 g
s
.57839 .49745 m .56627 .5048 L .56551 .50572 L p 0 0 0 r
F P
0 g
s
.41664 .49657 m .4096 .5075 L .41232 .50542 L p 0 0 0 r
F P
0 g
s
.48769 .4436 m .49657 .43009 L .49191 .43163 L p .838 .966 .886 r
F P
0 g
s
.49191 .43163 m .48109 .44406 L .48769 .4436 L p .838 .966 .886 r
F P
0 g
s
.57654 .38243 m .59152 .39239 L .58371 .40123 L p .727 .492 .571 r
F P
0 g
s
.58371 .40123 m .56937 .39257 L .57654 .38243 L p .727 .492 .571 r
F P
0 g
s
.40603 .57525 m .41856 .58685 L .42403 .58171 L p .527 .585 .856 r
F P
0 g
s
.43817 .58893 m .42403 .58171 L .41856 .58685 L p .59 .682 .905 r
F P
0 g
s
.42396 .49109 m .43633 .48233 L .43557 .4831 L p .622 .941 .729 r
F P
0 g
s
.56551 .50572 m .57792 .4981 L .57839 .49745 L p 0 0 0 r
F P
0 g
s
.57792 .4981 m .56551 .50572 L .56363 .50861 L p .016 0 0 r
F P
0 g
s
.60484 .40527 m .61537 .42041 L .60584 .42723 L p .823 .623 .632 r
F P
0 g
s
.61191 .44253 m .60584 .42723 L .61537 .42041 L p .85 .688 .682 r
F P
0 g
s
.53627 .39446 m .54954 .3955 L .54539 .40107 L p .518 .212 .388 r
F P
0 g
s
.54539 .40107 m .53188 .4016 L .53627 .39446 L p .518 .212 .388 r
F P
0 g
s
.39639 .56105 m .40603 .57525 L .41182 .57076 L p .486 .491 .788 r
F P
0 g
s
.41182 .57076 m .40277 .55696 L .39639 .56105 L p .486 .491 .788 r
F P
0 g
s
.43633 .48233 m .42396 .49109 L .42519 .48949 L p .702 .976 .776 r
F P
0 g
s
.42519 .48949 m .43821 .47994 L .43633 .48233 L p .702 .976 .776 r
F P
0 g
s
.39608 .52655 m .39758 .54167 L .40218 .53894 L p .363 .249 .587 r
F P
0 g
s
.40218 .53894 m .40181 .52368 L .39608 .52655 L p .363 .249 .587 r
F P
0 g
s
.40484 .51011 m .40181 .52368 L .40528 .52139 L p .22 .014 .374 r
F P
0 g
s
.40528 .52139 m .4096 .5075 L .40484 .51011 L p .22 .014 .374 r
F P
0 g
s
.55472 .3872 m .56937 .39257 L .56401 .3996 L p .654 .38 .492 r
F P
0 g
s
.56401 .3996 m .54954 .3955 L .55472 .3872 L p .654 .38 .492 r
F P
0 g
s
.42403 .58171 m .41182 .57076 L .40603 .57525 L p .527 .585 .856 r
F P
0 g
s
.5053 .55826 m .49434 .57018 L .49238 .57091 L p .011 0 0 r
F P
0 g
s
.49434 .57018 m .5053 .55826 L .50995 .5576 L p .123 0 .034 r
F P
0 g
s
.52074 .54461 m .50995 .5576 L .5053 .55826 L p .207 0 .198 r
F P
0 g
s
.59152 .39239 m .60484 .40527 L .59624 .41305 L p .781 .555 .593 r
F P
0 g
s
.59624 .41305 m .58371 .40123 L .59152 .39239 L p .781 .555 .593 r
F P
0 g
s
.60584 .42723 m .59624 .41305 L .60484 .40527 L p .823 .623 .632 r
F P
0 g
s
.53677 .52889 m .53308 .53184 L .53782 .53821 L p .378 .093 .348 r
F P
0 g
s
.52957 .53502 m .53308 .53184 L .53782 .53821 L p .38 .093 .347 r
F P
0 g
s
.52074 .54461 m .52957 .53502 L .53501 .54065 L p .354 .058 .317 r
F P
0 g
s
.53782 .53821 m .53501 .54065 L .52957 .53502 L p .38 .093 .347 r
F P
0 g
s
.59712 .47813 m .60022 .46541 L .60597 .46174 L p .928 .926 .786 r
F P
0 g
s
.60022 .46541 m .59712 .47813 L .59234 .48146 L p .934 .969 .715 r
F P
0 g
s
.54754 .5218 m .53677 .52889 L .54067 .53583 L p .35 .057 .32 r
F P
0 g
s
.53782 .53821 m .54067 .53583 L .53677 .52889 L p .378 .093 .348 r
F P
0 g
s
.51678 .41104 m .52818 .40622 L .5254 .40884 L p .064 0 0 r
F P
0 g
s
.42403 .58171 m .43817 .58893 L .44198 .5853 L p .512 .689 .948 r
F P
0 g
s
.4567 .58763 m .44198 .5853 L .43817 .58893 L p .605 .809 .978 r
F P
0 g
s
.60584 .42723 m .61191 .44253 L .60455 .4472 L p .898 .718 .65 r
F P
0 g
s
.60597 .46174 m .60455 .4472 L .61191 .44253 L p .906 .794 .726 r
F P
0 g
s
.50757 .41911 m .49657 .43009 L .49948 .4284 L p .699 .976 .777 r
F P
0 g
s
.47383 .58236 m .45985 .58498 L .4567 .58763 L p .605 .929 .964 r
F P
0 g
s
.56363 .50861 m .57668 .50009 L .57792 .4981 L p .016 0 0 r
F P
0 g
s
.57668 .50009 m .56363 .50861 L .5618 .51346 L p .081 0 .06 r
F P
0 g
s
.54754 .5218 m .5618 .51346 L .56363 .50861 L p .25 0 .17 r
F P
0 g
s
.50995 .5576 m .52074 .54461 L .52712 .54791 L p .297 0 .242 r
F P
0 g
s
.53501 .54065 m .52712 .54791 L .52074 .54461 L p .354 .058 .317 r
F P
0 g
s
.60455 .4472 m .60597 .46174 L .60022 .46541 L p .959 .846 .689 r
F P
0 g
s
.44198 .5853 m .4567 .58763 L .45985 .58498 L p .493 .82 1 r
F P
0 g
s
.5618 .51346 m .54754 .5218 L .54905 .52924 L p .279 0 .255 r
F P
0 g
s
.54067 .53583 m .54905 .52924 L .54754 .5218 L p .35 .057 .32 r
F P
0 g
s
.43821 .47994 m .42519 .48949 L .42657 .48672 L p .796 .999 .819 r
F P
0 g
s
.42657 .48672 m .44003 .47595 L .43821 .47994 L p .796 .999 .819 r
F P
0 g
s
.39758 .54167 m .40277 .55696 L .40679 .55424 L p .355 .332 .695 r
F P
0 g
s
.40679 .55424 m .40218 .53894 L .39758 .54167 L p .355 .332 .695 r
F P
0 g
s
.56937 .39257 m .58371 .40123 L .57819 .40729 L p .733 .452 .503 r
F P
0 g
s
.57819 .40729 m .56401 .3996 L .56937 .39257 L p .733 .452 .503 r
F P
0 g
s
.47935 .57909 m .49238 .57091 L .49434 .57018 L p 0 0 0 r
F P
0 g
s
.46874 .45661 m .47226 .45345 L .4668 .44946 L p .837 .941 .892 r
F P
0 g
s
.4668 .44946 m .46399 .45189 L .46874 .45661 L p .837 .941 .892 r
F P
0 g
s
.46874 .45661 m .46505 .4596 L .46114 .4543 L p .839 .941 .891 r
F P
0 g
s
.46114 .4543 m .46399 .45189 L .46874 .45661 L p .839 .941 .891 r
F P
0 g
s
.46505 .4596 m .45428 .46696 L .45276 .46102 L p .841 .943 .889 r
F P
0 g
s
.45276 .46102 m .46114 .4543 L .46505 .4596 L p .841 .943 .889 r
F P
0 g
s
.47226 .45345 m .48109 .44406 L .4747 .44227 L p .835 .942 .894 r
F P
0 g
s
.4747 .44227 m .4668 .44946 L .47226 .45345 L p .835 .942 .894 r
F P
0 g
s
.53188 .4016 m .54539 .40107 L .54222 .40446 L p .439 .062 .225 r
F P
0 g
s
.54222 .40446 m .52818 .40622 L .53188 .4016 L p .439 .062 .225 r
F P
0 g
s
.41182 .57076 m .42403 .58171 L .42774 .57864 L p .434 .563 .885 r
F P
0 g
s
.44198 .5853 m .42774 .57864 L .42403 .58171 L p .512 .689 .948 r
F P
0 g
s
.4096 .5075 m .40528 .52139 L .40713 .51975 L p .001 0 .231 r
F P
0 g
s
.59624 .41305 m .60584 .42723 L .59943 .43222 L p .862 .628 .583 r
F P
0 g
s
.60455 .4472 m .59943 .43222 L .60584 .42723 L p .898 .718 .65 r
F P
0 g
s
.54954 .3955 m .56401 .3996 L .56017 .40408 L p .631 .298 .389 r
F P
0 g
s
.56017 .40408 m .54539 .40107 L .54954 .3955 L p .631 .298 .389 r
F P
0 g
s
.49657 .43009 m .50757 .41911 L .50427 .42034 L p .74 .992 .86 r
F P
0 g
s
.50427 .42034 m .49191 .43163 L .49657 .43009 L p .74 .992 .86 r
F P
0 g
s
.45428 .46696 m .44003 .47595 L .44033 .47078 L p .848 .96 .88 r
F P
0 g
s
.44033 .47078 m .45276 .46102 L .45428 .46696 L p .848 .96 .88 r
F P
0 g
s
.40181 .52368 m .40218 .53894 L .40483 .53701 L p .205 .111 .521 r
F P
0 g
s
.40483 .53701 m .40528 .52139 L .40181 .52368 L p .205 .111 .521 r
F P
0 g
s
.40277 .55696 m .41182 .57076 L .41556 .56797 L p .383 .441 .797 r
F P
0 g
s
.41556 .56797 m .40679 .55424 L .40277 .55696 L p .383 .441 .797 r
F P
0 g
s
.59234 .48146 m .59674 .46842 L .60022 .46541 L p .934 .969 .715 r
F P
0 g
s
.58371 .40123 m .59624 .41305 L .59041 .41846 L p .805 .537 .533 r
F P
0 g
s
.59041 .41846 m .57819 .40729 L .58371 .40123 L p .805 .537 .533 r
F P
0 g
s
.50995 .5576 m .49763 .56965 L .49434 .57018 L p .123 0 .034 r
F P
0 g
s
.49763 .56965 m .50995 .5576 L .51572 .55883 L p .25 0 .131 r
F P
0 g
s
.52712 .54791 m .51572 .55883 L .50995 .5576 L p .297 0 .242 r
F P
0 g
s
.42774 .57864 m .41556 .56797 L .41182 .57076 L p .434 .563 .885 r
F P
0 g
s
.48109 .44406 m .49191 .43163 L .48612 .43166 L p .821 .957 .903 r
F P
0 g
s
.48612 .43166 m .4747 .44227 L .48109 .44406 L p .821 .957 .903 r
F P
0 g
s
.59943 .43222 m .59041 .41846 L .59624 .41305 L p .862 .628 .583 r
F P
0 g
s
.49434 .57018 m .48078 .57873 L .47935 .57909 L p 0 0 0 r
F P
0 g
s
.48078 .57873 m .49434 .57018 L .49763 .56965 L p .081 0 0 r
F P
0 g
s
.59943 .43222 m .60455 .4472 L .59993 .45075 L p .944 .741 .597 r
F P
0 g
s
.60022 .46541 m .59993 .45075 L .60455 .4472 L p .959 .846 .689 r
F P
0 g
s
.42774 .57864 m .44198 .5853 L .44465 .5834 L p .38 .673 .974 r
F P
0 g
s
.45985 .58498 m .44465 .5834 L .44198 .5853 L p .493 .82 1 r
F P
0 g
s
.59993 .45075 m .60022 .46541 L .59674 .46842 L p .99 .88 .615 r
F P
0 g
s
.5618 .51346 m .57529 .50354 L .57668 .50009 L p .081 0 .06 r
F P
0 g
s
.57529 .50354 m .5618 .51346 L .56149 .51988 L p .161 0 .188 r
F P
0 g
s
.54905 .52924 m .56149 .51988 L .5618 .51346 L p .279 0 .255 r
F P
0 g
s
.52818 .40622 m .54222 .40446 L .54002 .40628 L p .332 0 .021 r
F P
0 g
s
.54002 .40628 m .5254 .40884 L .52818 .40622 L p .332 0 .021 r
F P
0 g
s
.40218 .53894 m .40679 .55424 L .40902 .55261 L p .204 .226 .661 r
F P
0 g
s
.40902 .55261 m .40483 .53701 L .40218 .53894 L p .204 .226 .661 r
F P
0 g
s
.56401 .3996 m .57819 .40729 L .57445 .4112 L p .736 .397 .407 r
F P
0 g
s
.57445 .4112 m .56017 .40408 L .56401 .3996 L p .736 .397 .407 r
F P
0 g
s
.44003 .47595 m .42657 .48672 L .42712 .4828 L p .859 .991 .837 r
F P
0 g
s
.42712 .4828 m .44033 .47078 L .44003 .47595 L p .859 .991 .837 r
F P
0 g
s
.58687 .48842 m .57668 .50009 L .57529 .50354 L p 0 0 0 r
F P
0 g
s
.42519 .48949 m .41505 .5021 L .41585 .50012 L p .736 .934 .597 r
F P
0 g
s
.41585 .50012 m .42657 .48672 L .42519 .48949 L p .736 .934 .597 r
F P
0 g
s
.54539 .40107 m .56017 .40408 L .55749 .4067 L p .592 .19 .249 r
F P
0 g
s
.55749 .4067 m .54222 .40446 L .54539 .40107 L p .592 .19 .249 r
F P
0 g
s
.40528 .52139 m .40483 .53701 L .4062 .53572 L p .011 0 .428 r
F P
0 g
s
.4062 .53572 m .40713 .51975 L .40528 .52139 L p .011 0 .428 r
F P
0 g
s
.41556 .56797 m .42774 .57864 L .43005 .5771 L p .288 .514 .899 r
F P
0 g
s
.44465 .5834 m .43005 .5771 L .42774 .57864 L p .38 .673 .974 r
F P
0 g
s
.59041 .41846 m .59943 .43222 L .59538 .43577 L p .899 .626 .516 r
F P
0 g
s
.59993 .45075 m .59538 .43577 L .59943 .43222 L p .944 .741 .597 r
F P
0 g
s
.49191 .43163 m .50427 .42034 L .49979 .42071 L p .761 .98 .913 r
F P
0 g
s
.49979 .42071 m .48612 .43166 L .49191 .43163 L p .761 .98 .913 r
F P
0 g
s
.49763 .56965 m .48315 .5786 L .48078 .57873 L p .081 0 0 r
F P
0 g
s
.48315 .5786 m .49763 .56965 L .5021 .5703 L p .241 0 0 r
F P
0 g
s
.51572 .55883 m .5021 .5703 L .49763 .56965 L p .25 0 .131 r
F P
0 g
s
.40679 .55424 m .41556 .56797 L .41769 .5665 L p .228 .359 .789 r
F P
0 g
s
.41769 .5665 m .40902 .55261 L .40679 .55424 L p .228 .359 .789 r
F P
0 g
s
.57819 .40729 m .59041 .41846 L .58665 .42208 L p .826 .509 .453 r
F P
0 g
s
.58665 .42208 m .57445 .4112 L .57819 .40729 L p .826 .509 .453 r
F P
0 g
s
.43005 .5771 m .41769 .5665 L .41556 .56797 L p .288 .514 .899 r
F P
0 g
s
.52712 .54791 m .53501 .54065 L .54055 .54726 L p .388 .096 .343 r
F P
0 g
s
.53501 .54065 m .53782 .53821 L .543 .54516 L p .39 .106 .357 r
F P
0 g
s
.543 .54516 m .54055 .54726 L .53501 .54065 L p .39 .106 .357 r
F P
0 g
s
.54067 .53583 m .53782 .53821 L .543 .54516 L p .387 .105 .359 r
F P
0 g
s
.59538 .43577 m .58665 .42208 L .59041 .41846 L p .899 .626 .516 r
F P
0 g
s
.54905 .52924 m .54067 .53583 L .54546 .54307 L p .371 .093 .355 r
F P
0 g
s
.543 .54516 m .54546 .54307 L .54067 .53583 L p .387 .105 .359 r
F P
0 g
s
.43005 .5771 m .44465 .5834 L .44641 .58255 L p .223 .625 .955 r
F P
0 g
s
.59674 .46842 m .59727 .45339 L .59993 .45075 L p .99 .88 .615 r
F P
0 g
s
.59727 .45339 m .59674 .46842 L .59487 .47063 L p .981 .875 .509 r
F P
0 g
s
.51572 .55883 m .52712 .54791 L .53334 .55337 L p .378 .065 .304 r
F P
0 g
s
.54055 .54726 m .53334 .55337 L .52712 .54791 L p .388 .096 .343 r
F P
0 g
s
.51882 .41216 m .50427 .42034 L .50757 .41911 L p .474 .887 .769 r
F P
0 g
s
.46511 .58302 m .48078 .57873 L .48315 .5786 L p .103 0 0 r
F P
0 g
s
.59538 .43577 m .59993 .45075 L .59727 .45339 L p .984 .753 .507 r
F P
0 g
s
.5254 .40884 m .54002 .40628 L .53872 .4071 L p .222 0 0 r
F P
0 g
s
.56149 .51988 m .54905 .52924 L .55263 .53696 L p .33 .055 .337 r
F P
0 g
s
.54546 .54307 m .55263 .53696 L .54905 .52924 L p .371 .093 .355 r
F P
0 g
s
.57529 .50354 m .58607 .49099 L .58687 .48842 L p 0 0 0 r
F P
0 g
s
.58607 .49099 m .57529 .50354 L .57473 .50849 L p 0 0 .144 r
F P
0 g
s
.56149 .51988 m .57473 .50849 L .57529 .50354 L p .161 0 .188 r
F P
0 g
s
.40483 .53701 m .40902 .55261 L .41013 .55168 L p .036 .104 .605 r
F P
0 g
s
.41013 .55168 m .4062 .53572 L .40483 .53701 L p .036 .104 .605 r
F P
0 g
s
.5021 .5703 m .51572 .55883 L .522 .56272 L p .369 .02 .237 r
F P
0 g
s
.53334 .55337 m .522 .56272 L .51572 .55883 L p .378 .065 .304 r
F P
0 g
s
.42657 .48672 m .41585 .50012 L .41598 .49728 L p .866 .986 .708 r
F P
0 g
s
.41598 .49728 m .42712 .4828 L .42657 .48672 L p .866 .986 .708 r
F P
0 g
s
.56017 .40408 m .57445 .4112 L .57213 .41345 L p .726 .323 .284 r
F P
0 g
s
.57213 .41345 m .55749 .4067 L .56017 .40408 L p .726 .323 .284 r
F P
0 g
s
.54222 .40446 m .55749 .4067 L .55573 .4081 L p .534 .063 .082 r
F P
0 g
s
.55573 .4081 m .54002 .40628 L .54222 .40446 L p .534 .063 .082 r
F P
0 g
s
.41769 .5665 m .43005 .5771 L .43141 .57646 L p .14 .45 .882 r
F P
0 g
s
.44641 .58255 m .43141 .57646 L .43005 .5771 L p .223 .625 .955 r
F P
0 g
s
.46399 .45189 m .46114 .4543 L .45633 .44881 L p .84 .937 .89 r
F P
0 g
s
.46114 .4543 m .45276 .46102 L .44917 .45501 L p .847 .938 .884 r
F P
0 g
s
.44917 .45501 m .45633 .44881 L .46114 .4543 L p .847 .938 .884 r
F P
0 g
s
.46399 .45189 m .4668 .44946 L .46125 .4446 L p .837 .937 .892 r
F P
0 g
s
.46125 .4446 m .45879 .44671 L .46399 .45189 L p .837 .937 .892 r
F P
0 g
s
.45633 .44881 m .45879 .44671 L .46399 .45189 L p .84 .937 .89 r
F P
0 g
s
.4668 .44946 m .4747 .44227 L .46847 .43851 L p .829 .936 .899 r
F P
0 g
s
.46847 .43851 m .46125 .4446 L .4668 .44946 L p .829 .936 .899 r
F P
0 g
s
.45276 .46102 m .44033 .47078 L .43822 .46487 L p .862 .945 .87 r
F P
0 g
s
.43822 .46487 m .44917 .45501 L .45276 .46102 L p .862 .945 .87 r
F P
0 g
s
.58665 .42208 m .59538 .43577 L .59314 .43811 L p .93 .609 .411 r
F P
0 g
s
.59727 .45339 m .59314 .43811 L .59538 .43577 L p .984 .753 .507 r
F P
0 g
s
.57473 .50849 m .56149 .51988 L .56359 .52734 L p .254 0 .314 r
F P
0 g
s
.55263 .53696 m .56359 .52734 L .56149 .51988 L p .33 .055 .337 r
F P
0 g
s
.40902 .55261 m .41769 .5665 L .41886 .56577 L p .06 .264 .757 r
F P
0 g
s
.41886 .56577 m .41013 .55168 L .40902 .55261 L p .06 .264 .757 r
F P
0 g
s
.59487 .47063 m .59588 .45522 L .59727 .45339 L p .981 .875 .509 r
F P
0 g
s
.43141 .57646 m .41886 .56577 L .41769 .5665 L p .14 .45 .882 r
F P
0 g
s
.48315 .5786 m .46678 .58322 L .46511 .58302 L p .103 0 0 r
F P
0 g
s
.46678 .58322 m .48315 .5786 L .48641 .57941 L p .282 0 0 r
F P
0 g
s
.5021 .5703 m .48641 .57941 L .48315 .5786 L p .241 0 0 r
F P
0 g
s
.4747 .44227 m .48612 .43166 L .47983 .42931 L p .811 .94 .912 r
F P
0 g
s
.47983 .42931 m .46847 .43851 L .4747 .44227 L p .811 .94 .912 r
F P
0 g
s
.57445 .4112 m .58665 .42208 L .5845 .42426 L p .84 .462 .335 r
F P
0 g
s
.5845 .42426 m .57213 .41345 L .57445 .4112 L p .84 .462 .335 r
F P
0 g
s
.50427 .42034 m .51882 .41216 L .51555 .41223 L p .597 .949 .902 r
F P
0 g
s
.51555 .41223 m .49979 .42071 L .50427 .42034 L p .597 .949 .902 r
F P
0 g
s
.59314 .43811 m .59727 .45339 L .59588 .45522 L p .992 .74 .397 r
F P
0 g
s
.59314 .43811 m .5845 .42426 L .58665 .42208 L p .93 .609 .411 r
F P
0 g
s
.4062 .53572 m .41013 .55168 L .41062 .5512 L p 0 0 .521 r
F P
0 g
s
.41062 .5512 m .40674 .53504 L .4062 .53572 L p 0 0 .521 r
F P
0 g
s
.44033 .47078 m .42712 .4828 L .4257 .47783 L p .888 .962 .838 r
F P
0 g
s
.4257 .47783 m .43822 .46487 L .44033 .47078 L p .888 .962 .838 r
F P
0 g
s
.48641 .57941 m .5021 .5703 L .50745 .57325 L p .383 0 .147 r
F P
0 g
s
.522 .56272 m .50745 .57325 L .5021 .5703 L p .369 .02 .237 r
F P
0 g
s
.54002 .40628 m .55573 .4081 L .55479 .40866 L p .465 0 0 r
F P
0 g
s
.55479 .40866 m .53872 .4071 L .54002 .40628 L p .465 0 0 r
F P
0 g
s
.41886 .56577 m .43141 .57646 L .43212 .57624 L p 0 .343 .815 r
F P
0 g
s
.55749 .4067 m .57213 .41345 L .57076 .41463 L p .701 .238 .148 r
F P
0 g
s
.57076 .41463 m .55573 .4081 L .55749 .4067 L p .701 .238 .148 r
F P
0 g
s
.48612 .43166 m .49979 .42071 L .49442 .4191 L p .769 .95 .935 r
F P
0 g
s
.49442 .4191 m .47983 .42931 L .48612 .43166 L p .769 .95 .935 r
F P
0 g
s
.41585 .50012 m .40909 .51598 L .40875 .5141 L p .862 .902 .488 r
F P
0 g
s
.40875 .5141 m .41598 .49728 L .41585 .50012 L p .862 .902 .488 r
F P
0 g
s
.41013 .55168 m .41886 .56577 L .41933 .56553 L p 0 .176 .708 r
F P
0 g
s
.41933 .56553 m .41062 .5512 L .41013 .55168 L p 0 .176 .708 r
F P
0 g
s
.43212 .57624 m .41933 .56553 L .41886 .56577 L p 0 .343 .815 r
F P
0 g
s
.5929 .47583 m .58607 .49099 L .58592 .49471 L p 0 0 .139 r
F P
0 g
s
.57473 .50849 m .58592 .49471 L .58607 .49099 L p 0 0 .144 r
F P
0 g
s
.58592 .49471 m .57473 .50849 L .57614 .5148 L p .143 0 .306 r
F P
0 g
s
.56359 .52734 m .57614 .5148 L .57473 .50849 L p .254 0 .314 r
F P
0 g
s
.5845 .42426 m .59314 .43811 L .59202 .43958 L p .938 .579 .305 r
F P
0 g
s
.59588 .45522 m .59202 .43958 L .59314 .43811 L p .992 .74 .397 r
F P
0 g
s
.59202 .43958 m .59588 .45522 L .59535 .45626 L p .975 .711 .3 r
F P
0 g
s
.41933 .56553 m .43212 .57624 L .43232 .57621 L p 0 .336 .809 r
F P
0 g
s
.53872 .4071 m .55479 .40866 L .55449 .40882 L p .406 0 0 r
F P
0 g
s
.55449 .40882 m .53832 .40731 L .53872 .4071 L p .406 0 0 r
F P
0 g
s
.44966 .58265 m .46678 .58322 L .46898 .58429 L p .38 0 0 r
F P
0 g
s
.48641 .57941 m .46898 .58429 L .46678 .58322 L p .282 0 0 r
F P
0 g
s
.57213 .41345 m .5845 .42426 L .58332 .42553 L p .837 .405 .209 r
F P
0 g
s
.58332 .42553 m .57076 .41463 L .57213 .41345 L p .837 .405 .209 r
F P
0 g
s
.42712 .4828 m .41598 .49728 L .41447 .49358 L p .924 .971 .765 r
F P
0 g
s
.41447 .49358 m .4257 .47783 L .42712 .4828 L p .924 .971 .765 r
F P
0 g
s
.43232 .57621 m .41948 .56546 L .41933 .56553 L p 0 .336 .809 r
F P
0 g
s
.41948 .56546 m .43232 .57621 L .43246 .57623 L p 0 .268 .751 r
F P
0 g
s
.53832 .40731 m .55449 .40882 L .55426 .40893 L p .392 0 0 r
F P
0 g
s
.55426 .40893 m .53797 .40747 L .53832 .40731 L p .392 0 0 r
F P
0 g
s
.41062 .5512 m .41933 .56553 L .41948 .56546 L p 0 .093 .651 r
F P
0 g
s
.41948 .56546 m .41074 .55107 L .41062 .5512 L p 0 .093 .651 r
F P
0 g
s
.59202 .43958 m .58332 .42553 L .5845 .42426 L p .938 .579 .305 r
F P
0 g
s
.43246 .57623 m .41958 .56542 L .41948 .56546 L p 0 .268 .751 r
F P
0 g
s
.41958 .56542 m .43246 .57623 L .43289 .57627 L p 0 .209 .693 r
F P
0 g
s
.46898 .58429 m .48641 .57941 L .49041 .58215 L p .437 0 .052 r
F P
0 g
s
.50745 .57325 m .49041 .58215 L .48641 .57941 L p .383 0 .147 r
F P
0 g
s
.41074 .55107 m .41948 .56546 L .41958 .56542 L p 0 .007 .579 r
F P
0 g
s
.41958 .56542 m .41079 .55099 L .41074 .55107 L p 0 .007 .579 r
F P
0 g
s
.51882 .41216 m .53526 .40823 L .53306 .40794 L p .322 .809 .846 r
F P
0 g
s
.59535 .45626 m .59152 .44039 L .59202 .43958 L p .975 .711 .3 r
F P
0 g
s
.59152 .44039 m .59535 .45626 L .5952 .45659 L p .94 .669 .202 r
F P
0 g
s
.41079 .55099 m .41958 .56542 L .41981 .56537 L p 0 .001 .575 r
F P
0 g
s
.41981 .56537 m .41095 .55073 L .41079 .55099 L p 0 .001 .575 r
F P
0 g
s
.43289 .57627 m .41981 .56537 L .41958 .56542 L p 0 .209 .693 r
F P
0 g
s
.53334 .55337 m .54055 .54726 L .54716 .55564 L p .439 .162 .395 r
F P
0 g
s
.54055 .54726 m .543 .54516 L .54947 .55369 L p .431 .162 .403 r
F P
0 g
s
.54947 .55369 m .54716 .55564 L .54055 .54726 L p .431 .162 .403 r
F P
0 g
s
.54546 .54307 m .543 .54516 L .54947 .55369 L p .429 .162 .405 r
F P
0 g
s
.522 .56272 m .53334 .55337 L .54025 .56126 L p .448 .154 .372 r
F P
0 g
s
.54716 .55564 m .54025 .56126 L .53334 .55337 L p .439 .162 .395 r
F P
0 g
s
.40909 .51598 m .40728 .53328 L .40666 .53233 L p .846 .747 .23 r
F P
0 g
s
.55263 .53696 m .54546 .54307 L .55177 .55171 L p .418 .158 .41 r
F P
0 g
s
.54947 .55369 m .55177 .55171 L .54546 .54307 L p .429 .162 .405 r
F P
0 g
s
.5952 .45659 m .59141 .44063 L .59152 .44039 L p .94 .669 .202 r
F P
0 g
s
.59141 .44063 m .5952 .45659 L .5951 .45686 L p .887 .615 .1 r
F P
0 g
s
.49979 .42071 m .51555 .41223 L .51154 .41066 L p .673 .943 .962 r
F P
0 g
s
.51154 .41066 m .49442 .4191 L .49979 .42071 L p .673 .943 .962 r
F P
0 g
s
.58332 .42553 m .59202 .43958 L .59152 .44039 L p .917 .521 .151 r
F P
0 g
s
.43345 .57659 m .4339 .57754 L p .43258 .57639 L .636 .095 0 r
F P
0 g
s
.42003 .56542 m .41981 .56537 L p .42095 .5663 L 0 .12 .597 r
F P
0 g
s
.43345 .57659 m .42003 .56542 L p .42095 .5663 L 0 .12 .597 r
F P
0 g
s
.41095 .55073 m .41981 .56537 L .41996 .5654 L p 0 0 .455 r
F P
0 g
s
.41996 .5654 m .42003 .56542 L p .41787 .56192 L 0 0 .455 r
F P
0 g
s
.41787 .56192 m .41095 .55073 L .41996 .5654 L 0 0 .455 r
F
.42003 .56542 m .41097 .55041 L .41095 .55073 L p F P
0 g
s
.41979 .56598 m .41045 .55023 L .41096 .5504 L p .725 .302 0 r
F P
0 g
s
.41096 .5504 m .41097 .55041 L p .41115 .55072 L .725 .302 0 r
F P
0 g
s
.41979 .56598 m .41096 .5504 L .41115 .55072 L .725 .302 0 r
F
.42003 .56542 m .41979 .56598 L p .4188 .56423 L F P
0 g
s
.41097 .55041 m .42003 .56542 L p .4188 .56423 L .725 .302 0 r
F P
0 g
s
.42003 .56542 m .43345 .57659 L p .43258 .57639 L .636 .095 0 r
F P
0 g
s
.43345 .57659 m .43289 .57627 L p .43409 .57673 L .299 0 0 r
F P
0 g
s
.44966 .58265 m .43345 .57659 L p .43409 .57673 L .299 0 0 r
F P
0 g
s
.56359 .52734 m .55263 .53696 L .55842 .54581 L p .391 .142 .413 r
F P
0 g
s
.55177 .55171 m .55842 .54581 L .55263 .53696 L p .418 .158 .41 r
F P
0 g
s
.5951 .45686 m .59136 .44081 L .59141 .44063 L p .887 .615 .1 r
F P
0 g
s
.59136 .44081 m .5951 .45686 L .59485 .45771 L p .885 .617 .098 r
F P
0 g
s
.50745 .57325 m .522 .56272 L .52887 .56977 L p .462 .14 .334 r
F P
0 g
s
.54025 .56126 m .52887 .56977 L .522 .56272 L p .448 .154 .372 r
F P
0 g
s
.46898 .58429 m .45087 .58384 L .44966 .58265 L p .38 0 0 r
F P
0 g
s
.57076 .41463 m .58332 .42553 L .58285 .4261 L p .817 .349 .101 r
F P
0 g
s
.58285 .4261 m .57005 .41518 L .57076 .41463 L p .817 .349 .101 r
F P
0 g
s
.58592 .49471 m .59323 .47851 L .5929 .47583 L p 0 0 .139 r
F P
0 g
s
.41598 .49728 m .40875 .5141 L .40691 .51177 L p .961 .938 .629 r
F P
0 g
s
.40691 .51177 m .41447 .49358 L .41598 .49728 L p .961 .938 .629 r
F P
0 g
s
.59323 .47851 m .58592 .49471 L .58742 .49959 L p .008 0 .33 r
F P
0 g
s
.57614 .5148 m .58742 .49959 L .58592 .49471 L p .143 0 .306 r
F P
0 g
s
.57614 .5148 m .56359 .52734 L .5686 .53598 L p .344 .116 .417 r
F P
0 g
s
.55842 .54581 m .5686 .53598 L .56359 .52734 L p .391 .142 .413 r
F P
0 g
s
.45087 .58384 m .46898 .58429 L .47153 .58708 L p .53 .015 0 r
F P
0 g
s
.49041 .58215 m .47153 .58708 L .46898 .58429 L p .437 0 .052 r
F P
0 g
s
.40728 .53328 m .41097 .55041 L .41045 .55023 L p .814 .544 0 r
F P
0 g
s
.5827 .42628 m .59141 .44063 L .59136 .44081 L p .886 .474 .053 r
F P
0 g
s
.49041 .58215 m .50745 .57325 L .51353 .57952 L p .491 .131 .283 r
F P
0 g
s
.52887 .56977 m .51353 .57952 L .50745 .57325 L p .462 .14 .334 r
F P
0 g
s
.45087 .58384 m .4339 .57754 L .43345 .57659 L p .489 0 0 r
F P
0 g
s
.45879 .44671 m .45633 .44881 L .45 .44206 L p .839 .91 .885 r
F P
0 g
s
.45633 .44881 m .44917 .45501 L .44335 .44803 L p .848 .911 .877 r
F P
0 g
s
.44335 .44803 m .45 .44206 L .45633 .44881 L p .848 .911 .877 r
F P
0 g
s
.59136 .44081 m .5826 .42642 L .5827 .42628 L p .886 .474 .053 r
F P
0 g
s
.5826 .42642 m .59136 .44081 L .59119 .44136 L p .853 .433 0 r
F P
0 g
s
.45879 .44671 m .46125 .4446 L .45461 .43811 L p .836 .91 .888 r
F P
0 g
s
.45461 .43811 m .45229 .44007 L .45879 .44671 L p .836 .91 .888 r
F P
0 g
s
.45 .44206 m .45229 .44007 L .45879 .44671 L p .839 .91 .885 r
F P
0 g
s
.44917 .45501 m .43822 .46487 L .43318 .45801 L p .866 .914 .861 r
F P
0 g
s
.43318 .45801 m .44335 .44803 L .44917 .45501 L p .866 .914 .861 r
F P
0 g
s
.46125 .4446 m .46847 .43851 L .46153 .43248 L p .827 .909 .895 r
F P
0 g
s
.46153 .43248 m .45461 .43811 L .46125 .4446 L p .827 .909 .895 r
F P
0 g
s
.46847 .43851 m .47983 .42931 L .47294 .42403 L p .807 .908 .91 r
F P
0 g
s
.47294 .42403 m .46153 .43248 L .46847 .43851 L p .807 .908 .91 r
F P
0 g
s
.4339 .57754 m .41979 .56598 L .42003 .56542 L p .636 .095 0 r
F P
0 g
s
.43822 .46487 m .4257 .47783 L .42124 .4718 L p .893 .92 .833 r
F P
0 g
s
.42124 .4718 m .43318 .45801 L .43822 .46487 L p .893 .92 .833 r
F P
0 g
s
.51555 .41223 m .53306 .40794 L .53051 .40621 L p .5 .878 .973 r
F P
0 g
s
.53051 .40621 m .51154 .41066 L .51555 .41223 L p .5 .878 .973 r
F P
0 g
s
.59119 .44136 m .58237 .42675 L .5826 .42642 L p .853 .433 0 r
F P
0 g
s
.40875 .5141 m .40666 .53233 L .40466 .53138 L p .979 .84 .445 r
F P
0 g
s
.40466 .53138 m .40691 .51177 L .40875 .5141 L p .979 .84 .445 r
F P
0 g
s
.58742 .49959 m .57614 .5148 L .58057 .52249 L p .277 .086 .432 r
F P
0 g
s
.5686 .53598 m .58057 .52249 L .57614 .5148 L p .344 .116 .417 r
F P
0 g
s
.58237 .42675 m .59119 .44136 L .59117 .44217 L p .791 .366 0 r
F P
0 g
s
.59323 .47851 m .59541 .46073 L .59479 .45903 L p 0 0 .193 r
F P
0 g
s
.4339 .57754 m .45087 .58384 L .452 .58653 L p .654 .12 0 r
F P
0 g
s
.47153 .58708 m .452 .58653 L .45087 .58384 L p .53 .015 0 r
F P
0 g
s
.47983 .42931 m .49442 .4191 L .48832 .41446 L p .772 .909 .934 r
F P
0 g
s
.48832 .41446 m .47294 .42403 L .47983 .42931 L p .772 .909 .934 r
F P
0 g
s
.47153 .58708 m .49041 .58215 L .49496 .58802 L p .546 .144 .231 r
F P
0 g
s
.51353 .57952 m .49496 .58802 L .49041 .58215 L p .491 .131 .283 r
F P
0 g
s
.59541 .46073 m .59323 .47851 L .59506 .48192 L p 0 0 .396 r
F P
0 g
s
.58742 .49959 m .59506 .48192 L .59323 .47851 L p .008 0 .33 r
F P
0 g
s
.4257 .47783 m .41447 .49358 L .41009 .48904 L p .93 .922 .782 r
F P
0 g
s
.41009 .48904 m .42124 .4718 L .4257 .47783 L p .93 .922 .782 r
F P
0 g
s
.40666 .53233 m .41045 .55023 L .40865 .5506 L p .96 .677 .243 r
F P
0 g
s
.40865 .5506 m .40466 .53138 L .40666 .53233 L p .96 .677 .243 r
F P
0 g
s
.41979 .56598 m .4339 .57754 L .43374 .57982 L p .778 .273 0 r
F P
0 g
s
.452 .58653 m .43374 .57982 L .4339 .57754 L p .654 .12 0 r
F P
0 g
s
.49442 .4191 m .51154 .41066 L .50698 .40625 L p .709 .901 .965 r
F P
0 g
s
.50698 .40625 m .48832 .41446 L .49442 .4191 L p .709 .901 .965 r
F P
0 g
s
.41045 .55023 m .41979 .56598 L .41868 .56741 L p .893 .48 .076 r
F P
0 g
s
.41868 .56741 m .40865 .5506 L .41045 .55023 L p .893 .48 .076 r
F P
0 g
s
.43374 .57982 m .41868 .56741 L .41979 .56598 L p .778 .273 0 r
F P
0 g
s
.53306 .40794 m .55125 .40891 L .55012 .4072 L p .268 .732 .948 r
F P
0 g
s
.55012 .4072 m .53051 .40621 L .53306 .40794 L p .268 .732 .948 r
F P
0 g
s
.59506 .48192 m .58742 .49959 L .59178 .50564 L p .198 .072 .472 r
F P
0 g
s
.58057 .52249 m .59178 .50564 L .58742 .49959 L p .277 .086 .432 r
F P
0 g
s
.452 .58653 m .47153 .58708 L .47417 .59273 L p .628 .188 .185 r
F P
0 g
s
.49496 .58802 m .47417 .59273 L .47153 .58708 L p .546 .144 .231 r
F P
0 g
s
.41447 .49358 m .40691 .51177 L .4024 .50907 L p .969 .901 .697 r
F P
0 g
s
.4024 .50907 m .41009 .48904 L .41447 .49358 L p .969 .901 .697 r
F P
0 g
s
.5917 .44307 m .59541 .46073 L .59741 .46269 L p 0 0 .504 r
F P
0 g
s
.59506 .48192 m .59741 .46269 L .59541 .46073 L p 0 0 .396 r
F P
0 g
s
.52887 .56977 m .54025 .56126 L .54882 .57247 L p .507 .238 .441 r
F P
0 g
s
.54025 .56126 m .54716 .55564 L .55587 .56691 L p .492 .237 .455 r
F P
0 g
s
.55587 .56691 m .54882 .57247 L .54025 .56126 L p .492 .237 .455 r
F P
0 g
s
.54716 .55564 m .54947 .55369 L .55825 .56499 L p .493 .237 .455 r
F P
0 g
s
.55825 .56499 m .55587 .56691 L .54716 .55564 L p .493 .237 .455 r
F P
0 g
s
.55177 .55171 m .54947 .55369 L .55825 .56499 L p .472 .233 .47 r
F P
0 g
s
.55842 .54581 m .55177 .55171 L .56052 .56296 L p .472 .233 .47 r
F P
0 g
s
.55825 .56499 m .56052 .56296 L .55177 .55171 L p .472 .233 .47 r
F P
0 g
s
.43374 .57982 m .452 .58653 L .45264 .59177 L p .734 .285 .184 r
F P
0 g
s
.47417 .59273 m .45264 .59177 L .452 .58653 L p .628 .188 .185 r
F P
0 g
s
.40691 .51177 m .40466 .53138 L .40021 .53069 L p .994 .836 .575 r
F P
0 g
s
.40021 .53069 m .4024 .50907 L .40691 .51177 L p .994 .836 .575 r
F P
0 g
s
.51353 .57952 m .52887 .56977 L .53699 .58081 L p .53 .24 .419 r
F P
0 g
s
.54882 .57247 m .53699 .58081 L .52887 .56977 L p .507 .238 .441 r
F P
0 g
s
.55125 .40891 m .56828 .41557 L .56844 .41426 L p .026 .516 .876 r
F P
0 g
s
.56844 .41426 m .55012 .4072 L .55125 .40891 L p .026 .516 .876 r
F P
0 g
s
.5686 .53598 m .55842 .54581 L .56713 .55689 L p .454 .228 .481 r
F P
0 g
s
.56052 .56296 m .56713 .55689 L .55842 .54581 L p .472 .233 .47 r
F P
0 g
s
.51154 .41066 m .53051 .40621 L .52786 .4019 L p .603 .863 .992 r
F P
0 g
s
.52786 .4019 m .50698 .40625 L .51154 .41066 L p .603 .863 .992 r
F P
0 g
s
.58239 .42734 m .5917 .44307 L .5935 .44368 L p 0 .062 .626 r
F P
0 g
s
.59741 .46269 m .5935 .44368 L .5917 .44307 L p 0 0 .504 r
F P
0 g
s
.59741 .46269 m .59506 .48192 L .59957 .486 L p .114 .083 .541 r
F P
0 g
s
.59178 .50564 m .59957 .486 L .59506 .48192 L p .198 .072 .472 r
F P
0 g
s
.49496 .58802 m .51353 .57952 L .52049 .59023 L p .564 .246 .389 r
F P
0 g
s
.53699 .58081 m .52049 .59023 L .51353 .57952 L p .53 .24 .419 r
F P
0 g
s
.58057 .52249 m .5686 .53598 L .57724 .54658 L p .424 .22 .496 r
F P
0 g
s
.56713 .55689 m .57724 .54658 L .5686 .53598 L p .454 .228 .481 r
F P
0 g
s
.56828 .41557 m .58239 .42734 L .58351 .42686 L p 0 .283 .768 r
F P
0 g
s
.40466 .53138 m .40865 .5506 L .40467 .55193 L p .986 .722 .433 r
F P
0 g
s
.40467 .55193 m .40021 .53069 L .40466 .53138 L p .986 .722 .433 r
F P
0 g
s
.41868 .56741 m .43374 .57982 L .43243 .58425 L p .843 .418 .223 r
F P
0 g
s
.45264 .59177 m .43243 .58425 L .43374 .57982 L p .734 .285 .184 r
F P
0 g
s
.5935 .44368 m .58351 .42686 L .58239 .42734 L p 0 .062 .626 r
F P
0 g
s
.40865 .5506 m .41868 .56741 L .41576 .57052 L p .933 .573 .311 r
F P
0 g
s
.43243 .58425 m .41576 .57052 L .41868 .56741 L p .843 .418 .223 r
F P
0 g
s
.41576 .57052 m .40467 .55193 L .40865 .5506 L p .933 .573 .311 r
F P
0 g
s
.47417 .59273 m .49496 .58802 L .49995 .59841 L p .613 .266 .359 r
F P
0 g
s
.52049 .59023 m .49995 .59841 L .49496 .58802 L p .564 .246 .389 r
F P
0 g
s
.59178 .50564 m .58057 .52249 L .58914 .53185 L p .382 .211 .522 r
F P
0 g
s
.57724 .54658 m .58914 .53185 L .58057 .52249 L p .424 .22 .496 r
F P
0 g
s
.53051 .40621 m .55012 .4072 L .5495 .40323 L p .454 .771 .997 r
F P
0 g
s
.5495 .40323 m .52786 .4019 L .53051 .40621 L p .454 .771 .997 r
F P
0 g
s
.45 .44206 m .44335 .44803 L .43458 .43898 L p .84 .87 .865 r
F P
0 g
s
.44335 .44803 m .43318 .45801 L .42449 .44941 L p .857 .871 .849 r
F P
0 g
s
.42449 .44941 m .43458 .43898 L .44335 .44803 L p .857 .871 .849 r
F P
0 g
s
.45229 .44007 m .45 .44206 L .4412 .43286 L p .841 .868 .864 r
F P
0 g
s
.43458 .43898 m .4412 .43286 L .45 .44206 L p .84 .87 .865 r
F P
0 g
s
.45229 .44007 m .45461 .43811 L .44585 .42889 L p .819 .866 .882 r
F P
0 g
s
.44585 .42889 m .44347 .43081 L .45229 .44007 L p .819 .866 .882 r
F P
0 g
s
.4412 .43286 m .44347 .43081 L .45229 .44007 L p .841 .868 .864 r
F P
0 g
s
.45461 .43811 m .46153 .43248 L .45292 .4233 L p .82 .868 .882 r
F P
0 g
s
.45292 .4233 m .44585 .42889 L .45461 .43811 L p .82 .868 .882 r
F P
0 g
s
.43318 .45801 m .42124 .4718 L .41263 .46435 L p .88 .87 .823 r
F P
0 g
s
.41263 .46435 m .42449 .44941 L .43318 .45801 L p .88 .87 .823 r
F P
0 g
s
.46153 .43248 m .47294 .42403 L .46477 .41496 L p .802 .866 .896 r
F P
0 g
s
.46477 .41496 m .45292 .4233 L .46153 .43248 L p .802 .866 .896 r
F P
0 g
s
.5935 .44368 m .59741 .46269 L .60187 .46469 L p .073 .157 .647 r
F P
0 g
s
.59957 .486 m .60187 .46469 L .59741 .46269 L p .114 .083 .541 r
F P
0 g
s
.42124 .4718 m .41009 .48904 L .40143 .48353 L p .91 .865 .783 r
F P
0 g
s
.40143 .48353 m .41263 .46435 L .42124 .4718 L p .91 .865 .783 r
F P
0 g
s
.47294 .42403 m .48832 .41446 L .48134 .40561 L p .771 .861 .916 r
F P
0 g
s
.48134 .40561 m .46477 .41496 L .47294 .42403 L p .771 .861 .916 r
F P
0 g
s
.45264 .59177 m .47417 .59273 L .47657 .60272 L p .681 .314 .343 r
F P
0 g
s
.49995 .59841 m .47657 .60272 L .47417 .59273 L p .613 .266 .359 r
F P
0 g
s
.59957 .486 m .59178 .50564 L .60041 .51297 L p .335 .214 .563 r
F P
0 g
s
.58914 .53185 m .60041 .51297 L .59178 .50564 L p .382 .211 .522 r
F P
0 g
s
.55012 .4072 m .56844 .41426 L .56978 .41105 L p .285 .624 .96 r
F P
0 g
s
.56978 .41105 m .5495 .40323 L .55012 .4072 L p .285 .624 .96 r
F P
0 g
s
.41009 .48904 m .4024 .50907 L .39368 .50614 L p .939 .844 .723 r
F P
0 g
s
.39368 .50614 m .40143 .48353 L .41009 .48904 L p .939 .844 .723 r
F P
0 g
s
.58351 .42686 m .5935 .44368 L .5975 .4436 L p .08 .282 .767 r
F P
0 g
s
.60187 .46469 m .5975 .4436 L .5935 .44368 L p .073 .157 .647 r
F P
0 g
s
.48832 .41446 m .50698 .40625 L .50197 .39759 L p .723 .847 .94 r
F P
0 g
s
.50197 .39759 m .48134 .40561 L .48832 .41446 L p .723 .847 .94 r
F P
0 g
s
.43243 .58425 m .45264 .59177 L .45213 .60097 L p .763 .389 .348 r
F P
0 g
s
.47657 .60272 m .45213 .60097 L .45264 .59177 L p .681 .314 .343 r
F P
0 g
s
.56844 .41426 m .58351 .42686 L .58646 .42498 L p .155 .449 .88 r
F P
0 g
s
.58646 .42498 m .56978 .41105 L .56844 .41426 L p .155 .449 .88 r
F P
0 g
s
.5975 .4436 m .58646 .42498 L .58351 .42686 L p .08 .282 .767 r
F P
0 g
s
.4024 .50907 m .40021 .53069 L .39178 .5307 L p .958 .796 .64 r
F P
0 g
s
.39178 .5307 m .39368 .50614 L .4024 .50907 L p .958 .796 .64 r
F P
0 g
s
.60187 .46469 m .59957 .486 L .60828 .49065 L p .295 .243 .627 r
F P
0 g
s
.60041 .51297 m .60828 .49065 L .59957 .486 L p .335 .214 .563 r
F P
0 g
s
.41576 .57052 m .43243 .58425 L .42907 .59206 L p .844 .491 .387 r
F P
0 g
s
.45213 .60097 m .42907 .59206 L .43243 .58425 L p .763 .389 .348 r
F P
0 g
s
.50698 .40625 m .52786 .4019 L .52548 .39353 L p .652 .816 .962 r
F P
0 g
s
.52548 .39353 m .50197 .39759 L .50698 .40625 L p .652 .816 .962 r
F P
0 g
s
.40021 .53069 m .40467 .55193 L .39718 .55494 L p .95 .714 .545 r
F P
0 g
s
.39718 .55494 m .39178 .5307 L .40021 .53069 L p .95 .714 .545 r
F P
0 g
s
.40467 .55193 m .41576 .57052 L .41 .57621 L p .912 .607 .454 r
F P
0 g
s
.42907 .59206 m .41 .57621 L .41576 .57052 L p .844 .491 .387 r
F P
0 g
s
.41 .57621 m .39718 .55494 L .40467 .55193 L p .912 .607 .454 r
F P
0 g
s
.53699 .58081 m .54882 .57247 L .5604 .58857 L p .558 .314 .503 r
F P
0 g
s
.54882 .57247 m .55587 .56691 L .56804 .58264 L p .544 .312 .514 r
F P
0 g
s
.56804 .58264 m .5604 .58857 L .54882 .57247 L p .544 .312 .514 r
F P
0 g
s
.52049 .59023 m .53699 .58081 L .54737 .59729 L p .579 .32 .487 r
F P
0 g
s
.5604 .58857 m .54737 .59729 L .53699 .58081 L p .558 .314 .503 r
F P
0 g
s
.55587 .56691 m .55825 .56499 L .57054 .58052 L p .535 .311 .522 r
F P
0 g
s
.57054 .58052 m .56804 .58264 L .55587 .56691 L p .535 .311 .522 r
F P
0 g
s
.56052 .56296 m .55825 .56499 L .57054 .58052 L p .535 .311 .522 r
F P
0 g
s
.5975 .4436 m .60187 .46469 L .61031 .4663 L p .276 .305 .711 r
F P
0 g
s
.60828 .49065 m .61031 .4663 L .60187 .46469 L p .295 .243 .627 r
F P
0 g
s
.56713 .55689 m .56052 .56296 L .57304 .57839 L p .525 .309 .528 r
F P
0 g
s
.57054 .58052 m .57304 .57839 L .56052 .56296 L p .535 .311 .522 r
F P
0 g
s
.52786 .4019 m .5495 .40323 L .55004 .39556 L p .556 .752 .969 r
F P
0 g
s
.55004 .39556 m .52548 .39353 L .52786 .4019 L p .556 .752 .969 r
F P
0 g
s
.57724 .54658 m .56713 .55689 L .58013 .57181 L p .51 .306 .539 r
F P
0 g
s
.57304 .57839 m .58013 .57181 L .56713 .55689 L p .525 .309 .528 r
F P
0 g
s
.49995 .59841 m .52049 .59023 L .52891 .607 L p .611 .332 .47 r
F P
0 g
s
.54737 .59729 m .52891 .607 L .52049 .59023 L p .579 .32 .487 r
F P
0 g
s
.58914 .53185 m .57724 .54658 L .59082 .56037 L p .489 .304 .556 r
F P
0 g
s
.58013 .57181 m .59082 .56037 L .57724 .54658 L p .51 .306 .539 r
F P
0 g
s
.47657 .60272 m .49995 .59841 L .50546 .61518 L p .653 .355 .454 r
F P
0 g
s
.52891 .607 m .50546 .61518 L .49995 .59841 L p .611 .332 .47 r
F P
0 g
s
.58646 .42498 m .5975 .4436 L .60503 .44214 L p .296 .404 .803 r
F P
0 g
s
.61031 .4663 m .60503 .44214 L .5975 .4436 L p .276 .305 .711 r
F P
0 g
s
.5495 .40323 m .56978 .41105 L .57319 .40475 L p .449 .652 .946 r
F P
0 g
s
.57319 .40475 m .55004 .39556 L .5495 .40323 L p .449 .652 .946 r
F P
0 g
s
.60041 .51297 m .58914 .53185 L .60336 .54374 L p .463 .306 .582 r
F P
0 g
s
.59082 .56037 m .60336 .54374 L .58914 .53185 L p .489 .304 .556 r
F P
0 g
s
.45213 .60097 m .47657 .60272 L .47833 .61903 L p .707 .395 .448 r
F P
0 g
s
.50546 .61518 m .47833 .61903 L .47657 .60272 L p .653 .355 .454 r
F P
0 g
s
.56978 .41105 m .58646 .42498 L .59227 .42079 L p .355 .528 .889 r
F P
0 g
s
.59227 .42079 m .57319 .40475 L .56978 .41105 L p .355 .528 .889 r
F P
0 g
s
.60503 .44214 m .59227 .42079 L .58646 .42498 L p .296 .404 .803 r
F P
0 g
s
.4412 .43286 m .43458 .43898 L .42151 .42628 L p .825 .821 .845 r
F P
0 g
s
.43458 .43898 m .42449 .44941 L .41083 .43784 L p .839 .821 .831 r
F P
0 g
s
.41083 .43784 m .42151 .42628 L .43458 .43898 L p .839 .821 .831 r
F P
0 g
s
.42449 .44941 m .41263 .46435 L .39834 .45465 L p .858 .819 .81 r
F P
0 g
s
.39834 .45465 m .41083 .43784 L .42449 .44941 L p .858 .819 .81 r
F P
0 g
s
.60828 .49065 m .60041 .51297 L .61514 .52194 L p .435 .317 .62 r
F P
0 g
s
.60336 .54374 m .61514 .52194 L .60041 .51297 L p .463 .306 .582 r
F P
0 g
s
.44347 .43081 m .4412 .43286 L .42859 .41964 L p .817 .822 .854 r
F P
0 g
s
.42151 .42628 m .42859 .41964 L .4412 .43286 L p .825 .821 .845 r
F P
0 g
s
.44347 .43081 m .44585 .42889 L .4336 .41535 L p .817 .822 .854 r
F P
0 g
s
.4336 .41535 m .4311 .41749 L .44347 .43081 L p .817 .822 .854 r
F P
0 g
s
.42859 .41964 m .4311 .41749 L .44347 .43081 L p .817 .822 .854 r
F P
0 g
s
.42907 .59206 m .45213 .60097 L .44975 .61601 L p .768 .455 .457 r
F P
0 g
s
.47833 .61903 m .44975 .61601 L .45213 .60097 L p .707 .395 .448 r
F P
0 g
s
.44585 .42889 m .45292 .4233 L .44126 .40938 L p .806 .819 .861 r
F P
0 g
s
.44126 .40938 m .4336 .41535 L .44585 .42889 L p .806 .819 .861 r
F P
0 g
s
.41263 .46435 m .40143 .48353 L .38665 .47667 L p .88 .811 .777 r
F P
0 g
s
.38665 .47667 m .39834 .45465 L .41263 .46435 L p .88 .811 .777 r
F P
0 g
s
.45292 .4233 m .46477 .41496 L .45433 .40062 L p .791 .817 .873 r
F P
0 g
s
.45433 .40062 m .44126 .40938 L .45292 .4233 L p .791 .817 .873 r
F P
0 g
s
.40143 .48353 m .39368 .50614 L .37873 .50302 L p .9 .791 .732 r
F P
0 g
s
.37873 .50302 m .38665 .47667 L .40143 .48353 L p .9 .791 .732 r
F P
0 g
s
.46477 .41496 m .48134 .40561 L .47286 .3909 L p .766 .811 .888 r
F P
0 g
s
.47286 .3909 m .45433 .40062 L .46477 .41496 L p .766 .811 .888 r
F P
0 g
s
.41 .57621 m .42907 .59206 L .42252 .6049 L p .828 .531 .487 r
F P
0 g
s
.44975 .61601 m .42252 .6049 L .42907 .59206 L p .768 .455 .457 r
F P
0 g
s
.39368 .50614 m .39178 .5307 L .37743 .53183 L p .911 .753 .673 r
F P
0 g
s
.37743 .53183 m .37873 .50302 L .39368 .50614 L p .911 .753 .673 r
F P
0 g
s
.48134 .40561 m .50197 .39759 L .49644 .38278 L p .729 .797 .906 r
F P
0 g
s
.49644 .38278 m .47286 .3909 L .48134 .40561 L p .729 .797 .906 r
F P
0 g
s
.39718 .55494 m .41 .57621 L .39984 .58582 L p .876 .615 .54 r
F P
0 g
s
.42252 .6049 m .39984 .58582 L .41 .57621 L p .828 .531 .487 r
F P
0 g
s
.61031 .4663 m .60828 .49065 L .62322 .4958 L p .414 .346 .672 r
F P
0 g
s
.61514 .52194 m .62322 .4958 L .60828 .49065 L p .435 .317 .62 r
F P
0 g
s
.39178 .5307 m .39718 .55494 L .38436 .5605 L p .905 .692 .605 r
F P
0 g
s
.38436 .5605 m .37743 .53183 L .39178 .5307 L p .905 .692 .605 r
F P
0 g
s
.39984 .58582 m .38436 .5605 L .39718 .55494 L p .876 .615 .54 r
F P
0 g
s
.50197 .39759 m .52548 .39353 L .52374 .37907 L p .677 .769 .92 r
F P
0 g
s
.52374 .37907 m .49644 .38278 L .50197 .39759 L p .677 .769 .92 r
F P
0 g
s
.60503 .44214 m .61031 .4663 L .6247 .46712 L p .408 .397 .736 r
F P
0 g
s
.62322 .4958 m .6247 .46712 L .61031 .4663 L p .414 .346 .672 r
F P
0 g
s
.52548 .39353 m .55004 .39556 L .55247 .38231 L p .612 .72 .923 r
F P
0 g
s
.55247 .38231 m .52374 .37907 L .52548 .39353 L p .612 .72 .923 r
F P
0 g
s
.59227 .42079 m .60503 .44214 L .61792 .43846 L p .426 .471 .804 r
F P
0 g
s
.6247 .46712 m .61792 .43846 L .60503 .44214 L p .408 .397 .736 r
F P
0 g
s
.55004 .39556 m .57319 .40475 L .57982 .39369 L p .539 .649 .905 r
F P
0 g
s
.57982 .39369 m .55247 .38231 L .55004 .39556 L p .539 .649 .905 r
F P
0 g
s
.57319 .40475 m .59227 .42079 L .60253 .413 L p .473 .561 .865 r
F P
0 g
s
.61792 .43846 m .60253 .413 L .59227 .42079 L p .426 .471 .804 r
F P
0 g
s
.52891 .607 m .54737 .59729 L .56149 .6216 L p .616 .385 .543 r
F P
0 g
s
.54737 .59729 m .5604 .58857 L .57661 .61174 L p .597 .379 .556 r
F P
0 g
s
.57661 .61174 m .56149 .6216 L .54737 .59729 L p .597 .379 .556 r
F P
0 g
s
.60253 .413 m .57982 .39369 L .57319 .40475 L p .473 .561 .865 r
F P
0 g
s
.5604 .58857 m .56804 .58264 L .58547 .60503 L p .585 .375 .563 r
F P
0 g
s
.58547 .60503 m .57661 .61174 L .5604 .58857 L p .585 .375 .563 r
F P
0 g
s
.50546 .61518 m .52891 .607 L .53973 .63229 L p .642 .397 .532 r
F P
0 g
s
.56149 .6216 m .53973 .63229 L .52891 .607 L p .616 .385 .543 r
F P
0 g
s
.56804 .58264 m .57054 .58052 L .58834 .60259 L p .577 .374 .569 r
F P
0 g
s
.58834 .60259 m .58547 .60503 L .56804 .58264 L p .577 .374 .569 r
F P
0 g
s
.57304 .57839 m .57054 .58052 L .58834 .60259 L p .577 .374 .569 r
F P
0 g
s
.58013 .57181 m .57304 .57839 L .59121 .60015 L p .57 .373 .575 r
F P
0 g
s
.58834 .60259 m .59121 .60015 L .57304 .57839 L p .577 .374 .569 r
F P
0 g
s
.59082 .56037 m .58013 .57181 L .59927 .5925 L p .559 .373 .585 r
F P
0 g
s
.59121 .60015 m .59927 .5925 L .58013 .57181 L p .57 .373 .575 r
F P
0 g
s
.47833 .61903 m .50546 .61518 L .5118 .64098 L p .676 .418 .523 r
F P
0 g
s
.53973 .63229 m .5118 .64098 L .50546 .61518 L p .642 .397 .532 r
F P
0 g
s
.60336 .54374 m .59082 .56037 L .61145 .57918 L p .542 .372 .601 r
F P
0 g
s
.59927 .5925 m .61145 .57918 L .59082 .56037 L p .559 .373 .585 r
F P
0 g
s
.44975 .61601 m .47833 .61903 L .47913 .64448 L p .718 .451 .521 r
F P
0 g
s
.5118 .64098 m .47913 .64448 L .47833 .61903 L p .676 .418 .523 r
F P
0 g
s
.61514 .52194 m .60336 .54374 L .62552 .55945 L p .525 .377 .623 r
F P
0 g
s
.61145 .57918 m .62552 .55945 L .60336 .54374 L p .542 .372 .601 r
F P
0 g
s
.42252 .6049 m .44975 .61601 L .44434 .63972 L p .763 .497 .531 r
F P
0 g
s
.47913 .64448 m .44434 .63972 L .44975 .61601 L p .718 .451 .521 r
F P
0 g
s
.62322 .4958 m .61514 .52194 L .63858 .53329 L p .508 .391 .655 r
F P
0 g
s
.62552 .55945 m .63858 .53329 L .61514 .52194 L p .525 .377 .623 r
F P
0 g
s
.39984 .58582 m .42252 .6049 L .411 .62527 L p .807 .554 .556 r
F P
0 g
s
.44434 .63972 m .411 .62527 L .42252 .6049 L p .763 .497 .531 r
F P
0 g
s
.38436 .5605 m .39984 .58582 L .38292 .60136 L p .842 .614 .594 r
F P
0 g
s
.411 .62527 m .38292 .60136 L .39984 .58582 L p .807 .554 .556 r
F P
0 g
s
.41083 .43784 m .39834 .45465 L .37605 .44136 L p .833 .771 .793 r
F P
0 g
s
.39834 .45465 m .38665 .47667 L .36312 .46772 L p .848 .764 .769 r
F P
0 g
s
.36312 .46772 m .37605 .44136 L .39834 .45465 L p .848 .764 .769 r
F P
0 g
s
.42151 .42628 m .41083 .43784 L .39004 .42143 L p .817 .774 .813 r
F P
0 g
s
.37605 .44136 m .39004 .42143 L .41083 .43784 L p .833 .771 .793 r
F P
0 g
s
.38665 .47667 m .37873 .50302 L .35468 .4996 L p .862 .746 .734 r
F P
0 g
s
.35468 .4996 m .36312 .46772 L .38665 .47667 L p .862 .746 .734 r
F P
0 g
s
.37743 .53183 m .38436 .5605 L .36345 .57001 L p .863 .671 .642 r
F P
0 g
s
.38292 .60136 m .36345 .57001 L .38436 .5605 L p .842 .614 .594 r
F P
0 g
s
.42859 .41964 m .42151 .42628 L .40221 .40798 L p .807 .775 .824 r
F P
0 g
s
.39004 .42143 m .40221 .40798 L .42151 .42628 L p .817 .774 .813 r
F P
0 g
s
.37873 .50302 m .37743 .53183 L .35415 .53481 L p .868 .715 .69 r
F P
0 g
s
.35415 .53481 m .35468 .4996 L .37873 .50302 L p .868 .715 .69 r
F P
0 g
s
.36345 .57001 m .35415 .53481 L .37743 .53183 L p .863 .671 .642 r
F P
0 g
s
.4311 .41749 m .42859 .41964 L .41027 .40025 L p .799 .774 .83 r
F P
0 g
s
.40221 .40798 m .41027 .40025 L .42859 .41964 L p .807 .775 .824 r
F P
0 g
s
.4311 .41749 m .4336 .41535 L .41602 .39532 L p .799 .774 .83 r
F P
0 g
s
.41602 .39532 m .41315 .39779 L .4311 .41749 L p .799 .774 .83 r
F P
0 g
s
.41027 .40025 m .41315 .39779 L .4311 .41749 L p .799 .774 .83 r
F P
0 g
s
.6247 .46712 m .62322 .4958 L .64725 .50159 L p .495 .416 .696 r
F P
0 g
s
.63858 .53329 m .64725 .50159 L .62322 .4958 L p .508 .391 .655 r
F P
0 g
s
.4336 .41535 m .44126 .40938 L .4249 .38854 L p .791 .773 .837 r
F P
0 g
s
.4249 .38854 m .41602 .39532 L .4336 .41535 L p .791 .773 .837 r
F P
0 g
s
.44126 .40938 m .45433 .40062 L .44008 .37858 L p .779 .771 .846 r
F P
0 g
s
.44008 .37858 m .4249 .38854 L .44126 .40938 L p .779 .771 .846 r
F P
0 g
s
.45433 .40062 m .47286 .3909 L .46194 .36782 L p .757 .763 .858 r
F P
0 g
s
.46194 .36782 m .44008 .37858 L .45433 .40062 L p .757 .763 .858 r
F P
0 g
s
.47286 .3909 m .49644 .38278 L .49006 .35909 L p .729 .752 .87 r
F P
0 g
s
.49006 .35909 m .46194 .36782 L .47286 .3909 L p .729 .752 .87 r
F P
0 g
s
.61792 .43846 m .6247 .46712 L .64804 .46644 L p .496 .457 .744 r
F P
0 g
s
.64725 .50159 m .64804 .46644 L .6247 .46712 L p .495 .416 .696 r
F P
0 g
s
.49644 .38278 m .52374 .37907 L .52296 .35567 L p .691 .728 .879 r
F P
0 g
s
.52296 .35567 m .49006 .35909 L .49644 .38278 L p .691 .728 .879 r
F P
0 g
s
.60253 .413 m .61792 .43846 L .63896 .43115 L p .512 .512 .793 r
F P
0 g
s
.64804 .46644 m .63896 .43115 L .61792 .43846 L p .496 .457 .744 r
F P
0 g
s
.52374 .37907 m .55247 .38231 L .55799 .36062 L p .643 .69 .879 r
F P
0 g
s
.55799 .36062 m .52296 .35567 L .52374 .37907 L p .643 .69 .879 r
F P
0 g
s
.55247 .38231 m .57982 .39369 L .5915 .37535 L p .593 .639 .866 r
F P
0 g
s
.5915 .37535 m .55799 .36062 L .55247 .38231 L p .593 .639 .866 r
F P
0 g
s
.57982 .39369 m .60253 .413 L .61961 .39957 L p .546 .576 .836 r
F P
0 g
s
.63896 .43115 m .61961 .39957 L .60253 .413 L p .512 .512 .793 r
F P
0 g
s
.61961 .39957 m .5915 .37535 L .57982 .39369 L p .546 .576 .836 r
F P
0 g
s
.5118 .64098 m .53973 .63229 L .55451 .67013 L p .663 .445 .579 r
F P
0 g
s
.53973 .63229 m .56149 .6216 L .58141 .65743 L p .641 .435 .588 r
F P
0 g
s
.58141 .65743 m .55451 .67013 L .53973 .63229 L p .641 .435 .588 r
F P
0 g
s
.56149 .6216 m .57661 .61174 L .60003 .64557 L p .627 .429 .595 r
F P
0 g
s
.60003 .64557 m .58141 .65743 L .56149 .6216 L p .627 .429 .595 r
F P
0 g
s
.47913 .64448 m .5118 .64098 L .51968 .68006 L p .689 .462 .574 r
F P
0 g
s
.55451 .67013 m .51968 .68006 L .5118 .64098 L p .663 .445 .579 r
F P
0 g
s
.57661 .61174 m .58547 .60503 L .61088 .63742 L p .617 .427 .602 r
F P
0 g
s
.61088 .63742 m .60003 .64557 L .57661 .61174 L p .617 .427 .602 r
F P
0 g
s
.58547 .60503 m .58834 .60259 L .61439 .63445 L p .611 .426 .607 r
F P
0 g
s
.61439 .63445 m .61088 .63742 L .58547 .60503 L p .611 .426 .607 r
F P
0 g
s
.59121 .60015 m .58834 .60259 L .61439 .63445 L p .611 .426 .607 r
F P
0 g
s
.59927 .5925 m .59121 .60015 L .6179 .63148 L p .605 .425 .612 r
F P
0 g
s
.61439 .63445 m .6179 .63148 L .59121 .60015 L p .611 .426 .607 r
F P
0 g
s
.44434 .63972 m .47913 .64448 L .47855 .6832 L p .721 .489 .574 r
F P
0 g
s
.51968 .68006 m .47855 .6832 L .47913 .64448 L p .689 .462 .574 r
F P
0 g
s
.61145 .57918 m .59927 .5925 L .62772 .6221 L p .595 .424 .62 r
F P
0 g
s
.6179 .63148 m .62772 .6221 L .59927 .5925 L p .605 .425 .612 r
F P
0 g
s
.62552 .55945 m .61145 .57918 L .64246 .60567 L p .585 .427 .633 r
F P
0 g
s
.62772 .6221 m .64246 .60567 L .61145 .57918 L p .595 .424 .62 r
F P
0 g
s
.411 .62527 m .44434 .63972 L .43446 .67614 L p .754 .524 .583 r
F P
0 g
s
.47855 .6832 m .43446 .67614 L .44434 .63972 L p .721 .489 .574 r
F P
0 g
s
.63858 .53329 m .62552 .55945 L .6594 .58118 L p .571 .431 .652 r
F P
0 g
s
.64246 .60567 m .6594 .58118 L .62552 .55945 L p .585 .427 .633 r
F P
0 g
s
.38292 .60136 m .411 .62527 L .39195 .65686 L p .786 .567 .602 r
F P
0 g
s
.43446 .67614 m .39195 .65686 L .411 .62527 L p .754 .524 .583 r
F P
0 g
s
.36345 .57001 m .38292 .60136 L .35591 .62571 L p .812 .611 .631 r
F P
0 g
s
.39195 .65686 m .35591 .62571 L .38292 .60136 L p .786 .567 .602 r
F P
0 g
s
.64725 .50159 m .63858 .53329 L .67485 .5484 L p .56 .443 .676 r
F P
0 g
s
.6594 .58118 m .67485 .5484 L .63858 .53329 L p .571 .431 .652 r
F P
0 g
s
.35415 .53481 m .36345 .57001 L .33041 .58543 L p .828 .653 .665 r
F P
0 g
s
.35591 .62571 m .33041 .58543 L .36345 .57001 L p .812 .611 .631 r
F P
0 g
s
.35468 .4996 m .35415 .53481 L .31765 .54044 L p .833 .686 .7 r
F P
0 g
s
.33041 .58543 m .31765 .54044 L .35415 .53481 L p .828 .653 .665 r
F P
0 g
s
.64804 .46644 m .64725 .50159 L .6846 .50824 L p .553 .464 .708 r
F P
0 g
s
.67485 .5484 m .6846 .50824 L .64725 .50159 L p .56 .443 .676 r
F P
0 g
s
.36312 .46772 m .35468 .4996 L .31728 .49565 L p .829 .71 .733 r
F P
0 g
s
.31765 .54044 m .31728 .49565 L .35468 .4996 L p .833 .686 .7 r
F P
0 g
s
.37605 .44136 m .36312 .46772 L .32669 .45532 L p .819 .723 .759 r
F P
0 g
s
.31728 .49565 m .32669 .45532 L .36312 .46772 L p .829 .71 .733 r
F P
0 g
s
.39004 .42143 m .37605 .44136 L .34192 .42228 L p .807 .731 .781 r
F P
0 g
s
.32669 .45532 m .34192 .42228 L .37605 .44136 L p .819 .723 .759 r
F P
0 g
s
.40221 .40798 m .39004 .42143 L .35875 .39754 L p .796 .733 .794 r
F P
0 g
s
.34192 .42228 m .35875 .39754 L .39004 .42143 L p .807 .731 .781 r
F P
0 g
s
.41027 .40025 m .40221 .40798 L .37346 .3809 L p .787 .733 .803 r
F P
0 g
s
.35875 .39754 m .37346 .3809 L .40221 .40798 L p .796 .733 .794 r
F P
0 g
s
.41315 .39779 m .41027 .40025 L .38328 .37141 L p .781 .733 .808 r
F P
0 g
s
.37346 .3809 m .38328 .37141 L .41027 .40025 L p .787 .733 .803 r
F P
0 g
s
.63896 .43115 m .64804 .46644 L .68465 .46347 L p .556 .496 .743 r
F P
0 g
s
.6846 .50824 m .68465 .46347 L .64804 .46644 L p .553 .464 .708 r
F P
0 g
s
.41315 .39779 m .41602 .39532 L .39031 .36538 L p .781 .733 .808 r
F P
0 g
s
.39031 .36538 m .3868 .3684 L .41315 .39779 L p .781 .733 .808 r
F P
0 g
s
.38328 .37141 m .3868 .3684 L .41315 .39779 L p .781 .733 .808 r
F P
0 g
s
.41602 .39532 m .4249 .38854 L .4012 .35712 L p .775 .732 .813 r
F P
0 g
s
.4012 .35712 m .39031 .36538 L .41602 .39532 L p .775 .732 .813 r
F P
0 g
s
.4249 .38854 m .44008 .37858 L .41991 .34511 L p .765 .73 .821 r
F P
0 g
s
.41991 .34511 m .4012 .35712 L .4249 .38854 L p .765 .73 .821 r
F P
0 g
s
.44008 .37858 m .46194 .36782 L .44699 .33222 L p .75 .725 .829 r
F P
0 g
s
.44699 .33222 m .41991 .34511 L .44008 .37858 L p .75 .725 .829 r
F P
0 g
s
.46194 .36782 m .49006 .35909 L .48209 .32218 L p .726 .713 .838 r
F P
0 g
s
.48209 .32218 m .44699 .33222 L .46194 .36782 L p .726 .713 .838 r
F P
0 g
s
.61961 .39957 m .63896 .43115 L .67225 .41826 L p .569 .537 .779 r
F P
0 g
s
.68465 .46347 m .67225 .41826 L .63896 .43115 L p .556 .496 .743 r
F P
0 g
s
.49006 .35909 m .52296 .35567 L .52359 .31904 L p .698 .696 .844 r
F P
0 g
s
.52359 .31904 m .48209 .32218 L .49006 .35909 L p .698 .696 .844 r
F P
0 g
s
.5915 .37535 m .61961 .39957 L .64694 .37758 L p .594 .583 .81 r
F P
0 g
s
.67225 .41826 m .64694 .37758 L .61961 .39957 L p .569 .537 .779 r
F P
0 g
s
.52296 .35567 m .55799 .36062 L .56806 .32631 L p .663 .666 .843 r
F P
0 g
s
.56806 .32631 m .52359 .31904 L .52296 .35567 L p .663 .666 .843 r
F P
0 g
s
.55799 .36062 m .5915 .37535 L .61084 .34597 L p .627 .629 .832 r
F P
0 g
s
.61084 .34597 m .56806 .32631 L .55799 .36062 L p .627 .629 .832 r
F P
0 g
s
.64694 .37758 m .61084 .34597 L .5915 .37535 L p .594 .583 .81 r
F P
0 g
s
.51968 .68006 m .55451 .67013 L .57548 .7268 L p .677 .483 .616 r
F P
0 g
s
.55451 .67013 m .58141 .65743 L .61049 .71079 L p .66 .474 .622 r
F P
0 g
s
.61049 .71079 m .57548 .7268 L .55451 .67013 L p .66 .474 .622 r
F P
0 g
s
.47855 .6832 m .51968 .68006 L .52992 .73896 L p .697 .496 .612 r
F P
0 g
s
.57548 .7268 m .52992 .73896 L .51968 .68006 L p .677 .483 .616 r
F P
0 g
s
.43446 .67614 m .47855 .6832 L .47599 .74211 L p .721 .517 .614 r
F P
0 g
s
.52992 .73896 m .47599 .74211 L .47855 .6832 L p .697 .496 .612 r
F P
0 g
s
.58141 .65743 m .60003 .64557 L .63468 .69572 L p .649 .47 .628 r
F P
0 g
s
.63468 .69572 m .61049 .71079 L .58141 .65743 L p .649 .47 .628 r
F P
0 g
s
.60003 .64557 m .61088 .63742 L .64865 .68519 L p .641 .468 .633 r
F P
0 g
s
.64865 .68519 m .63468 .69572 L .60003 .64557 L p .641 .468 .633 r
F P
0 g
s
.61088 .63742 m .61439 .63445 L .65318 .68136 L p .637 .467 .637 r
F P
0 g
s
.65318 .68136 m .64865 .68519 L .61088 .63742 L p .637 .467 .637 r
F P
0 g
s
.39195 .65686 m .43446 .67614 L .41785 .73172 L p .746 .543 .621 r
F P
0 g
s
.47599 .74211 m .41785 .73172 L .43446 .67614 L p .721 .517 .614 r
F P
0 g
s
.6179 .63148 m .61439 .63445 L .65318 .68136 L p .637 .467 .637 r
F P
0 g
s
.62772 .6221 m .6179 .63148 L .65771 .67753 L p .632 .467 .641 r
F P
0 g
s
.65318 .68136 m .65771 .67753 L .6179 .63148 L p .637 .467 .637 r
F P
0 g
s
.64246 .60567 m .62772 .6221 L .67041 .66549 L p .625 .467 .647 r
F P
0 g
s
.65771 .67753 m .67041 .66549 L .62772 .6221 L p .632 .467 .641 r
F P
0 g
s
.35591 .62571 m .39195 .65686 L .36153 .70532 L p .769 .574 .635 r
F P
0 g
s
.41785 .73172 m .36153 .70532 L .39195 .65686 L p .746 .543 .621 r
F P
0 g
s
.6594 .58118 m .64246 .60567 L .68929 .64411 L p .617 .468 .657 r
F P
0 g
s
.67041 .66549 m .68929 .64411 L .64246 .60567 L p .625 .467 .647 r
F P
0 g
s
.67485 .5484 m .6594 .58118 L .71089 .61218 L p .608 .473 .672 r
F P
0 g
s
.68929 .64411 m .71089 .61218 L .6594 .58118 L p .617 .468 .657 r
F P
0 g
s
.33041 .58543 m .35591 .62571 L .31338 .66347 L p .787 .607 .656 r
F P
0 g
s
.36153 .70532 m .31338 .66347 L .35591 .62571 L p .769 .574 .635 r
F P
0 g
s
.31765 .54044 m .33041 .58543 L .27898 .60969 L p .799 .637 .681 r
F P
0 g
s
.31338 .66347 m .27898 .60969 L .33041 .58543 L p .787 .607 .656 r
F P
0 g
s
.6846 .50824 m .67485 .5484 L .73041 .56914 L p .599 .482 .691 r
F P
0 g
s
.71089 .61218 m .73041 .56914 L .67485 .5484 L p .608 .473 .672 r
F P
0 g
s
.31728 .49565 m .31765 .54044 L .26109 .54996 L p .803 .662 .707 r
F P
0 g
s
.27898 .60969 m .26109 .54996 L .31765 .54044 L p .799 .637 .681 r
F P
0 g
s
.68465 .46347 m .6846 .50824 L .74233 .51628 L p .596 .499 .714 r
F P
0 g
s
.73041 .56914 m .74233 .51628 L .6846 .50824 L p .599 .482 .691 r
F P
0 g
s
.32669 .45532 m .31728 .49565 L .25947 .4907 L p .8 .68 .731 r
F P
0 g
s
.26109 .54996 m .25947 .4907 L .31728 .49565 L p .803 .662 .707 r
F P
0 g
s
.34192 .42228 m .32669 .45532 L .27079 .43758 L p .794 .691 .751 r
F P
0 g
s
.25947 .4907 m .27079 .43758 L .32669 .45532 L p .8 .68 .731 r
F P
0 g
s
.67225 .41826 m .68465 .46347 L .74142 .45695 L p .598 .523 .741 r
F P
0 g
s
.74233 .51628 m .74142 .45695 L .68465 .46347 L p .596 .499 .714 r
F P
0 g
s
.35875 .39754 m .34192 .42228 L .28992 .39413 L p .785 .696 .767 r
F P
0 g
s
.27079 .43758 m .28992 .39413 L .34192 .42228 L p .794 .691 .751 r
F P
0 g
s
.37346 .3809 m .35875 .39754 L .31133 .36179 L p .776 .698 .777 r
F P
0 g
s
.28992 .39413 m .31133 .36179 L .35875 .39754 L p .785 .696 .767 r
F P
0 g
s
.38328 .37141 m .37346 .3809 L .33016 .34008 L p .77 .699 .784 r
F P
0 g
s
.31133 .36179 m .33016 .34008 L .37346 .3809 L p .776 .698 .777 r
F P
0 g
s
.3868 .3684 m .38328 .37141 L .34287 .32783 L p .765 .698 .788 r
F P
0 g
s
.33016 .34008 m .34287 .32783 L .38328 .37141 L p .77 .699 .784 r
F P
0 g
s
.64694 .37758 m .67225 .41826 L .72416 .3968 L p .609 .553 .766 r
F P
0 g
s
.74142 .45695 m .72416 .3968 L .67225 .41826 L p .598 .523 .741 r
F P
0 g
s
.3868 .3684 m .39031 .36538 L .35195 .32003 L p .765 .698 .788 r
F P
0 g
s
.35195 .32003 m .34741 .32393 L .3868 .3684 L p .765 .698 .788 r
F P
0 g
s
.34287 .32783 m .34741 .32393 L .3868 .3684 L p .765 .698 .788 r
F P
0 g
s
.39031 .36538 m .4012 .35712 L .36598 .3093 L p .761 .698 .792 r
F P
0 g
s
.36598 .3093 m .35195 .32003 L .39031 .36538 L p .761 .698 .792 r
F P
0 g
s
.4012 .35712 m .41991 .34511 L .39032 .29394 L p .752 .696 .798 r
F P
0 g
s
.39032 .29394 m .36598 .3093 L .4012 .35712 L p .752 .696 .798 r
F P
0 g
s
.41991 .34511 m .44699 .33222 L .42564 .27759 L p .741 .692 .804 r
F P
0 g
s
.42564 .27759 m .39032 .29394 L .41991 .34511 L p .741 .692 .804 r
F P
0 g
s
.44699 .33222 m .48209 .32218 L .47169 .26518 L p .723 .683 .811 r
F P
0 g
s
.47169 .26518 m .42564 .27759 L .44699 .33222 L p .723 .683 .811 r
F P
0 g
s
.61084 .34597 m .64694 .37758 L .69009 .34231 L p .627 .587 .789 r
F P
0 g
s
.72416 .3968 m .69009 .34231 L .64694 .37758 L p .609 .553 .766 r
F P
0 g
s
.48209 .32218 m .52359 .31904 L .52626 .262 L p .702 .668 .814 r
F P
0 g
s
.52626 .262 m .47169 .26518 L .48209 .32218 L p .702 .668 .814 r
F P
0 g
s
.56806 .32631 m .61084 .34597 L .64184 .29969 L p .651 .619 .805 r
F P
0 g
s
.69009 .34231 m .64184 .29969 L .61084 .34597 L p .627 .587 .789 r
F P
0 g
s
.52359 .31904 m .56806 .32631 L .58506 .27267 L p .677 .647 .813 r
F P
0 g
s
.58506 .27267 m .52626 .262 L .52359 .31904 L p .677 .647 .813 r
F P
0 g
s
.64184 .29969 m .58506 .27267 L .56806 .32631 L p .651 .619 .805 r
F P
0 g
s
.47599 .74211 m .52992 .73896 L .54433 .82844 L p .701 .522 .642 r
F P
0 g
s
.52992 .73896 m .57548 .7268 L .60633 .81261 L p .686 .511 .644 r
F P
0 g
s
.60633 .81261 m .54433 .82844 L .52992 .73896 L p .686 .511 .644 r
F P
0 g
s
.41785 .73172 m .47599 .74211 L .4706 .83189 L p .719 .537 .643 r
F P
0 g
s
.54433 .82844 m .4706 .83189 L .47599 .74211 L p .701 .522 .642 r
F P
0 g
s
.57548 .7268 m .61049 .71079 L .65396 .79127 L p .674 .505 .648 r
F P
0 g
s
.65396 .79127 m .60633 .81261 L .57548 .7268 L p .674 .505 .648 r
F P
0 g
s
.36153 .70532 m .41785 .73172 L .39098 .81675 L p .737 .557 .649 r
F P
0 g
s
.4706 .83189 m .39098 .81675 L .41785 .73172 L p .719 .537 .643 r
F P
0 g
s
.61049 .71079 m .63468 .69572 L .68673 .77098 L p .665 .502 .653 r
F P
0 g
s
.68673 .77098 m .65396 .79127 L .61049 .71079 L p .665 .502 .653 r
F P
0 g
s
.63468 .69572 m .64865 .68519 L .70566 .75678 L p .66 .5 .657 r
F P
0 g
s
.70566 .75678 m .68673 .77098 L .63468 .69572 L p .66 .5 .657 r
F P
0 g
s
.64865 .68519 m .65318 .68136 L .71185 .75168 L p .657 .5 .659 r
F P
0 g
s
.71185 .75168 m .70566 .75678 L .64865 .68519 L p .657 .5 .659 r
F P
0 g
s
.65771 .67753 m .65318 .68136 L .71185 .75168 L p .655 .499 .66 r
F P
0 g
s
.31338 .66347 m .36153 .70532 L .31355 .7798 L p .754 .579 .659 r
F P
0 g
s
.39098 .81675 m .31355 .7798 L .36153 .70532 L p .737 .557 .649 r
F P
0 g
s
.67041 .66549 m .65771 .67753 L .71793 .74644 L p .653 .499 .662 r
F P
0 g
s
.71185 .75168 m .71793 .74644 L .65771 .67753 L p .655 .499 .66 r
F P
0 g
s
.68929 .64411 m .67041 .66549 L .73512 .73016 L p .648 .499 .667 r
F P
0 g
s
.71793 .74644 m .73512 .73016 L .67041 .66549 L p .653 .499 .662 r
F P
0 g
s
.71089 .61218 m .68929 .64411 L .76067 .70123 L p .641 .5 .675 r
F P
0 g
s
.73512 .73016 m .76067 .70123 L .68929 .64411 L p .648 .499 .667 r
F P
0 g
s
.27898 .60969 m .31338 .66347 L .24701 .72176 L p .767 .603 .675 r
F P
0 g
s
.31355 .7798 m .24701 .72176 L .31338 .66347 L p .754 .579 .659 r
F P
0 g
s
.73041 .56914 m .71089 .61218 L .78977 .65778 L p .635 .504 .686 r
F P
0 g
s
.76067 .70123 m .78977 .65778 L .71089 .61218 L p .641 .5 .675 r
F P
0 g
s
.26109 .54996 m .27898 .60969 L .199 .64754 L p .776 .625 .693 r
F P
0 g
s
.24701 .72176 m .199 .64754 L .27898 .60969 L p .767 .603 .675 r
F P
0 g
s
.74233 .51628 m .73041 .56914 L .81582 .59907 L p .63 .512 .7 r
F P
0 g
s
.78977 .65778 m .81582 .59907 L .73041 .56914 L p .635 .504 .686 r
F P
0 g
s
.25947 .4907 m .26109 .54996 L .17348 .5653 L p .779 .643 .712 r
F P
0 g
s
.199 .64754 m .17348 .5653 L .26109 .54996 L p .776 .625 .693 r
F P
0 g
s
.74142 .45695 m .74233 .51628 L .83148 .52655 L p .627 .524 .718 r
F P
0 g
s
.81582 .59907 m .83148 .52655 L .74233 .51628 L p .63 .512 .7 r
F P
0 g
s
.27079 .43758 m .25947 .4907 L .17014 .48386 L p .777 .656 .729 r
F P
0 g
s
.17348 .5653 m .17014 .48386 L .25947 .4907 L p .779 .643 .712 r
F P
0 g
s
.72416 .3968 m .74142 .45695 L .82947 .44498 L p .629 .542 .737 r
F P
0 g
s
.83148 .52655 m .82947 .44498 L .74142 .45695 L p .627 .524 .718 r
F P
0 g
s
.28992 .39413 m .27079 .43758 L .18467 .4109 L p .772 .664 .744 r
F P
0 g
s
.17014 .48386 m .18467 .4109 L .27079 .43758 L p .777 .656 .729 r
F P
0 g
s
.31133 .36179 m .28992 .39413 L .20998 .35146 L p .766 .668 .755 r
F P
0 g
s
.18467 .4109 m .20998 .35146 L .28992 .39413 L p .772 .664 .744 r
F P
0 g
s
.69009 .34231 m .72416 .3968 L .80513 .36193 L p .637 .564 .755 r
F P
0 g
s
.82947 .44498 m .80513 .36193 L .72416 .3968 L p .629 .542 .737 r
F P
0 g
s
.33016 .34008 m .31133 .36179 L .23874 .30722 L p .759 .67 .764 r
F P
0 g
s
.20998 .35146 m .23874 .30722 L .31133 .36179 L p .766 .668 .755 r
F P
0 g
s
.34287 .32783 m .33016 .34008 L .26419 .27768 L p .754 .67 .769 r
F P
0 g
s
.23874 .30722 m .26419 .27768 L .33016 .34008 L p .759 .67 .764 r
F P
0 g
s
.34741 .32393 m .34287 .32783 L .2814 .26101 L p .752 .67 .771 r
F P
0 g
s
.26419 .27768 m .2814 .26101 L .34287 .32783 L p .754 .67 .769 r
F P
0 g
s
.34741 .32393 m .35195 .32003 L .2937 .25041 L p .75 .67 .772 r
F P
0 g
s
.2937 .25041 m .28749 .25564 L .34741 .32393 L p .75 .67 .772 r
F P
0 g
s
.2814 .26101 m .28749 .25564 L .34741 .32393 L p .752 .67 .771 r
F P
0 g
s
.35195 .32003 m .36598 .3093 L .31274 .23585 L p .748 .67 .774 r
F P
0 g
s
.31274 .23585 m .2937 .25041 L .35195 .32003 L p .748 .67 .774 r
F P
0 g
s
.64184 .29969 m .69009 .34231 L .75773 .28637 L p .651 .588 .771 r
F P
0 g
s
.80513 .36193 m .75773 .28637 L .69009 .34231 L p .637 .564 .755 r
F P
0 g
s
.36598 .3093 m .39032 .29394 L .3458 .21499 L p .742 .668 .778 r
F P
0 g
s
.3458 .21499 m .31274 .23585 L .36598 .3093 L p .742 .668 .778 r
F P
0 g
s
.39032 .29394 m .42564 .27759 L .394 .193 L p .733 .665 .783 r
F P
0 g
s
.394 .193 m .3458 .21499 L .39032 .29394 L p .733 .665 .783 r
F P
0 g
s
.42564 .27759 m .47169 .26518 L .45693 .17668 L p .72 .658 .788 r
F P
0 g
s
.45693 .17668 m .394 .193 L .42564 .27759 L p .72 .658 .788 r
F P
0 g
s
.58506 .27267 m .64184 .29969 L .69102 .22687 L p .668 .611 .783 r
F P
0 g
s
.75773 .28637 m .69102 .22687 L .64184 .29969 L p .651 .588 .771 r
F P
0 g
s
.47169 .26518 m .52626 .262 L .53187 .17313 L p .705 .648 .79 r
F P
0 g
s
.53187 .17313 m .45693 .17668 L .47169 .26518 L p .705 .648 .79 r
F P
0 g
s
.52626 .262 m .58506 .27267 L .61272 .18879 L p .686 .632 .789 r
F P
0 g
s
.69102 .22687 m .61272 .18879 L .58506 .27267 L p .668 .611 .783 r
F P
0 g
s
.61272 .18879 m .53187 .17313 L .52626 .262 L p .686 .632 .789 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 287.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00017b000`400?l00000o`00003oV_ooool2
o`0008Cooooo002Iooooo`03o`000?oooooo000008Cooooo002Hooooo`03o`000?oooooooooo00;o
0000Poooool009Oooooo00Oo0000ooooooooooooooooo`000?oooooo000008;ooooo002Fooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000POooool009Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07kooooo002Cooooo`;o0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07gooooo002Booooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`00TOooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0O?ooool0
093ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
07_ooooo002?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1jooooo`00S_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0NOooool008gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo07Sooooo002;ooooo`;o00003?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo07Sooooo002:ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1gooooo`00ROooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0M_ooool008Sooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Gooooo0027ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1dooooo`00Q_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Loooool0
08Cooooo0_l0000Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0L_ooool008?o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07;o
oooo0022ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1aooooo`00POooool00ol0003oooooooooo`0Cooooo`;o00005?ooool00ol0003ooooooooo
o`1`ooooo`00P?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000001Gooooo00?o0000
ooooooooool0Koooool007oooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo
000001Gooooo00?o0000ooooooooool0K_ooool007kooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0KOooool007co
oooo0_l0000Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`1]ooooo`00Noooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1/ooooo`00N_ooool00ol0003ooooooooo
o`0Cooooo`;o00002oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06_ooooo001i
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo06[ooooo001hooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06Wooooo001gooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo06Sooooo001eooooo`;o00005Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0J?ooool007Cooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Iooo
ool007?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0I_ooool007;ooooo00?o0000ooooooooool04oooool2o`00
01Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Uooooo`00LOooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1Tooooo`00L?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`1Sooooo`00K_ooool2o`0001Gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06?ooooo001]
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo06;ooooo001/ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo067ooooo001[ooooo`03
o`000?oooooooooo01?ooooo0_l0000Uooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0H?ooool006[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0Goooool006Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0G_oo
ool006Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0GOooool006Kooooo0_l0000Eooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Mooooo`00IOooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`1Looooo`00I?ooool00ol0003oooooooooo`0Cooooo`;o0000<Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo05_ooooo001Sooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05[ooooo001R
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo05Wooooo001Qooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool05?ooool>o`0001?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Hoooo
o`00Goooool2o`0001Gooooo00?o0000ooooooooool02?ooool=o`0000[o]:G:00Co0000ojnQbOn_
XLWo[j791_l0000>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0F?ooool005ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`Go00000_nhZ<T00ol0003o
]:G:okBUbP0BokBUbP03o`000?n_XLWo[j7900Oo[j791Ol0000:ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0Eoooool005gooooo00?o0000ooooooooool04oooool2o`0000?ooooo
1?l00007okRXb@03o`000?ndYL[o]:G:01;o]:G:00?o0000ojnQbOn_XLT03?n_XLT6o`0000Gooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Fooooo`00G?ooool00ol0003ooooooooo
o`0Cooooo`Ko00002onhZ<T00ol0003o]:G:okBUbP0BokBUbP03o`000?n_XLWo[j7901;o[j791?l0
0002ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0EOooool005_ooooo00?o0000
ooooooooool04_ooool3o`00017o^:S900?o0000okBUb_ndYLX04OndYLX00ol0003o[j79ojnQb@0D
ojnQb@06o`000?n[W<So0000o`000?oooooo00005?ooool00ol0003oooooooooo`1Dooooo`00F_oo
ool00ol0003oooooooooo`0Aooooo`;o000000?o^j[8o`000?nhZ<T04OnhZ<T00ol0003o]:G:okBU
bP0AokBUbP03o`000?n_XLWo[j7901?o[j7900?o0000oj^Lb?n[W<P00_n[W<P2o`0001Gooooo00?o
0000ooooooooool0Doooool005Sooooo0_l0000Booooo`;o00001?nkZ/P00ol0003o^:S9okRXb@0?
okRXb@03o`000?ndYL[o]:G:017o]:G:00?o0000ojnQbOn_XLT04on_XLT00ol0003oZic8oj^Lb004
oj^Lb0;o00004oooool00ol0003oooooooooo`1Cooooo`00Eoooool00ol0003oooooooooo`0@oooo
o`;o00001_nkZ/P00ol0003o^:S9okRXb@0?okRXb@03o`000?ndYL[o]:G:017o]:G:00?o0000ojnQ
bOn_XLT04on_XLT00ol0003oZic8oj^Lb006oj^Lb0;o00004_ooool00ol0003oooooooooo`1Boooo
o`00E_ooool00ol0003oooooooooo`0?ooooo`;o00002?nkZ/P00ol0003o^:S9okRXb@0?okRXb@03
o`000?ndYL[o]:G:017o]:G:00?o0000ojnQbOn_XLT04_n_XLT00ol0003oZic8oj^Lb009oj^Lb0?o
00004?ooool00ol0003oooooooooo`1Aooooo`00EOooool00ol0003oooooooooo`0>ooooo`;o0000
2onkZ/P00ol0003o^:S9okRXb@0>okRXb@03o`000?ndYL[o]:G:017o]:G:00?o0000ojnQbOn_XLT0
4_n_XLT00ol0003oZic8oj^Lb00<oj^Lb0;o00003oooool00ol0003oooooooooo`1@ooooo`00E?oo
ool00ol0003oooooooooo`0=ooooo`;o00003OnkZ/P00ol0003o^:S9okRXb@0?okRXb@03o`000?nd
YL[o]:G:013o]:G:00?o0000ojnQbOn_XLT04_n_XLT00ol0003oZic8oj^Lb00>oj^Lb0;o00003_oo
ool00ol0003oooooooooo`1?ooooo`00Doooool00ol0003oooooooooo`0<ooooo`;o00003onkZ/P0
0ol0003o^:S9okRXb@0?okRXb@03o`000?ndYL[o]:G:013o]:G:00?o0000ojnQbOn_XLT04On_XLT0
0ol0003oZic8oj^Lb00Aoj^Lb0;o00003Oooool00ol0003oooooooooo`1>ooooo`00D_ooool00ol0
003oooooooooo`0;ooooo`;o000000?o_J_7o`000?nkZ/P03onkZ/P00ol0003o^:S9okRXb@0>okRX
b@03o`000?ndYL[o]:G:00oo]:G:00?o0000ojnQbOn_XLT04_n_XLT00ol0003oZic8oj^Lb00Coj^L
b0;o00002oooool00ol0003oooooooooo`1>ooooo`00D?ooool2o`0000gooooo00?o0000okf[aonm
ZlL00_nmZlL00ol0003o^j[8ok^Zb00=ok^Zb003o`000?nhZ<Wo^:S900ko^:S900?o0000okBUb_nd
YLX03ondYLX00ol0003o[j79ojnQb@0BojnQb@03o`000?n[W<SoZic801GoZic80_l0000:ooooo`03
o`000?oooooooooo04gooooo001?ooooo`03o`000?oooooooooo00_ooooo0_l00005okf[a`03o`00
0?nkZ/So^j[800go^j[800?o0000okRXbOnhZ<T03_nhZ<T00ol0003o]:G:okBUbP0?okBUbP03o`00
0?n_XLWo[j79017o[j7900?o0000oj^Lb?n[W<P06?n[W<P2o`0000Wooooo00?o0000ooooooooool0
C?ooool004kooooo00?o0000ooooooooool02_ooool2o`0000So_J_700?o0000ok^Zb?nkZ/P03Onk
Z/P00ol0003o^:S9okRXb@0=okRXb@03o`000?ndYL[o]:G:00oo]:G:00?o0000ojnQbOn_XLT04On_
XLT00ol0003oZic8oj^Lb00Hoj^Lb003o`000?nVU/Go000000Wooooo00?o0000ooooooooool0Booo
ool004gooooo00?o0000ooooooooool02_ooool00ol0003o_J_7okf[a`09okf[a`03o`000?nkZ/So
^j[800co^j[800?o0000okRXbOnhZ<T03OnhZ<T00ol0003o]:G:okBUbP0?okBUbP03o`000?n_XLWo
[j79017o[j7900?o0000oj^Lb?n[W<P05on[W<P01Ol0003oYYK5ojJFaOnVU/Go000000Wooooo00?o
0000ooooooooool0B_ooool004cooooo00?o0000ooooooooool02Oooool2o`0000co_J_700?o0000
ok^Zb?nkZ/P03OnkZ/P00ol0003o^:S9okRXb@0=okRXb@03o`000?ndYL[o]:G:00ko]:G:00?o0000
ojnQbOn_XLT04?n_XLT00ol0003oZic8oj^Lb00Goj^Lb003o`000?nVU/GoYYK500?oYYK500?o0000
ooooooooool01oooool00ol0003oooooooooo`19ooooo`00Boooool00ol0003oooooooooo`09oooo
o`03o`000?noZlKo000000go_J_700?o0000ok^Zb?nkZ/P03?nkZ/P00ol0003o^:S9okRXb@0=okRX
b@03o`000?ndYL[o]:G:00ko]:G:00?o0000ojnQbOn_XLT04?n_XLT00ol0003oZic8oj^Lb00Goj^L
b003o`000?nVU/GoYYK500CoYYK500?o0000ooooooooool01oooool00ol0003oooooooooo`18oooo
o`00BOooool2o`0000_ooooo00Go0000okn[a_noZlKo_j_6o`00000<okf[a`03o`000?nkZ/So^j[8
00co^j[800?o0000okRXbOnhZ<T03OnhZ<T00ol0003o]:G:okBUbP0>okBUbP03o`000?n_XLWo[j79
013o[j7900?o0000oj^Lb?n[W<P05_n[W<P00ol0003oYYK5ojJFa@06ojJFa@03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0B?ooool004Sooooo00?o0000ooooooooool02_ooool00ol0003o
_j_6okn[aP03okn[aP03o`000?nmZlOo_J_700[o_J_700?o0000ok^Zb?nkZ/P03?nkZ/P00ol0003o
^:S9okRXb@0<okRXb@03o`000?ndYL[o]:G:00ko]:G:00?o0000ojnQbOn_XLT03on_XLT00ol0003o
Zic8oj^Lb00Foj^Lb003o`000?nVU/GoYYK500SoYYK500?o0000ooooooooool01_ooool00ol0003o
ooooooooo`17ooooo`00Aoooool00ol0003oooooooooo`09ooooo`;o00001onoZlH00ol0003o_J_7
okf[a`0:okf[a`03o`000?nkZ/So^j[800_o^j[800?o0000okRXbOnhZ<T03?nhZ<T00ol0003o]:G:
okBUbP0>okBUbP03o`000?n_XLWo[j7900oo[j7900?o0000oj^Lb?n[W<P05_n[W<P00ol0003oYYK5
ojJFa@09ojJFa@03o`000?oooooooooo00Kooooo00?o0000ooooooooool0A_ooool004Kooooo00?o
0000ooooooooool02Oooool00ol0003o_j_5o`000007okn[aP03o`000?nmZlOo_J_700[o_J_700?o
0000ok^Zb?nkZ/P02onkZ/P00ol0003o^:S9okRXb@0<okRXb@03o`000?ndYL[o]:G:00ko]:G:00?o
0000ojnQbOn_XLT03on_XLT00ol0003oZic8oj^Lb00Eoj^Lb003o`000?nVU/GoYYK500_oYYK50_l0
0007ooooo`03o`000?oooooooooo04Gooooo0015ooooo`03o`000?oooooooooo00Wooooo0_l00002
okn[a@03o`000?noZlKo_j_600Go_j_600?o0000okf[aonmZlL02_nmZlL00ol0003o^j[8ok^Zb00;
ok^Zb003o`000?nhZ<Wo^:S900co^:S900?o0000okBUb_ndYLX03OndYLX00ol0003o[j79ojnQb@0>
ojnQb@03o`000?n[W<SoZic801GoZic800?o0000ojJFaOnVU/D03_nVU/D00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04Cooooo0014ooooo`03o`000?oooooooooo00Wooooo00Co0000ol2[
aOo0ZlGo00000_noZlD00ol0003o_j_6okn[aP05okn[aP03o`000?nmZlOo_J_700Wo_J_700?o0000
ok^Zb?nkZ/P02onkZ/P00ol0003o^:S9okRXb@0<okRXb@03o`000?ndYL[o]:G:00Go]:G:3?l0000=
ojnQb@03o`000?n[W<SoZic801GoZic800?o0000ojJFaOnVU/D03onVU/D00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04?ooooo0013ooooo`03o`000?oooooooooo00Wooooo0_l00003ol2[
a@04o`000?noZlGo_j_5o`0000Oo_j_600?o0000okf[aonmZlL02OnmZlL00ol0003o^j[8ok^Zb00:
ok^Zb003o`000?nhZ<Wo^:S900[o^:S92_l00008ok>[d004o`000?n]YM3o[JG@ojfUd0Go00002?n_
XLT00ol0003oZic8oj^Lb00Doj^Lb003o`000?nVU/GoYYK5017oYYK500?o0000ooooooooool01?oo
ool00ol0003oooooooooo`13ooooo`00@Oooool2o`0000_ooooo00Co0000ol6[a?o1ZlCo00000oo0
ZlD01?l0003o_j_5okn[aOl00006okn[aP03o`000?nmZlOo_J_700[o_J_700?o0000ok^Zb?nkZ/P0
2_nkZ/P00ol0003o^:S9okRXb@06okRXb@?o00000_ni[/l00ol0003o/j_@ok>[d00=ok>[d003o`00
0?n]YM3o[JG@00Ko[JG@1Ol00002ojnQb@03o`000?n[W<SoZic801CoZic800?o0000ojJFaOnVU/D0
4onVU/D00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo0010ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ol6[a?o1Zl@00_o1Zl@01Ol0003o`:_5ol2[aOo0ZlGo000000;o_j_5
00?o0000okn[a_noZlH01?noZlH00ol0003o_J_7okf[a`09okf[a`03o`000?nkZ/So^j[800[o^j[8
00?o0000okRXbOnhZ<T00onhZ<T3o`0000Go^Jk?00?o0000ok>[d?ncZm003OncZm000ol0003o[JG@
ojfUd00;ojfUd0Co00005On[W<P00ol0003oYYK5ojJFa@0DojJFa@03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0@Oooool003oooooo00?o0000ooooooooool02_ooool00ol0003o`J_4ol6[
a004ol6[a005o`000?o0ZlGo`:_5ol2[aOl000000_noZlD00ol0003o_j_6okn[aP04okn[aP03o`00
0?nmZlOo_J_700Wo_J_700?o0000ok^Zb?nkZ/P02OnkZ/P00ol0003o^:S9okRXb@03o`0000So^Jk?
00?o0000ok>[d?ncZm003OncZm000ol0003o[JG@ojfUd00=ojfUd004o`000?nVW/ko0000o`0001;o
Zic800?o0000ojJFaOnVU/D05_nVU/D00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043o
oooo000nooooo`03o`000?oooooooooo00[ooooo00?o0000ol6[a?o1Zl@01_o1Zl@01ol0003o`:_5
ol2[aOo0ZlGo0000okn[aOl000001onoZlH00ol0003o_J_7okf[a`08okf[a`03o`000?nkZ/So^j[8
00Wo^j[80ol0000<okV^c`03o`000?ncZm3o/j_@00co/j_@00?o0000ojfUd?n]YM003On]YM001?l0
003oYYk>ojJNc_nVW/h2o`0000ooZic800?o0000ojJFaOnVU/D06?nVU/D00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03oooooo000mooooo`03o`000?oooooooooo00_ooooo00?o0000ol:[
`oo1Zl@01oo1Zl@01?l0003o`:_5ol2[aOl00002okn[a@03o`000?noZlKo_j_600Go_j_600?o0000
okf[aonmZlL02?nmZlL00ol0003o^j[8ok^Zb005ok^Zb0?o000000?o_K7=o`000?ni[/l03?ni[/l0
0ol0003o/j_@ok>[d00<ok>[d003o`000?n]YM3o[JG@00co[JG@00?o0000ojJNc_nVW/h01?nVW/h2
o`0000goZic800?o0000ojJFaOnVU/D06OnVU/D00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03kooooo000looooo`03o`000?oooooooooo00_ooooo00Co0000ol:[`oo2Zl?o`Z_32?o1Zl@0
1?l0003o`:_5ol2[aOl00002okn[a@03o`000?noZlKo_j_600Co_j_600?o0000okf[aonmZlL02Onm
ZlL00ol0003o^j[8ok^Zb002ok^Zb0;o00001Onm/Ld00ol0003o^Jk?okV^c`0:okV^c`03o`000?nc
Zm3o/j_@00co/j_@00?o0000ojfUd?n]YM003?n]YM000ol0003oYYk>ojJNcP06ojJNcP?o00002On[
W<P00ol0003oYYK5ojJFa@0KojJFa@03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_oo
ool003[ooooo0_l0000=ooooo`03o`000?o2Zl?o`Z_300?o`Z_300?o0000ol6[a?o1Zl@01Oo1Zl@0
1?l0003o`:_5ol2[aOl00002okn[a@03o`000?noZlKo_j_600Co_j_600?o0000okf[aonmZlL02?nm
ZlL00ol0003o^j[8o`000002o`0000Oo_K7=00?o0000okV^coni[/l02_ni[/l00ol0003o/j_@ok>[
d00<ok>[d003o`000?n]YM3o[JG@00co[JG@00?o0000ojJNc_nVW/h02OnVW/h2o`0000KoZic800?o
0000ojJFaOnVU/D06_nVU/D00ol0003oXi31o`000006ooooo`03o`000?oooooooooo03gooooo000i
ooooo`03o`000?oooooooooo00cooooo00?o0000ol:[`oo2Zl<01Oo2Zl<00ol0003o`J_4ol6[a005
ol6[a004o`000?o0ZlGo`:_5o`0000;o_j_500?o0000okn[a_noZlH01?noZlH00ol0003o_J_7okf[
a`07okf[a`;o00002_nm/Ld00ol0003o^Jk?okV^c`0:okV^c`03o`000?ncZm3o/j_@00_o/j_@00?o
0000ojfUd?n]YM003On]YM000ol0003oYYk>ojJNcP0;ojJNcP;o00001?n[W<P00ol0003oYYK5ojJF
a@0IojJFa@05o`000?nST<7oXi31oj>@`Ol000001_ooool00ol0003oooooooooo`0looooo`00>?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?o2Zl?o`Z_300Oo`Z_300?o0000ol6[a?o1Zl@01Oo1
Zl@01?l0003o`:_5ol2[aOl00002okn[a@03o`000?noZlKo_j_600Co_j_600?o0000okf[aonmZlL0
1OnmZlL00ol0003o`;;<o`00000;okfac@03o`000?ni[/oo^Jk?00[o^Jk?00?o0000ok>[d?ncZm00
2_ncZm000ol0003o[JG@ojfUd00<ojfUd003o`000?nVW/koYYk>00koYYk>0_l000000on[W<So0000
ojJFa@0JojJFa@03o`000?nST<7oXi3100?oXi3100?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0kooooo`00=oooool00ol0003oooooooooo`0<ooooo`03o`000?o2Zl?o`Z_300Wo`Z_300?o
0000ol6[a?o1Zl@01Oo1Zl@01_l0003o`:_5ol2[aOl0003o_j_5o`0000Ko_j_600?o0000okf[aonm
ZlL00onmZlL2o`0000?o`;;<00?o0000okfacOnm/Ld02?nm/Ld00ol0003o^Jk?okV^c`0:okV^c`03
o`000?ncZm3o/j_@00[o/j_@00?o0000ojfUd?n]YM003?n]YM000ol0003oYYk>ojJNcP0@ojJNcP03
o`000?nVU/GoYYK501WoYYK500?o0000oj>@`OnST<401?nST<400ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03[ooooo000fooooo`03o`000?oooooooooo00cooooo00?o0000ol:[`oo2Zl<0
2oo2Zl<00ol0003o`J_4ol6[a005ol6[a003o`000?o0ZlGo000000;o_j_500?o0000okn[a_noZlH0
1?noZlH01Ol0003o_J_7okf[aonmZlOo000000Go`;;<00?o0000okfacOnm/Ld02Onm/Ld00ol0003o
^Jk?okV^c`09okV^c`03o`000?ncZm3o/j_@00[o/j_@00?o0000ojfUd?n]YM003?n]YM000ol0003o
YYk>ojJNcP0@ojJNcP03o`000?nPU/Wo000001OoYYK50_l00008oj>@`@03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0>Oooool003Gooooo00?o0000ooooooooool03?ooool00ol0003o`Z_3
ol:[``0=ol:[``03o`000?o1ZlCo`J_400Go`J_400?o0000ol2[aOl000000_noZlD00ol0003o_j_6
okn[aP04okn[aP03o`000?nmZlOo000000Oo`;;<00?o0000okfacOnm/Ld02?nm/Ld00ol0003o^Jk?
okV^c`09okV^c`03o`000?ncZm3o/j_@00[o/j_@00?o0000ojfUd?n]YM003?n]YM000ol0003oYYk>
ojJNcP0?ojJNcP05o`000?nPU/WoX9K9oj2FbOl000005OnVU/D00ol0003oXi31oj>@`@09oj>@`@03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0>Oooool003?ooooo0_l0000?ooooo`03o`00
0?o4Zl7o`Z_300ko`Z_300?o0000ol6[a?o1Zl@01Oo1Zl@00ol0003o`:_5o`000002okn[a@03o`00
0?noZlKo_j_600?o_j_60_l00008ol2bc003o`000?nm/Lgo_K7=00So_K7=00?o0000okV^coni[/l0
2Oni[/l00ol0003o/j_@ok>[d00:ok>[d003o`000?n]YM3o[JG@00_o[JG@00?o0000ojJNc_nVW/h0
3onVW/h00ol0003oX9K9oj2Fb@03oj2Fb@03o`000?nVU/GoYYK5017oYYK500?o0000oj>@`OnST<40
2_nST<400ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo000booooo`03o`000?oo
oooooooo00kooooo00Go0000olB[`Oo4Zl7oa:_1o`00000>ol:[``03o`000?o1ZlCo`J_400Go`J_4
00?o0000ol2[aOl000000_noZlD01ol0003o_j_6okn[a_noZlKo0000ol:bb_l000002Oo0//`00ol0
003o_K7=okfac@08okfac@03o`000?ni[/oo^Jk?00Wo^Jk?00?o0000ok>[d?ncZm002OncZm000ol0
003o[JG@ojfUd00;ojfUd003o`000?nVW/koYYk>00ooYYk>00?o0000oj2FbOnPU/T01?nPU/T00ol0
003oYYK5ojJFa@0?ojJFa@03o`000?nST<7oXi3100coXi3100?o0000ooooooooool01Oooool00ol0
003oooooooooo`0gooooo`00<Oooool00ol0003oooooooooo`0>ooooo`03o`000?o4Zl7oa:_100?o
a:_10_l0000=ol:[``03o`000?o1ZlCo`J_400Go`J_400?o0000ol2[aOl000000_noZlD00ol0003o
_j_6o`000003ol:bbP03o`000?o0//co`;;<00Ko`;;<00?o0000okfacOnm/Ld02?nm/Ld00ol0003o
^Jk?okV^c`09okV^c`03o`000?ncZm3o/j_@00Wo/j_@00?o0000ojfUd?n]YM002on]YM000ol0003o
YYk>ojJNcP0>ojJNcP03o`000?nPU/WoX9K900KoX9K900?o0000ojJFaOnVU/D03OnVU/D00ol0003o
Xi31oj>@`@0=oj>@`@03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=_ooool0033ooooo
00?o0000ooooooooool03oooool00ol0003oa:_1olB[`@05olB[`@03o`000?o2Zl?o`Z_300_o`Z_3
00?o0000ol6[a?o1Zl@01Oo1Zl@01?l0003o`:_5o`000?noZlD2o`0000Go`[;:00?o0000ol2bc?o0
//`01_o0//`00ol0003o_K7=okfac@08okfac@03o`000?ni[/oo^Jk?00Ko^Jk?4_l0000:ojfUd003
o`000?nVW/koYYk>00goYYk>00?o0000oj2FbOnPU/T02?nPU/T2o`0000coYYK500?o0000oj>@`OnS
T<403onST<400ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Gooooo000_ooooo`03o`00
0?oooooooooo00oooooo00?o0000olB[`Oo4Zl401oo4Zl400ol0003o`Z_3ol:[``0;ol:[``03o`00
0?o1ZlCo`J_400Go`J_400Go0000ol2[aOl0003o`k;9o`000006ol:bbP03o`000?o0//co`;;<00Ko
`;;<00?o0000okfacOnm/Ld01onm/Ld00ol0003o^Jk?okV^c`03okV^c`?o00000_ni]]H00ol0003o
/[;Hok:bf009ok:bf004o`000?nYZ]OoZJ[GojVZe`Oo00000_n]YM000ol0003oYYk>ojJNcP0=ojJN
cP03o`000?nPU/WoX9K900_oX9K900?o0000ojJFaOnVU/D01onVU/D2o`0001?oXi3100?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0dooooo`00;_ooool00ol0003oooooooooo`0@ooooo`03
o`000?o4Zl7oa:_100Soa:_10_l0000<ol:[``03o`000?o1ZlCo`J_400Go`J_40_l00002ol>bb@03
o`000?o2//[o`[;:00?o`[;:00?o0000ol2bc?o0//`01_o0//`00ol0003o_K7=okfac@07okfac@03
o`000?ni[/oo^Jk?00?o00001Oni]]H00ol0003o/[;Hok:bf009ok:bf003o`000?nYZ]OoZJ[G00So
ZJ[G1?l0000>ojJNcP03o`000?nPU/WoX9K900coX9K900?o0000ojJFaOnVU/D01OnVU/D00ol0003o
Xi31oj>@`@0Coj>@`@03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<oooool002gooooo
00?o0000ooooooooool04?ooool00ol0003oa:_1olB[`@0;olB[`@03o`000?o2Zl?o`Z_300[o`Z_3
00?o0000ol6[a?o1Zl@00oo1Zl@2o`000005ol>bbOl0003o`k;9ol>bbOl000001Oo2//X00ol0003o
`;;<ol2bc006ol2bc003o`000?nm/Lgo_K7=00Ko_K7=0ol00008okVfeP03o`000?nb/]So/[;H00Wo
/[;H00?o0000ojVZeonYZ]L02_nYZ]L00ol0003oX:7Do`000002o`0000[oYYk>00?o0000oj2FbOnP
U/T03_nPU/T00ol0003oYYK5ojJFa@03ojJFa@03o`000?nST<7oXi3101GoXi3100?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0cooooo`00:oooool2o`0001;ooooo00?o0000olB[`Oo4Zl40
3Oo4Zl400ol0003o`Z_3ol:[``0:ol:[``05o`000?o1ZlCo`J_4ol6[a?l000000_o5//P00ol0003o
`k;9o`000002ol>bb@03o`000?o2//[o`[;:00?o`[;:00?o0000ol2bc?o0//`01Oo0//`00ol0003o
_K7=okfac@04okfac@;o000000?o_kWDo`000?ni]]H02Oni]]H00ol0003o/[;Hok:bf008ok:bf003
o`000?nYZ]OoZJ[G00WoZJ[G00?o0000oj2Qe?nPXM@00onPXM@2o`0000OoYYk>00?o0000oj2FbOnP
U/T04?nPU/T01Ol0003oYYK5ojJFaOnVU/Go000001WoXi3100?o0000ooooooooool01_ooool00ol0
003oooooooooo`0booooo`00:_ooool00ol0003oooooooooo`0Booooo`03o`000?o4Zl7oa:_100ko
a:_100?o0000ol:[`oo2Zl<02_o2Zl<00ol0003o`J_4o`000004olFbb003o`000?o3//Wo000000;o
`k;900?o0000ol:bb_o2//X00oo2//X00ol0003o`;;<ol2bc005ol2bc004o`000?nm/Lgo_K7=okfa
c@;o00001?no^M@00ol0003o^KKFokVfeP07okVfeP03o`000?nb/]So/[;H00So/[;H00?o0000ojVZ
eonYZ]L02OnYZ]L00ol0003oX:7Doj2Qe005oj2Qe0;o00001OnVW/h00ol0003oX9K9oj2Fb@0Aoj2F
b@03o`000?nVU/Go000001[oXi3100?o0000ooooooooool01oooool00ol0003oooooooooo`0aoooo
o`00:Oooool00ol0003oooooooooo`0Booooo`03o`000?o4Zl7oa:_1013oa:_10_l0000;ol:[``03
o`000?o5//SoaK;800CoaK;800?o0000ol>bbOl000000_o3//T00ol0003o`[;:ol:bbP03ol:bbP03
o`000?o0//co`;;<00Co`;;<00Co0000okfacOl0003o00001_no^M@00ol0003o^KKFokVfeP07okVf
eP03o`000?nb/]So/[;H00So/[;H00?o0000ojVZeonYZ]L02OnYZ]L00ol0003oX:7Doj2Qe007oj2Q
e0?o000000?oYYk>o`000?nPU/T05?nPU/T00ol0003oXi31oj>@`@0Joj>@`@03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0<?ooool002Sooooo00?o0000ooooooooool04oooool00ol0003o
a:_1olB[`@0BolB[`@03o`000?o2Zl?o`Z_300So`Z_300?o0000olJba_o5//P01Oo5//P00ol0003o
`k;9o`000002ol>bb@03o`000?o2//[o`[;:00;o`[;:00?o0000ol2bc?o0//`01?o0//`2o`0000So
_kWD00?o0000okVfe_ni]]H01oni]]H00ol0003o/[;Hok:bf008ok:bf003o`000?nYZ]OoZJ[G00So
ZJ[G00?o0000oj2Qe?nPXM@02onPXM@00ol0003oX9K9oj2Fb@0Boj2Fb@03o`000?nKSLCo000001go
Xi3100?o0000ooooooooool01oooool00ol0003oooooooooo`0_ooooo`009oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?o4Zl7oa:_101Coa:_100?o0000ol:[`oo2Zl<01_o2Zl<01Ol0003oa[;6
olJba_o6//Ko000000GoaK;800Go0000ol>bbOl0003o`k;9o`000005ol:bbP04o`000?o0//co`;;<
ol2bc0;o000000?o`k[Bo`000?no^M@02?no^M@00ol0003o^KKFokVfeP06okVfeP03o`000?nb/]So
/[;H00So/[;H00?o0000ojVZeonYZ]L02?nYZ]L00ol0003oX:7Doj2Qe00;oj2Qe003o`000?nHULoo
0000017oX9K900Go0000oi^=a?nKSLCoVhg4o`00000Loj>@`@03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0;_ooool002Kooooo00?o0000ooooooooool04oooool00ol0003oa:_1olB[`@0F
olB[`@;o00001Oo2Zl<00ol0003oa[;6olJbaP03olJbaP03o`000?o5//SoaK;800?oaK;800Go0000
ol>bbOl0003o`k;9o`000005ol:bbP03o`000?o0//co000000Co`k[B00?o0000oknie?no^M@01_no
^M@00ol0003o^KKFokVfeP07okVfeP03o`000?nb/]So/[;H00Oo/[;H00?o0000ojVZeonYZ]L02?nY
Z]L00ol0003oX:7Doj2Qe00:oj2Qe005o`000?nHULooV9G?oiREcol000003_nPU/T2o`0000CoVhg4
00?o0000oj>@`OnST<406onST<400ol0003oooooooooo`07ooooo`03o`000?oooooooooo02kooooo
000Tooooo`;o00005Oooool2o`000003olFY__l0003o000001Ooa:_100Go0000ol:[`oo2Zl?o`Z_3
o`000007olJbaP03o`000?o5//SoaK;800?oaK;800Go0000ol>bbOl0003o`k;9o`000005ol:bbP03
o`000?o3^];o`k[B00Co`k[B00?o0000oknie?no^M@01Ono^M@00ol0003o^KKFokVfeP07okVfeP03
o`000?nb/]So/[;H00;o/[;H2ol00004ojVZe`03o`000?nPXMCoX:7D00[oX:7D00?o0000oiREconH
ULl00onHULl00ol0003oX9K9oj2Fb@0:oj2Fb@03o`000?nKSLCoVhg400GoVhg400?o0000oj>@`OnS
T<406_nST<400ol0003oooooooooo`08ooooo`03o`000?oooooooooo02gooooo000Sooooo`03o`00
0?oooooooooo01Cooooo0_l00004olFY_P;o00005_o4Zl400ol0003o`Z_3o`000009olJbaP;o0000
1?o5//P01Ol0003o`k;9o`000?o3//Wo000000?o`[;:0_l00006ol>jdP03o`000?no^MCo_kWD00Ko
_kWD00?o0000okVfe_ni]]H01Oni]]H6o`0000Go/;[Q00?o0000ojB`hOnT/>400onT/>45o`0000co
X:7D00?o0000oiREconHULl01?nHULl00ol0003oX9K9oj2Fb@08oj2Fb@03o`000?nKSLCoVhg400Oo
Vhg400?o0000oj>@`OnST<406_nST<400ol0003oooooooooo`08ooooo`03o`000?oooooooooo02co
oooo000Rooooo`03o`000?oooooooooo01?ooooo0_l000000ooooooo0000olFY_P05olFY_P;o0000
5Oo4Zl400ol0003oa[;6olJbaP0:olJbaP03o`000?o5//SoaK;800;oaK;800Oo0000ol>bbOl0003o
`k;9o`000?o2//[o000000;oa[_@00?o0000ol>jd_o3^]801?o3^]800ol0003o_kWDoknie005okni
e003o`000?ni]]Ko^KKF00;o^KKF0ol000000onj`=ko0000ok2jh@08ok2jh@03o`000?nT/>7oY;3Q
00OoY;3Q00Co0000oiNSgOl0003o00002?nPXM@00ol0003oV9G?oiREc`06oiREc`03o`000?nPU/Wo
X9K900KoX9K900?o0000oi^=a?nKSL@02?nKSL@00ol0003oXi31oj>@`@0Koj>@`@03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0:oooool0027ooooo00?o0000ooooooooool04oooool01Ol0
003ooooooooooooooooo000000SoaJVn0_l0000ColB[`@03o`000?o8//Co000000_oa[;600?o0000
olFbb?o5//P00_o5//P01Ol0003o`k;9o`000?o3//Wo000000Coa[_@00?o0000ol>jd_o3^]800oo3
^]800ol0003o_kWDoknie005oknie003o`000?ni]]Ko000000;o00001?nj`=h00ol0003o/;[Qok2j
h@07ok2jh@03o`000?nT/>7oY;3Q00OoY;3Q00Co0000oiNSgOnGXmgoUj?M0_l00005oj2Qe003o`00
0?nHULooV9G?00SoV9G?00?o0000oj2FbOnPU/T00onPU/T2o`0000coVhg400?o0000oj>@`OnST<40
5_nST<43o`000003oj6:_?l0003ooooo00[ooooo00?o0000ooooooooool0:_ooool0023ooooo00?o
0000ooooooooool04oooool01Ol0003ooooooooooooooooo000000_oaJVn0_l0000@olB[`@05o`00
0?o8//Cob;;4olRba?l000002oo6//H00ol0003oaK;8olFbb002olFbb004o`000?o3//Wo0000o`00
00Coa[_@00?o0000ol>jd_o3^]801?o3^]800ol0003o_kWDoknie004oknie0;o00002?nj`=h00ol0
003o/;[Qok2jh@06ok2jh@03o`000?nT/>7oY;3Q00KoY;3Q00?o0000oiNSgOnGXmd01?nGXmd00ol0
003oX:7Doj2Qe002oj2Qe003o`000?nHULooV9G?00WoV9G?00Go0000oj2FbOnPU/WoX9K9o`00000>
oi^=a003o`000?nST<7oXi3101CoXi310_l00004oj6:_003o`000?oooooooooo00[ooooo00?o0000
ooooooooool0:Oooool001oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02oooo
o`03o`000?o5ZKkoaJVn00_oaJVn00?o0000olB[`Oo4Zl403?o4Zl400ol0003ob;;4olRba003olRb
a0;o00002_o6//H01?l0003oaK;8olFbb?o5//P3o`000003olNkc_l0003oa[_@00?oa[_@00?o0000
ol>jd_o3^]801?o3^]801?l0003o_kWDoknie?no^M@2o`000003ol73fol0003o^/3N00Oo^/3N00?o
0000ok2jhOn`^^401_n`^^400ol0003oY;3QojB`h@06ojB`h@03o`000?nGXmgoUj?M00GoUj?M0_l0
00000onPXMCo0000oiREc`0<oiREc`03o`000?nPU/Wo0000013oVhg400?o0000oj>@`OnST<404OnS
T<42o`0000OoXHZl00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`007Oooool2
o`0001Gooooo00?o0000ooooooooool00_ooool00ol0003oaJVnolFY_P0=olFY_P;o00003?o4Zl40
0ol0003ob;;4olRba005olRba003o`000?o6//Koa[;600Soa[;600Wo0000olFbb?l0003obK_=o`00
0?o7^lko0000olNkc_l000001?o6^m000ol0003o`k[Bol>jdP03ol>jdP04o`000?no^MCo0000o`00
00Co`L?K00?o0000ok[0g_nj`=h01Onj`=h00ol0003o/;[Qok2jh@06ok2jh@03o`000?nT/>7oY;3Q
00KoY;3Q00?o0000oiNSgOnGXmd01onGXmd00ol0003oV9G?oiREc`0=oiREc`03o`000?nKSLCoVhg4
00ooVhg400?o0000oj>@`OnST<403_nST<43o`0000WoXHZl00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Xooooo`007?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?o
oooo00?o0000olFY__o5ZKh03oo5ZKh2o`0000Woa:_100?o0000olRba?o8//@01oo8//@00ol0003o
a[;6olJbaP08olJbaP09o`000?o9^lgobK_=olVkcOl0003oak_>o`000?o7^lko000000?oa[_@00?o
0000ol>jd_o3^]800oo3^]82o`0000Ko`L?K00?o0000ok[0g_nj`=h01_nj`=h01?l0003o/;[Qok2j
hOn`^^49o`0000?oY;3Q00?o0000oiNSgOnGXmd02?nGXmd00ol0003oRi?Fo`00000;oiREc`03o`00
0?nARLOo000001;oVhg400?o0000oj>@`OnST<402onST<42o`0000coXHZl00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Wooooo`006oooool00ol0003oooooooooo`0Cooooo`;o00001Ooo
ool00ol0003oaJVnolFY_P0BolFY_P;o00001_o4Zl400ol0003ob;;4olRba009olRba003o`000?o6
//Koa[;600Koa[;600?o0000ol^kbol000000oo9^ld01Ol0003oak_>o`000?o7^lko000000?oa[_@
00?o0000ol>jd_l000000_l000000oo7aMSo0000ol73f`06ol73f`03o`000?nj`=ko^/3N00?o^/3N
1_l00004ojg4j`03o`000?nL^>coW;S/00;oW;S/1?l00009oiNSg@05o`000?n;TmKoRi?Foh^Ce_l0
00002OnHULl01Ol0003oTHW7oi69aonARLOo0000017oVhg400?o0000oj>@`OnST<402?nST<43o`00
00ooXHZl00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`006_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000olFY__o5ZKh05?o5ZKh2o`0000Co
a:_100?o0000olRba?o8//@02_o8//@2o`0000Goa[;600Go0000ol^kboo;^l_obk_;o`000003olVk
c@05o`000?o7^lko0000olNkc_l000000oo6^m000ol0003oalGHolO5f003olO5f003o`000?o1`m_o
`L?K00Co`L?K00?o0000ok[0g_nj`=h00ol00002ok[<i`03o`000?n]a>_o[LC[00Go[LC[00?o0000
oibhk?nL^>`01OnL^>`00ol0003oRJKWo`000002o`0000CoUj?M00?o0000oh^Ce_n;TmH00on;TmH0
0ol0003oV9G?oiREc`05oiREc`03o`000?nARLOoTHW700;oTHW700?o0000oi^=a?nKSL@04?nKSL@0
0ol0003oXi31oj>@`@05oj>@`@;o00004_nQR[`00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02Gooooo000Iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0
003oaJVnolFY_P0FolFY_P;o000000?oa:_1o`000?o8//@03_o8//@01Ol0003oa[;6olJba_o6//Ko
000000Gobk_;00[o0000olVkcOo9^lgobK_=o`000?o7^lko0000olNkc_l0003oa[_@0_l00006olO5
f003o`000?o1`m_o`L?K00?o`L?K0ol00006ok[<i`03o`000?n]a>_o[LC[00Co[LC[00?o0000oibh
k?nL^>`01OnL^>`00ol0003oRJKWohVVi`02ohVVi`?o000000?oUj?Mo`000?n;TmH01On;TmH00ol0
003oV9G?oiREc`03oiREc`03o`000?nARLOoTHW700CoTHW700?o0000oi^=a?nKSL@04?nKSL@00ol0
003oXi31oj>@`@02oj>@`@;o00005?nQR[`00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
02Cooooo000Hooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003o
aJVnolFY_P0IolFY_P03o`000?o8//Cob;;400oob;;400?o0000olJba_l000001oo;^l/02Ol0003o
bK_=olVkcOo9^lgo0000olNkc_l0003oak_>o`000002ol[5eP03o`000?o7aMSoalGH00?oalGH00Co
0000ol73foo1`m_o`L?K0_l000000oo4cn?o0000ok[<i`06ok[<i`04o`000?n]a>_o[LC[ojg4j`So
00000_nL^>`00ol0003oRJKWohVVi`06ohVVi`03o`000?n;TmKoRi?F00KoRi?F00Go0000oiREconH
ULooV9G?o`000008oi69a`03o`000?nKSLCoVhg400ooVhg400?o0000oj>@`Ol000000_l0000Foj6:
_003o`000?oooooooooo00gooooo00?o0000ooooooooool09?ooool001Oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`07ooooo`03o`000?o5ZKkoaJVn01WoaJVn00Co0000ol^``?l0
003o00003oo8//@00ol0003obk_;ol^kb`07ol^kb`06o`000?o9^lgobK_=olVkcOl0003oak_>0_l0
0003ol[5eP03o`000?o7aMSoalGH00?oalGH00?o0000ol73fol000001?o4cn<00ol0003o^/cWok[<
i`04ok[<i`Co00000onVd?H00ol0003oS/3hohk0n002ohk0n0?o00002?n9Y^L2o`0000SoRi?F00?o
0000oiREcol000002OnARLL00ol0003oVhg4oi^=a00@oi^=a003o`000?nQR[coXHZl01SoXHZl00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Sooooo`005Oooool2o`0001Gooooo00?o0000
ooooooooool01oooool00ol0003oaJVnolFY_P0IolFY_P03o`000?o;/<3obk3000;obk300_l0000=
olRba003o`000?o>^lOo000000Sobk_;00Co0000olVkcOo9^lgobK_=0_l000000oo<a]Co0000ol[5
eP02ol[5eP03o`000?o7aMSoalGH00;oalGH0_l00006olC?h`03o`000?njc>Oo^/cW00?o000000?o
^MS`o`000?nVd?H01?nVd?H2o`0000;oS/3h00Co0000ohk0n?n>`?So00000_mbY_83o`0000;oRJKW
00Co0000ogV?gOmiSmgo00002?n;TmH00ol0003oTHW7oi69a`09oi69a`03o`000?nKSLCoVhg400_o
Vhg40ol000000onIQKgo0000oj6:_00Ioj6:_003o`000?oooooooooo00kooooo00?o0000oooooooo
ool08_ooool001Cooooo00?o0000ooooooooool04oooool2o`0000[ooooo00?o0000olFY__o5ZKh0
6Oo5ZKh00ol0003obk30ol^``004ol^``0;o00002_o8//@01Ol0003oc[_7oljkaoo>^lOo000000So
bk_;00?o0000olVkcOl000000_o>a]800ol0003oc<KDo`000003ol[5eP06o`000?o7aMSo0000o`00
0?o:dMoo00001_o4cn<3o`0000Go^MS`00?o0000ojK@m_l000000_l000000onJg?go0000ogC5o`02
ogC5o`?o00001OmbY_82o`0000CoNHoM00?o0000oh^Ce_n;TmH00on;TmH00ol0003oPh?;o`00000;
oi69a`03o`000?nKSLCoVhg400WoVhg40_l00004oiV5_@03o`000?nQR[coXHZl01SoXHZl00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Qooooo`004oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00[ooooo00?o0000olFY__o5ZKh06?o5ZKh00ol0003obk30ol^``007ol^`
`003o`000?o8//Cob;;400Oob;;400?o0000oljkaoo>^lL00_o>^lL2o`0000Oobk_;00?o0000olk6
d_o>a]800_o>a]800ol0003oc<KDo`000003ol[5eP03o`000?o:dMoob]7O00;ob]7O00Co0000olC?
hoo4cn?oa<oS0_l000000oo5g>[o0000okWHl004okWHl0?o00000_nJg?d4o`0000;oM<Go0ol00002
odROm@?o000000?oLZKbo`000?l000001?miSmd01Ol0003oRi?Foh^Ce_n;TmKo000000?oPh?;00?o
0000oi69aonARLL02OnARLL00ol0003oVhg4oi^=a005oi^=a0?o00001onIQKd00ol0003oXHZloj6:
_00Hoj6:_003o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool001;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03o`000?o5ZKkoaJVn01WoaJVn00?o0000
ol^``?o;/<002?o;/<02o`0000Kob;;400?o0000oljkaoo>^lL01Oo>^lL00ol0003obk_;ol^kb`03
ol^kb`03o`000?oAa]3o000000Coc/KB00Co0000olc6e?l0003ob/GF0_l00005ol[Ag`03o`000?o4
cn?o000000CoaMcZ00?o0000okWHl?nif?000_l000000onei_Oo0000o`000002o`000003ogoPnOl0
003o000000;odGe_00Oo0000olb3POo<Ph7oc8>1o`000?m3003o000000;oB9oe00Co0000oeZ7homJ
Qn?o00001?miSmd00ol0003oRi?Fo`000005oh>3b`03o`000?nARLOoTHW700WoTHW700?o0000oi^=
a?nKSL@00_nKSL@2o`0000[oVHFm00?o0000oj6:_?nQR[`06?nQR[`00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01oooooo000Aooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool02oooool00ol0003oaZNjolJW^P03o`0001GoaJVn00?o0000ol^``?o;/<002oo;/<02o`0000?o
b;;400?o0000oljkaoo>^lL01oo>^lL01Ol0003obk_;ol^kboo;^l_o000000?odLK@00?o0000olk6
d_o>a]800_o>a]800ol0003oc<KDo`000002olkAg003o`000?o:dMoob]7O00;ob]7O0_l00005olGL
jP;o00000_nei_L2o`000003ojcam_nHl^Ko000000?o00001?oAOFl00ol0003oc8>1o`000003om6;
QP04o`000?m3003o0000obMbh@;oFXOS00Co0000ogV?gOmiSmgoNHoM0_l00006oh>3b`03o`000?nA
RLOoTHW700WoTHW700?o0000oi^=a?l000000_l0000<oiV5_@03o`000?nQR[coXHZl01SoXHZl00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Nooooo`004?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00cooooo00?o0000olJW^_o6YkX00oo6YkX3o`0001;oaJVn00?o0000
ol^``?o;/<003Oo;/<02o`000003olRba?l0003oc[_700Woc[_700?o0000ol^kbol000001OoAa]00
1?l0003oc/KBolk6d_o>a]83o`0000?oc]7L00Ko0000ol[Agol0003o0000olgMiOl00003olGLjP;o
000000CoaNS_o`000?l0003o00000_n/lOH01?nHl^Ko0000o`000?l00002omAfFP04o`000?oAOFoo
dGe_om5mK`;o00000ooARhH00ol0003oe969o`000002o`000008obMbhOl0003oFXOSo`000?miSmgo
0000ofehcOl00007oh>3b`03o`000?nARLOoTHW700SoTHW70_l0000@oiV5_@03o`000?nQR[coXHZl
01SoXHZl00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Nooooo`003_ooool2o`0001Go
oooo00?o0000ooooooooool03?ooool00ol0003oaZNjolJW^P07olJW^P?o00003oo5ZKh00ol0003o
bk30ol^``00?ol^``003o`000?o>^lOoc[_700[oc[_700?o0000om76d?oAa]001OoAa]001?l0003o
c/KBo`000?oCd]P3o`0000?oc]7L00?o0000olgMiOo=gND00_o=gND00ol0003oaMcZo`000003olGX
k`;oa??_1?l000001?oIJ2_o0000omM^@ol00002omAfFP03o`000?oAOFoo000000;oehMf00?o0000
om6;Q_l000000ooDTHT00ol0003od9JGo`000002o`000003oeZ7hol0003oKGS=00;oKGS=00?o0000
oh>3bon3Pl/01On3Pl/00ol0003oTHW7oi69a`05oi69a`;o000000?oSWjno`000?nIQKd03onIQKd0
0ol0003oXHZloj6:_00Hoj6:_003o`000?oooooooooo017ooooo00?o0000ooooooooool07Oooool0
00gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03o`000?o6Yk[oaZNj
00[oaZNj0ol0000;olFY_P03o`000?o;/<3obk30013obk3000?o0000om6i`_l000002_o>^lL00ol0
003oeLG;o`000006om76d004o`000?oCd]Sodm;Hom?Bf0?o000000Coc]7Lo`000?oAg^7o00000oo=
gND3o`0000;oaNS_0_o4lnl01?l0003o`_[Yo`000?nbnLH2o`000005omUX:ol0003oefi3o`000?oD
MUX00_l00004omN7MP04o`000?oDTHWoe969omBAR@?o000000?odYRIo`000?l000000_l00004ofeh
c@03o`000?n3Pl_oPh?;00CoPh?;00?o0000oi69aonARLL00_nARLL3o`0000?oSWjn00?o0000oiV5
_OnIQKd03_nIQKd00ol0003oXHZloj6:_00Hoj6:_003o`000?oooooooooo01;ooooo00?o0000oooo
ooooool07?ooool000cooooo00?o0000ooooooooool04oooool2o`00013ooooo00?o0000olJW^_o6
YkX03Oo6YkX3o`0000SoaJVn00?o0000ol^``?o;/<003oo;/<001?l0003odKW2om6i`_oA^L82o`00
00Ooc[_700Go0000omG5booEaL_oeLG;o`000005om76d0;o00000ooCd]P3o`0000?odMkQ00?o0000
olgMiOl000000oo>j>P2o`000004olCckol0003o`_[Yol;jj@Go000000CofFP[o`000?oGKT?o0000
0_oKPVD01?l0003oehMfomN7M_oGQgH2o`00000;omBAROl0003oeiB;o`000?oHUhko0000om:HVOlD
B<Co0000od]WcOl000001?m]N<d00ol0003oPh?;oh>3b`04oh>3b`04o`000?nARLOo0000o`0000Oo
SWjn00?o0000oiV5_OnIQKd03_nIQKd00ol0003oXHZloj6:_00Goj6:_0;o00005?ooool00ol0003o
ooooooooo`0Kooooo`002oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo
00?o0000olJW^_o6YkX04?o6YkX3o`0000CoaJVn00?o0000ol^``?o;/<004?o;/<000ol0003odKW2
om6i`P03om6i`P03o`000?o>^lOoc[_700?oc[_700?o0000omG5booEaL/00ooEaL/01Ol0003odLK@
om76d?oAa]3o000000;oe];D00Co0000om?Bf?oCd]Sodm;H0ol00003om7Nh@05o`000?o>j>Soc^SX
olkXj?l000000_o?l>T5o`000003oo_RQol0003o000000Co000000OogWmGo`000?oKPVGofh9Uo`00
0?oGQgKo000000;ofXej00?o0000omNDRol000000ooHUhh01_l0003o00nPoaA8a?l0003oBfO=o`00
00?oKGS=00?o0000oh>3bon3Pl/01?n3Pl/2o`0000WoSWjn00?o0000oiV5_OnIQKd03_nIQKd00ol0
003oXHZloj6:_00Hoj6:_0;o00005?ooool00ol0003oooooooooo`0Jooooo`002_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000olJW^_o6YkX05?o6YkX3o`000003
olFY__l0003obk30013obk3000?o0000om6i`_oA^L801OoA^L82o`0000?oc[_700?o0000omG5booE
aL/01?oEaL/00ol0003odLK@o`000004omKBe004o`000?oCd]So0000omONg@?o000000KodMkQo`00
0?oCj>Go0000olkXj?l00002olo`j@03o`000?oBm>Oo000000So000000KohGm@o`000?oNOeOogWmG
o`000?oKPVD3o`000004omZ=N_l0003o0000o`0000;of9N>00Ko0000om^LTOl0003oe9bKo`0?X?lD
B<@2o`0000CoKGS=00?o0000oh>3bon3Pl/00ol000000omnM;ko0000ohin_P08ohin_P03o`000?nI
QKgoVHFm00koVHFm00?o0000oj6:_?nQR[`06?nQR[`00ol0003oooooo`00000Dooooo`03o`000?oo
oooooooo01Wooooo0009ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool0
0ol0003oaZNjolJW^P0GolJW^P03o`000?o;/<3o0000013obk3000?o0000om6i`_oA^L801ooA^L80
0ol0003oc[_7o`000008omG5b`;o00001OoFd]@01?l0003oemkMomONgOoGg]d3o`0000?odnSU0_l0
00002?o?l>Wo0000om;diol0003oe_ORomcjf_l0003on>V`0_l000001oom`goo0000o`000?l0003o
hGm@o`000?oNOeL00_l00003omj9JP06o`000?oJSG[ogYEoo`000?oHUhko00000ooKW944o`000004
od]WcOl0003oKGS=ofehc@Co00001?mnM;h00ol0003oSWjnohin_P08ohin_P03o`000?nIQKgoVHFm
00goVHFm00?o0000oj6:_?nQR[`06?nQR[`01?l0003oooooooooool0000Cooooo`03o`000?oooooo
oooo01Wooooo0008ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0
003oaZNjolJW^P0GolJW^P03o`000?o<[[_oc:jk00?o00003?o;/<000ol0003odKW2om6i`P09om6i
`P03o`000?oEaL_oeLG;00OoeLG;00?o0000om_Acol000000ooFd]@00ol0003ofmkIo`000003omON
g@?o000000?odnSUo`000?oDknH02?l000001?ohjK3o0000o`000?om`gl4o`000006on5oD?l0003o
hHINon66G_l0003ogXUZ0_l000001?oNUGoo0000omjDO_l00005om^LT@Oo00000_mXIK`00ol0003o
OWBnogid_P04ogid_P03o`000?n>O[koSWjn00OoSWjn00?o0000oiV5_OnIQKd03_nIQKd00ol0003o
XHZloj6:_00Hoj6:_004o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool06?ooool000Ko
oooo0_l0000Eooooo`03o`000?oooooooooo01?ooooo00?o0000olJW^_o6YkX05oo6YkX00ol0003o
c:jkolb^^`03olb^^`?o00002Oo;/<000ol0003odKW2om6i`P09om6i`P03o`000?oI`lCo000000;o
00001?oEaL/01ol0003ofm7?om_AcooKdLoo0000omKBe?l000000ooKg]T01Ol0003oemkMo`000?l0
003oe^SR00;o000000Soe>oVo`000?oElNCoeO7To`000?oHjn;o0000omWQg0Go000000WooL=oo`00
0?l0003o0000on>>JOl0003ohhMLo`000?oQQUh00_l000001ooPS6cohHe]o`000?oNU7ko0000on:J
P_l000000ooKW942o`000004o`00POlB::GoATjfodI>]PCoJ6Fl00?o0000ogid__mnM;h01?mnM;h0
0ol0003oSWjnohin_P07ohin_P03o`000?nIQKgoVHFm00koVHFm00?o0000oj6:_?nQR[`05?nQR[`5
o`0000;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`001Oooool00ol0
003oooooooooo`0Aooooo`Co00005Oooool00ol0003oaZNjolJW^P0GolJW^P03o`000?o<[[_oc:jk
00Ooc:jk0ol00005ol^``003o`000?oA^L;odKW200WodKW200?o0000omW3a?oI`l@00ooI`l@2o`00
0003omG5bol0003ofm7?00Cofm7?0_l00004om_Nf@05o`000?oIjN3ofNWPo`000?oGkn<00ol00000
1?oElNCo0000omS[h_l00002omWQg0Co000000Goooooo`000?l0003o0000on6FN`02o`0000;ohhML
00Co0000on:8Gol0003o00000_oST6l01ol0003ohYZ2on:JP_oRVX;o0000om^LTOl000000_oOY9H3
o`000003odI>]_l0003oJ6Fl00?oJ6Fl00?o0000ogid__mnM;h00omnM;h00ol0003oSWjnohin_P08
ohin_P03o`000?nIQKgoVHFm00goVHFm00?o0000oj6:_?nQR[`02onQR[`9o`0000CoX8Jg00Go0000
ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo01Kooooo0004ooooo`03o`000?oooooo
oooo00gooooo1Ol00003ooooo`03o`000?oooooooooo01?ooooo00?o0000olJW^_o6YkX05oo6YkX0
0ol0003oc:jkolb^^`0:olb^^`?o00000_o;/<000ol0003odKW2om6i`P09om6i`P03o`000?oI`lCo
fL?400GofL?40_l00005om_Ac`09o`000?oQg];o0000om_NfOl0003ogNWLo`000?oIjN3o000000;o
f?3R0_l000001_oFl>Co0000o`000?oHjn;o0000omWQg0Wo000000GohIIko`000?oSSVWo0000on>7
G004o`000003on>@Kol0003o000000CohYZ200?o0000omnTU_oOY9H00_oOY9H2o`0000;oATjf00Go
0000ofQU_?mXIKcoJ6Flo`000005ogid_P03o`000?n>O[koSWjn00SoSWjn00?o0000oiV5_OnIQKd0
3_nIQKd01?l0003oXHZloj6:_?nQR[`9o`0000goX8Jg00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01Gooooo0003ooooo`03o`000?oooooooooo00Sooooo
1_l00009ooooo`03o`000?oooooooooo01;ooooo00?o0000olJW^_o6YkX05oo6YkX00ol0003oc:jk
olb^^`0=olb^^`;o000000?odKW2o`000?oA^L802?oA^L800ol0003ofL?4omW3a006omW3a003o`00
0?oQclKo000000?ofm7?00Go0000on7Nd_oQg];ohMkBo`000003omgYg007o`000?oHl>;o0000omOa
hol0003oe_3To`000002omOZhPGo00000_oT_k<00ol0003ohkncon>o/`02o`000003on6FNol0003o
hhiY00Co00000_oUS6802?l0003oiYMaonJGLOl0003ohYZ2o`000?oWY8Oo00001?oOY9H01Ol0087o
4RRUo`000?m6C[Ko000000?oJ6Fl00?o0000ogid__mnM;h00omnM;h00ol0003oSWjnohin_P08ohin
_P03o`000?nIQKgoVHFm00[oVHFm2?l0000Foj26]`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Dooooo`000_ooool00ol0003oooooooooo`03ooooo`Ko
00004?ooool00ol0003oooooooooo`0Aooooo`03o`000?o6Yk[oaZNj01OoaZNj00?o0000olb^^oo<
[[/03_o<[[/00ol0003oe;FkomBe^`04o`0000GodKW200?o0000omW3a?oI`l@01OoI`l@01ol0003o
hLo6on7?a_oQclKo0000om_Acol000000ooQg]82o`000005omgYg?l0003og?7Nomcag_l000000ooG
lN<01Ol0003oe^[So`000?oGj^;o000000;oe=SL0_l00002onBo/`03o`000?oS_k?ohknc00Go0000
00?ohXe[o`000?oSR5h00_l000000ooUS6;o0000o`000002onJGL@05o`000?oWY8OoijB7onNTQol0
00000ooOY9H3o`000003odI>]_l0003oJ6Fl00;oJ6Fl00?o0000ogid__mnM;h01?mnM;h00ol0003o
SWjnohin_P08ohin_P04o`000?nIQKgoVHFmoiV5_@So00001?nHOkH00ol0003oX8Jgoj26]`0Goj26
]`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Doooo
o`0000?oooooo`000?ooool01Ol0000Gooooo`03o`000?oooooooooo013ooooo00?o0000olJW^_o6
YkX05oo6YkX00ol0003oc:jkolb^^`0>olb^^`03o`000?oD]K_oe;Fk00Coe;Fk0ol00002om6i`P03
o`000?oI`lCofL?400GofL?400?o0000on7?a_oQclH00_oQclH01Ol0003ohMkBon7Nd_oQg];o0000
00;oi>_E00?o0000omcag_oLlMh00_l000001OoGlN?o0000omC[i?l0003oe^[S00;o00000_oDf=`0
0ol0003o_Zo;o`000002onBo/`05o`000?oS_k?o0000ol:AXol000000ooKU8<01_l0003ohH]Zo`00
0?l0003oi8UMo`0000;oj91Q00?o0000onJGLOl000000ooWY8L01Ol0003ogjBFo`000?l0003o001U
00?o000000?oATjfo`000?mXIK`00_mXIK`00ol0003oOWBnogid_P03ogid_P03o`000?n>O[koSWjn
00?oSWjn2Ol0000<oiQo]P03o`000?nPQ[OoX8Jg01OoX8Jg00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo0003o`0001gooooo00?o0000oooooooo
ool03_ooool00ol0003oaZNjolJW^P0GolJW^P03o`000?o<[[_oc:jk00ooc:jk00?o0000omBe^ooD
]K/01ooD]K/3o`0000KofL?400?o0000on7?a_oQclH00ooQclH2o`000003on7Nd_l0003oi>_E00;o
i>_E00?o0000omcag_l000000_oImN401Ol0003oe>_TomC[i?oDjnCo000000;odMSN00?o0000omCH
g?l000000_nn[l/01Ol0003oi;nco`000?oS_k?o000000;o`Y6S00Oo0000om^DPol0003o0000on6;
J_l0003oh8UV00?o00000_oXT6400ol0003okJ1do`000003onNTQ`05o`000?oS[YgohjjMo`00IOlM
5HX00om;?Z0@o`0000GoSGJe00?o0000oiQo]_nHOkH03OnHOkH00ol0003oX8Jgoj26]`0Goj26]`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`00
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?o6Yk[oaZNj01OoaZNj
00?o0000olb^^oo<[[/03_o<[[/00ol0003oe;FkomBe^`09omBe^`04o`000?oL_[_o0000o`0000?o
fL?400?o0000on7?a_oQclH00ooQclH01?l0003oj=g8onSMb?l00003onC[e@06o`000?oSm]Ko0000
omWehOl0003odoOU0ol000001_o@hNCo0000om7Hg_l0003odMSNo`0000?o_Zo;00Go0000onBo/ol0
003ohknco`000002ol:AX`?o000000?ofI61o`000?l000000_oPRFH01Ol0003oiXUFo`000?oXT67o
000000;okJ1d00Co0000onNTQol0003o00000_oS[Yd00ol006Go7AF:od/nX002od/nX0CoJER/1_mn
J[8;ohef]@03o`000?nHOkKoV7nf00goV7nf00?o0000oj26]onPQ[L05onPQ[L00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00003ooooool0003o
oooo01oooooo00?o0000ooooooooool03?ooool00ol0003oaZNjolJW^P0GolJW^P03o`000?o<[[_o
c:jk00koc:jk00?o0000omBe^ooD]K/02?oD]K/00ol0003og;jkombn^`02ombn^`;o000000?ofL?4
o`000?oQclH01?oQclH00ol0003oj=g8onSMb002o`000003onC[eOl0003ohoKF00?o00000_oCmnD0
1?l0003od>7Tom3Qi?o@hN@2o`0000;oa[3400Ko0000okj_bonn[l_o_Zo;o`000?oT_k<2o`0000;o
`Y6S00Co0000olRLZoo8W:_ob9b[0_l000000ooJRG?o0000o`000002o`000004onJ9E_l0003okiML
o`0000;okJ1d00So0000onf`Soo]/8oo0000on>^WOl0003o7AF:o`0000;oBcjP00Go0000ofUH[?mY
F:coJER/o`000005ogiZ/P03o`000?n=M[GoSGJe00SoSGJe00?o0000oiQo]_nHOkH03OnHOkH00ol0
003oX8Jgoj26]`0Goj26]`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0@ooooo`000_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00co
oooo00?o0000olJW^_o6YkX05oo6YkX00ol0003oc:jkolb^^`0>olb^^`03o`000?oD]K_oe;Fk00So
e;Fk00?o0000ombn^ooL_[/01?oL_[/2o`0000CohLo600Co0000onSMb?oXgLSo00000_o^k<P01_l0
003ohoKFo`000?oKoMKo0000om?gi@Co000000?obMgXo`000?l000001?o6/<@00ol0003o_Zo;okj_
b`02o`000004on>o/ol0003o`Y6So`0000Gob9b[2?l00002onnGG003o`000?o]X7Co000000;okK2?
0ol000001OlM5H[o0000od/nX?m;?Z3o000000?oJER/00?o0000ogiZ/_mnJ[800omnJ[800ol0003o
SGJeohef]@08ohef]@03o`000?nHOkKoV7nf00goV7nf00?o0000oj26]onPQ[L05onPQ[L00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool000?ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?o6Yk[oaZNj01SoaZNj
00?o0000olb^^oo<[[/03_o<[[/00ol0003oe;FkomBe^`08omBe^`03o`000?oL_[_og;jk00Cog;jk
00?o0000onK:^ol000000_l000001?oQclKo0000onSMb?l00003onk/b0;o000000?ofogFo`000?o9
n>X01?l00002okcQlP03o`000?nU^NOo000000;o00000_o6/<@00ol0003o_Zo;o`000002o`000003
ol:AXol0003ob9b[00Gob9b[00Co0000omB1LOoDPG7oe85a1Ol00002onnGG004o`000?oe[WOo0000
onf`S`Go000000?oBcjPo`000?mYF:`00omYF:`00ol0003oOVZbogiZ/P03ogiZ/P03o`000?n=M[Go
SGJe00SoSGJe00?o0000oiQo]_nHOkH03OnHOkH00ol0003oX8Jgoj26]`0Goj26]`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`001?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Wooooo2?l0000BolJW^P03o`000?o<[[_oc:jk
00ooc:jk00?o0000omBe^ooD]K/01ooD]K/00ol0003og;jkombn^`05ombn^`03o`000?oVb[_oi/Zk
00;oi/Zk0_l000001?oXgLSo0000onk/b?o^k<P3o`000003oio`^_l0003o/oS]00Ko00001?nU^NL3
o`000003olJ`a?l0003o_Zo;00?o00001Oo8W:/<o`000005onnGG?l0003omJigo`000?o]/8l00_l0
0002oc8BN003o`000?m;?Z3o000000?oJER/00?o0000ogiZ/_mnJ[801?mnJ[800ol0003oSGJeohef
]@08ohef]@03o`000?nHOkKoV7nf00goV7nf00?o0000oj26]onPQ[L05onPQ[L00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool000Gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`08ooooo`03o`000?o7Y;KoajBf00GoajBf3Ol00005
olJW^P03o`000?o<[[_oc:jk00koc:jk00?o0000omBe^ooD]K/02?oD]K/00ol0003og;jkombn^`04
ombn^`03o`000?oVb[_oi/Zk00?oi/Zk00?o0000oo3H^Ol000000_o^k<P01?l0003ok?S3o`000?nO
l;X?o`000003ojFiiol0003o000000?o000000?ob9b[o`000?l000000ol00004ok5XN`Wo000000Co
mjACo`000?l0003okK2?0_l00002oc8BN003oeDfT?l0003o000000?oJER/00?o0000ogiZ/_mnJ[80
1?mnJ[800ol0003oSGJeohef]@08ohef]@03o`000?nHOkKoV7nf00koV7nf00?o0000oj26]onPQ[L0
5_nPQ[L00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3Oooool000Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?o7
Y;KoajBf01;oajBf3ol00007olb^^`03o`000?oD]K_oe;Fk00Soe;Fk00?o0000ombn^ooL_[/01?oL
_[/00ol0003oi/ZkonK:^`02onK:^`07o`000?o`f;Wol=Rio`000?o^k<So0000onch``03o`000003
o`0IX_l0I]Oo000000?oIJOf00?o0000oibfj_l000001_nV/=l;o`0000Co/FQk00Go0000ok1OL?n`
Gg3o0000okA2<P05o`000003ooNTDol0003omJig00?o000000Co<Q9ho`000?mE=Y3oECJ@0ol00000
0omYF:co0000ogiZ/P05ogiZ/P03o`000?n=M[GoSGJe00SoSGJe00?o0000oiQo]_nHOkH03_nHOkH0
0ol0003oX8Jgoj26]`0Foj26]`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0<ooooo`001oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Kooooo00?o0000olNT]_o7Y;H05oo7Y;H00ol0003ocJVdolfY]007olfY]0go00001?oD]K/00ol0
003og;jkombn^`05ombn^`03o`000?oVb[_oi/Zk00;oi/Zk00Ko0000oo3H^Ol0003on>Jbo`000?o/
n<<3o`000005oaI8a?l0003o0000o`000?l0I]L00_l000000omUYoKo0000o`000003ojJ`g`03o`00
0?nV/=ooY[3O00;oY[3O00Co0000oem_c?l0003oQ3e^0ol00002ok1^Q`co000000?oTa00o`000?l0
00001Ol000001?lb4WSo0000oeDfT?mE=Y03ofmAWPCo00001?mnJ[800ol0003oSGJeohef]@08ohef
]@03o`000?nHOkKoV7nf00koV7nf00?o0000oj26]onPQ[L05_nPQ[L00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool000Oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`05ooooo`03o`000?o7Y;KoajBf01OoajBf00?o0000olfY]?o=
ZK@03_o=ZK@00ol0003oeJncomF_/`03omF_/`Wo00000_oL_[/00ol0003oi/ZkonK:^`02onK:^`05
o`000?o`f;Wol=Rio`000?ohi[801Ol00002oaI8a003o`0e^ol4E]7o000000Co000000CoHIkao`00
0?nV/=ooY[3O1?m_Sn400ol0003oGfo<o`000002o`0000?oQ3e^0_l00004ok1^Q`03o`000?nZGGCo
ZUed00co000000Go<Q9ho`000?mE=Y3oECJ@o`000004ofmAWP?oPVBW0ol000000omnJ[;o0000ohef
]@09ohef]@03o`000?nHOkKoV7nf00koV7nf00?o0000oj26]onPQ[L05_nPQ[L00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool000Sooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03o`000?o7Y;KoajBf01OoajBf00?o0000
olfY]?o=ZK@03_o=ZK@00ol0003oeJncomF_/`07omF_/`03o`000?oN]k3og[N`00;og[N`1Ol00002
onK:^`06o`000?o`f;Wol=Rio`000?ohi[;om_2Q0ol000001OlmFlSo0000oaI8a?lFB<Co5UO@00;o
15KA00Co0000oeFDk_mEU>koEIC^1_m_Sn400ol0003oGfo<oem_c004o`0000CoQ3e^0ol000000on`
KXOo0000o`000002o`000003ohLWAOl0003o000000Ko000000Co901>o`000?lb4WSo00000_mE=Y00
0ol0003oKe6NofmAWP02ofmAWP03o`000?n2I:OoPVBW00?oPVBW1Ol00007ohef]@03o`000?nHOkKo
V7nf00koV7nf00?o0000oj26]onPQ[L05_nPQ[L00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool02Oooool000Wooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`04ooooo`03o`000?o7Y;KoajBf01OoajBf00?o0000olfY]?o=ZK@03_o=ZK@00ol0
003oeJncomF_/`07omF_/`03o`000?oN]k3og[N`00Cog[N`00?o0000onW0[?oY`:`01Ol000001?oh
i[;o0000ooK`XOl00002oea[b007o`000?lmFlSo0000oaI8a?l_Gm7o5UO@o`AFd@02oc5/fP;o=gWS
00?o0000ofn?hOm_Sn400_m_Sn401Ol0003oGfo<oem_c?mOKlcoPFbb00;o000000?oL3Umo`000?n4
?Fh01On4?Fh4o`000003oh8WBol0003o000000Co000000Go:@0`o`000?lT04ko0000odHFKP02o`00
00;oECJ@00Go0000ofmAW_m_DIkoKe6No`000007oh9TY`CoSg6]1Ol00002ohef]@03o`000?nHOkKo
V7nf00koV7nf00?o0000oj26]onPQ[L05_nPQ[L00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`03ooooo`03o`000?o7Y;KoajBf01OoajBf00?o0000olfY]?o=ZK@03_o=ZK@00ol0
003oeJncomF_/`07omF_/`03o`000?oN]k3og[N`00Cog[N`00Go0000onW0[?oY`:cojL2/o`000002
ooG;X`03o`000?ohi[;o000000;o00000omLJlP2oceKb005o`000?l_Gm7o;eoAoaIGd?l000000_la
K=X00olgNN?oHX3Jof:0fP02ofn?h@06o`000?mOKlcoGfo<oem_c?l0003oPFbb0_l00002og0iO@03
o`000?n4?FkoQ3e^00?oQ3e^00?o0000ogTOBOmi7dT01ol000001?lY033o0000ob@0C_l00002odHF
KP;oHCJ50_l00004ofmAWP03o`000?n2I:OoPVBW00GoPVBW00?o0000ohma[On?LJd01_n?LJd7o`00
00coV7nf00?o0000oj26]onPQ[L05_nPQ[L00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`02ooooo`03o`000?o7Y;KoajBf01OoajBf00?o0000olfY]?o=ZK@03_o=ZK@00ol0003o
eJncomF_/`07omF_/`03o`000?oN]k3og[N`00Cog[N`00Go0000onW0[?oY`:cojL2/o`000002ooG;
X`;o000000Com_2Qo`000?mdM/Oo00000_mLJlP2o`000004odYZdOl0003o;eoAobmOd@;o<fSG0_la
K=X01?l0003oHX3Jo`000?l00004oem_c0;o00000_n2Ij/01?l0003oL3Umog0iOOl00002oh@mKPGo
00000_mR2d<4o`000007obT0<?l0003o0000ob@0C_l0003oAQI^o`000003of4fQ@;o00000om_DIh0
0ol0003oPVBWoh9TY`04oh9TY`03o`000?n?LJgoSg6]00WoSg6]1OnINk09o`0000?oV7nf00?o0000
oj26]onPQ[L05_nPQ[L00ol0003oooooooooo`0@ooooo`Co00004Oooool00ol0003oooooooooo`07
ooooo`003?ooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool000006Oo7Y;H0
0ol0003ocJVdolfY]00>olfY]003o`000?oE[k?oeJnc00OoeJnc00?o0000omjg/?oN]k001?oN]k00
1Ol0003ojL2/onW0[?oY`:co000000;omL^S0ol00002ogAfa`05o`000?mLJlSo0000of=fd?l00000
0_m:J]42obmOd@07o`000?lcJ=Oo<fSGo`000?m>MMWo0000oeiieP04oem_c003o`000?n1K;;o0000
00;oPVN[00Co0000og0iOOm`>GgoL3Um0_l00002ogPdKP03o`000?mR2d?o000000;o000000?o?`0[
o`000?m704400_l000001Om1053o0000o`000?m65Vko000000CoHCJ50_mfCY@01?l0003oKe6NofmA
W_l00006oh9TY`03o`000?n?LJgoSg6]00WoSg6]00?o0000oiUk/?nINk002onINk08o`0001CoX8Jg
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`?o00003oooool00ol0003ooooo
ooooo`06ooooo`003Oooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0001WoajBf
00?o0000olfY]?o=ZK@03_o=ZK@00ol0003oeJncomF_/`07omF_/`03o`000?oN]k3og[N`00Cog[N`
00Go0000onW0[?oY`:cojL2/o`000002ooG;X`?o00000_mdM/L2o`0000?oHgK@00Go0000odYZdOl0
003o0000oce[eP02oc=Xe`?o00000_mNNMH3oem_c003o`000?n1K;;o000000;oPVN[00Go0000og0i
OOm`>GgoL3Umo`000003ogPdKP;o00000_mJ2d/2o`000009odL0@Ol0003o0000od40D?l0003oF1eZ
o`000?m65Vko000000?oHCJ500Co0000ogI>U?mfCYCoMTjD0_l00007oh9TY`03o`000?n?LJgoSg6]
00SoSg6]00?o0000oiUk/?nINk003onINk05oj63/`Wo00002onPQ[L00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Kooooo0ol0000=ooooo`03o`000?oooooooooo00Gooooo000=ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooool000006Oo7Y;H00ol0003ocJVdolfY]00>olfY]003
o`000?oE[k?oeJnc00OoeJnc00?o0000omjg/?oN]k001?oN]k002?l0003ojL2/onW0[?oY`:co0000
ooG;Xol0003oo]JC0_l000001OmdM/Oo0000ogQncOmhO/go000000?oHgK@00Co0000oe5ce_l0003o
?F_F0_l000000oloK]So0000o`000003o`0000;oGfo<00?o0000oh5//_l000000_n2Ij/01ol0003o
L3Umog0iOOl0003oLcAao`000?mh=6h00_l00002oeX;B`;o000000?oA`11o`000?mD3UH00_l00003
oePMJP03o`000?mQ=XGoHCJ500;oHCJ500?o0000ogI>U?mfCY@00_mfCY@2o`0000KoPVBW00?o0000
ohma[On?LJd02?n?LJd00ol0003oVG^`oiUk/00?oiUk/003o`000?nQPk?oXH>c00_oXH>c2?l00003
oj26]`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool3o`0000_ooooo00?o0000
ooooooooool01?ooool000kooooo00?o0000ooooooooool07_ooool00ol0003oooooo`00000HolNT
]P03o`000?o=ZKCocJVd00kocJVd00?o0000omF_/ooE[k<01ooE[k<00ol0003og[N`omjg/004omjg
/008o`000?oY`:cojL2/onW0[?l0003omL^So`000?oneY<3o`0000CoN7k=00Go0000of=fd?l0003o
0000oe5ceP03o`000004od=`fOl0003o0000ob]Pd`?o8e7800?o<4Zlo`000?n1K;800_l00003oh9W
Z`Co000000CoLcAao`000?mZ96;oJRAR0_l000000omI3U7o0000o`000002oe@>EP03o`000?mH7F[o
F1eZ00;oF1eZ00GoK3Qno`000?mQ=XGoHCJ5o`000005ogI>U0;oQV2O0ol00003oh9TY`03o`000?n?
LJgoSg6]00SoSg6]00?o0000oiUk/?nINk003_nINk000ol0003oXH>coj63/`0Doj63/`Co00003_oo
ool00ol0003oooooooooo`0>ooooo`?o00002?ooool00ol0003oooooooooo`04ooooo`003oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooo000001SoajBf00?o0000olfY]?o=ZK@03_o=ZK@0
0ol0003oeJncomF_/`07omF_/`03o`000?oN]k3og[N`00Cog[N`00?o0000onW0[?l000001_l00000
0on9Q/Wo0000ogQnc@03ogQnc@;o00000_mWO=@01?l0003oE7OHo`000?l00002od5bf`;o000000[o
:f3Cob=Ab?lSDLSo<4ZlocE7]ol0003oK5^^ofiCX_l0003oPVN[0ol00002odL5E@;o000000?oJRAR
o`000?l000000_mI3U400ol0003oE0iFoe@>EP02o`0000?oF1eZ00Ko0000of`hO_m/>7ko0000of4f
QOl00004ogI>U003o`000?n6H9ooQV2O00?oQV2O00?o0000oh9TYol000002_n?LJd00ol0003oVG^`
oiUk/00?oiUk/003o`000?nQPk?oXH>c01OoXH>c00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Booooo`?o00001_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003ooooooooo
o`0Mooooo`;o00006?o7Y;H00ol0003ocJVdolfY]00>olfY]003o`000?oE[k?oeJnc00GoeJnc2ol0
0002onNaVP05o`000?oc]X_o0000oobhK_l000000_n9Q/T01ol0003oN7k=o`000?l0003oNhCAo`00
0?mWO=@01?l000001?mFNm_o0000od5bfom1L]/3o`000005ob=Ab?l0003o=DNgo`000?m/Fjh00_m^
Dj801?l0003oBA]do`000?l00002odL5E@03o`000?mY8f?o000000;o000000GoF@iAo`000?l0003o
E0iFo`000002of@TJ@03o`000?mH7F[o000000CoK3Qn0_l00004ogI>U003o`000?n6H9ooQV2O00Go
QV2O0_l00009ohma[@03o`000?nINk3oVG^`00ooVG^`00?o0000oj63/onQPk<05onQPk<00ol0003o
ooooooooo`09ooooo`;o00006?ooool3o`0000Cooooo00?o0000ooooooooool00_ooool0017ooooo
00?o0000ooooooooool07Oooool00ol0003oajBfolNT]P0FolNT]P03o`000?o=ZKCocJVd00kocJVd
00?o0000omF_/ooE[k<01Ol00002om>WZP03o`000?oLZjCog:^T00Cog:^T00Go0000onNaV_oW/I[o
ik6Jo`000002oo>fR`;o00000_n9Q/T2o`0000?oNhCA0ol00002of^4fP06o`000?mFNm_o0000o`00
0?liL]go00000_l0ALH01OlSDLSo0000ocE7]ol0003oK5^^00;oKU>R00?o0000odTKM?l000000_m7
1ED01Ol0003oDPU@o`000?l0003oHAMH00;o00000_mN5eX00ol0003oI2AYof@TJ@02of@TJ@03o`00
0?m/>7koK3Qn00;oK3Qn00Co0000oge=S_mmCHko00000_mfCY@00ol0003oQV2OohIPW`06ohIPW`;o
TVjV0ol00006ohma[@03o`000?nINk3oVG^`00ooVG^`00?o0000oj63/onQPk<05onQPk<00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01_ooooo0ol00002ooooo`03o`000?oooooooooo007o
oooo000Booooo`03o`000?oooooooooo01cooooo00?o0000olNT]_o7Y;H05_o7Y;H00ol0003ocJVd
olfY]00;olfY]0Ko00001ooCYjX00ol0003og:^Tomb[Y004omb[Y005o`000?oW/I[oik6JonNaV_l0
00000_oc]X/2o`000006ohV6bOl0003oRh[<oh^:c?l0003oNhCA0_l000000ommR=?o0000of^4fP02
of^4fP08o`000?mEPN3oEH7Po`000?liL]go0000o`15a_l0<;P2o`000004obll[_m/Fjko0000ofiC
XP?o000000CoA`EEo`000?mB2E3o00000_mJ3U43o`000003oehGF_l0003o000000?oI2AY0_l00003
of`hOP03o`000?mmCHkoODf>00;oODf>00?o0000ogI>U?l000001on6H9l00ol0003oTVjVoi9^YP03
oi9^YP;o00001?n?LJd00ol0003oVG^`oiUk/00>oiUk/003o`000?nQPk?oXH>c01OoXH>c00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`Co00000_ooool001?ooooo00?o0000oooo
ooooool06oooool00ol0003oajBfolNT]P0FolNT]P03o`000?o=ZKCocJVd00GocJVd1_l00003olbS
[P03o`000?oCYj[odjNZ00SodjNZ00?o0000omb[Y?oLZj@01?oLZj@02Ol0003oik6JonNaV_oW/I[o
0000oo>fRol0003oo;Q^o`000003oh^:c0?o000000SoOHSCo`000?moRmGo0000of^4f_l0003oKX_N
o`0000;oEH7P0_l000001OlJG]Go04G6o`0V/?l0003o;cb^00?o000000?o@1Qgo`000?l000001?l0
00000omJ3U7o0000of<HE`03o`0000;oJbQX00?o0000of@TJOl000000_md>W/00ol0003oK3Qno`00
0006oge=SP;o00001on6H9l00ol0003oTVjVoi9^YP05oi9^YP;o000000?oSg6]o`000?nINk004?nI
Nk000ol0003oXH>coj63/`0Goj63/`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08ooo
ool2o`00007ooooo000Dooooo`03o`000?oooooooooo01[ooooo00?o0000olNT]_o7Y;H05_o7Y;H0
0ol0003ocJVdolfY]005o`0000Woc:>^00?o0000om>WZ_oCYjX02?oCYjX00ol0003og:^Tomb[Y004
omb[Y005o`000?oW/I[oik6JonNaV_l000000_oc]X/2o`0000;oRh[<0ol000000ommR=?o0000ogn;
e@02ogn;e@06o`000?m^RmkoKX_Nofj;g_l0003oEH7P1_l000001Ol_?:ko0000oc/XSol0003o@1Qg
00?o000000Co=00bo`000?m<03go00000omS65L01?l0003oKBUWo`000?m[:6P2o`0000CoM3Yk00?o
0000oge=S_mmCHh01OmmCHh2ohYOV@03o`000?n6H9ooQV2O00?oQV2O00?o0000oi9^Y_nBKZH02OnB
KZH2o`00013oVG^`00?o0000oj63/onQPk<05onQPk<00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool00Oooool001Cooooo00?o0000ooooooooool06_ooool0
0ol0003oajBfolNT]P0ColNT]PKo00003oo<Xjh00ol0003odjNZom>WZP07om>WZP03o`000?oLZjCo
g:^T00Cog:^T00Ko0000onNaV_oW/I[oik6Jo`000?oc]X/6o`0000;oSHg>00Co0000ogn;eOmoRmGo
00000_n2TMT01Ol0003oKX_Nofj;g_m^Rmko000000;oE8WW00Co0000obafh_l0Em;o02J`0_l00000
0olk:8oo@1Qgo`000002o`00000>oc@0<_l0003oC00mo`000?mP44go0000of<HEol0003oL2UUo`00
0?m]:FOo0000ogPkN?l00003og@jN`03o`000?n2CXWo000000GoODf>00Go0000ohYOVOn:GiWoRUnI
o`000004ohIPW`03o`000?nBKZKoTVjV00WoTVjV0_nKNJ`3o`0000coVG^`00?o0000oj63/onQPk<0
6?nQPk<00ol0003oooooooooo`04ooooo`;o00009Oooool00ol0003oooooooooo`02ooooo`005Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?o7Y;KoajBf00goajBf1_l00003olJO/@03o`000?o<
Xjkoc:>^00ooc:>^00?o0000om>WZ_oCYjX02?oCYjX00ol0003og:^Tomb[Y003omb[Y003o`000?oW
/I[oik6J00?o000000?ojI]do`000?l000000_l00002ohf=cP;oSXo@00?o0000oh:AfOn2TMT00on2
TMT2o`0000;oLYCT00Go0000oeB9iomDRNOo0000obafhP03o`000003oc/XSol0003o000000?o0000
00CoC00mo`000?mP44goH11=0_l00003og0YI@;o00000_mh>gP00ol0003oM3Yko`000003oh9>R@05
o`000?mmCHkoODf>oge=S_l000001On:GiT01?l0003oQV2OohIPWol0000;oi9^YP03o`000?nKNJco
VgV/00?oVgV/0ol00009oiUk/003o`000?nQPk?oXH>c01SoXH>c00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo000Fooooo`03o`000?oooooooooo
01Sooooo00?o0000olNT]_o7Y;H01_o7Y;H7o`0000[oaYna00?o0000olbS[_o<Xjh03_o<Xjh00ol0
003odjNZom>WZP08om>WZP03o`000?oLZjCog:^T00Cog:^T0_l000000ooPWH[o0000onVKM002onVK
M0;o000000?oSHg>o`000?n>Sm000_n>Sm02o`0000?oPY7I00Co0000ohJIg_n6VMko00000_mbU>@0
0ol0003oE8WWo`000006o`000003oa/0=?l0003o000000;o000000?oH11=o`000?l000000_mb9el0
0ol0003oL2UUo`000003o`0000;oN3]h00?o0000oh9>ROn2CXT00on2CXT00ol0003oODf>o`000007
ohYOV@03o`000?n6H9oo000000_oTVjV00?o0000oi]i[?nKNJ`01_nKNJ`2o`0000OoVG^`00?o0000
oj63/onQPk<05onQPk<00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool01?ooool001Oooooo00?o0000ooooooooool05oooool00ol0003oajBfolNT]P06o`00
017oaYna00?o0000olbS[_o<Xjh03_o<Xjh00ol0003odjNZom>WZP08om>WZP03o`000?oLZjCog:^T
00?og:^T0_l00003on2MRP06o`000?oYVgCojI]do`000?o^TToo00000on>Sm001_l0003oTICCoi6D
dol0003oPY7Io`0000CoQYWN00Co0000og:Di?l0003o00000omFV?45o`0000;o?`0Q0ol00004og8W
G`;o00000_mm?7@2o`000004ogPkN?l0003oQTn7o`0000GoPTj90_l00008ohYOV@;o00002onBKZH0
0ol0003oVgV/oi]i[008oi]i[0?o00001?nINk000ol0003oXH>coj63/`0Goj63/`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool08oooool2o`0000Oooooo000Hooooo`03o`000?oooooooooo
01Kooooo0ol0000GolJO/@03o`000?o<Xjkoc:>^00ooc:>^00?o0000om>WZ_oCYjX01ooCYjX01?l0
003og:^Tomb[Y?oLZj@2o`000003omNMV?l0003oh9f:00?oh9f:00?o0000onVKM?oYVg@01Ol00004
oi6Dd`03o`000?n6VMkoQYWN00CoQYWN00Go0000ogRRk?mhX^coN:;/o`000002oeJHl@?o00000_lo
0242o`000003ogHSEOl0003oLRMO00;oLRMO00?o0000oh4lL?l000000_mm?7@00ol0003oOSado`00
0003ohI?Q`05o`000?n2CXWoPTj9oh9>ROl000000_n?GiD00ol0003oRUnIohYOV@05ohYOV@;oUFfR
0_l00008oi9^YP03o`000?nKNJcoVgV/00coVgV/0_l000000onINk3o0000oj63/`0Ioj63/`05o`00
0?ooooooooooooooool000009Oooool00ol0003oooooooooo`07ooooo`006Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?o6Wk7oaYna01SoaYna00?o0000olbS[_o<Xjh03_o<Xjh00ol0003odjNZ
om>WZP08om>WZP?o00001?oGWIP01Ol0003oh9f:on2MR_oPWH[o000000;ojI]d00?o0000onjBCol0
00000_l00004oi6Dd`04o`000?nEVmOo0000o`0000?oQYWN00Co0000ohfTi?l0003o00000omhX^`3
o`000003ocl08Ol0003o000000?oMR=E00?o0000og8WGol000000on1?7001_l0003oOCado`000?l0
003oR4n5o`0000?oQTn700?o0000oh9>ROl000001?n?GiD00ol0003oRUnIohYOV@03ohYOV@03o`00
0?nEKJ;oUFfR00;oUFfR00?o0000oi9^Y_nBKZH01OnBKZH00ol0003oVgV/oi]i[00?oi]i[0;o0000
6OnQPk<01?l0003oooooooooool0000Uooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo01Gooooo00?o0000olJO/Oo6Wk405oo6Wk400ol0003oc:>^olbS[P0>olbS[P03o`00
0?oCYj[odjNZ00OodjNZ0_l00006omNMV003o`000?oPWH[oh9f:00;oh9f:00?o0000onVKM?l00000
0_l000000ooGJcWo0000o`000002oi6Dd`03o`000?nEVmOoUI_G00;oUI_G00?o0000ohJIg_l00000
1?n=Y>@3o`0000;o?@000ol00004ogHSE@;o00001On1?7001_l0003oRdn3oh]?Pol0003oR4n5o`00
00?oQTn700?o0000ohmOUOn?GiD01?n?GiD01Ol0003oRUnIohYOVOn:GiWo000000KoUFfR0_l00004
oi9^YP03o`000?nKNJcoVgV/013oVgV/0_nRPJl3o`0001KoXH>c0ol0000Uooooo`03o`000?oooooo
oooo00Wooooo000Jooooo`03o`000?oooooooooo01Gooooo00?o0000olJO/Oo6Wk405oo6Wk400ol0
003oc:>^olbS[P0>olbS[P03o`000?oCYj[odjNZ00CodjNZ0ol000000oo?W:7o0000omNMV006omNM
V003o`000?oPWH[oh9f:00;oh9f:0_l00002omQmH`03o`000?oGJcWo000000;o00001_nEVmL00ol0
003oSJCTohfTi003ohfTi0Ko00000_mm8DP01?l0003oMR=Eo`000?l00002ohLmJ`04o`000?n1?73o
PCa`oh4lL0;o00000on;Ch<01?l0003oR4n5o`000?n6ChL2o`0000OoSenE00?o0000ohYOVOl00000
2OnEKJ82o`0000;oTVjV00?o0000oi]i[?nKNJ`03onKNJ`00ol0003oXX6_oj:1[`03oj:1[`?o0000
4_nQPk<2o`0002Kooooo00?o0000ooooooooool02_ooool001_ooooo00?o0000ooooooooool05?oo
ool00ol0003oaYnaolJO/@0HolJO/@03o`000?o<Xjkoc:>^00goc:>^00?o0000om>WZ_oCYjX00_oC
YjX2o`0000GocibQ00?o0000omNMV?oGWIP01OoGWIP01?l0003oh9f:on2MR_l00002om>7O005o`00
0?oHOF?of7eSo`000?oGJcT01Ol00003oiFKe`03o`000?nKXm_o000000Go000000?oHP0Uo`000?mm
8DP00omm8DP2o`0000GoQce[00?o0000oh4lL?l000000_n>D8001?l0003oRdn3oh]?Pon;Ch<2ohQ?
Q@04o`000?nAGi?oTEnCo`0000OoSenE0_l0000;oiE]XP;oTVjV00?o0000oi]i[?nKNJ`03onKNJ`0
0ol0003oXX6_oj:1[`06oj:1[`?o00003onQPk<00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00_ooooo000Looooo`03o`000?oooooooooo01Cooooo00?o0000olJO/Oo6Wk405oo6Wk400ol0
003oc:>^olbS[P0>olbS[PCo00001oo?W:400ol0003oeifHomNMV005omNMV003o`000?oPWH[o0000
00CodhMl00?o0000omQmHooHOF<00_l000000onkB2oo0000o`00000=o`0000?oOB580_l000000on@
?V?o0000ohLmJ`04ohLmJ`;o00001?n>D8000ol0003oRdn3oh]?P`03o`0000?oTEnC00?o0000ohmO
UOn?GiD00on?GiD01?l0003oV6bNoiQ/W_l0000;oiE]XP;o00004OnKNJ`00ol0003oXX6_oj:1[`09
oj:1[`?o00003?nQPk<00ol0003oooooooooo`0Rooooo`;o00003_ooool001gooooo00?o0000oooo
ooooool04oooool00ol0003oaYnaolJO/@0GolJO/@03o`000?o<Xjkoc:>^00goc:>^0_l0000;olnL
X@03o`000?oGWISoeifH00GoeifH0_l00005om>7O003o`000?oHOF?of7eS00;o00000onkB2l9o`00
00?oRb@k00?o0000ogdQB?l000001?n@?V<00ol0003oQce[o`000002o`000003oiAAO?l0003oSU20
00?oSU2000Oo0000oh]?Pol0003oUEn@o`000?nCGi7o000000?oTEnC00Go0000ohmOUOn?GiGoSenE
o`000004oiQ/WP03o`000?nEKJ;oUFfR00SoUFfR0_nMMjP2o`0000koVgV/00?o0000oj:1[onRPJl0
3OnRPJl2o`0000[oXH>c00?o0000ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`007_oo
ool00ol0003oooooooooo`0Booooo`03o`000?o6Wk7oaYna01SoaYna00?o0000olbS[_o<Xjh02_o<
Xjh2o`000003olVKYol0003ocibQ00_ocibQ00?o0000omNMV?oGWIP00ooGWIP01?l0003ocXf>olj=
S_l00005om>7O004o`000?oHOF?o0000ol=SF@Co00001OnP<2l01?l0003oRb@koh/T>on;93/4o`00
00GoT3iS0_l00005oiAAO004o`000?n>D83oSU20ohi@P0;o00000onEGi000ol0003oTenAo`000003
oi5OT`03o`000?n?GiGo000000KoV6bN00?o0000oiE]X_nEKJ801_nEKJ800ol0003oWGNXoiegZ002
oiegZ003o`000?nKNJcoVgV/00_oVgV/00?o0000oj:1[onRPJl03onRPJl3o`0000OoXH>c00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0?ooooo`007oooool00ol0003oooooooooo`0Boooo
o`03o`000?o6Wk7oaYna01OoaYna00?o0000olbS[_o<Xjh02?o<Xjh2o`0000CobI^W00?o0000olnL
XOo?W:402Oo?W:400ol0003oeifHomNMV002omNMV003o`000?o>SHkocXf>00;ocXf>00?o0000om>7
O?oCQg`00ooCQg`3o`0000?o`f=I2_l00003oia4F`04o`000?n@?V?oT3iSoi0nH`;o000000?oW5Ah
o`000?nDDG`01OnDDG`01Ol0003oSU20o`000?nHHHko000000CoUEn@00?o0000oi=OTOl000000onA
Gi<00ol0003oV6bNoiQ/WP06oiQ/WP03o`000?nEKJ;oUFfR00CoUFfR00?o0000oiegZ?nMMjP01?nM
MjP2o`0000[oVgV/00?o0000oj:1[onRPJl04onRPJl3o`0000?oXH>c00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`0Aooooo`03o`000?o6Wk7o
aYna01OoaYna00?o0000olbS[_o<Xjh01_o<Xjh2o`0000OobI^W00?o0000olnLXOo?W:402Oo?W:40
1?l0003oeifHomNMV?l00006olj=SP03o`000?oCQgcodhMl00;odhMl00?o0000olAdM?o4M7@01?l0
0006oji@E`03o`000?nLA5_oW4AK00CoW4AK0ol00004oiaDN003o`000?nDDGcoU55l00?oU55l0_l0
0003oiQQSP03o`000?nEGi3oUEn@00;oUEn@00Oo0000oi=OTOnAGi?oTEnCo`000?nJK9co000000So
V6bN00?o0000oiE]X_nEKJ800_nEKJ800ol0003oWGNXoiegZ007oiegZ0;o00002?nKNJ`00ol0003o
XX6_oj:1[`0Foj:1[`;o000000?oXH>co`000?ooool08?ooool00ol0003oooooooooo`0Aooooo`00
8Oooool00ol0003oooooooooo`0@ooooo`03o`000?o6Wk7oaYna01SoaYna00?o0000olbS[_o<Xjh0
0oo<Xjh2o`0000WobI^W00?o0000olnLXOo?W:402Oo?W:400ol0003oeifHo`000008olj=SP04o`00
0?oCQgcodhMlo`0000Koa7Ad1Ol00002oji@E`04o`000?nLA5_oW4AKoia4F`Co00001_nLE7P01?l0
003oU55loiAAO?nDDG`2o`000003oieRRol0003oV66>00?oV66>00Go0000oiEOT?nEGi3oUEn@o`00
0002oi=OT@05o`000?nJK9coVVbLoiY/W?l000002?nHK9h01Ol0003oUFfRoiE]X_nEKJ;o000000_o
WGNX00?o0000oi]i[?nKNJ`01OnKNJ`00ol0003oXX6_oj:1[`0Ioj:1[`03o`000?oooooooooo01go
oooo0_l0000Dooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?o6Wk7oaYna01OoaYna
00Co0000olbS[_o<Xjkoc:>^0_l0000<olVKY`03o`000?o?W:7ocibQ00WocibQ0_l00009olj=SP03
o`000?oCQgco000000Koa7Ad00?o0000okAUL_ndIG800_ndIG86o`0000?oYeYd00?o0000oiaDN?nL
E7P01?nLE7P01?l0003oU55lo`000?l00004oieRR`03o`000?nHHHkoV66>00;oV66>00Co0000oiEO
T?nEGi3oUEn@0ol00004oiY/W003o`000?nHK9koV6bN00KoV6bN0_nEKJ800ol0003oWGNXoiegZ00;
oiegZ0;o00001?nKNJ`00ol0003oXX6_oj:1[`0Joj:1[`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05?ooool002;ooooo00?o0000ooooooooool04?ooool00ol0003oaYnaolJO/@0GolJO
/@04o`000?o<Xjko0000o`0000oobI^W00?o0000olnLXOo?W:401oo?W:401?l0003obI6JolVAV_l0
0009olj=SP;o00001_o4M7@00ol0003o]6EbokAULP04okAULP03o`000?nWFWCoYeYd00GoYeYd00?o
0000oiaDN?nLE7P00onLE7P2o`0000KoWF:;00?o0000oiQQS_nHHHh00_nHHHh01?l0003oUEn@oiEO
T?nEGi02o`000003oia]Vol0003oVVbL00?oVVbL00?o0000oiQ/W_nHK9h01_nHK9h2o`0000ooWGNX
0_l00002oi]i[003o`000?nRPJooXX6_01WoXX6_00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Eooooo`008oooool00ol0003oooooooooo`0?ooooo`03o`000?o6Wk7oaYna01OoaYna0_l0
000AolVKY`03o`000?o?W:7ocibQ00KocibQ00?o0000olVAV_o9TIX00_o9TIX00ol0003ocXf>olj=
SP06olj=SP03o`000?o3OhOo000000;o00000oo4M7@00ol0003o]6EbokAULP04okAULP03o`000?nW
FWCoYeYd00GoYeYd00Co0000oiaDN?nLE7SoW5Ah0_l000000onTIHSo0000oieRR`06oieRR`03o`00
0?nHHHkoV66>00;oV66>00Co0000oiEOT?l0003oWFfJ0_l000000onLKI_o0000oiY/W003oiY/W003
o`000?nHK9koV6bN00GoV6bN0_nOMjD00ol0003oWGNXoiegZ00>oiegZ0;oVgV/00?o0000oj:1[onR
PJl06OnRPJl00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo000Tooooo`03o`00
0?oooooooooo00oooooo00?o0000olJO/Oo6Wk405?o6Wk42o`000003olBJ[?l0003obI^W017obI^W
00?o0000olnLXOo?W:401?o?W:400ol0003obI6JolVAVP04olVAVP;o00001Oo>SHh00ol0003o`gn7
ol=oQ`03ol=oQ`Co00001ondIG800ol0003oYeYdojMJM004ojMJM004o`000?nLE7So0000o`0000Co
Y6F800?o0000oieRRonMHX/01OnMHX/01?l0003oV66>oiQQS_nHHHh2o`0000?oWFfJ0_l000000onL
KI_o0000oiY/W003oiY/W003o`000?nHK9koV6bN00?oV6bN00Go0000oimgYOnOMjGoWgNUo`00000@
oiegZ0;o00006_nRPJl00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo000Uoooo
o`03o`000?oooooooooo00kooooo00?o0000olJO/Oo6Wk404_o6Wk42o`0000Coa9Z/00?o0000olVK
Yoo9VjL04?o9VjL00ol0003ocibQolnLX@02olnLX@03o`000?o9TI[obI6J00OobI6J00Go0000olj=
S_o>SHkocXf>o`000009ol=oQ`Go00000ondIG801?l0003oYeYdojMJM?nWFW@5o`0000KoY6F800?o
0000oieRRonMHX/01OnMHX/01_l0003oV66>o`000?l0003oX6fHo`0000CoWFfJ0_l000000onLKI_o
0000oiY/W003oiY/W005o`000?nHK9koV6bNoiQ/W_l000001OnOMjD00ol0003oWGNXoiegZ00=oieg
Z0;oY7n/0_l0000Hoj:1[`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool002Ko
oooo00?o0000ooooooooool03Oooool00ol0003oaYnaolJO/@0@olJO/@;o00001oo4VZ`00ol0003o
bI^WolVKY`0?olVKY`05o`000?o?W:7ocibQolnLXOl000002oo9TIX00ol0003ocXf>o`00000:ol=o
Q`03o`000?ngLhGo]g>500;o]g>51ol00004oje[Q@03o`000?nTIHSoY6F800GoY6F800?o0000oieR
RonMHX/01?nMHX/2o`0000CoX6fH00?o0000oie]V_nMKIX00_nMKIX2o`000003oia]Vol0003oVVbL
00?oVVbL0_nHK9h00ol0003oWgNUoimgY@05oimgY@03o`000?nMMjSoWGNX00_oWGNX00?o0000ojAo
[?nTOj`00_nTOj`00ol0003oXX6_oj:1[`0Doj:1[`03o`000?oooooooooo01Wooooo0_l0000Koooo
o`009oooool00ol0003oooooooooo`0=ooooo`03o`000?o6Wk7oaYna00goaYna0_l00009olBJ[003
o`000?o9VjOobI^W013obI^W00?o0000olnLXOl000003Oo9TIX2o`0000[o`gn700?o0000okMcQOng
LhD01OngLhD00ol0003o[F^5oje[Q@05oje[Q@03o`000?nTIHSoY6F800GoY6F800Co0000oieRRonM
HX_oWF:;0ol000000onTKiKo0000oj1]V004oj1]V003o`000?nMKI[oWFfJ00;oWFfJ0_l000000onL
KI_o0000oiY/W002oiY/W0;o00002OnOMjD2o`0000[oWGNX00?o0000ojAo[?nTOj`01?nTOj`2o`00
01CoXX6_00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Kooooo`00:?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?o6Wk7oaYna00[oaYna0ol0000<olBJ[003o`000?o9VjOobI^W00oo
bI^W0ol0000=olVAVP04o`000?o1QYGo0000o`0000Oo`gn700?o0000okMcQOngLhD01_ngLhD00ol0
003o[F^5oje[Q@05oje[Q@03o`000?nTIHSoY6F800GoY6F800Co0000oieRRol0003o00001OnTKiH0
0ol0003oX6fHoj1]V003oj1]V005o`000?nMKI[oWFfJoie]V_l000000onLKI/2oiY/W004o`000?nQ
MjCoXGNTo`0000[oWgNU00?o0000oiegZ?nMMjP01_nMMjP00ol0003oY7n/ojAo[007ojAo[0;o0000
4OnRPJl00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo000Xooooo`03o`000?oo
oooooooo00cooooo00?o0000olJO/Oo6Wk402?o6Wk42o`0000ooa9Z/00?o0000olVKYoo9VjL03_o9
VjL01Ol0003oa9:RolBBX_o4TZ;o000000_obI6J00?o0000ol66UOo1QYD00_o1QYD2o`0000Go`gn7
00?o0000okMcQOngLhD01_ngLhD00ol0003o[F^5oje[Q@06oje[Q@03o`000?nTIHSoY6F800CoY6F8
0_l00007ojA_UP03o`000?nPKISoX6fH00CoX6fH00Go0000oie]V_nMKI[oWFfJo`000003oia]V`03
o`000?nQMjCoXGNT00;oXGNT00?o0000oimgYOnOMjD02?nOMjD00ol0003oWGNXoiegZ004oiegZ003
o`000?nTOjcoY7n/00[oY7n/00?o0000oj:1[onRPJl03_nRPJl00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01gooooo000Yooooo`03o`000?oooooooooo00cooooo00?o0000olJO/Oo6Wk40
1Oo6Wk42o`0001;oa9Z/00?o0000olVKYoo9VjL03?o9VjL00ol0003oa9:RolBBXP03olBBXP03o`00
0?o9TI[obI6J00SobI6J00?o0000ol66UOo1QYD01?o1QYD2o`0000?o`gn700?o0000okMcQOngLhD0
1_ngLhD00ol0003o[F^5oje[Q@06oje[Q@04o`000?nTIHSoY6F8ojAUR0?o000000?oZG6Do`000?nT
KiH01onTKiH00ol0003oX6fHoj1]V003oj1]V003o`000?nMKI[oWFfJ00;oWFfJ00Co0000oia]Vol0
003o00001OnQMj@00ol0003oWgNUoimgY@08oimgY@03o`000?nMMjSoWGNX00?oWGNX00?o0000ojAo
[?nTOj`02onTOj`2o`0000koXX6_00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Noooo
o`00:_ooool00ol0003oooooooooo`0;ooooo`03o`000?o6Wk7oaYna00?oaYna0_l0000EolBJ[003
o`000?o9VjOobI^W00WobI^W0_l00007olBBXP03o`000?o9TI[obI6J00KobI6J00?o0000ol66UOo1
QYD01oo1QYD3o`0000Wo]g>500?o0000oje[QOn]JhD01_n]JhD4o`0000GoZG6D00?o0000ojA_U_nT
KiH01OnTKiH00ol0003oX6fHoj1]V004oj1]V004o`000?nMKI[oWFfJoie]VP?o000000?oXgNSo`00
0?nQMj@01?nQMj@00ol0003oWgNUoimgY@08oimgY@05o`000?nMMjSoWGNXoiegZ?l000004?nTOj`2
o`0000_oXX6_00?o0000ooooooooool05Oooool2o`00027ooooo000[ooooo`03o`000?oooooooooo
00[ooooo00Co0000olJO/Oo6Wk7oaYna0_l0000GolBJ[003o`000?o9VjOobI^W00SobI^W00?o0000
olBBX_o4TZ802?o4TZ82o`0000GobI6J00?o0000ol66UOo1QYD02_o1QYD6o`0000Co]g>500?o0000
oje[QOn]JhD00_n]JhD5o`0000SoZG6D00?o0000ojA_U_nTKiH01_nTKiH00ol0003oX6fHoj1]V004
oj1]V009o`000?nMKI[o0000ojAgX_l0003oXgNSo`000?nSMj?o000000GoXGNT00?o0000oimgYOnO
MjD02?nOMjD2oiegZ003o`000?nTOjcoY7n/017oY7n/00?o0000oj:1[onRPJl02?nRPJl00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo027ooooo000/ooooo`03o`000?oooooooooo00[ooooo
00?o0000olJO/Ol000006_o4VZ`00ol0003obI^WolVKY`06olVKY`03o`000?o4TZ;oa9:R00_oa9:R
00?o0000olVAV_o9TIX00_o9TIX00ol0003o`HJEol66U@0:ol66U@03o`000?nhOI;o^7fB00?o^7fB
2Ol00004ok1fTP03o`000?nYLICoZG6D00OoZG6D00?o0000ojA_U_nTKiH01OnTKiH00ol0003oX6fH
oj1]V004oj1]V0;o00000onTMj801Ol0003oXgNSo`000?nSMj?o000000GoXGNT00?o0000oimgYOnO
MjD02?nOMjD2o`0001CoY7n/0_l00007oj:1[`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool08_ooool002gooooo00?o0000ooooooooool02Oooool00ol0003oa9Z/olBJ[00JolBJ[003o`00
0?o9VjOobI^W00GobI^W00?o0000olBBX_o4TZ803Oo4TZ801?l0003obI6JolVAV_l0000=ol66U@03
o`000?nhOI;o^7fB00Oo^7fB00?o0000ok1fT_n`MY801_n`MY800ol0003oZG6DojUaU007ojUaU003
o`000?nTKiKoY6nF00GoY6nF00?o0000oj1]V?nPKIP00onPKIP00ol0003oYWRPo`000004ojAgXP05
o`000?nSMj?o0000oj=gXol000001OnQMj@00ol0003oWgNUoimgY@07oimgY@;oYGnZ00?o0000ojAo
[?nTOj`04onTOj`2o`0000GoXX6_00?o0000ooooooooool04oooool00ol0003oooooooooo`0Soooo
o`00;_ooool00ol0003oooooooooo`08ooooo`03o`000?o4VZcoa9Z/01_oa9Z/00?o0000olVKYoo9
VjL00_o9VjL2o`00017oa9:R00?o0000olVAV_l000003?o1QYD00ol0003o^7fBokQmTP08okQmTP03
o`000?n`MY;o/7JB00Oo/7JB00?o0000ojUaU?nYLI@01onYLI@00ol0003oY6nFojA_UP05ojA_UP03
o`000?nPKISoX6fH00;o00000onVN:000ol0003oY7NRojAgXP02ojAgXP05o`000?nSMj?o0000oj=g
Xol000001OnQMj@00ol0003oWgNUoimgY@05oimgY@05o`000?nUOj[oYGnZojEoZ_l000005_nTOj`0
1Ol0003oXX6_oj:1[onRPJoo000001Gooooo00?o0000ooooooooool09?ooool002kooooo00?o0000
ooooooooool02Oooool00ol0003oa9Z/olBJ[00KolBJ[004o`000?o9VjOobI^Wo`0001Coa9:R0_l0
000<ol66U@03o`000?nhOI;o^7fB00So^7fB00?o0000ok1fT_n`MY801on`MY800ol0003oZG6DojUa
U007ojUaU003o`000?nTKiKoY6nF00GoY6nF00?o0000oj1]V?l000001_nVN:000ol0003oY7NRojAg
XP02ojAgXP;o00000_nSMj<00ol0003oXGNToj5gY003oj5gY003o`000?nOMjGoWgNU00?oWgNU00?o
0000ojEoZ_nUOjX00onUOjX2o`0001GoY7n/00Co0000oj:1[onRPJoo00004oooool2o`0002Oooooo
000_ooooo`03o`000?oooooooooo00Wooooo00?o0000olBJ[?o4VZ`06_o4VZ`00ol0003obI^Wo`00
000EolBBXP04o`000?nnRiko0000o`0000[o`HJE00?o0000okQmT_nhOI802?nhOI800ol0003o/7JB
ok1fTP07ok1fTP03o`000?nYLICoZG6D00OoZG6D00?o0000ojA_U_nTKiH01OnTKiH2o`0000OoYWRP
00?o0000ojAgX_nTMj800_nTMj801Ol0003oXgNSo`000?nSMj?o000000KoXGNT00Go0000oimgYOnO
MjGoWgNUo`000008ojEoZP03o`000?nTOjcoY7n/01CoY7n/00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Wooooo`00<?ooool00ol0003oooooooooo`08ooooo`03o`000?o4VZcoa9Z/01[o
a9Z/0ol0000DolBBXP03o`000?nnRiko_X^N00;o_X^N0_l00007ol66U@03o`000?nhOI;o^7fB00Wo
^7fB00?o0000ok1fT_n`MY802?n`MY800ol0003oZG6DojUaU007ojUaU004o`000?nTKiKoY6nFojA_
UP?o000000?oZ7VOo`000?nVN:001onVN:000ol0003oY7NRojAgXP02ojAgXP05o`000?nSMj?o0000
oj=gXol000001_nQMj@2oimgY@03o`000?nUOj[oYGnZ00SoYGnZ00?o0000ojAo[?nTOj`04onTOj`0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo000aooooo`03o`000?oooooooooo
00Sooooo00?o0000olBJ[?o4VZ`06?o4VZ`01Ol0003o`IBXol6DZ?o1U:So000001;oa9:R00?o0000
okj;W_nnRih01OnnRih2o`0000Go`HJE00?o0000okQmT_nhOI802OnhOI800ol0003o/7JBok1fTP08
ok1fTP03o`000?nYLICoZG6D00OoZG6D00Co0000ojA_U_l0003o00001OnXNIl00ol0003oYWRPojIh
X006ojIhX003o`000?nTMj;oY7NR00;oY7NR00Go0000oj=gXonSMj?oXgNSo`000005oj5gY0;o0000
3?nUOjX2o`0001;oY7n/00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Yooooo`00<_oo
ool00ol0003oooooooooo`07ooooo`03o`000?o4VZcoa9Z/01Ooa9Z/00?o0000ol6DZ?o1U:P00oo1
U:P00ol0003oa9:RolBBXP0?olBBXP03o`000?nnRiko_X^N00Oo_X^N0_l00003ol66U@03o`000?nh
OI;o^7fB00Wo^7fB00?o0000ok1fT_n`MY802?n`MY800ol0003oZG6DojUaU006ojUaU0?o00002?nX
NIl00ol0003oYWRPojIhX005ojIhX003o`000?nTMj;oY7NR00?oY7NR0_l00002oj=gX`07o`000?nQ
MjCoXGNToj5gY?l0003oYgnYo`00000>ojEoZP03o`000?nTOjcoY7n/00koY7n/00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Zooooo`00<oooool00ol0003oooooooooo`07ooooo`03o`00
0?o4VZcoa9Z/01Goa9Z/00?o0000ol6DZ?o1U:P01Oo1U:P00ol0003oa9:RolBBXP0=olBBXP03o`00
0?nnRiko_X^N00[o_X^N0ol0000<okQmTP03o`000?n`MY;o/7JB00So/7JB00?o0000ojUaU?nYLI@0
0onYLI@3o`0000;o[G^M00?o0000ojQiWonXNIl01_nXNIl00ol0003oYWRPojIhX006ojIhX003o`00
0?nTMj;oY7NR00;oY7NR00?o0000oj=gXol000000_nSMj<2oj5gY005o`000?nWOjWoYgnYojMoZOl0
00003_nUOjX00ol0003oY7n/ojAo[00=ojAo[003o`000?oooooooooo00oooooo00?o0000oooooooo
ool0:oooool003Cooooo00?o0000ooooooooool01oooool00ol0003oa9Z/olBJ[00ColBJ[003o`00
0?o1U:So`IBX00Oo`IBX00?o0000olBBX_o4TZ802oo4TZ800ol0003o_X^Nokj;WP0=okj;WPCo0000
2OnhOI800ol0003o/7JBok1fTP09ok1fTP03o`000?nYLICo000000;o00001_n]Nid00ol0003oZ7VO
ojQiW`06ojQiW`03o`000?nVN:3oYWRP00KoYWRP00?o0000ojAgX_nTMj800_nTMj800ol0003oXgNS
oj=gX`02oj=gX`03o`000?nWOjWoYgnY00?oYgnY00?o0000ojEoZ_nUOjX03?nUOjX00ol0003oY7n/
ojAo[00;ojAo[003o`000?oooooooooo00kooooo0_l0000^ooooo`00=Oooool00ol0003ooooooooo
o`06ooooo`03o`000?o4VZcoa9Z/01;oa9Z/00?o0000ol6DZ?o1U:P02Oo1U:P00ol0003oa9:RolBB
XP0:olBBXP03o`000?nnRiko_X^N00go_X^N00Co0000okR4WOnhQ9go^8BM1ol00002okQmTP03o`00
0?n`MY;o/7JB00?o/7JB2?l00009ojekW@03o`000?nXNIooZ7VO00KoZ7VO00?o0000ojIhX?nVN:00
1_nVN:000ol0003oY7NRojAgXP03ojAgXP05o`000?nSMj?oXgNSoj=gXol000001_nWOjT00ol0003o
YGnZojEoZP0<ojEoZP;o00002_nTOj`00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02ko
oooo000eooooo`03o`000?oooooooooo00Oooooo00?o0000olBJ[?o4VZ`04?o4VZ`00ol0003o`IBX
ol6DZ00;ol6DZ0;o00002Oo4TZ800ol0003o_X^Nokj;WP0>okj;WP03o`000?nhQ9go^8BM00So^8BM
2?l00006ok9nW003o`000?n]Nigo[G^M00So[G^M00?o0000ojQiWonXNIl01onXNIl00ol0003oYWRP
ojIhX006ojIhX003o`000?nTMj;oY7NR00?oY7NR00Go0000oj=gXol0003oYgnXo`000006ojMoZ@03
o`000?nUOj[oYGnZ00goYGnZ00?o0000ojAo[?nTOj`01onTOj`00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02oooooo000fooooo`03o`000?oooooooooo00Oooooo00?o0000olBJ[?o4VZ`0
3_o4VZ`00ol0003o`IBXol6DZ00>ol6DZ003o`000?o4TZ;oa9:R00Koa9:R00?o0000okj;W_nnRih0
3OnnRih00ol0003o^8BMokR4W@0;okR4W@03o`000?nbOYco/WjL00Wo/WjL00?o0000ojekWOn]Nid0
2On]Nid00ol0003oZ7VOojQiW`07ojQiW`03o`000?nVN:3oYWRP00KoYWRP00?o0000ojAgX_nTMj80
0_nTMj83o`0000;oYgnX00?o0000ojMoZOnWOjT01?nWOjT00ol0003oYGnZojEoZP0=ojEoZP03o`00
0?nTOjcoY7n/00GoY7n/00?o0000ooooooooool03Oooool00ol0003oooooooooo`0`ooooo`00=ooo
ool00ol0003oooooooooo`06ooooo`03o`000?o4VZcoa9Z/00coa9Z/0_l0000Bol6DZ003o`000?o4
TZ;oa9:R00Coa9:R00?o0000okj;W_nnRih03_nnRih00ol0003o^8BMokR4W@0;okR4W@03o`000?nb
OYco/WjL00Wo/WjL00?o0000ojekWOn]Nid02On]Nid00ol0003oZ7VOojQiW`07ojQiW`03o`000?nV
N:3oYWRP00KoYWRP00Wo0000ojAgX_nTMj;oY7NRo`000?nXOjSo0000ojQoZ?l000000_nWOjP00ol0
003oYgnYojMoZ@04ojMoZ@03o`000?nUOj[oYGnZ00goYGnZ0_l00004ojAo[003o`000?oooooooooo
00gooooo00?o0000ooooooooool0<Oooool003Sooooo00?o0000ooooooooool01_ooool00ol0003o
a9Z/olBJ[00:olBJ[003o`000?o1U:So`IBX01?o`IBX00?o0000olBBX_o4TZ800_o4TZ800ol0003o
_X^Nokj;WP0?okj;WP03o`000?nhQ9go^8BM00_o^8BM00?o0000ok9nW?nbOY`02_nbOY`00ol0003o
[G^MojekW@08ojekW@03o`000?nXNIooZ7VO00SoZ7VO00?o0000ojIhX?nVN:001_nVN:000ol0003o
Y7NRo`000003ojQoZ003o`000?nXOjSo000000;oYgnX00?o0000ojMoZOnWOjT01?nWOjT00ol0003o
YGnZojEoZP0>ojEoZP05o`000?nTOjcoY7n/ojAo[?l000003Oooool2o`0003Cooooo000iooooo`03
o`000?oooooooooo00Gooooo00?o0000olBJ[?o4VZ`02Oo4VZ`00ol0003o`IBXol6DZ00Eol6DZ005
o`000?o4TZ;oa9:RolBBX_l000004?nnRih00ol0003o^8BMokR4W@0<okR4W@03o`000?nbOYco/WjL
00[o/WjL00?o0000ojekWOn]Nid02On]Nid00ol0003oZ7VOojQiW`07ojQiW`03o`000?nVN:3oYWRP
00KoYWRP0_l00005ojQoZ003o`000?nXOjSo000000;oYgnX00?o0000ojMoZOnWOjT01?nWOjT00ol0
003oYGnZojEoZP0>ojEoZP;oY7n/00?o0000ooooooooool02oooool00ol0003oooooooooo`0doooo
o`00>_ooool00ol0003oooooooooo`05ooooo`03o`000?o4VZcoa9Z/00Ooa9Z/00?o0000ol6DZ?o1
U:P05oo1U:P00ol0003oa9:Ro`00000Aokj;WP03o`000?nhQ9go^8BM00co^8BM00?o0000ok9nW?nb
OY`02_nbOY`00ol0003o[G^MojekW@09ojekW@03o`000?nXNIooZ7VO00SoZ7VO00?o0000ojIhX?nV
N:000onVN:02o`000003ojZ0Yol0003oZ7nX00GoZ7nX00?o0000ojQoZ?l000000_nWOjP00ol0003o
YgnYojMoZ@04ojMoZ@03o`000?nUOj[oYGnZ00koYGnZ00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0eooooo`00>oooool00ol0003oooooooooo`05ooooo`03o`000?o4VZcoa9Z/00Goa9Z/
00?o0000ol6DZ?o1U:P06Oo1U:P2o`00017o_X^N00?o0000okR4WOnhQ9d03?nhQ9d00ol0003o/WjL
ok9nW00:ok9nW003o`000?n]Nigo[G^M00Wo[G^M00?o0000ojQiWonXNIl02OnXNIl01Ol0003oYWRP
ojIhX?nVN:3o000000CoZX2W00?o0000ojQoZ?nXOjP01?nXOjP00ol0003oZ7nXo`000002ojMoZ003
o`000?nWOjWoYgnY00CoYgnY00?o0000ojEoZ_nUOjX03OnUOjX00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo03Kooooo000kooooo`03o`000?oooooooooo00Gooooo00?o0000olBJ[?o4VZ`0
1?o4VZ`00ol0003o`IBXol6DZ00Jol6DZ004o`000?nlSZKo0000o`0000ko_X^N00?o0000okR4WOnh
Q9d03OnhQ9d00ol0003o/WjLok9nW00:ok9nW003o`000?n]Nigo[G^M00[o[G^M00?o0000ojQiWonX
NIl02?nXNIl01?l0003oYWRPo`000?l00006ojZ0Y`03o`000?nXOjSoZ7nX00?oZ7nX00Co0000ojQo
Z?nXOjSo00000_nWOjP00ol0003oYgnYojMoZ@04ojMoZ@03o`000?nUOj[oYGnZ00_oYGnZ00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0gooooo`00??ooool00ol0003oooooooooo`05oooo
o`03o`000?o4VZcoa9Z/00;oa9Z/00?o0000ol6DZ?o1U:P06_o1U:P00ol0003o_8jVokb>YP02okb>
YP;o00003?nnRih00ol0003o^8BMokR4W@0=okR4W@03o`000?nbOYco/WjL00_o/WjL00?o0000ojek
WOn]Nid02On]Nid00ol0003oZ7VOojQiW`08ojQiW`;o00002OnZP:L00ol0003oZ7nXojQoZ003ojQo
Z003o`000?nXOjSo000000?oYgnX00?o0000ojMoZOnWOjT01?nWOjT00ol0003oYGnZojEoZP09ojEo
ZP03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool003gooooo00?o0000oooooooo
ool01?ooool01Ol0003oa9Z/olBJ[?o4VZco000001co`IBX00?o0000okb>Y_nlSZH01OnlSZH2o`00
00[o_X^N00?o0000okR4WOnhQ9d03?nhQ9d00ol0003o/WjLok9nW00<ok9nW003o`000?n]Nigo[G^M
00Wo[G^M00?o0000ojQiWonXNIl01_nXNIl2o`000003ojb1YOl0003oZX2W00SoZX2W00?o0000ojQo
Z?nXOjP01?nXOjP00ol0003oZ7nXo`000002ojMoZ003o`000?nWOjWoYgnY00GoYgnY00?o0000ojEo
Z_nUOjX01onUOjX00ol0003oooooooooo`09ooooo`;o0000>oooool003kooooo00?o0000oooooooo
ool01?ooool00ol0003oa9Z/o`00000Mol6DZ003o`000?nlSZKo_8jV00Oo_8jV0_l00007okj;WP03
o`000?nhQ9go^8BM00go^8BM00?o0000ok9nW?nbOY`03?nbOY`00ol0003o[G^MojekW@0:ojekW@03
o`000?nXNIooZ7VO00?oZ7VO0_l00004ojb1Y@03o`000?nZP:OoZX2W00OoZX2W00?o0000ojQoZ?nX
OjP01?nXOjP00ol0003oZ7nXo`000002ojMoZ003o`000?nWOjWoYgnY00GoYgnY00?o0000ojEoZ_nU
OjX01OnUOjX00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03_ooooo000oooooo`03o`00
0?oooooooooo00Cooooo0_l0000Lol6DZ003o`000?nlSZKo_8jV00[o_8jV0_l00005okj;WP03o`00
0?nhQ9go^8BM00go^8BM00?o0000ok9nW?nbOY`03?nbOY`00ol0003o[G^MojekW@0:ojekW@04o`00
0?nXNIooZ7VOojQiW`;o00001_n/PJD00ol0003oZX2WojZ0Y`08ojZ0Y`03o`000?nXOjSoZ7nX00Co
Z7nX00?o0000ojQoZ?l000000_nWOjP00ol0003oYgnYojMoZ@05ojMoZ@03o`000?nUOj[oYGnZ00?o
YGnZ00?o0000ooooooooool02Oooool00ol0003oooooooooo`0looooo`00@?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?o1U:So`IBX01So`IBX00?o0000okb>Y_nlSZH03OnlSZH2o`0000?o_X^N
00?o0000okR4WOnhQ9d03OnhQ9d00ol0003o/WjLok9nW00<ok9nW003o`000?n]Nigo[G^M00[o[G^M
00Co0000ojQiWol0003o00002On/PJD00ol0003oZX2WojZ0Y`07ojZ0Y`03o`000?nXOjSoZ7nX00Co
Z7nX00Co0000ojQoZ?nXOjSo00000_nWOjP00ol0003oYgnYojMoZ@05ojMoZ@05o`000?nUOj[oYGnZ
ojEoZ_l000002oooool00ol0003oooooooooo`0mooooo`00@Oooool00ol0003oooooooooo`05oooo
o`03o`000?o1U:So`IBX01Oo`IBX00?o0000okb>Y_nlSZH03onlSZH3o`00013o^8BM00?o0000ok9n
W?nbOY`03?nbOY`00ol0003o[G^MojekW@09ojekW@?o00002on/PJD00ol0003oZX2WojZ0Y`08ojZ0
Y`03o`000?nXOjSoZ7nX00CoZ7nX00Co0000ojQoZ?nXOjSo00000_nWOjP00ol0003oYgnYojMoZ@05
ojMoZ@;oYGnZ00?o0000ooooooooool02Oooool00ol0003oooooooooo`0nooooo`00@_ooool00ol0
003oooooooooo`05ooooo`03o`000?o1U:So`IBX01Go`IBX00?o0000okb>Y_nlSZH04_nlSZH4o`00
00go^8BM00?o0000ok9nW?nbOY`03OnbOY`00ol0003o[G^MojekW@03ojekW@Go00000_n_PZ@00ol0
003o[86Uojb1Y@0:ojb1Y@03o`000?nZP:OoZX2W00SoZX2W00?o0000ojQoZ?nXOjP01?nXOjP00ol0
003oZ7nXo`000003ojMoZ003o`000?nWOjWoYgnY00GoYgnY00?o0000ooooooooool02?ooool2o`00
047ooooo0012ooooo`03o`000?oooooooooo00Kooooo00?o0000ol6DZ?o1U:P05?o1U:P00ol0003o
_8jVokb>YP0Bokb>YP04o`000?nhRJCo^8VTokR9Y0Ko00001onhQ9d00ol0003o/WjLok9nW00=ok9n
W003o`000?n]Nigo000000?o00002?n_PZ@00ol0003o[86Uojb1Y@09ojb1Y@03o`000?nZP:OoZX2W
00WoZX2W00?o0000ojQoZ?nXOjP01?nXOjP00ol0003oZ7nXo`000003ojMoZ003o`000?nWOjWoYgnY
00?oYgnY00?o0000ooooooooool02?ooool00ol0003oooooooooo`11ooooo`00@oooool00ol0003o
ooooooooo`06ooooo`03o`000?o1U:So`IBX01;o`IBX00?o0000okb>Y_nlSZH04onlSZH00ol0003o
^8VTokR9Y007okR9Y0Go00000_nhQ9d00ol0003o/WjLok9nW005ok9nW0[o00003?n_PZ@00ol0003o
[86Uojb1Y@0:ojb1Y@03o`000?nZP:OoZX2W00SoZX2W00?o0000ojQoZ?nXOjP01OnXOjP00ol0003o
Z7nXo`000003ojMoZ0CoYgnY00?o0000ooooooooool02?ooool00ol0003oooooooooo`12ooooo`00
A?ooool00ol0003oooooooooo`06ooooo`03o`000?o1U:So`IBX013o`IBX00?o0000okb>Y_nlSZH0
4onlSZH00ol0003o^8VTokR9Y00=okR9Y0[o00002?ncQJ@00ol0003o[h:Tojn2Y00;ojn2Y003o`00
0?n/PJGo[86U00[o[86U00?o0000ojZ0YonZP:L02OnZP:L00ol0003oZ7nXojQoZ004ojQoZ003o`00
0?nXOjSoZ7nX00CoYgnX0_nWOjT00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04?ooooo
0015ooooo`03o`000?oooooooooo00Kooooo00?o0000ol6DZ?o1U:P03oo1U:P00ol0003o_8jVokb>
YP0Cokb>YP03o`000?nhRJCo^8VT00oo^8VT00?o0000ok>5Y?ncQJ@03OncQJ@00ol0003o[h:Tojn2
Y00<ojn2Y003o`000?n/PJGo[86U00[o[86U00?o0000ojZ0YonZP:L02OnZP:L00ol0003oZ7nXojQo
Z004ojQoZ003o`000?nXOjSoZ7nX00CoYgnX00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`14ooooo`00A_ooool00ol0003oooooooooo`06ooooo`;o00003_o1U:P00ol0003o_8jVokb>YP0D
okb>YP03o`000?nhRJCo^8VT00oo^8VT00?o0000ok>5Y?ncQJ@03OncQJ@00ol0003o[h:Tojn2Y00<
ojn2Y003o`000?n/PJGo[86U00[o[86U00?o0000ojZ0YonZP:L02OnZP:L00ol0003oZ7nXojQoZ005
ojQoZ003o`000?nXOjSoZ7nX00;oYgnX00?o0000ooooooooool02?ooool00ol0003oooooooooo`15
ooooo`00Aoooool00ol0003oooooooooo`07ooooo`03o`000?o1U:So`IBX00[o`IBX00?o0000okb>
Y_nlSZH05?nlSZH00ol0003o^8VTokR9Y00@okR9Y003o`000?ncQJCo/hFT00ko/hFT00?o0000ojn2
Y?n_PZ@02on_PZ@00ol0003o[86Uojb1Y@0;ojb1Y@03o`000?nZP:OoZX2W00WoZX2W00?o0000ojQo
Z?nXOjP01OnXOjP01?l0003oZ7nXo`000?l00009ooooo`;o0000B?ooool004Sooooo00?o0000oooo
ooooool01oooool00ol0003o`IBXol6DZ009ol6DZ003o`000?nlSZKo_8jV01Co_8jV00?o0000okR9
Y?nhRJ@04?nhRJ@00ol0003o/hFTok>5Y00>ok>5Y003o`000?n_PZCo[h:T00co[h:T00?o0000ojb1
YOn/PJD02on/PJD00ol0003oZX2WojZ0Y`09ojZ0Y`03o`000?nXOjSoZ7nX00CoZ7nX0_l0000:oooo
o`03o`000?oooooooooo04Sooooo0019ooooo`03o`000?oooooooooo00Oooooo00?o0000ol6DZ?o1
U:P01oo1U:P00ol0003o_8jVokb>YP0Eokb>YP03o`000?nhRJCo^8VT013o^8VT00?o0000ok>5Y?nc
QJ@03_ncQJ@00ol0003o[h:Tojn2Y00<ojn2Y003o`000?n/PJGo[86U00_o[86U00?o0000ojZ0YonZ
P:L02_nZP:L00ol0003oZ7nXojQoZ002ojQoZ003o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0BOooool004Wooooo00?o0000ooooooooool02?ooool00ol0003o`IBXol6DZ005ol6DZ003o`00
0?nlSZKo_8jV01Ko_8jV00?o0000okR9Y?nhRJ@04?nhRJ@00ol0003o/hFTok>5Y00>ok>5Y003o`00
0?n_PZCo[h:T00go[h:T00?o0000ojb1YOn/PJD02on/PJD00ol0003oZX2WojZ0Y`09ojZ0Y`05o`00
0?nXOjSoZ7nXojQoZ?l000002oooool00ol0003oooooooooo`1:ooooo`00B_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?o1U:So`IBX00Co`IBX00?o0000okb>Y_nlSZH05OnlSZH00ol0003o^8VT
okR9Y00AokR9Y003o`000?ncQJCo/hFT00ko/hFT00?o0000ojn2Y?n_PZ@03On_PZ@00ol0003o[86U
ojb1Y@0;ojb1Y@03o`000?nZP:OoZX2W00[oZX2W00?o0000ojQoZ?l000002oooool00ol0003ooooo
ooooo`1;ooooo`00Boooool00ol0003oooooooooo`08ooooo`03o`000?o1U:So`IBX00;o`IBX00?o
0000okb>Y_nlSZH05_nlSZH00ol0003o^8VTokR9Y00AokR9Y003o`000?ncQJCo/hFT00ko/hFT00?o
0000ojn2Y?n_PZ@03On_PZ@00ol0003o[86Uojb1Y@0<ojb1Y@03o`000?nZP:OoZX2W00WoZX2W0_l0
000:ooooo`;o0000C_ooool004cooooo00?o0000ooooooooool02?ooool01Ol0003o`IBXol6DZ?o1
U:So000001So_8jV00?o0000okR9Y?nhRJ@04OnhRJ@00ol0003o/hFTok>5Y00>ok>5Y003o`000?n_
PZCo[h:T00ko[h:T00?o0000ojb1YOn/PJD02on/PJD00ol0003oZX2WojZ0Y`07ojZ0Y`;o00002ooo
ool00ol0003oooooooooo`1>ooooo`00COooool00ol0003oooooooooo`08ooooo`03o`000?o1U:So
000001So_8jV00?o0000okR9Y?nhRJ@04_nhRJ@00ol0003o/hFTok>5Y00?ok>5Y003o`000?n_PZCo
[h:T00go[h:T00?o0000ojb1YOn/PJD03?n/PJD00ol0003oZX2WojZ0Y`05ojZ0Y`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0Coooool004kooooo00?o0000ooooooooool02?ooool2o`00
01So_8jV00?o0000okR9Y?nhRJ@04_nhRJ@00ol0003o/hFTok>5Y00?ok>5Y003o`000?n_PZCo[h:T
00go[h:T00?o0000ojb1YOn/PJD03?n/PJD00ol0003oZX2WojZ0Y`03ojZ0Y`;o00003?ooool00ol0
003oooooooooo`1@ooooo`00Coooool00ol0003oooooooooo`09ooooo`;o00005_nlSZH00ol0003o
^8VTokR9Y00BokR9Y003o`000?ncQJCo/hFT00oo/hFT00?o0000ojn2Y?n_PZ@03_n_PZ@00ol0003o
[86Uojb1Y@0<ojb1Y@03o`000?nZP:OoZX2W00;o00003Oooool00ol0003oooooooooo`1Aooooo`00
Coooool00ol0003oooooooooo`0;ooooo`?o00004_nlSZH00ol0003o^8VTokR9Y00CokR9Y003o`00
0?ncQJCo/hFT00oo/hFT00?o0000ojn2Y?n_PZ@03_n_PZ@00ol0003o[86Uojb1Y@0<ojb1Y@03o`00
0?nZP:Oo000000gooooo0_l0001Dooooo`00D?ooool00ol0003oooooooooo`0=ooooo`;o00004?nl
SZH00ol0003o^8VTokR9Y00BokR9Y003o`000?ncQJCo/hFT013o/hFT00?o0000ojn2Y?n_PZ@03on_
PZ@00ol0003o[86Uojb1Y@0;ojb1Y@;o00003Oooool00ol0003oooooooooo`1Dooooo`00DOooool0
0ol0003oooooooooo`0>ooooo`;o00003_nlSZH00ol0003o^8VTokR9Y00BokR9Y003o`000?ncQJCo
/hFT013o/hFT00?o0000ojn2Y?n_PZ@03on_PZ@00ol0003o[86Uojb1Y@09ojb1Y@;o00003_ooool0
0ol0003oooooooooo`1Eooooo`00D_ooool00ol0003oooooooooo`0?ooooo`?o00002onlSZH00ol0
003o^8VTokR9Y00BokR9Y003o`000?ncQJCo/hFT017o/hFT00?o0000ojn2Y?n_PZ@03_n_PZ@00ol0
003o[86Uojb1Y@07ojb1Y@;o00003oooool00ol0003oooooooooo`1Fooooo`00Doooool00ol0003o
ooooooooo`0Aooooo`;o00002?nlSZH00ol0003o^8VTokR9Y00CokR9Y003o`000?ncQJCo/hFT017o
/hFT00?o0000ojn2Y?n_PZ@03on_PZ@00ol0003o[86Uojb1Y@03ojb1Y@?o00004?ooool00ol0003o
ooooooooo`1Gooooo`00E?ooool00ol0003oooooooooo`0Booooo`;o00001_nlSZH00ol0003o^8VT
okR9Y00CokR9Y003o`000?ncQJCo/hFT017o/hFT00?o0000ojn2Y?n_PZ@03on_PZ@01?l0003o[86U
ojb1YOn/PJD2o`0001;ooooo00?o0000ooooooooool0F?ooool005Gooooo00?o0000ooooooooool0
4oooool3o`0000?o_8jV00?o0000okR9Y?nhRJ@04onhRJ@00ol0003o/hFTok>5Y00Aok>5Y003o`00
0?n_PZCo[h:T00oo[h:T00Co0000ojb1YOl0003o00004_ooool2o`0005_ooooo001Fooooo`03o`00
0?oooooooooo01Gooooo0ol0000FokR9Y003o`000?ncQJCo/hFT017o/hFT00?o0000ojn2Y?n_PZ@0
3_n_PZ@3o`0001?ooooo00?o0000ooooooooool0Foooool005Kooooo00?o0000ooooooooool05ooo
ool3o`0001Co^8VT00?o0000ok>5Y?ncQJ@04OncQJ@00ol0003o[h:Tojn2Y00;ojn2Y0?o00005Ooo
ool00ol0003oooooooooo`1Looooo`00Eoooool00ol0003oooooooooo`0Iooooo`Go00003onhRJ@0
0ol0003o/hFTok>5Y00Aok>5Y003o`000?n_PZCo[h:T00Oo[h:T1?l0000Gooooo`03o`000?oooooo
oooo05gooooo001Hooooo`03o`000?oooooooooo01gooooo1Ol0000:okR9Y003o`000?ncQJCo/hFT
01;o/hFT00?o0000ojn2Y?n_PZ@00_n_PZ@4o`0001[ooooo00?o0000ooooooooool0G_ooool005Wo
oooo00?o0000ooooooooool07Oooool01?l0003oooooooooooooool4o`0000Ko^8VT00?o0000ok>5
Y?ncQJ@04_ncQJ@00ol0003o[h:To`000002o`0001cooooo0_l0001Qooooo`00F_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Cooooo1Ol000000onhRJCo0000ok>5Y009ok>5Y0co
00007_ooool00ol0003oooooooooo`1Qooooo`00Foooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00Wooooo3?l00003ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
H_ooool005cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0Hoooool005cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Cooooo`;o00009Oooool00ol0003oooooooooo`1Tooooo`00GOooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1Uooooo`00G_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool08oooool2o`0006Sooooo001Oooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Sooooo
001Pooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo06Wooooo001Qooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool02Oooool2o`0002Gooooo00?o0000ooooooooool0J_ooool006;ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0Joooool006?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02?ooooo0_l0001^ooooo`00Hoooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1^ooooo`00I?oo
ool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool000009Oooool00ol0003ooooo
ooooo`1_ooooo`00IOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000002Gooooo00?o
0000ooooooooool0L?ooool006Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo077ooooo001Wooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool08Oooool2o`0007Cooooo001Xooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`1dooooo`00JOooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0MOooool006[ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Kooooo001Zooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1gooooo`00Joooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0N?ooool006co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Jooooo`;o0000Noooool006gooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo07_ooooo
001^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1looooo`00Koooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0OOooool0073ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo07kooooo001`ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool05Oooool2o`00087ooooo001aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`21ooooo`00L_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0P_ooool007?ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo08?ooooo001dooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`24ooooo`00MOooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0QOooool007Kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`;o0000R?ooool007Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Sooooo001g
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`29
ooooo`00N?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0R_ooool007Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo08_ooooo001jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool2o`0008kooooo001kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2>ooooo`00O?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Soooool007gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo093ooooo001mooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Aooooo`00O_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0T_ooool007oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o0000UOooool0083ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo09Gooooo0021ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool0U_ooool008;ooooo00Go0000ooooool0003oooooo`00
002Iooooo`00Poooool3o`0009[ooooo0024ooooo`03o`000?oooooooooo09Wooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {286.5, 0}} -> {0.00629048, 0.0152735, \
0.00343711, 0.00343711}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Troubleshooting", "Subsubtitle"],

Cell[TextData[{
  "You need to have some surface data file on disk saved by 3D XplorMath \
before you con convet it to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics.\nTo save a surface data file in 3D XplorMath, choose the Save \
Surface Data under the File menu."
}], "Text"],

Cell[TextData[{
  "You need to place the saved file in a location where ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can find it. On Mac OS X, by default ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will search the Document directory under your home directory. In any \
case, you can append any directory you want ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to search by modifying the $Path global variable."
}], "Text"],

Cell["The following code locates the folder of this notebook:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(myFolder = 
      ToFileName[\(("\<FileName\>" /. 
              NotebookInformation[
                EvaluationNotebook[]])\)[\([{1}]\)]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \("/Users/xah/Documents/public_html/PageTwo_dir/MathPrograms_dir/_\
programs/3dxm/"\)], "Output"]
}, Open  ]],

Cell["\<\
the following code append the path of your notebook folder to the \
Mathematica search path\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Path = Join[$Path, {myFolder}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({"/Users/xah/Library/Mathematica/4.1/Kernel", 
      "/Users/xah/Library/Mathematica/4.1/AddOns/Autoload", 
      "/Users/xah/Library/Mathematica/4.1/AddOns/Applications", 
      "/Library/Mathematica/Kernel/", "/Library/Mathematica/Autoload/", 
      "/Library/Mathematica/Applications/", "/Library/Mathematica/", ".", 
      "/Users/xah", 
      "/Applications/Mathematica 4.1.app/AddOns/StandardPackages", 
      "/Applications/Mathematica 4.1.app/AddOns/StandardPackages/StartUp", 
      "/Applications/Mathematica 4.1.app/AddOns/Autoload", 
      "/Applications/Mathematica 4.1.app/AddOns/Applications", 
      "/Applications/Mathematica 4.1.app/AddOns/ExtraPackages", 
      "/Applications/Mathematica 4.1.app/SystemFiles/Graphics/Packages", 
      "/Applications/Mathematica 4.1.app/Configuration/Kernel", 
      "/Users/xah/Documents/public_html/PageTwo_dir/MathPrograms_dir/_\
programs/3dxm/"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Setting $HistoryLength to 10 reduce the memory usage stored in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " kernel. (by default it is Infinity)"
}], "Text"],

Cell[BoxData[
    \(\($HistoryLength = 10;\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Advanced Examples", "Subtitle"],

Cell["\<\
Once ShowSurface reads a surface data in as aMathematicaGraphics3D \
object,it can then be manipulated in anyway like standardMathematicagraphics \
object.\
\>", "Text"],

Cell["\<\
Here we define a function that cuts open a polygon graphics \
primitive.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[\ WindowPolygon];\)\), "\n", 
    \(\(WindowPolygon::"\<usage\>" = "\<WindowPolygon[p_Polygon, s] will cut \
a Polygon p open by the scale of 0<s<1. WindowPolygon[gra,s] will cut every \
Polygon in gra. Usage Example: \
Needs[\"Graphics`Shapes`\"];Show[Graphics3D[WindowPolygon[Sphere[1,10,8],.7]]]\
\>";\)\)}], "Input"],

Cell[BoxData[{
    \(\(WindowPolygon[\ poly_Polygon\ , scale_] := \ 
        Module[{centerP, pts1, pts2}, \n\t\tpts1 = First@\ poly; 
          centerP = \((Plus @@ pts1)\)/
              Length@pts1; \n\t\tpts2 = \(\((\((# - centerP)\) scale + 
                    centerP)\)\  &\) /@ \ pts1; 
          Polygon /@ \ 
            Thread[{pts1, RotateLeft[pts1], RotateLeft[pts2], 
                pts2}]];\)\), "\n", 
    \(\(WindowPolygon[\ g_, scale_] := 
        g /. l_Polygon :> WindowPolygon[l, scale];\)\)}], "Input"],

Cell["Now we apply it to the surface", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics3D@WindowPolygon[First@mySurface,  .7]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .97101 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00692488 1.0652 -1.66533e-16 1.0652 [
[ 0 0 0 0 ]
[ 1 .97101 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06678 .25008 m
0 .67149 L
s
0 .67149 m
.39925 .97101 L
s
.39925 .97101 m
.41257 .59009 L
s
.41257 .59009 m
.06678 .25008 L
s
.67926 0 m
.94495 .42182 L
s
.94495 .42182 m
1 .82462 L
s
1 .82462 m
.70489 .4415 L
s
.70489 .4415 m
.67926 0 L
s
.06678 .25008 m
0 .67149 L
s
0 .67149 m
.70489 .4415 L
s
.70489 .4415 m
.67926 0 L
s
.67926 0 m
.06678 .25008 L
s
.41257 .59009 m
.94495 .42182 L
s
.94495 .42182 m
1 .82462 L
s
1 .82462 m
.39925 .97101 L
s
.39925 .97101 m
.41257 .59009 L
s
0 0 m
1 0 L
1 .97101 L
0 .97101 L
closepath
clip
newpath
.5 Mabswid
.50762 .50444 m .5048 .52827 L .49718 .524 L p .529 .79 .993 r
F P
0 g
s
.45399 .51968 m .49718 .524 L .5048 .52827 L p .529 .79 .993 r
F P
0 g
s
.5048 .52827 m .44339 .52215 L .45399 .51968 L p .529 .79 .993 r
F P
0 g
s
.5144 .50793 m .51226 .52462 L .5048 .52827 L p .558 .816 .994 r
F P
0 g
s
.5048 .52827 m .50762 .50444 L .5144 .50793 L p .558 .816 .994 r
F P
0 g
s
.55849 .527 m .5048 .52827 L .51226 .52462 L p .558 .816 .994 r
F P
0 g
s
.54891 .50335 m .55849 .527 L .55002 .52373 L p .558 .816 .994 r
F P
0 g
s
.51226 .52462 m .55002 .52373 L .55849 .527 L p .558 .816 .994 r
F P
0 g
s
.55616 .50624 m .56274 .52282 L .55849 .527 L p .588 .835 .992 r
F P
0 g
s
.55849 .527 m .54891 .50335 L .55616 .50624 L p .588 .835 .992 r
F P
0 g
s
.60155 .52151 m .55849 .527 L .56274 .52282 L p .588 .835 .991 r
F P
0 g
s
.46067 .49984 m .44339 .52215 L .43757 .5168 L p .507 .758 .986 r
F P
0 g
s
.39246 .50546 m .43757 .5168 L .44339 .52215 L p .507 .758 .986 r
F P
0 g
s
.44339 .52215 m .3792 .50604 L .39246 .50546 L p .507 .758 .986 r
F P
0 g
s
.46626 .5041 m .45399 .51968 L .44339 .52215 L p .529 .79 .993 r
F P
0 g
s
.44339 .52215 m .46067 .49984 L .46626 .5041 L p .529 .79 .993 r
F P
0 g
s
.582 .49895 m .60155 .52151 L .59302 .51895 L p .588 .835 .991 r
F P
0 g
s
.56274 .52282 m .59302 .51895 L .60155 .52151 L p .588 .835 .991 r
F P
0 g
s
.58915 .50153 m .60275 .51735 L .60155 .52151 L p .613 .846 .988 r
F P
0 g
s
.60155 .52151 m .582 .49895 L .58915 .50153 L p .613 .846 .988 r
F P
0 g
s
.63247 .51488 m .60155 .52151 L .60275 .51735 L p .613 .847 .988 r
F P
0 g
s
.49718 .524 m .49897 .50729 L .50762 .50444 L p .529 .79 .993 r
F P
0 g
s
.55002 .52373 m .54316 .50717 L .54891 .50335 L p .558 .816 .994 r
F P
0 g
s
.60578 .49381 m .63247 .51488 L .62449 .51268 L p .612 .847 .988 r
F P
0 g
s
.60275 .51735 m .62449 .51268 L .63247 .51488 L p .613 .847 .988 r
F P
0 g
s
.61236 .49636 m .63099 .51113 L .63247 .51488 L p .63 .853 .984 r
F P
0 g
s
.63247 .51488 m .60578 .49381 L .61236 .49636 L p .63 .853 .984 r
F P
0 g
s
.65095 .5098 m .63247 .51488 L .63099 .51113 L p .63 .853 .984 r
F P
0 g
s
.59302 .51895 m .57921 .50318 L .582 .49895 L p .588 .835 .991 r
F P
0 g
s
.43757 .5168 m .44949 .50113 L .46067 .49984 L p .507 .758 .986 r
F P
0 g
s
.61995 .48983 m .65095 .5098 L .64398 .50755 L p .63 .853 .984 r
F P
0 g
s
.63099 .51113 m .64398 .50755 L .65095 .5098 L p .63 .853 .984 r
F P
0 g
s
.62554 .49264 m .64722 .50662 L .65095 .5098 L p .639 .856 .982 r
F P
0 g
s
.65095 .5098 m .61995 .48983 L .62554 .49264 L p .639 .856 .982 r
F P
0 g
s
.65711 .5079 m .65095 .5098 L .64722 .50662 L p .638 .856 .982 r
F P
0 g
s
.62449 .51268 m .60573 .49796 L .60578 .49381 L p .612 .847 .988 r
F P
0 g
s
.62465 .48832 m .65711 .5079 L .65155 .50529 L p .639 .856 .982 r
F P
0 g
s
.64722 .50662 m .65155 .50529 L .65711 .5079 L p .638 .856 .982 r
F P
0 g
s
.62465 .48832 m .65711 .5079 L .65316 .50477 L p .642 .857 .981 r
F P
0 g
s
.65745 .50337 m .65316 .50477 L .65711 .5079 L p .643 .857 .981 r
F P
0 g
s
.65711 .5079 m .66321 .50591 L .65745 .50337 L p .643 .857 .981 r
F P
0 g
s
.41191 .48764 m .3792 .50604 L .37616 .49982 L p .498 .725 .973 r
F P
0 g
s
.33352 .48056 m .37616 .49982 L .3792 .50604 L p .498 .725 .973 r
F P
0 g
s
.3792 .50604 m .31844 .47866 L .33352 .48056 L p .498 .725 .973 r
F P
0 g
s
.4155 .49264 m .39246 .50546 L .3792 .50604 L p .507 .758 .986 r
F P
0 g
s
.3792 .50604 m .41191 .48764 L .4155 .49264 L p .507 .758 .986 r
F P
0 g
s
.62935 .4868 m .66321 .50591 L .66058 .50228 L p .651 .859 .979 r
F P
0 g
s
.67298 .49779 m .66058 .50228 L .66321 .50591 L p .651 .859 .979 r
F P
0 g
s
.66321 .50591 m .68088 .49953 L .67298 .49779 L p .651 .859 .979 r
F P
0 g
s
.63374 .49001 m .65745 .50337 L .66321 .50591 L p .642 .857 .981 r
F P
0 g
s
.66321 .50591 m .62935 .4868 L .63374 .49001 L p .642 .857 .981 r
F P
0 g
s
.64398 .50755 m .62224 .4936 L .61995 .48983 L p .63 .853 .984 r
F P
0 g
s
.65155 .50529 m .62882 .49159 L .62465 .48832 L p .639 .856 .982 r
F P
0 g
s
.65316 .50477 m .63046 .49106 L .62465 .48832 L p .642 .857 .981 r
F P
0 g
s
.64286 .48185 m .68088 .49953 L .67891 .49537 L p .667 .862 .974 r
F P
0 g
s
.69824 .48694 m .67891 .49537 L .68088 .49953 L p .667 .862 .974 r
F P
0 g
s
.68088 .49953 m .70843 .48756 L .69824 .48694 L p .667 .862 .974 r
F P
0 g
s
.64633 .48543 m .67298 .49779 L .68088 .49953 L p .651 .859 .979 r
F P
0 g
s
.68088 .49953 m .64286 .48185 L .64633 .48543 L p .651 .859 .979 r
F P
0 g
s
.66058 .50228 m .63691 .48888 L .62935 .4868 L p .651 .859 .979 r
F P
0 g
s
.37616 .49982 m .39894 .48684 L .41191 .48764 L p .498 .725 .973 r
F P
0 g
s
.67891 .49537 m .65235 .48295 L .64286 .48185 L p .667 .862 .974 r
F P
0 g
s
.66384 .47251 m .70843 .48756 L .70636 .48283 L p .689 .863 .965 r
F P
0 g
s
.7304 .46921 m .70636 .48283 L .70843 .48756 L p .689 .864 .965 r
F P
0 g
s
.70843 .48756 m .74272 .46819 L .7304 .46921 L p .689 .864 .965 r
F P
0 g
s
.667 .47645 m .69824 .48694 L .70843 .48756 L p .667 .862 .974 r
F P
0 g
s
.70843 .48756 m .66384 .47251 L .667 .47645 L p .667 .862 .974 r
F P
0 g
s
.54316 .50717 m .5144 .50793 L .50762 .50444 L p .558 .816 .994 r
F P
0 g
s
.49897 .50729 m .46626 .5041 L .46067 .49984 L p .529 .79 .993 r
F P
0 g
s
.46067 .49984 m .50762 .50444 L .49897 .50729 L p .529 .79 .993 r
F P
0 g
s
.50762 .50444 m .54891 .50335 L .54316 .50717 L p .558 .816 .994 r
F P
0 g
s
.57921 .50318 m .55616 .50624 L .54891 .50335 L p .589 .835 .991 r
F P
0 g
s
.36639 .46695 m .31844 .47866 L .31901 .47205 L p .504 .694 .954 r
F P
0 g
s
.28351 .44522 m .31901 .47205 L .31844 .47866 L p .504 .694 .954 r
F P
0 g
s
.31844 .47866 m .26772 .44047 L .28351 .44522 L p .504 .694 .954 r
F P
0 g
s
.36716 .47244 m .33352 .48056 L .31844 .47866 L p .498 .725 .973 r
F P
0 g
s
.31844 .47866 m .36639 .46695 L .36716 .47244 L p .498 .725 .973 r
F P
0 g
s
.70636 .48283 m .67519 .47224 L .66384 .47251 L p .689 .863 .965 r
F P
0 g
s
.54891 .50335 m .582 .49895 L .57921 .50318 L p .589 .835 .991 r
F P
0 g
s
.44949 .50113 m .4155 .49264 L .41191 .48764 L p .507 .758 .986 r
F P
0 g
s
.41191 .48764 m .46067 .49984 L .44949 .50113 L p .507 .758 .986 r
F P
0 g
s
.60573 .49796 m .58915 .50153 L .582 .49895 L p .612 .846 .988 r
F P
0 g
s
.50879 .49308 m .50762 .50444 L .50154 .50217 L p .402 .778 .992 r
F P
0 g
s
.46856 .49894 m .50154 .50217 L .50762 .50444 L p .401 .777 .992 r
F P
0 g
s
.50762 .50444 m .46067 .49984 L .46856 .49894 L p .401 .777 .992 r
F P
0 g
s
.51422 .49466 m .5133 .50262 L .50762 .50444 L p .449 .819 .993 r
F P
0 g
s
.50762 .50444 m .50879 .49308 L .51422 .49466 L p .449 .819 .993 r
F P
0 g
s
.54891 .50335 m .50762 .50444 L .5133 .50262 L p .449 .819 .993 r
F P
0 g
s
.54157 .49214 m .54891 .50335 L .54231 .50185 L p .448 .818 .993 r
F P
0 g
s
.5133 .50262 m .54231 .50185 L .54891 .50335 L p .449 .819 .993 r
F P
0 g
s
.54719 .49324 m .55225 .5011 L .54891 .50335 L p .502 .853 .993 r
F P
0 g
s
.54891 .50335 m .54157 .49214 L .54719 .49324 L p .502 .853 .993 r
F P
0 g
s
.582 .49895 m .54891 .50335 L .55225 .5011 L p .502 .852 .993 r
F P
0 g
s
.582 .49895 m .60578 .49381 L .60573 .49796 L p .612 .846 .988 r
F P
0 g
s
.62224 .4936 m .61236 .49636 L .60578 .49381 L p .63 .853 .984 r
F P
0 g
s
.47164 .48963 m .46067 .49984 L .45583 .49673 L p .37 .732 .989 r
F P
0 g
s
.4216 .48816 m .45583 .49673 L .46067 .49984 L p .371 .732 .989 r
F P
0 g
s
.46067 .49984 m .41191 .48764 L .4216 .48816 L p .371 .732 .989 r
F P
0 g
s
.47634 .4918 m .46856 .49894 L .46067 .49984 L p .4 .778 .992 r
F P
0 g
s
.46067 .49984 m .47164 .48963 L .47634 .4918 L p .4 .778 .992 r
F P
0 g
s
.68983 .45766 m .74272 .46819 L .73965 .46298 L p .714 .861 .952 r
F P
0 g
s
.76502 .44311 m .73965 .46298 L .74272 .46819 L p .714 .861 .952 r
F P
0 g
s
.74272 .46819 m .77897 .43992 L .76502 .44311 L p .714 .861 .952 r
F P
0 g
s
.69336 .46189 m .7304 .46921 L .74272 .46819 L p .689 .864 .965 r
F P
0 g
s
.74272 .46819 m .68983 .45766 L .69336 .46189 L p .689 .864 .965 r
F P
0 g
s
.31901 .47205 m .35256 .46375 L .36639 .46695 L p .504 .694 .954 r
F P
0 g
s
.56795 .48849 m .582 .49895 L .57549 .49801 L p .503 .853 .993 r
F P
0 g
s
.55225 .5011 m .57549 .49801 L .582 .49895 L p .502 .852 .993 r
F P
0 g
s
.57332 .48939 m .58311 .49672 L .582 .49895 L p .544 .873 .992 r
F P
0 g
s
.582 .49895 m .56795 .48849 L .57332 .48939 L p .544 .873 .992 r
F P
0 g
s
.60578 .49381 m .582 .49895 L .58311 .49672 L p .544 .874 .992 r
F P
0 g
s
.50154 .50217 m .50226 .49421 L .50879 .49308 L p .402 .778 .992 r
F P
0 g
s
.60578 .49381 m .61995 .48983 L .62224 .4936 L p .63 .853 .984 r
F P
0 g
s
.54231 .50185 m .53708 .49401 L .54157 .49214 L p .448 .818 .993 r
F P
0 g
s
.62882 .49159 m .62554 .49264 L .61995 .48983 L p .641 .856 .982 r
F P
0 g
s
.61995 .48983 m .62465 .48832 L .62882 .49159 L p .641 .856 .982 r
F P
0 g
s
.63046 .49106 m .63374 .49001 L .62935 .4868 L p .641 .856 .982 r
F P
0 g
s
.62935 .4868 m .62465 .48832 L .63046 .49106 L p .641 .856 .982 r
F P
0 g
s
.58691 .48434 m .60578 .49381 L .59981 .49311 L p .543 .873 .992 r
F P
0 g
s
.58311 .49672 m .59981 .49311 L .60578 .49381 L p .544 .874 .992 r
F P
0 g
s
.59172 .48524 m .6049 .49189 L .60578 .49381 L p .576 .887 .99 r
F P
0 g
s
.60578 .49381 m .58691 .48434 L .59172 .48524 L p .576 .887 .99 r
F P
0 g
s
.61995 .48983 m .60578 .49381 L .6049 .49189 L p .576 .887 .99 r
F P
0 g
s
.57549 .49801 m .56559 .4907 L .56795 .48849 L p .503 .853 .993 r
F P
0 g
s
.63691 .48888 m .64633 .48543 L .64286 .48185 L p .651 .859 .979 r
F P
0 g
s
.64286 .48185 m .62935 .4868 L .63691 .48888 L p .651 .859 .979 r
F P
0 g
s
.45583 .49673 m .46342 .48955 L .47164 .48963 L p .37 .732 .989 r
F P
0 g
s
.39894 .48684 m .36716 .47244 L .36639 .46695 L p .498 .725 .973 r
F P
0 g
s
.36639 .46695 m .41191 .48764 L .39894 .48684 L p .498 .725 .973 r
F P
0 g
s
.73965 .46298 m .70264 .45553 L .68983 .45766 L p .714 .861 .952 r
F P
0 g
s
.59825 .48115 m .61995 .48983 L .61485 .48909 L p .576 .887 .99 r
F P
0 g
s
.6049 .49189 m .61485 .48909 L .61995 .48983 L p .576 .887 .99 r
F P
0 g
s
.60221 .48227 m .61739 .48835 L .61995 .48983 L p .595 .894 .989 r
F P
0 g
s
.61995 .48983 m .59825 .48115 L .60221 .48227 L p .595 .894 .989 r
F P
0 g
s
.62465 .48832 m .61995 .48983 L .61739 .48835 L p .595 .894 .989 r
F P
0 g
s
.43341 .48013 m .41191 .48764 L .4091 .48383 L p .371 .69 .981 r
F P
0 g
s
.37718 .46929 m .4091 .48383 L .41191 .48764 L p .371 .69 .981 r
F P
0 g
s
.41191 .48764 m .36639 .46695 L .37718 .46929 L p .371 .69 .981 r
F P
0 g
s
.43674 .48293 m .4216 .48816 L .41191 .48764 L p .372 .732 .99 r
F P
0 g
s
.41191 .48764 m .43341 .48013 L .43674 .48293 L p .372 .732 .99 r
F P
0 g
s
.59981 .49311 m .58655 .48649 L .58691 .48434 L p .543 .873 .992 r
F P
0 g
s
.602 .47993 m .62465 .48832 L .62194 .48688 L p .595 .894 .989 r
F P
0 g
s
.62524 .48582 m .62194 .48688 L .62465 .48832 L p .595 .894 .989 r
F P
0 g
s
.62465 .48832 m .62935 .4868 L .62524 .48582 L p .595 .894 .989 r
F P
0 g
s
.602 .47993 m .62465 .48832 L .62068 .48729 L p .595 .894 .989 r
F P
0 g
s
.61739 .48835 m .62068 .48729 L .62465 .48832 L p .595 .894 .989 r
F P
0 g
s
.65235 .48295 m .667 .47645 L .66384 .47251 L p .668 .862 .973 r
F P
0 g
s
.66384 .47251 m .64286 .48185 L .65235 .48295 L p .668 .862 .973 r
F P
0 g
s
.60575 .47871 m .62935 .4868 L .62768 .48495 L p .614 .9 .987 r
F P
0 g
s
.63716 .48147 m .62768 .48495 L .62935 .4868 L p .613 .9 .987 r
F P
0 g
s
.62935 .4868 m .64286 .48185 L .63716 .48147 L p .613 .9 .987 r
F P
0 g
s
.60872 .48015 m .62524 .48582 L .62935 .4868 L p .595 .894 .989 r
F P
0 g
s
.62935 .4868 m .60575 .47871 L .60872 .48015 L p .595 .894 .989 r
F P
0 g
s
.61485 .48909 m .59964 .48302 L .59825 .48115 L p .576 .887 .99 r
F P
0 g
s
.62068 .48729 m .60482 .48142 L .602 .47993 L p .595 .894 .989 r
F P
0 g
s
.62194 .48688 m .6061 .481 L .602 .47993 L p .595 .894 .989 r
F P
0 g
s
.61651 .4747 m .64286 .48185 L .64178 .47955 L p .644 .907 .982 r
F P
0 g
s
.6565 .47299 m .64178 .47955 L .64286 .48185 L p .644 .907 .982 r
F P
0 g
s
.64286 .48185 m .66384 .47251 L .6565 .47299 L p .644 .907 .982 r
F P
0 g
s
.6187 .47647 m .63716 .48147 L .64286 .48185 L p .614 .9 .987 r
F P
0 g
s
.64286 .48185 m .61651 .4747 L .6187 .47647 L p .614 .9 .987 r
F P
0 g
s
.4091 .48383 m .42409 .47852 L .43341 .48013 L p .371 .69 .981 r
F P
0 g
s
.62768 .48495 m .61119 .47927 L .60575 .47871 L p .614 .9 .987 r
F P
0 g
s
.67519 .47224 m .69336 .46189 L .68983 .45766 L p .689 .864 .965 r
F P
0 g
s
.68983 .45766 m .66384 .47251 L .67519 .47224 L p .689 .864 .965 r
F P
0 g
s
.64178 .47955 m .62337 .47452 L .61651 .4747 L p .644 .907 .982 r
F P
0 g
s
.32654 .44381 m .28351 .44522 L .26772 .44047 L p .504 .694 .954 r
F P
0 g
s
.32923 .43835 m .26772 .44047 L .27245 .43423 L p .521 .669 .93 r
F P
0 g
s
.24842 .4016 m .27245 .43423 L .26772 .44047 L p .521 .669 .93 r
F P
0 g
s
.26772 .44047 m .23321 .39395 L .24842 .4016 L p .521 .669 .93 r
F P
0 g
s
.26772 .44047 m .32923 .43835 L .32654 .44381 L p .504 .694 .954 r
F P
0 g
s
.63326 .46721 m .66384 .47251 L .6628 .46975 L p .68 .912 .974 r
F P
0 g
s
.68102 .45933 m .6628 .46975 L .66384 .47251 L p .68 .912 .974 r
F P
0 g
s
.66384 .47251 m .68983 .45766 L .68102 .45933 L p .68 .912 .974 r
F P
0 g
s
.63507 .4693 m .6565 .47299 L .66384 .47251 L p .644 .907 .982 r
F P
0 g
s
.66384 .47251 m .63326 .46721 L .63507 .4693 L p .644 .907 .982 r
F P
0 g
s
.71708 .43604 m .77897 .43992 L .77398 .43445 L p .737 .851 .934 r
F P
0 g
s
.79638 .40773 m .77398 .43445 L .77897 .43992 L p .737 .851 .934 r
F P
0 g
s
.77897 .43992 m .81108 .40185 L .79638 .40773 L p .737 .851 .934 r
F P
0 g
s
.72172 .44045 m .76502 .44311 L .77897 .43992 L p .714 .861 .952 r
F P
0 g
s
.77897 .43992 m .71708 .43604 L .72172 .44045 L p .714 .861 .952 r
F P
0 g
s
.53708 .49401 m .51422 .49466 L .50879 .49308 L p .448 .818 .993 r
F P
0 g
s
.35256 .46375 m .32654 .44381 L .32923 .43835 L p .504 .694 .954 r
F P
0 g
s
.32923 .43835 m .36639 .46695 L .35256 .46375 L p .504 .694 .954 r
F P
0 g
s
.50226 .49421 m .47634 .4918 L .47164 .48963 L p .401 .778 .992 r
F P
0 g
s
.47164 .48963 m .50879 .49308 L .50226 .49421 L p .401 .778 .992 r
F P
0 g
s
.50879 .49308 m .54157 .49214 L .53708 .49401 L p .448 .818 .993 r
F P
0 g
s
.39814 .46417 m .36639 .46695 L .36625 .46281 L p .398 .654 .961 r
F P
0 g
s
.34024 .44275 m .36625 .46281 L .36639 .46695 L p .398 .654 .961 r
F P
0 g
s
.36639 .46695 m .32923 .43835 L .34024 .44275 L p .398 .654 .961 r
F P
0 g
s
.39945 .46739 m .37718 .46929 L .36639 .46695 L p .37 .69 .981 r
F P
0 g
s
.36639 .46695 m .39814 .46417 L .39945 .46739 L p .37 .69 .981 r
F P
0 g
s
.56559 .4907 m .54719 .49324 L .54157 .49214 L p .503 .853 .993 r
F P
0 g
s
.46342 .48955 m .43674 .48293 L .43341 .48013 L p .371 .732 .989 r
F P
0 g
s
.43341 .48013 m .47164 .48963 L .46342 .48955 L p .371 .732 .989 r
F P
0 g
s
.54157 .49214 m .56795 .48849 L .56559 .4907 L p .503 .853 .993 r
F P
0 g
s
.6628 .46975 m .64142 .46601 L .63326 .46721 L p .68 .912 .974 r
F P
0 g
s
.50849 .49 m .50879 .49308 L .50371 .49216 L p .133 .662 .869 r
F P
0 g
s
.47764 .48974 m .50371 .49216 L .50879 .49308 L p .134 .663 .87 r
F P
0 g
s
.50879 .49308 m .47164 .48963 L .47764 .48974 L p .134 .663 .87 r
F P
0 g
s
.51306 .49032 m .51322 .49248 L .50879 .49308 L p .211 .728 .873 r
F P
0 g
s
.50879 .49308 m .50849 .49 L .51306 .49032 L p .211 .728 .873 r
F P
0 g
s
.54157 .49214 m .50879 .49308 L .51322 .49248 L p .213 .728 .876 r
F P
0 g
s
.58655 .48649 m .57332 .48939 L .56795 .48849 L p .543 .873 .992 r
F P
0 g
s
.27245 .43423 m .31559 .43267 L .32923 .43835 L p .521 .669 .93 r
F P
0 g
s
.53565 .48904 m .54157 .49214 L .53622 .49182 L p .219 .732 .879 r
F P
0 g
s
.51322 .49248 m .53622 .49182 L .54157 .49214 L p .213 .728 .876 r
F P
0 g
s
.5402 .48902 m .5443 .49119 L .54157 .49214 L p .308 .794 .894 r
F P
0 g
s
.54157 .49214 m .53565 .48904 L .5402 .48902 L p .308 .794 .894 r
F P
0 g
s
.56795 .48849 m .54157 .49214 L .5443 .49119 L p .307 .794 .892 r
F P
0 g
s
.77398 .43445 m .7306 .43165 L .71708 .43604 L p .737 .851 .934 r
F P
0 g
s
.47801 .48723 m .47164 .48963 L .46743 .488 L p .095 .609 .888 r
F P
0 g
s
.44061 .48133 m .46743 .488 L .47164 .48963 L p .095 .609 .888 r
F P
0 g
s
.47164 .48963 m .43341 .48013 L .44061 .48133 L p .095 .609 .888 r
F P
0 g
s
.48215 .48806 m .47764 .48974 L .47164 .48963 L p .134 .663 .87 r
F P
0 g
s
.47164 .48963 m .47801 .48723 L .48215 .48806 L p .134 .663 .87 r
F P
0 g
s
.52064 .68162 m .52033 .69949 L .52403 .70358 L p .625 .743 .932 r
F P
0 g
s
.52403 .70358 m .52454 .67805 L .52064 .68162 L p .625 .743 .932 r
F P
0 g
s
.49651 .70167 m .52403 .70358 L .52033 .69949 L p .633 .746 .929 r
F P
0 g
s
.55083 .7001 m .52847 .6999 L .52403 .70358 L p .632 .753 .935 r
F P
0 g
s
.52403 .70358 m .55589 .70386 L .55083 .7001 L p .632 .753 .935 r
F P
0 g
s
.52454 .67805 m .52403 .70358 L .52847 .6999 L p .629 .746 .932 r
F P
0 g
s
.56795 .48849 m .58691 .48434 L .58655 .48649 L p .543 .873 .992 r
F P
0 g
s
.4976 .67923 m .4942 .69742 L .49651 .70167 L p .628 .737 .926 r
F P
0 g
s
.49651 .70167 m .50141 .67569 L .4976 .67923 L p .628 .737 .926 r
F P
0 g
s
.47441 .699 m .49651 .70167 L .4942 .69742 L p .635 .741 .924 r
F P
0 g
s
.52033 .69949 m .50101 .69815 L .49651 .70167 L p .633 .746 .929 r
F P
0 g
s
.50141 .67569 m .49651 .70167 L .50101 .69815 L p .63 .739 .926 r
F P
0 g
s
.70264 .45553 m .72172 .44045 L .71708 .43604 L p .714 .861 .951 r
F P
0 g
s
.71708 .43604 m .68983 .45766 L .70264 .45553 L p .714 .861 .951 r
F P
0 g
s
.36625 .46281 m .38846 .46081 L .39814 .46417 L p .398 .654 .961 r
F P
0 g
s
.59964 .48302 m .59172 .48524 L .58691 .48434 L p .575 .887 .99 r
F P
0 g
s
.54754 .68272 m .55083 .7001 L .55589 .70386 L p .624 .751 .938 r
F P
0 g
s
.55589 .70386 m .55126 .67903 L .54754 .68272 L p .624 .751 .938 r
F P
0 g
s
.58456 .69847 m .55999 .69995 L .55589 .70386 L p .633 .761 .939 r
F P
0 g
s
.55589 .70386 m .59089 .70176 L .58456 .69847 L p .633 .761 .939 r
F P
0 g
s
.55126 .67903 m .55589 .70386 L .55999 .69995 L p .631 .756 .937 r
F P
0 g
s
.4793 .67643 m .47343 .69475 L .47441 .699 L p .632 .733 .921 r
F P
0 g
s
.47441 .699 m .48284 .67284 L .4793 .67643 L p .632 .733 .921 r
F P
0 g
s
.45814 .69643 m .47441 .699 L .47343 .69475 L p .639 .738 .92 r
F P
0 g
s
.4942 .69742 m .47869 .69555 L .47441 .699 L p .635 .741 .924 r
F P
0 g
s
.48284 .67284 m .47441 .699 L .47869 .69555 L p .632 .734 .921 r
F P
0 g
s
.50371 .49216 m .50343 .49 L .50849 .49 L p .133 .662 .869 r
F P
0 g
s
.55766 .48609 m .56795 .48849 L .56281 .48863 L p .301 .79 .889 r
F P
0 g
s
.5443 .49119 m .56281 .48863 L .56795 .48849 L p .307 .794 .892 r
F P
0 g
s
.56185 .48587 m .56902 .48756 L .56795 .48849 L p .381 .839 .905 r
F P
0 g
s
.56795 .48849 m .55766 .48609 L .56185 .48587 L p .381 .839 .905 r
F P
0 g
s
.58691 .48434 m .56795 .48849 L .56902 .48756 L p .38 .838 .906 r
F P
0 g
s
.53622 .49182 m .53202 .48966 L .53565 .48904 L p .219 .732 .879 r
F P
0 g
s
.65395 .45542 m .68983 .45766 L .68816 .45446 L p .724 .911 .959 r
F P
0 g
s
.70723 .43929 m .68816 .45446 L .68983 .45766 L p .723 .911 .959 r
F P
0 g
s
.68983 .45766 m .71708 .43604 L .70723 .43929 L p .723 .911 .959 r
F P
0 g
s
.65588 .45778 m .68102 .45933 L .68983 .45766 L p .68 .913 .974 r
F P
0 g
s
.68983 .45766 m .65395 .45542 L .65588 .45778 L p .68 .913 .974 r
F P
0 g
s
.58691 .48434 m .59825 .48115 L .59964 .48302 L p .575 .887 .99 r
F P
0 g
s
.46619 .67388 m .45843 .69227 L .45814 .69643 L p .635 .731 .917 r
F P
0 g
s
.45814 .69643 m .46925 .67016 L .46619 .67388 L p .635 .731 .917 r
F P
0 g
s
.44826 .69459 m .45814 .69643 L .45843 .69227 L p .641 .736 .918 r
F P
0 g
s
.47343 .69475 m .46201 .69294 L .45814 .69643 L p .639 .738 .92 r
F P
0 g
s
.46925 .67016 m .45814 .69643 L .46201 .69294 L p .635 .731 .917 r
F P
0 g
s
.60482 .48142 m .60221 .48227 L .59825 .48115 L p .595 .894 .989 r
F P
0 g
s
.52847 .6999 m .52889 .68203 L .52454 .67805 L p .629 .746 .932 r
F P
0 g
s
.45509 .6721 m .44584 .69048 L .44426 .69447 L p .634 .724 .913 r
F P
0 g
s
.44426 .69447 m .45747 .66821 L .45509 .6721 L p .634 .724 .913 r
F P
0 g
s
.44154 .69376 m .44426 .69447 L .44584 .69048 L p .64 .732 .915 r
F P
0 g
s
.50101 .69815 m .50449 .67997 L .50141 .67569 L p .63 .739 .926 r
F P
0 g
s
.45865 .67224 m .44975 .69064 L .44826 .69459 L p .633 .725 .914 r
F P
0 g
s
.44826 .69459 m .46097 .66831 L .45865 .67224 L p .633 .725 .914 r
F P
0 g
s
.44542 .69412 m .44826 .69459 L .44975 .69064 L p .64 .732 .915 r
F P
0 g
s
.45843 .69227 m .45149 .69098 L .44826 .69459 L p .641 .736 .918 r
F P
0 g
s
.46097 .66831 m .44826 .69459 L .45149 .69098 L p .637 .73 .915 r
F P
0 g
s
.59825 .48115 m .602 .47993 L .60482 .48142 L p .595 .894 .989 r
F P
0 g
s
.44975 .69064 m .44776 .69031 L .44542 .69412 L p .64 .732 .915 r
F P
0 g
s
.45865 .66785 m .44542 .69412 L .44776 .69031 L p .634 .724 .913 r
F P
0 g
s
.5773 .68173 m .58456 .69847 L .59089 .70176 L p .627 .76 .942 r
F P
0 g
s
.59089 .70176 m .5806 .67783 L .5773 .68173 L p .627 .76 .942 r
F P
0 g
s
.61994 .69392 m .59436 .69755 L .59089 .70176 L p .639 .769 .942 r
F P
0 g
s
.59089 .70176 m .62736 .6966 L .61994 .69392 L p .639 .769 .942 r
F P
0 g
s
.5806 .67783 m .59089 .70176 L .59436 .69755 L p .637 .765 .941 r
F P
0 g
s
.46743 .488 m .47183 .4863 L .47801 .48723 L p .095 .609 .888 r
F P
0 g
s
.45183 .67118 m .44223 .68957 L .44154 .69376 L p .639 .729 .914 r
F P
0 g
s
.44154 .69376 m .45527 .6675 L .45183 .67118 L p .639 .729 .914 r
F P
0 g
s
.43178 .69163 m .44154 .69376 L .44223 .68957 L p .644 .734 .914 r
F P
0 g
s
.44584 .69048 m .44394 .68998 L .44154 .69376 L p .64 .732 .915 r
F P
0 g
s
.45527 .6675 m .44154 .69376 L .44394 .68998 L p .635 .724 .912 r
F P
0 g
s
.6061 .481 m .60872 .48015 L .60575 .47871 L p .595 .894 .989 r
F P
0 g
s
.60575 .47871 m .602 .47993 L .6061 .481 L p .595 .894 .989 r
F P
0 g
s
.42409 .47852 m .39945 .46739 L .39814 .46417 L p .371 .69 .981 r
F P
0 g
s
.39814 .46417 m .43341 .48013 L .42409 .47852 L p .371 .69 .981 r
F P
0 g
s
.47869 .69555 m .48463 .67724 L .48284 .67284 L p .632 .734 .921 r
F P
0 g
s
.56281 .48863 m .55557 .48695 L .55766 .48609 L p .301 .79 .889 r
F P
0 g
s
.55999 .69995 m .55682 .68256 L .55126 .67903 L p .631 .756 .937 r
F P
0 g
s
.57351 .48252 m .58691 .48434 L .58232 .48465 L p .384 .84 .908 r
F P
0 g
s
.56902 .48756 m .58232 .48465 L .58691 .48434 L p .38 .838 .906 r
F P
0 g
s
.57712 .48235 m .58648 .48363 L .58691 .48434 L p .44 .871 .919 r
F P
0 g
s
.58691 .48434 m .57351 .48252 L .57712 .48235 L p .44 .871 .919 r
F P
0 g
s
.59825 .48115 m .58691 .48434 L .58648 .48363 L p .439 .871 .919 r
F P
0 g
s
.4426 .66882 m .43189 .68718 L .43178 .69163 L p .641 .728 .912 r
F P
0 g
s
.43178 .69163 m .4471 .6654 L .4426 .66882 L p .641 .728 .912 r
F P
0 g
s
.41605 .68773 m .43178 .69163 L .43189 .68718 L p .647 .733 .912 r
F P
0 g
s
.44223 .68957 m .43538 .68806 L .43178 .69163 L p .644 .734 .914 r
F P
0 g
s
.4471 .6654 m .43178 .69163 L .43538 .68806 L p .641 .728 .911 r
F P
0 g
s
.61119 .47927 m .6187 .47647 L .61651 .4747 L p .614 .9 .986 r
F P
0 g
s
.61651 .4747 m .60575 .47871 L .61119 .47927 L p .614 .9 .986 r
F P
0 g
s
.46201 .69294 m .46981 .67456 L .46925 .67016 L p .635 .731 .917 r
F P
0 g
s
.44697 .47958 m .43341 .48013 L .4307 .47791 L p .121 .577 .92 r
F P
0 g
s
.40598 .46672 m .4307 .47791 L .43341 .48013 L p .122 .577 .92 r
F P
0 g
s
.43341 .48013 m .39814 .46417 L .40598 .46672 L p .122 .577 .92 r
F P
0 g
s
.45015 .48096 m .44061 .48133 L .43341 .48013 L p .095 .609 .888 r
F P
0 g
s
.44697 .47958 m .44429 .47837 L p .44436 .4784 L 0 .29 .646 r
F P
0 g
s
.44697 .47958 m .45015 .48096 L p .45 .48096 L .095 .609 .888 r
F P
0 g
s
.47183 .4863 m .45015 .48096 L .44697 .47958 L p .095 .609 .888 r
F P
0 g
s
.44697 .47958 m .47801 .48723 L .47183 .4863 L p .095 .609 .888 r
F P
0 g
s
.47801 .48723 m .44697 .47958 L .45244 .48117 L p .312 0 0 r
F P
0 g
s
.44697 .47958 m .45492 .48315 L .45804 .48368 L p .314 0 0 r
F P
0 g
s
.45492 .48315 m .44697 .47958 L p .44436 .4784 L 0 .29 .646 r
F P
0 g
s
.43341 .48013 m .44697 .47958 L p .45 .48096 L .095 .609 .888 r
F P
0 g
s
.45149 .69098 m .46041 .67259 L .46097 .66831 L p .637 .73 .915 r
F P
0 g
s
.44776 .69031 m .45703 .67192 L .45865 .66785 L p .634 .724 .913 r
F P
0 g
s
.44394 .68998 m .45355 .6716 L .45527 .6675 L p .635 .724 .912 r
F P
0 g
s
.58302 .47981 m .59825 .48115 L .59444 .48139 L p .441 .871 .92 r
F P
0 g
s
.58648 .48363 m .59444 .48139 L .59825 .48115 L p .439 .871 .919 r
F P
0 g
s
.58586 .47984 m .59652 .48078 L .59825 .48115 L p .477 .889 .926 r
F P
0 g
s
.59825 .48115 m .58302 .47981 L .58586 .47984 L p .477 .889 .926 r
F P
0 g
s
.602 .47993 m .59825 .48115 L .59652 .48078 L p .477 .889 .926 r
F P
0 g
s
.42837 .66475 m .41586 .68301 L .41605 .68773 L p .646 .728 .909 r
F P
0 g
s
.41605 .68773 m .43396 .66168 L .42837 .66475 L p .646 .728 .909 r
F P
0 g
s
.39529 .68176 m .41605 .68773 L .41586 .68301 L p .652 .733 .909 r
F P
0 g
s
.43189 .68718 m .42086 .68444 L .41605 .68773 L p .647 .733 .912 r
F P
0 g
s
.43396 .66168 m .41605 .68773 L .42086 .68444 L p .645 .727 .908 r
F P
0 g
s
.58232 .48465 m .57292 .48338 L .57351 .48252 L p .384 .84 .908 r
F P
0 g
s
.68816 .45446 m .66304 .45285 L .65395 .45542 L p .724 .911 .959 r
F P
0 g
s
.59436 .69755 m .58721 .68079 L .5806 .67783 L p .637 .765 .941 r
F P
0 g
s
.58617 .47878 m .602 .47993 L .60017 .47959 L p .477 .889 .926 r
F P
0 g
s
.60281 .47873 m .60017 .47959 L .602 .47993 L p .477 .889 .926 r
F P
0 g
s
.602 .47993 m .60575 .47871 L .60281 .47873 L p .477 .889 .926 r
F P
0 g
s
.58617 .47878 m .602 .47993 L .59914 .47992 L p .477 .889 .926 r
F P
0 g
s
.59652 .48078 m .59914 .47992 L .602 .47993 L p .477 .889 .926 r
F P
0 g
s
.43538 .68806 m .44612 .66971 L .4471 .6654 L p .641 .728 .911 r
F P
0 g
s
.62337 .47452 m .63507 .4693 L .63326 .46721 L p .644 .907 .982 r
F P
0 g
s
.63326 .46721 m .61651 .4747 L .62337 .47452 L p .644 .907 .982 r
F P
0 g
s
.60857 .67805 m .61994 .69392 L .62736 .6966 L p .635 .769 .944 r
F P
0 g
s
.62736 .6966 m .61118 .6739 L .60857 .67805 L p .635 .769 .944 r
F P
0 g
s
.65531 .68612 m .62991 .69209 L .62736 .6966 L p .647 .775 .942 r
F P
0 g
s
.62736 .6966 m .66357 .68811 L .65531 .68612 L p .647 .775 .942 r
F P
0 g
s
.61118 .6739 m .62736 .6966 L .62991 .69209 L p .646 .774 .941 r
F P
0 g
s
.58932 .47775 m .60575 .47871 L .6048 .47802 L p .512 .906 .932 r
F P
0 g
s
.61234 .47521 m .6048 .47802 L .60575 .47871 L p .513 .906 .932 r
F P
0 g
s
.60575 .47871 m .61651 .4747 L .61234 .47521 L p .513 .906 .932 r
F P
0 g
s
.5913 .47807 m .60281 .47873 L .60575 .47871 L p .477 .889 .926 r
F P
0 g
s
.60575 .47871 m .58932 .47775 L .5913 .47807 L p .477 .889 .926 r
F P
0 g
s
.59444 .48139 m .58377 .48046 L .58302 .47981 L p .441 .871 .92 r
F P
0 g
s
.42086 .68444 m .43342 .66622 L .43396 .66168 L p .645 .727 .908 r
F P
0 g
s
.4307 .47791 m .44015 .47751 L .44697 .47958 L p .121 .577 .92 r
F P
0 g
s
.41586 .68301 m .4013 .67881 L .39529 .68176 L p .652 .733 .909 r
F P
0 g
s
.59914 .47992 m .58806 .47912 L .58617 .47878 L p .477 .889 .926 r
F P
0 g
s
.40996 .65865 m .39505 .67672 L .39529 .68176 L p .652 .728 .905 r
F P
0 g
s
.39529 .68176 m .41662 .65597 L .40996 .65865 L p .652 .728 .905 r
F P
0 g
s
.37046 .67321 m .39529 .68176 L .39505 .67672 L p .658 .733 .905 r
F P
0 g
s
.41662 .65597 m .39529 .68176 L .4013 .67881 L p .65 .726 .904 r
F P
0 g
s
.60017 .47959 m .5891 .47878 L .58617 .47878 L p .477 .889 .926 r
F P
0 g
s
.59836 .4744 m .61651 .4747 L .61612 .47364 L p .565 .927 .939 r
F P
0 g
s
.62787 .46838 m .61612 .47364 L .61651 .4747 L p .566 .928 .938 r
F P
0 g
s
.61651 .4747 m .63326 .46721 L .62787 .46838 L p .566 .928 .938 r
F P
0 g
s
.59962 .475 m .61234 .47521 L .61651 .4747 L p .512 .905 .931 r
F P
0 g
s
.61651 .4747 m .59836 .4744 L .59962 .475 L p .512 .905 .931 r
F P
0 g
s
.6048 .47802 m .59331 .47734 L .58932 .47775 L p .512 .906 .932 r
F P
0 g
s
.62991 .69209 m .61863 .67618 L .61118 .6739 L p .646 .774 .941 r
F P
0 g
s
.4013 .67881 m .41626 .66078 L .41662 .65597 L p .65 .726 .904 r
F P
0 g
s
.64142 .46601 m .65588 .45778 L .65395 .45542 L p .679 .912 .974 r
F P
0 g
s
.65395 .45542 m .63326 .46721 L .64142 .46601 L p .679 .912 .974 r
F P
0 g
s
.36874 .44548 m .34024 .44275 L .32923 .43835 L p .398 .654 .961 r
F P
0 g
s
.36997 .44221 m .32923 .43835 L .33216 .43445 L p .442 .628 .932 r
F P
0 g
s
.31528 .41028 m .33216 .43445 L .32923 .43835 L p .442 .628 .932 r
F P
0 g
s
.32923 .43835 m .30504 .40386 L .31528 .41028 L p .442 .628 .932 r
F P
0 g
s
.32923 .43835 m .36997 .44221 L .36874 .44548 L p .398 .654 .961 r
F P
0 g
s
.30504 .40386 m .32923 .43835 L .31559 .43267 L p .521 .669 .93 r
F P
0 g
s
.39505 .67672 m .37765 .67071 L .37046 .67321 L p .658 .733 .905 r
F P
0 g
s
.31559 .43267 m .29857 .40857 L .30504 .40386 L p .521 .669 .93 r
F P
0 g
s
.61612 .47364 m .60343 .47341 L .59836 .4744 L p .565 .927 .939 r
F P
0 g
s
.63977 .67127 m .65531 .68612 L .66357 .68811 L p .646 .775 .942 r
F P
0 g
s
.66357 .68811 m .64144 .66685 L .63977 .67127 L p .646 .775 .942 r
F P
0 g
s
.68907 .67525 m .66498 .68337 L .66357 .68811 L p .656 .778 .938 r
F P
0 g
s
.66357 .68811 m .69794 .67655 L .68907 .67525 L p .656 .778 .938 r
F P
0 g
s
.64144 .66685 m .66357 .68811 L .66498 .68337 L p .657 .779 .938 r
F P
0 g
s
.38846 .46081 m .36874 .44548 L .36997 .44221 L p .398 .654 .961 r
F P
0 g
s
.36997 .44221 m .39814 .46417 L .38846 .46081 L p .398 .654 .961 r
F P
0 g
s
.53202 .48966 m .51306 .49032 L .50849 .49 L p .217 .731 .876 r
F P
0 g
s
.50343 .49 m .48215 .48806 L .47801 .48723 L p .133 .663 .87 r
F P
0 g
s
.47801 .48723 m .50849 .49 L .50343 .49 L p .133 .663 .87 r
F P
0 g
s
.38826 .65025 m .3705 .66788 L .37046 .67321 L p .659 .731 .902 r
F P
0 g
s
.37046 .67321 m .39587 .64807 L .38826 .65025 L p .659 .731 .902 r
F P
0 g
s
.34312 .66182 m .37046 .67321 L .3705 .66788 L p .664 .735 .902 r
F P
0 g
s
.39587 .64807 m .37046 .67321 L .37765 .67071 L p .657 .727 .901 r
F P
0 g
s
.7306 .43165 m .7472 .41162 L .7407 .40734 L p .737 .851 .934 r
F P
0 g
s
.7407 .40734 m .71708 .43604 L .7306 .43165 L p .737 .851 .934 r
F P
0 g
s
.61245 .46818 m .63326 .46721 L .63301 .46573 L p .636 .95 .944 r
F P
0 g
s
.64751 .45746 m .63301 .46573 L .63326 .46721 L p .635 .949 .945 r
F P
0 g
s
.63326 .46721 m .65395 .45542 L .64751 .45746 L p .635 .949 .945 r
F P
0 g
s
.61328 .46907 m .62787 .46838 L .63326 .46721 L p .563 .927 .937 r
F P
0 g
s
.63326 .46721 m .61245 .46818 L .61328 .46907 L p .563 .927 .937 r
F P
0 g
s
.41866 .4668 m .39814 .46417 L .39744 .46164 L p .208 .561 .936 r
F P
0 g
s
.37772 .44625 m .39744 .46164 L .39814 .46417 L p .208 .561 .936 r
F P
0 g
s
.39814 .46417 m .36997 .44221 L .37772 .44625 L p .208 .561 .936 r
F P
0 g
s
.42036 .46858 m .40598 .46672 L .39814 .46417 L p .123 .578 .921 r
F P
0 g
s
.39814 .46417 m .41866 .4668 L .42036 .46858 L p .123 .578 .921 r
F P
0 g
s
.67549 .4383 m .71708 .43604 L .71406 .4326 L p .76 .897 .938 r
F P
0 g
s
.73056 .41248 m .71406 .4326 L .71708 .43604 L p .76 .897 .938 r
F P
0 g
s
.71708 .43604 m .7407 .40734 L .73056 .41248 L p .76 .897 .938 r
F P
0 g
s
.67812 .4409 m .70723 .43929 L .71708 .43604 L p .724 .91 .959 r
F P
0 g
s
.71708 .43604 m .67549 .4383 L .67812 .4409 L p .724 .91 .959 r
F P
0 g
s
.7472 .41162 m .79638 .40773 L .81108 .40185 L p .737 .851 .934 r
F P
0 g
s
.50849 .49 m .53565 .48904 L .53202 .48966 L p .217 .731 .876 r
F P
0 g
s
.55557 .48695 m .5402 .48902 L .53565 .48904 L p .301 .79 .891 r
F P
0 g
s
.7407 .40734 m .81108 .40185 L .80329 .39665 L p .753 .833 .913 r
F P
0 g
s
.81745 .3637 m .80329 .39665 L .81108 .40185 L p .753 .833 .913 r
F P
0 g
s
.81108 .40185 m .83157 .35481 L .81745 .3637 L p .753 .833 .913 r
F P
0 g
s
.81108 .40185 m .7407 .40734 L .7472 .41162 L p .737 .851 .934 r
F P
0 g
s
.37765 .67071 m .39545 .65314 L .39587 .64807 L p .657 .727 .901 r
F P
0 g
s
.50449 .67997 m .52064 .68162 L .52454 .67805 L p .621 .735 .928 r
F P
0 g
s
.52454 .67805 m .50141 .67569 L .50449 .67997 L p .621 .735 .928 r
F P
0 g
s
.52889 .68203 m .54754 .68272 L .55126 .67903 L p .62 .744 .935 r
F P
0 g
s
.55126 .67903 m .52454 .67805 L .52889 .68203 L p .62 .744 .935 r
F P
0 g
s
.48463 .67724 m .4976 .67923 L .50141 .67569 L p .624 .729 .922 r
F P
0 g
s
.50709 .49207 m .50849 .49 L .50406 .48992 L p .247 0 0 r
F P
0 g
s
.48268 .48797 m .50406 .48992 L .50849 .49 L p .247 0 0 r
F P
0 g
s
.50849 .49 m .47801 .48723 L .48268 .48797 L p .247 0 0 r
F P
0 g
s
.51112 .49163 m .51206 .49018 L .50849 .49 L p .14 0 0 r
F P
0 g
s
.50849 .49 m .50709 .49207 L .51112 .49163 L p .14 0 0 r
F P
0 g
s
.53565 .48904 m .50849 .49 L .51206 .49018 L p .141 0 0 r
F P
0 g
s
.50141 .67569 m .48284 .67284 L .48463 .67724 L p .624 .729 .922 r
F P
0 g
s
.53565 .48904 m .55766 .48609 L .55557 .48695 L p .301 .79 .891 r
F P
0 g
s
.46981 .67456 m .4793 .67643 L .48284 .67284 L p .627 .725 .917 r
F P
0 g
s
.66498 .68337 m .64952 .66846 L .64144 .66685 L p .657 .779 .938 r
F P
0 g
s
.33216 .43445 m .36071 .43711 L .36997 .44221 L p .442 .628 .932 r
F P
0 g
s
.3705 .66788 m .35134 .65988 L .34312 .66182 L p .664 .735 .902 r
F P
0 g
s
.55682 .68256 m .5773 .68173 L .5806 .67783 L p .624 .754 .94 r
F P
0 g
s
.5806 .67783 m .55126 .67903 L .55682 .68256 L p .624 .754 .94 r
F P
0 g
s
.57292 .48338 m .56185 .48587 L .55766 .48609 L p .385 .841 .907 r
F P
0 g
s
.48284 .67284 m .46925 .67016 L .46981 .67456 L p .627 .725 .917 r
F P
0 g
s
.48106 .48962 m .47801 .48723 L .4742 .48653 L p .311 0 0 r
F P
0 g
s
.45244 .48117 m .4742 .48653 L .47801 .48723 L p .312 0 0 r
F P
0 g
s
.48486 .48965 m .48268 .48797 L .47801 .48723 L p .247 0 0 r
F P
0 g
s
.47801 .48723 m .48106 .48962 L .48486 .48965 L p .247 0 0 r
F P
0 g
s
.63301 .46573 m .61846 .4664 L .61245 .46818 L p .636 .95 .944 r
F P
0 g
s
.53058 .49134 m .53565 .48904 L .53111 .48951 L p .142 0 0 r
F P
0 g
s
.51206 .49018 m .53111 .48951 L .53565 .48904 L p .141 0 0 r
F P
0 g
s
.53445 .49057 m .53797 .48896 L .53565 .48904 L p .025 0 0 r
F P
0 g
s
.53565 .48904 m .53058 .49134 L .53445 .49057 L p .025 0 0 r
F P
0 g
s
.55766 .48609 m .53565 .48904 L .53797 .48896 L p .024 0 0 r
F P
0 g
s
.46041 .67259 m .46619 .67388 L .46925 .67016 L p .63 .723 .914 r
F P
0 g
s
.29857 .40857 m .24842 .4016 L .23321 .39395 L p .521 .669 .93 r
F P
0 g
s
.46925 .67016 m .46097 .66831 L .46041 .67259 L p .63 .723 .914 r
F P
0 g
s
.45355 .6716 m .45509 .6721 L .45747 .66821 L p .627 .715 .91 r
F P
0 g
s
.39744 .46164 m .41179 .46346 L .41866 .4668 L p .208 .561 .936 r
F P
0 g
s
.45703 .67192 m .45865 .67224 L .46097 .66831 L p .626 .716 .911 r
F P
0 g
s
.46097 .66831 m .45865 .66785 L .45703 .67192 L p .626 .716 .911 r
F P
0 g
s
.45747 .66821 m .45527 .6675 L .45355 .6716 L p .627 .715 .91 r
F P
0 g
s
.44612 .66971 m .45183 .67118 L .45527 .6675 L p .634 .721 .91 r
F P
0 g
s
.50406 .48992 m .50304 .49136 L .50709 .49207 L p .247 0 0 r
F P
0 g
s
.52164 .66142 m .5214 .67482 L .52454 .67805 L p .599 .735 .939 r
F P
0 g
s
.52454 .67805 m .52492 .65892 L .52164 .66142 L p .599 .735 .939 r
F P
0 g
s
.50141 .67569 m .52454 .67805 L .5214 .67482 L p .614 .74 .936 r
F P
0 g
s
.54703 .67611 m .52829 .67543 L .52454 .67805 L p .611 .752 .945 r
F P
0 g
s
.52454 .67805 m .55126 .67903 L .54703 .67611 L p .611 .752 .945 r
F P
0 g
s
.52492 .65892 m .52454 .67805 L .52829 .67543 L p .607 .741 .94 r
F P
0 g
s
.55766 .48609 m .57351 .48252 L .57292 .48338 L p .385 .841 .907 r
F P
0 g
s
.50208 .65845 m .49942 .6723 L .50141 .67569 L p .606 .725 .929 r
F P
0 g
s
.50141 .67569 m .50526 .65592 L .50208 .65845 L p .606 .725 .929 r
F P
0 g
s
.48284 .67284 m .50141 .67569 L .49942 .6723 L p .619 .732 .927 r
F P
0 g
s
.5214 .67482 m .50518 .67316 L .50141 .67569 L p .614 .74 .936 r
F P
0 g
s
.50526 .65592 m .50141 .67569 L .50518 .67316 L p .61 .729 .93 r
F P
0 g
s
.45527 .6675 m .4471 .6654 L .44612 .66971 L p .634 .721 .91 r
F P
0 g
s
.71406 .4326 m .68492 .43415 L .67549 .4383 L p .76 .897 .938 r
F P
0 g
s
.43342 .66622 m .4426 .66882 L .4471 .6654 L p .638 .72 .907 r
F P
0 g
s
.30504 .40386 m .23321 .39395 L .24208 .38899 L p .545 .653 .906 r
F P
0 g
s
.23204 .35354 m .24208 .38899 L .23321 .39395 L p .545 .653 .906 r
F P
0 g
s
.23321 .39395 m .21859 .3433 L .23204 .35354 L p .545 .653 .906 r
F P
0 g
s
.23321 .39395 m .30504 .40386 L .29857 .40857 L p .521 .669 .93 r
F P
0 g
s
.53111 .48951 m .52753 .49112 L .53058 .49134 L p .142 0 0 r
F P
0 g
s
.48658 .65526 m .48195 .66942 L .48284 .67284 L p .613 .719 .921 r
F P
0 g
s
.48284 .67284 m .48948 .65261 L .48658 .65526 L p .613 .719 .921 r
F P
0 g
s
.46925 .67016 m .48284 .67284 L .48195 .66942 L p .625 .726 .92 r
F P
0 g
s
.49942 .6723 m .48639 .6703 L .48284 .67284 L p .619 .732 .927 r
F P
0 g
s
.48948 .65261 m .48284 .67284 L .48639 .6703 L p .615 .72 .921 r
F P
0 g
s
.58377 .48046 m .57712 .48235 L .57351 .48252 L p .442 .872 .919 r
F P
0 g
s
.5498 .48869 m .55766 .48609 L .55341 .48689 L p .017 0 0 r
F P
0 g
s
.53797 .48896 m .55341 .48689 L .55766 .48609 L p .024 0 0 r
F P
0 g
s
.55324 .4878 m .55872 .48598 L .55766 .48609 L p 0 0 0 r
F P
0 g
s
.55766 .48609 m .5498 .48869 L .55324 .4878 L p 0 0 0 r
F P
0 g
s
.57351 .48252 m .55766 .48609 L .55872 .48598 L p 0 0 0 r
F P
0 g
s
.58721 .68079 m .60857 .67805 L .61118 .6739 L p .632 .765 .943 r
F P
0 g
s
.61118 .6739 m .5806 .67783 L .58721 .68079 L p .632 .765 .943 r
F P
0 g
s
.54449 .66331 m .54703 .67611 L .55126 .67903 L p .597 .748 .95 r
F P
0 g
s
.55126 .67903 m .54768 .66075 L .54449 .66331 L p .597 .748 .95 r
F P
0 g
s
.57536 .67538 m .55478 .67622 L .55126 .67903 L p .613 .766 .953 r
F P
0 g
s
.55126 .67903 m .5806 .67783 L .57536 .67538 L p .613 .766 .953 r
F P
0 g
s
.54768 .66075 m .55126 .67903 L .55478 .67622 L p .61 .757 .949 r
F P
0 g
s
.66304 .45285 m .67812 .4409 L .67549 .4383 L p .724 .91 .959 r
F P
0 g
s
.67549 .4383 m .65395 .45542 L .66304 .45285 L p .724 .91 .959 r
F P
0 g
s
.4742 .48653 m .4763 .48819 L .48106 .48962 L p .311 0 0 r
F P
0 g
s
.44015 .47751 m .42036 .46858 L .41866 .4668 L p .122 .577 .92 r
F P
0 g
s
.41866 .4668 m .44697 .47958 L .44015 .47751 L p .122 .577 .92 r
F P
0 g
s
.47551 .65251 m .4694 .66684 L .46925 .67016 L p .619 .715 .914 r
F P
0 g
s
.46925 .67016 m .47799 .64969 L .47551 .65251 L p .619 .715 .914 r
F P
0 g
s
.46097 .66831 m .46925 .67016 L .4694 .66684 L p .629 .724 .915 r
F P
0 g
s
.48195 .66942 m .47242 .66755 L .46925 .67016 L p .625 .726 .92 r
F P
0 g
s
.47799 .64969 m .46925 .67016 L .47242 .66755 L p .62 .716 .914 r
F P
0 g
s
.4471 .6654 m .43396 .66168 L .43342 .66622 L p .638 .72 .907 r
F P
0 g
s
.36474 .6394 m .34373 .65626 L .34312 .66182 L p .667 .736 .901 r
F P
0 g
s
.34312 .66182 m .37315 .63779 L .36474 .6394 L p .667 .736 .901 r
F P
0 g
s
.31483 .64752 m .34312 .66182 L .34373 .65626 L p .671 .739 .901 r
F P
0 g
s
.37315 .63779 m .34312 .66182 L .35134 .65988 L p .665 .73 .898 r
F P
0 g
s
.57351 .48252 m .58302 .47981 L .58377 .48046 L p .442 .872 .919 r
F P
0 g
s
.46597 .65059 m .45871 .66504 L .45747 .66821 L p .617 .703 .906 r
F P
0 g
s
.45747 .66821 m .46784 .64757 L .46597 .65059 L p .617 .703 .906 r
F P
0 g
s
.45527 .6675 m .45747 .66821 L .45871 .66504 L p .627 .715 .91 r
F P
0 g
s
.46911 .65076 m .46213 .66519 L .46097 .66831 L p .615 .703 .908 r
F P
0 g
s
.46097 .66831 m .47094 .6477 L .46911 .65076 L p .615 .703 .908 r
F P
0 g
s
.45865 .66785 m .46097 .66831 L .46213 .66519 L p .626 .716 .911 r
F P
0 g
s
.4694 .66684 m .46359 .66554 L .46097 .66831 L p .629 .724 .915 r
F P
0 g
s
.47094 .6477 m .46097 .66831 L .46359 .66554 L p .623 .714 .911 r
F P
0 g
s
.80329 .39665 m .75389 .40044 L .7407 .40734 L p .753 .833 .913 r
F P
0 g
s
.46213 .66519 m .46051 .66486 L .45865 .66785 L p .626 .716 .911 r
F P
0 g
s
.46905 .64721 m .45865 .66785 L .46051 .66486 L p .617 .703 .906 r
F P
0 g
s
.46331 .64964 m .45575 .66412 L .45527 .6675 L p .626 .712 .908 r
F P
0 g
s
.45527 .6675 m .46608 .64683 L .46331 .64964 L p .626 .712 .908 r
F P
0 g
s
.4471 .6654 m .45527 .6675 L .45575 .66412 L p .635 .721 .909 r
F P
0 g
s
.45871 .66504 m .45717 .66454 L .45527 .6675 L p .627 .715 .91 r
F P
0 g
s
.46608 .64683 m .45527 .6675 L .45717 .66454 L p .618 .702 .905 r
F P
0 g
s
.66949 .66152 m .68907 .67525 L .69794 .67655 L p .657 .778 .937 r
F P
0 g
s
.69794 .67655 m .67001 .65689 L .66949 .66152 L p .657 .778 .937 r
F P
0 g
s
.71971 .66176 m .69801 .67168 L .69794 .67655 L p .665 .777 .933 r
F P
0 g
s
.69794 .67655 m .72892 .66243 L .71971 .66176 L p .665 .777 .933 r
F P
0 g
s
.67001 .65689 m .69794 .67655 L .69801 .67168 L p .668 .779 .933 r
F P
0 g
s
.41626 .66078 m .42837 .66475 L .43396 .66168 L p .644 .72 .904 r
F P
0 g
s
.58806 .47912 m .58586 .47984 L .58302 .47981 L p .477 .889 .926 r
F P
0 g
s
.6298 .45819 m .65395 .45542 L .65332 .45351 L p .716 .961 .944 r
F P
0 g
s
.6684 .44151 m .65332 .45351 L .65395 .45542 L p .717 .962 .943 r
F P
0 g
s
.65395 .45542 m .67549 .4383 L .6684 .44151 L p .717 .962 .943 r
F P
0 g
s
.63059 .45942 m .64751 .45746 L .65395 .45542 L p .638 .95 .946 r
F P
0 g
s
.65395 .45542 m .6298 .45819 L .63059 .45942 L p .638 .95 .946 r
F P
0 g
s
.50518 .67316 m .5079 .65932 L .50526 .65592 L p .61 .729 .93 r
F P
0 g
s
.52829 .67543 m .52859 .66203 L .52492 .65892 L p .607 .741 .94 r
F P
0 g
s
.42445 .46941 m .44429 .47837 L .44697 .47958 L p 0 .292 .648 r
F P
0 g
s
.44697 .47958 m .41866 .4668 L .42445 .46941 L p 0 .292 .648 r
F P
0 g
s
.45804 .48368 m .45244 .48117 L .44697 .47958 L p .314 0 0 r
F P
0 g
s
.58302 .47981 m .58617 .47878 L .58806 .47912 L p .477 .889 .926 r
F P
0 g
s
.55341 .48689 m .54788 .48872 L .5498 .48869 L p .017 0 0 r
F P
0 g
s
.48639 .6703 m .49106 .65614 L .48948 .65261 L p .615 .72 .921 r
F P
0 g
s
.5891 .47878 m .5913 .47807 L .58932 .47775 L p .477 .889 .926 r
F P
0 g
s
.58932 .47775 m .58617 .47878 L .5891 .47878 L p .477 .889 .926 r
F P
0 g
s
.45547 .64723 m .44708 .66176 L .4471 .6654 L p .63 .711 .905 r
F P
0 g
s
.4471 .6654 m .45912 .64465 L .45547 .64723 L p .63 .711 .905 r
F P
0 g
s
.43396 .66168 m .4471 .6654 L .44708 .66176 L p .64 .72 .905 r
F P
0 g
s
.45575 .66412 m .45002 .66264 L .4471 .6654 L p .635 .721 .909 r
F P
0 g
s
.45912 .64465 m .4471 .6654 L .45002 .66264 L p .63 .711 .905 r
F P
0 g
s
.35134 .65988 m .37238 .64308 L .37315 .63779 L p .665 .73 .898 r
F P
0 g
s
.56382 .48559 m .57351 .48252 L .56984 .48347 L p 0 0 0 r
F P
0 g
s
.55872 .48598 m .56984 .48347 L .57351 .48252 L p 0 0 0 r
F P
0 g
s
.56664 .48474 m .57341 .48259 L .57351 .48252 L p 0 0 0 r
F P
0 g
s
.57351 .48252 m .56382 .48559 L .56664 .48474 L p 0 0 0 r
F P
0 g
s
.58302 .47981 m .57351 .48252 L .57341 .48259 L p 0 0 0 r
F P
0 g
s
.56976 .66334 m .57536 .67538 L .5806 .67783 L p .602 .765 .957 r
F P
0 g
s
.5806 .67783 m .57266 .66063 L .56976 .66334 L p .602 .765 .957 r
F P
0 g
s
.60508 .67201 m .58363 .67478 L .5806 .67783 L p .622 .781 .957 r
F P
0 g
s
.5806 .67783 m .61118 .6739 L .60508 .67201 L p .622 .781 .957 r
F P
0 g
s
.57266 .66063 m .5806 .67783 L .58363 .67478 L p .62 .775 .955 r
F P
0 g
s
.47242 .66755 m .47855 .65322 L .47799 .64969 L p .62 .716 .914 r
F P
0 g
s
.55478 .67622 m .55231 .66342 L .54768 .66075 L p .61 .757 .949 r
F P
0 g
s
.59331 .47734 m .59962 .475 L .59836 .4744 L p .511 .905 .932 r
F P
0 g
s
.59836 .4744 m .58932 .47775 L .59331 .47734 L p .511 .905 .932 r
F P
0 g
s
.43396 .66168 m .41662 .65597 L .41626 .66078 L p .644 .72 .904 r
F P
0 g
s
.46359 .66554 m .47058 .65112 L .47094 .6477 L p .623 .714 .911 r
F P
0 g
s
.45717 .66454 m .46474 .65008 L .46608 .64683 L p .618 .702 .905 r
F P
0 g
s
.46051 .66486 m .46779 .65041 L .46905 .64721 L p .617 .703 .906 r
F P
0 g
s
.44349 .64315 m .43366 .65774 L .43396 .66168 L p .638 .711 .9 r
F P
0 g
s
.43396 .66168 m .44803 .64085 L .44349 .64315 L p .638 .711 .9 r
F P
0 g
s
.41662 .65597 m .43396 .66168 L .43366 .65774 L p .648 .719 .9 r
F P
0 g
s
.44708 .66176 m .43787 .65915 L .43396 .66168 L p .64 .72 .905 r
F P
0 g
s
.44803 .64085 m .43396 .66168 L .43787 .65915 L p .637 .709 .899 r
F P
0 g
s
.57224 .48319 m .58302 .47981 L .58008 .48069 L p 0 0 0 r
F P
0 g
s
.57341 .48259 m .58008 .48069 L .58302 .47981 L p 0 0 0 r
F P
0 g
s
.57432 .48253 m .58187 .48016 L .58302 .47981 L p .228 .735 .682 r
F P
0 g
s
.58302 .47981 m .57224 .48319 L .57432 .48253 L p .228 .735 .682 r
F P
0 g
s
.58617 .47878 m .58302 .47981 L .58187 .48016 L p .228 .735 .682 r
F P
0 g
s
.45002 .66264 m .45844 .64812 L .45912 .64465 L p .63 .711 .905 r
F P
0 g
s
.61863 .67618 m .63977 .67127 L .64144 .66685 L p .645 .774 .942 r
F P
0 g
s
.64144 .66685 m .61118 .6739 L .61863 .67618 L p .645 .774 .942 r
F P
0 g
s
.56984 .48347 m .56303 .48563 L .56382 .48559 L p 0 0 0 r
F P
0 g
s
.39545 .65314 m .40996 .65865 L .41662 .65597 L p .651 .721 .9 r
F P
0 g
s
.34373 .65626 m .32392 .64622 L .31483 .64752 L p .671 .739 .901 r
F P
0 g
s
.44429 .47837 m .44983 .48085 L .45492 .48315 L p 0 .29 .646 r
F P
0 g
s
.57503 .48228 m .58617 .47878 L .58496 .47915 L p .228 .735 .682 r
F P
0 g
s
.58717 .47843 m .58496 .47915 L .58617 .47878 L p .228 .735 .682 r
F P
0 g
s
.58617 .47878 m .58932 .47775 L .58717 .47843 L p .228 .735 .682 r
F P
0 g
s
.57503 .48228 m .58617 .47878 L .58407 .47944 L p .228 .735 .682 r
F P
0 g
s
.58187 .48016 m .58407 .47944 L .58617 .47878 L p .228 .735 .682 r
F P
0 g
s
.69801 .67168 m .67848 .65788 L .67001 .65689 L p .668 .779 .933 r
F P
0 g
s
.65332 .45351 m .63642 .45543 L .6298 .45819 L p .716 .961 .944 r
F P
0 g
s
.58363 .67478 m .57812 .66273 L .57266 .66063 L p .62 .775 .955 r
F P
0 g
s
.57783 .48136 m .58932 .47775 L .58889 .47781 L p .284 .774 .707 r
F P
0 g
s
.59523 .47547 m .58889 .47781 L .58932 .47775 L p .284 .774 .707 r
F P
0 g
s
.58932 .47775 m .59836 .4744 L .59523 .47547 L p .284 .774 .707 r
F P
0 g
s
.57913 .48096 m .58717 .47843 L .58932 .47775 L p .228 .735 .682 r
F P
0 g
s
.58932 .47775 m .57783 .48136 L .57913 .48096 L p .228 .735 .682 r
F P
0 g
s
.60343 .47341 m .61328 .46907 L .61245 .46818 L p .562 .926 .938 r
F P
0 g
s
.61245 .46818 m .59836 .4744 L .60343 .47341 L p .562 .926 .938 r
F P
0 g
s
.43787 .65915 m .44773 .64457 L .44803 .64085 L p .637 .709 .899 r
F P
0 g
s
.24208 .38899 m .29253 .39589 L .30504 .40386 L p .545 .653 .906 r
F P
0 g
s
.58008 .48069 m .57252 .48306 L .57224 .48319 L p 0 0 0 r
F P
0 g
s
.43366 .65774 m .4215 .65373 L .41662 .65597 L p .648 .719 .9 r
F P
0 g
s
.59626 .66076 m .60508 .67201 L .61118 .6739 L p .615 .781 .961 r
F P
0 g
s
.61118 .6739 m .59863 .6578 L .59626 .66076 L p .615 .781 .961 r
F P
0 g
s
.6347 .66561 m .61348 .67056 L .61118 .6739 L p .638 .792 .956 r
F P
0 g
s
.61118 .6739 m .64144 .66685 L .6347 .66561 L p .638 .792 .956 r
F P
0 g
s
.59863 .6578 m .61118 .6739 L .61348 .67056 L p .637 .791 .956 r
F P
0 g
s
.41662 .65597 m .39587 .64807 L .39545 .65314 L p .651 .721 .9 r
F P
0 g
s
.42791 .63717 m .41624 .65173 L .41662 .65597 L p .648 .713 .894 r
F P
0 g
s
.41662 .65597 m .43332 .63519 L .42791 .63717 L p .648 .713 .894 r
F P
0 g
s
.39587 .64807 m .41662 .65597 L .41624 .65173 L p .658 .72 .894 r
F P
0 g
s
.43332 .63519 m .41662 .65597 L .4215 .65373 L p .646 .709 .893 r
F P
0 g
s
.58407 .47944 m .57627 .48189 L .57503 .48228 L p .228 .735 .682 r
F P
0 g
s
.58496 .47915 m .57717 .4816 L .57503 .48228 L p .228 .735 .682 r
F P
0 g
s
.5859 .47837 m .59836 .4744 L .59849 .47411 L p .371 .83 .745 r
F P
0 g
s
.60837 .46975 m .59849 .47411 L .59836 .4744 L p .37 .829 .746 r
F P
0 g
s
.59836 .4744 m .61245 .46818 L .60837 .46975 L p .37 .829 .746 r
F P
0 g
s
.5865 .47825 m .59523 .47547 L .59836 .4744 L p .284 .774 .707 r
F P
0 g
s
.59836 .4744 m .5859 .47837 L .5865 .47825 L p .284 .774 .707 r
F P
0 g
s
.58889 .47781 m .58086 .48034 L .57783 .48136 L p .284 .774 .707 r
F P
0 g
s
.4215 .65373 m .43321 .6392 L .43332 .63519 L p .646 .709 .893 r
F P
0 g
s
.39621 .4513 m .37772 .44625 L .36997 .44221 L p .209 .562 .936 r
F P
0 g
s
.3964 .44941 m .36997 .44221 L .37158 .43983 L p .314 .553 .919 r
F P
0 g
s
.35921 .42148 m .37158 .43983 L .36997 .44221 L p .314 .553 .919 r
F P
0 g
s
.36997 .44221 m .35226 .41601 L .35921 .42148 L p .314 .553 .919 r
F P
0 g
s
.36997 .44221 m .3964 .44941 L .39621 .4513 L p .209 .562 .936 r
F P
0 g
s
.35226 .41601 m .36997 .44221 L .36071 .43711 L p .442 .628 .932 r
F P
0 g
s
.36071 .43711 m .34827 .4188 L .35226 .41601 L p .442 .628 .932 r
F P
0 g
s
.37238 .64308 m .38826 .65025 L .39587 .64807 L p .659 .725 .897 r
F P
0 g
s
.41624 .65173 m .4017 .64618 L .39587 .64807 L p .658 .72 .894 r
F P
0 g
s
.41179 .46346 m .39621 .4513 L .3964 .44941 L p .209 .561 .936 r
F P
0 g
s
.3964 .44941 m .41866 .4668 L .41179 .46346 L p .209 .561 .936 r
F P
0 g
s
.50304 .49136 m .48486 .48965 L .48106 .48962 L p .247 0 0 r
F P
0 g
s
.48106 .48962 m .50709 .49207 L .50304 .49136 L p .247 0 0 r
F P
0 g
s
.52753 .49112 m .51112 .49163 L .50709 .49207 L p .142 0 0 r
F P
0 g
s
.43132 .47246 m .41866 .4668 L .41753 .46529 L p 0 .348 .794 r
F P
0 g
s
.40194 .45311 m .41753 .46529 L .41866 .4668 L p 0 .348 .794 r
F P
0 g
s
.41866 .4668 m .3964 .44941 L .40194 .45311 L p 0 .348 .794 r
F P
0 g
s
.43333 .47338 m .42445 .46941 L .41866 .4668 L p 0 .293 .65 r
F P
0 g
s
.41753 .46529 m .42639 .46924 L .43132 .47246 L p 0 .348 .794 r
F P
0 g
s
.43132 .47246 m .42989 .47155 L p .43041 .47203 L .562 .022 0 r
F P
0 g
s
.41866 .4668 m .43132 .47246 L p .43238 .47295 L 0 .293 .65 r
F P
0 g
s
.43856 .47953 m .43132 .47246 L p .43041 .47203 L .562 .022 0 r
F P
0 g
s
.43132 .47246 m .43333 .47338 L p .43238 .47295 L 0 .293 .65 r
F P
0 g
s
.61348 .67056 m .60473 .65927 L .59863 .6578 L p .637 .791 .956 r
F P
0 g
s
.61846 .4664 m .63059 .45942 L .6298 .45819 L p .641 .951 .945 r
F P
0 g
s
.6298 .45819 m .61245 .46818 L .61846 .4664 L p .641 .951 .945 r
F P
0 g
s
.4763 .48819 m .45804 .48368 L .45492 .48315 L p .312 0 0 r
F P
0 g
s
.45492 .48315 m .48106 .48962 L .4763 .48819 L p .312 0 0 r
F P
0 g
s
.64952 .66846 m .66949 .66152 L .67001 .65689 L p .659 .779 .937 r
F P
0 g
s
.67001 .65689 m .64144 .66685 L .64952 .66846 L p .659 .779 .937 r
F P
0 g
s
.3408 .62612 m .31632 .64184 L .31483 .64752 L p .675 .743 .902 r
F P
0 g
s
.31483 .64752 m .3498 .62512 L .3408 .62612 L p .675 .743 .902 r
F P
0 g
s
.28755 .63045 m .31483 .64752 L .31632 .64184 L p .677 .745 .902 r
F P
0 g
s
.3498 .62512 m .31483 .64752 L .32392 .64622 L p .672 .735 .898 r
F P
0 g
s
.50709 .49207 m .53058 .49134 L .52753 .49112 L p .142 0 0 r
F P
0 g
s
.39587 .64807 m .37315 .63779 L .37238 .64308 L p .659 .725 .897 r
F P
0 g
s
.4096 .62915 m .3957 .64354 L .39587 .64807 L p .661 .717 .89 r
F P
0 g
s
.39587 .64807 m .41575 .62754 L .4096 .62915 L p .661 .717 .89 r
F P
0 g
s
.37315 .63779 m .39587 .64807 L .3957 .64354 L p .669 .723 .89 r
F P
0 g
s
.41575 .62754 m .39587 .64807 L .4017 .64618 L p .657 .71 .887 r
F P
0 g
s
.59849 .47411 m .58979 .47688 L .5859 .47837 L p .371 .83 .745 r
F P
0 g
s
.54788 .48872 m .53445 .49057 L .53058 .49134 L p .018 0 0 r
F P
0 g
s
.69637 .64924 m .71971 .66176 L .72892 .66243 L p .668 .775 .93 r
F P
0 g
s
.72892 .66243 m .69559 .64449 L .69637 .64924 L p .668 .775 .93 r
F P
0 g
s
.74615 .64654 m .72757 .65759 L .72892 .66243 L p .672 .773 .926 r
F P
0 g
s
.72892 .66243 m .75546 .64671 L .74615 .64654 L p .672 .773 .926 r
F P
0 g
s
.69559 .64449 m .72892 .66243 L .72757 .65759 L p .676 .776 .925 r
F P
0 g
s
.32392 .64622 m .34841 .63057 L .3498 .62512 L p .672 .735 .898 r
F P
0 g
s
.50471 .49734 m .50709 .49207 L .50307 .49249 L p .518 0 0 r
F P
0 g
s
.48483 .49077 m .50307 .49249 L .50709 .49207 L p .518 0 0 r
F P
0 g
s
.50709 .49207 m .48106 .48962 L .48483 .49077 L p .518 0 0 r
F P
0 g
s
.50843 .49646 m .51007 .49277 L .50709 .49207 L p .413 0 0 r
F P
0 g
s
.50709 .49207 m .50471 .49734 L .50843 .49646 L p .413 0 0 r
F P
0 g
s
.53058 .49134 m .50709 .49207 L .51007 .49277 L p .413 0 0 r
F P
0 g
s
.59846 .47279 m .61245 .46818 L .61282 .46747 L p .504 .906 .801 r
F P
0 g
s
.62498 .46046 m .61282 .46747 L .61245 .46818 L p .505 .906 .799 r
F P
0 g
s
.61245 .46818 m .6298 .45819 L .62498 .46046 L p .505 .906 .799 r
F P
0 g
s
.59857 .47298 m .60837 .46975 L .61245 .46818 L p .373 .832 .748 r
F P
0 g
s
.61245 .46818 m .59846 .47279 L .59857 .47298 L p .373 .832 .748 r
F P
0 g
s
.48172 .49486 m .48106 .48962 L .4775 .48947 L p .606 .067 0 r
F P
0 g
s
.45918 .48494 m .4775 .48947 L .48106 .48962 L p .605 .065 0 r
F P
0 g
s
.48106 .48962 m .45492 .48315 L .45918 .48494 L p .605 .065 0 r
F P
0 g
s
.48531 .49444 m .48483 .49077 L .48106 .48962 L p .518 0 0 r
F P
0 g
s
.48106 .48962 m .48172 .49486 L .48531 .49444 L p .518 0 0 r
F P
0 g
s
.68492 .43415 m .69792 .41849 L .69402 .41589 L p .76 .898 .939 r
F P
0 g
s
.69402 .41589 m .67549 .4383 L .68492 .43415 L p .76 .898 .939 r
F P
0 g
s
.4017 .64618 m .41563 .63183 L .41575 .62754 L p .657 .71 .887 r
F P
0 g
s
.69792 .41849 m .73056 .41248 L .7407 .40734 L p .76 .898 .938 r
F P
0 g
s
.62268 .65522 m .6347 .66561 L .64144 .66685 L p .636 .793 .958 r
F P
0 g
s
.64144 .66685 m .62431 .65199 L .62268 .65522 L p .636 .793 .958 r
F P
0 g
s
.66284 .65627 m .64282 .66326 L .64144 .66685 L p .656 .798 .95 r
F P
0 g
s
.64144 .66685 m .67001 .65689 L .66284 .65627 L p .656 .798 .95 r
F P
0 g
s
.62431 .65199 m .64144 .66685 L .64282 .66326 L p .658 .8 .951 r
F P
0 g
s
.6479 .4441 m .67549 .4383 L .67393 .43614 L p .782 .952 .928 r
F P
0 g
s
.68689 .42044 m .67393 .43614 L .67549 .4383 L p .781 .952 .928 r
F P
0 g
s
.67549 .4383 m .69402 .41589 L .68689 .42044 L p .781 .952 .928 r
F P
0 g
s
.64909 .44559 m .6684 .44151 L .67549 .4383 L p .715 .962 .943 r
F P
0 g
s
.67549 .4383 m .6479 .4441 L .64909 .44559 L p .715 .962 .943 r
F P
0 g
s
.69402 .41589 m .7407 .40734 L .73569 .40404 L p .785 .871 .911 r
F P
0 g
s
.74575 .37956 m .73569 .40404 L .7407 .40734 L p .785 .871 .911 r
F P
0 g
s
.7407 .40734 m .75518 .37238 L .74575 .37956 L p .785 .871 .911 r
F P
0 g
s
.7407 .40734 m .69402 .41589 L .69792 .41849 L p .76 .898 .938 r
F P
0 g
s
.75518 .37238 m .7407 .40734 L .75389 .40044 L p .753 .833 .913 r
F P
0 g
s
.37158 .43983 m .3901 .44485 L .3964 .44941 L p .314 .553 .919 r
F P
0 g
s
.53058 .49134 m .5498 .48869 L .54788 .48872 L p .018 0 0 r
F P
0 g
s
.34827 .4188 m .31528 .41028 L .30504 .40386 L p .442 .627 .932 r
F P
0 g
s
.5079 .65932 m .52164 .66142 L .52492 .65892 L p .594 .722 .933 r
F P
0 g
s
.52492 .65892 m .50526 .65592 L .5079 .65932 L p .594 .722 .933 r
F P
0 g
s
.49106 .65614 m .50208 .65845 L .50526 .65592 L p .6 .712 .923 r
F P
0 g
s
.52585 .49695 m .53058 .49134 L .52653 .49226 L p .412 0 0 r
F P
0 g
s
.51007 .49277 m .52653 .49226 L .53058 .49134 L p .413 0 0 r
F P
0 g
s
.52933 .49573 m .53263 .4918 L .53058 .49134 L p .301 0 0 r
F P
0 g
s
.53058 .49134 m .52585 .49695 L .52933 .49573 L p .301 0 0 r
F P
0 g
s
.5498 .48869 m .53058 .49134 L .53263 .4918 L p .301 0 0 r
F P
0 g
s
.50526 .65592 m .48948 .65261 L .49106 .65614 L p .6 .712 .923 r
F P
0 g
s
.50307 .49249 m .50138 .49617 L .50471 .49734 L p .518 0 0 r
F P
0 g
s
.3957 .64354 m .37978 .63632 L .37315 .63779 L p .669 .723 .89 r
F P
0 g
s
.52859 .66203 m .54449 .66331 L .54768 .66075 L p .592 .737 .944 r
F P
0 g
s
.54768 .66075 m .52492 .65892 L .52859 .66203 L p .592 .737 .944 r
F P
0 g
s
.47855 .65322 m .48658 .65526 L .48948 .65261 L p .606 .706 .914 r
F P
0 g
s
.56303 .48563 m .55324 .4878 L .5498 .48869 L p 0 0 0 r
F P
0 g
s
.75389 .40044 m .76415 .37599 L .75518 .37238 L p .753 .833 .913 r
F P
0 g
s
.48948 .65261 m .47799 .64969 L .47855 .65322 L p .606 .706 .914 r
F P
0 g
s
.47058 .65112 m .47551 .65251 L .47799 .64969 L p .612 .703 .909 r
F P
0 g
s
.4775 .48947 m .47794 .49313 L .48172 .49486 L p .606 .067 0 r
F P
0 g
s
.44983 .48085 m .43333 .47338 L .43132 .47246 L p 0 .292 .649 r
F P
0 g
s
.43132 .47246 m .45492 .48315 L .44983 .48085 L p 0 .292 .649 r
F P
0 g
s
.46474 .65008 m .46597 .65059 L .46784 .64757 L p .605 .687 .9 r
F P
0 g
s
.35226 .41601 m .30504 .40386 L .31097 .40087 L p .488 .612 .901 r
F P
0 g
s
.30485 .37493 m .31097 .40087 L .30504 .40386 L p .488 .612 .901 r
F P
0 g
s
.30504 .40386 m .29616 .36679 L .30485 .37493 L p .488 .612 .901 r
F P
0 g
s
.30504 .40386 m .35226 .41601 L .34827 .4188 L p .442 .627 .932 r
F P
0 g
s
.29616 .36679 m .30504 .40386 L .29253 .39589 L p .545 .653 .906 r
F P
0 g
s
.31632 .64184 m .29723 .62985 L .28755 .63045 L p .677 .745 .902 r
F P
0 g
s
.47799 .64969 m .47094 .6477 L .47058 .65112 L p .612 .703 .909 r
F P
0 g
s
.46784 .64757 m .46608 .64683 L .46474 .65008 L p .605 .687 .9 r
F P
0 g
s
.46779 .65041 m .46911 .65076 L .47094 .6477 L p .603 .687 .902 r
F P
0 g
s
.47094 .6477 m .46905 .64721 L .46779 .65041 L p .603 .687 .902 r
F P
0 g
s
.45844 .64812 m .46331 .64964 L .46608 .64683 L p .62 .701 .903 r
F P
0 g
s
.55231 .66342 m .56976 .66334 L .57266 .66063 L p .597 .755 .954 r
F P
0 g
s
.57266 .66063 m .54768 .66075 L .55231 .66342 L p .597 .755 .954 r
F P
0 g
s
.52653 .49226 m .5232 .49619 L .52585 .49695 L p .412 0 0 r
F P
0 g
s
.46608 .64683 m .45912 .64465 L .45844 .64812 L p .62 .701 .903 r
F P
0 g
s
.61282 .46747 m .60304 .47068 L .59846 .47279 L p .504 .906 .801 r
F P
0 g
s
.45889 .48891 m .45492 .48315 L .45224 .48251 L p .65 .093 0 r
F P
0 g
s
.4357 .47502 m .45224 .48251 L .45492 .48315 L p .649 .091 0 r
F P
0 g
s
.45492 .48315 m .43132 .47246 L .4357 .47502 L p .649 .091 0 r
F P
0 g
s
.46198 .48897 m .45918 .48494 L .45492 .48315 L p .604 .064 0 r
F P
0 g
s
.45492 .48315 m .45889 .48891 L .46198 .48897 L p .604 .064 0 r
F P
0 g
s
.72757 .65759 m .70425 .64499 L .69559 .64449 L p .676 .776 .925 r
F P
0 g
s
.44773 .64457 m .45547 .64723 L .45912 .64465 L p .625 .699 .898 r
F P
0 g
s
.5498 .48869 m .56382 .48559 L .56303 .48563 L p 0 0 0 r
F P
0 g
s
.53263 .4918 m .54611 .48995 L .5498 .48869 L p .301 0 0 r
F P
0 g
s
.64282 .66326 m .63086 .65284 L .62431 .65199 L p .658 .8 .951 r
F P
0 g
s
.50569 .64274 m .50352 .65316 L .50526 .65592 L p .569 .704 .933 r
F P
0 g
s
.50526 .65592 m .50838 .64104 L .50569 .64274 L p .569 .704 .933 r
F P
0 g
s
.48948 .65261 m .50526 .65592 L .50352 .65316 L p .591 .715 .93 r
F P
0 g
s
.52224 .65633 m .50845 .65422 L .50526 .65592 L p .58 .728 .944 r
F P
0 g
s
.50526 .65592 m .52492 .65892 L .52224 .65633 L p .58 .728 .944 r
F P
0 g
s
.50838 .64104 m .50526 .65592 L .50845 .65422 L p .576 .711 .934 r
F P
0 g
s
.34841 .63057 m .36474 .6394 L .37315 .63779 L p .668 .731 .897 r
F P
0 g
s
.54351 .49462 m .5498 .48869 L .54611 .48995 L p .297 0 0 r
F P
0 g
s
.54649 .49328 m .55089 .48913 L .5498 .48869 L p .198 0 0 r
F P
0 g
s
.5498 .48869 m .54351 .49462 L .54649 .49328 L p .198 0 0 r
F P
0 g
s
.56382 .48559 m .5498 .48869 L .55089 .48913 L p .199 0 0 r
F P
0 g
s
.52241 .64654 m .52224 .65633 L .52492 .65892 L p .554 .719 .95 r
F P
0 g
s
.52492 .65892 m .52521 .64495 L .52241 .64654 L p .554 .719 .95 r
F P
0 g
s
.54408 .65848 m .52813 .6572 L .52492 .65892 L p .573 .747 .96 r
F P
0 g
s
.52492 .65892 m .54768 .66075 L .54408 .65848 L p .573 .747 .96 r
F P
0 g
s
.52521 .64495 m .52492 .65892 L .52813 .6572 L p .569 .731 .951 r
F P
0 g
s
.49234 .63891 m .48866 .64982 L .48948 .65261 L p .583 .695 .919 r
F P
0 g
s
.48948 .65261 m .49475 .63702 L .49234 .63891 L p .583 .695 .919 r
F P
0 g
s
.47799 .64969 m .48948 .65261 L .48866 .64982 L p .602 .707 .918 r
F P
0 g
s
.50352 .65316 m .49246 .65084 L .48948 .65261 L p .591 .715 .93 r
F P
0 g
s
.49475 .63702 m .48948 .65261 L .49246 .65084 L p .586 .698 .92 r
F P
0 g
s
.57252 .48306 m .56664 .48474 L .56382 .48559 L p 0 0 0 r
F P
0 g
s
.45912 .64465 m .44803 .64085 L .44773 .64457 L p .625 .699 .898 r
F P
0 g
s
.29253 .39589 m .28615 .36995 L .29616 .36679 L p .545 .653 .906 r
F P
0 g
s
.48284 .63575 m .47803 .64699 L .47799 .64969 L p .594 .69 .909 r
F P
0 g
s
.47799 .64969 m .48487 .63364 L .48284 .63575 L p .594 .69 .909 r
F P
0 g
s
.47094 .6477 m .47799 .64969 L .47803 .64699 L p .611 .704 .911 r
F P
0 g
s
.48866 .64982 m .48061 .64778 L .47799 .64969 L p .602 .707 .918 r
F P
0 g
s
.48487 .63364 m .47799 .64969 L .48061 .64778 L p .595 .691 .909 r
F P
0 g
s
.67393 .43614 m .65461 .44018 L .6479 .4441 L p .782 .952 .928 r
F P
0 g
s
.4746 .63356 m .46883 .64502 L .46784 .64757 L p .588 .667 .894 r
F P
0 g
s
.46784 .64757 m .47608 .6312 L .4746 .63356 L p .588 .667 .894 r
F P
0 g
s
.46608 .64683 m .46784 .64757 L .46883 .64502 L p .605 .687 .9 r
F P
0 g
s
.43321 .6392 m .44349 .64315 L .44803 .64085 L p .635 .699 .892 r
F P
0 g
s
.37315 .63779 m .3498 .62512 L .34841 .63057 L p .668 .731 .897 r
F P
0 g
s
.38977 .61909 m .37342 .63304 L .37315 .63779 L p .674 .725 .888 r
F P
0 g
s
.37315 .63779 m .39652 .6179 L .38977 .61909 L p .674 .725 .888 r
F P
0 g
s
.3498 .62512 m .37315 .63779 L .37342 .63304 L p .68 .73 .888 r
F P
0 g
s
.39652 .6179 m .37315 .63779 L .37978 .63632 L p .67 .716 .883 r
F P
0 g
s
.47239 .63252 m .46639 .64404 L .46608 .64683 L p .606 .687 .899 r
F P
0 g
s
.46608 .64683 m .47465 .63037 L .47239 .63252 L p .606 .687 .899 r
F P
0 g
s
.45912 .64465 m .46608 .64683 L .46639 .64404 L p .621 .7 .901 r
F P
0 g
s
.46883 .64502 m .4676 .6445 L .46608 .64683 L p .605 .687 .9 r
F P
0 g
s
.47465 .63037 m .46608 .64683 L .4676 .6445 L p .59 .667 .892 r
F P
0 g
s
.4774 .63378 m .47186 .6452 L .47094 .6477 L p .585 .668 .896 r
F P
0 g
s
.47094 .6477 m .47886 .63139 L .4774 .63378 L p .585 .668 .896 r
F P
0 g
s
.46905 .64721 m .47094 .6477 L .47186 .6452 L p .603 .688 .902 r
F P
0 g
s
.47803 .64699 m .47309 .64559 L .47094 .6477 L p .611 .704 .911 r
F P
0 g
s
.47886 .63139 m .47094 .6477 L .47309 .64559 L p .602 .688 .903 r
F P
0 g
s
.47186 .6452 m .47053 .64485 L .46905 .64721 L p .603 .688 .902 r
F P
0 g
s
.4773 .63083 m .46905 .64721 L .47053 .64485 L p .588 .667 .894 r
F P
0 g
s
.54208 .64947 m .54408 .65848 L .54768 .66075 L p .546 .741 .966 r
F P
0 g
s
.54768 .66075 m .54485 .64787 L .54208 .64947 L p .546 .741 .966 r
F P
0 g
s
.56825 .65882 m .55073 .6589 L .54768 .66075 L p .574 .771 .972 r
F P
0 g
s
.54768 .66075 m .57266 .66063 L .56825 .65882 L p .574 .771 .972 r
F P
0 g
s
.54485 .64787 m .54768 .66075 L .55073 .6589 L p .57 .758 .967 r
F P
0 g
s
.54611 .48995 m .54168 .4941 L .54351 .49462 L p .297 0 0 r
F P
0 g
s
.56382 .48559 m .57224 .48319 L .57252 .48306 L p 0 0 0 r
F P
0 g
s
.63642 .45543 m .64909 .44559 L .6479 .4441 L p .714 .962 .943 r
F P
0 g
s
.6479 .4441 m .6298 .45819 L .63642 .45543 L p .714 .962 .943 r
F P
0 g
s
.57812 .66273 m .59626 .66076 L .59863 .6578 L p .611 .775 .959 r
F P
0 g
s
.59863 .6578 m .57266 .66063 L .57812 .66273 L p .611 .775 .959 r
F P
0 g
s
.46571 .62992 m .459 .64159 L .45912 .64465 L p .614 .685 .894 r
F P
0 g
s
.45912 .64465 m .46871 .628 L .46571 .62992 L p .614 .685 .894 r
F P
0 g
s
.44803 .64085 m .45912 .64465 L .459 .64159 L p .629 .698 .895 r
F P
0 g
s
.46639 .64404 m .46151 .64252 L .45912 .64465 L p .621 .7 .901 r
F P
0 g
s
.46871 .628 m .45912 .64465 L .46151 .64252 L p .613 .685 .893 r
F P
0 g
s
.45224 .48251 m .455 .48654 L .45889 .48891 L p .65 .093 0 r
F P
0 g
s
.73569 .40404 m .70295 .41 L .69402 .41589 L p .785 .871 .911 r
F P
0 g
s
.57627 .48189 m .57432 .48253 L .57224 .48319 L p .228 .735 .682 r
F P
0 g
s
.37978 .63632 m .39615 .62242 L .39652 .6179 L p .67 .716 .883 r
F P
0 g
s
.50845 .65422 m .51065 .64381 L .50838 .64104 L p .576 .711 .934 r
F P
0 g
s
.49246 .65084 m .49617 .63993 L .49475 .63702 L p .586 .698 .92 r
F P
0 g
s
.55089 .48913 m .56071 .48695 L .56382 .48559 L p .199 0 0 r
F P
0 g
s
.57224 .48319 m .57503 .48228 L .57627 .48189 L p .228 .735 .682 r
F P
0 g
s
.67848 .65788 m .69637 .64924 L .69559 .64449 L p .671 .778 .93 r
F P
0 g
s
.69559 .64449 m .67001 .65689 L .67848 .65788 L p .671 .778 .93 r
F P
0 g
s
.44803 .64085 m .43332 .63519 L .43321 .6392 L p .635 .699 .892 r
F P
0 g
s
.52813 .6572 m .52835 .64742 L .52521 .64495 L p .569 .731 .951 r
F P
0 g
s
.55656 .49175 m .56382 .48559 L .56071 .48695 L p .194 0 0 r
F P
0 g
s
.55888 .49047 m .56396 .48615 L .56382 .48559 L p .116 0 0 r
F P
0 g
s
.56382 .48559 m .55656 .49175 L .55888 .49047 L p .116 0 0 r
F P
0 g
s
.57224 .48319 m .56382 .48559 L .56396 .48615 L p .117 0 0 r
F P
0 g
s
.48061 .64778 m .48544 .63654 L .48487 .63364 L p .595 .691 .909 r
F P
0 g
s
.57717 .4816 m .57913 .48096 L .57783 .48136 L p .228 .735 .682 r
F P
0 g
s
.57783 .48136 m .57503 .48228 L .57717 .4816 L p .228 .735 .682 r
F P
0 g
s
.61397 .46402 m .6298 .45819 L .63 .45708 L p .645 .967 .845 r
F P
0 g
s
.64267 .44721 m .63 .45708 L .6298 .45819 L p .645 .967 .845 r
F P
0 g
s
.6298 .45819 m .6479 .4441 L .64267 .44721 L p .645 .967 .845 r
F P
0 g
s
.61389 .46455 m .62498 .46046 L .6298 .45819 L p .499 .903 .795 r
F P
0 g
s
.6298 .45819 m .61397 .46402 L .61389 .46455 L p .499 .903 .795 r
F P
0 g
s
.45542 .6256 m .44764 .63747 L .44803 .64085 L p .626 .686 .886 r
F P
0 g
s
.44803 .64085 m .45916 .62391 L .45542 .6256 L p .626 .686 .886 r
F P
0 g
s
.43332 .63519 m .44803 .64085 L .44764 .63747 L p .642 .698 .886 r
F P
0 g
s
.459 .64159 m .45123 .63892 L .44803 .64085 L p .629 .698 .895 r
F P
0 g
s
.45916 .62391 m .44803 .64085 L .45123 .63892 L p .624 .683 .885 r
F P
0 g
s
.4676 .6445 m .4736 .63298 L .47465 .63037 L p .59 .667 .892 r
F P
0 g
s
.47309 .64559 m .47864 .63418 L .47886 .63139 L p .602 .688 .903 r
F P
0 g
s
.47053 .64485 m .47631 .63338 L .4773 .63083 L p .588 .667 .894 r
F P
0 g
s
.41563 .63183 m .42791 .63717 L .43332 .63519 L p .647 .702 .886 r
F P
0 g
s
.46151 .64252 m .46823 .63086 L .46871 .628 L p .613 .685 .893 r
F P
0 g
s
.58086 .48034 m .5865 .47825 L .5859 .47837 L p .284 .774 .707 r
F P
0 g
s
.5859 .47837 m .57783 .48136 L .58086 .48034 L p .284 .774 .707 r
F P
0 g
s
.31097 .40087 m .3441 .40937 L .35226 .41601 L p .488 .612 .901 r
F P
0 g
s
.56389 .65061 m .56825 .65882 L .57266 .66063 L p .551 .768 .979 r
F P
0 g
s
.57266 .66063 m .56647 .64891 L .56389 .65061 L p .551 .768 .979 r
F P
0 g
s
.59356 .65656 m .57535 .65855 L .57266 .66063 L p .59 .797 .979 r
F P
0 g
s
.57266 .66063 m .59863 .6578 L .59356 .65656 L p .59 .797 .979 r
F P
0 g
s
.56647 .64891 m .57266 .66063 L .57535 .65855 L p .586 .789 .976 r
F P
0 g
s
.55073 .6589 m .54879 .64989 L .54485 .64787 L p .57 .758 .967 r
F P
0 g
s
.64769 .64673 m .66284 .65627 L .67001 .65689 L p .658 .797 .949 r
F P
0 g
s
.67001 .65689 m .64839 .64324 L .64769 .64673 L p .658 .797 .949 r
F P
0 g
s
.68822 .64442 m .6703 .65312 L .67001 .65689 L p .673 .796 .94 r
F P
0 g
s
.67001 .65689 m .69559 .64449 L .68822 .64442 L p .673 .796 .94 r
F P
0 g
s
.64839 .64324 m .67001 .65689 L .6703 .65312 L p .678 .8 .94 r
F P
0 g
s
.37342 .63304 m .35707 .62414 L .3498 .62512 L p .68 .73 .888 r
F P
0 g
s
.56071 .48695 m .55562 .49127 L .55656 .49175 L p .194 0 0 r
F P
0 g
s
.56449 .48947 m .57224 .48319 L .56986 .48448 L p .113 0 0 r
F P
0 g
s
.56396 .48615 m .56986 .48448 L .57224 .48319 L p .117 0 0 r
F P
0 g
s
.56607 .48839 m .57149 .484 L .57224 .48319 L p .089 0 0 r
F P
0 g
s
.57224 .48319 m .56449 .48947 L .56607 .48839 L p .089 0 0 r
F P
0 g
s
.57503 .48228 m .57224 .48319 L .57149 .484 L p .067 0 0 r
F P
0 g
s
.45123 .63892 m .45903 .62707 L .45916 .62391 L p .624 .683 .885 r
F P
0 g
s
.56718 .48872 m .57503 .48228 L .57427 .4831 L p .044 0 0 r
F P
0 g
s
.57623 .48245 m .57427 .4831 L .57503 .48228 L p .067 0 0 r
F P
0 g
s
.57503 .48228 m .57783 .48136 L .57623 .48245 L p .067 0 0 r
F P
0 g
s
.56718 .48872 m .57503 .48228 L .57346 .48336 L p .097 0 0 r
F P
0 g
s
.57149 .484 m .57346 .48336 L .57503 .48228 L p .067 0 0 r
F P
0 g
s
.44764 .63747 m .43733 .6335 L .43332 .63519 L p .642 .698 .886 r
F P
0 g
s
.43332 .63519 m .41575 .62754 L .41563 .63183 L p .647 .702 .886 r
F P
0 g
s
.442 .61946 m .43283 .63149 L .43332 .63519 L p .643 .689 .878 r
F P
0 g
s
.43332 .63519 m .44642 .61802 L .442 .61946 L p .643 .689 .878 r
F P
0 g
s
.41575 .62754 m .43332 .63519 L .43283 .63149 L p .657 .7 .878 r
F P
0 g
s
.44642 .61802 m .43332 .63519 L .43733 .6335 L p .639 .683 .876 r
F P
0 g
s
.41363 .45929 m .40194 .45311 L .3964 .44941 L p 0 .347 .793 r
F P
0 g
s
.41309 .45823 m .3964 .44941 L .39709 .44798 L p .103 .413 .862 r
F P
0 g
s
.38772 .43366 m .39709 .44798 L .3964 .44941 L p .103 .413 .862 r
F P
0 g
s
.3964 .44941 m .38298 .42896 L .38772 .43366 L p .103 .413 .862 r
F P
0 g
s
.3964 .44941 m .41309 .45823 L .41363 .45929 L p 0 .347 .793 r
F P
0 g
s
.38298 .42896 m .3964 .44941 L .3901 .44485 L p .314 .553 .919 r
F P
0 g
s
.56979 .48774 m .57783 .48136 L .57781 .48188 L p .009 0 0 r
F P
0 g
s
.58347 .47978 m .57781 .48188 L .57783 .48136 L p .007 0 0 r
F P
0 g
s
.57783 .48136 m .5859 .47837 L .58347 .47978 L p .007 0 0 r
F P
0 g
s
.5706 .48692 m .57623 .48245 L .57783 .48136 L p .035 0 0 r
F P
0 g
s
.57783 .48136 m .56979 .48774 L .5706 .48692 L p .035 0 0 r
F P
0 g
s
.60473 .65927 m .62268 .65522 L .62431 .65199 L p .634 .791 .957 r
F P
0 g
s
.62431 .65199 m .59863 .6578 L .60473 .65927 L p .634 .791 .957 r
F P
0 g
s
.42639 .46924 m .41363 .45929 L .41309 .45823 L p 0 .348 .793 r
F P
0 g
s
.41309 .45823 m .43132 .47246 L .42639 .46924 L p 0 .348 .793 r
F P
0 g
s
.58979 .47688 m .59857 .47298 L .59846 .47279 L p .374 .832 .748 r
F P
0 g
s
.59846 .47279 m .5859 .47837 L .58979 .47688 L p .374 .832 .748 r
F P
0 g
s
.50138 .49617 m .48531 .49444 L .48172 .49486 L p .518 0 0 r
F P
0 g
s
.56986 .48448 m .56443 .48887 L .56449 .48947 L p .113 0 0 r
F P
0 g
s
.41712 .46159 m .42989 .47155 L .43132 .47246 L p .562 .023 0 r
F P
0 g
s
.43132 .47246 m .41309 .45823 L .41712 .46159 L p .562 .023 0 r
F P
0 g
s
.44078 .47997 m .4357 .47502 L .43132 .47246 L p .647 .089 0 r
F P
0 g
s
.43132 .47246 m .43856 .47953 L .44078 .47997 L p .647 .089 0 r
F P
0 g
s
.3901 .44485 m .38069 .43055 L .38298 .42896 L p .314 .553 .919 r
F P
0 g
s
.63 .45708 m .61892 .46116 L .61397 .46402 L p .645 .967 .845 r
F P
0 g
s
.48172 .49486 m .50471 .49734 L .50138 .49617 L p .518 0 0 r
F P
0 g
s
.47794 .49313 m .46198 .48897 L .45889 .48891 L p .606 .066 0 r
F P
0 g
s
.45889 .48891 m .48172 .49486 L .47794 .49313 L p .606 .066 0 r
F P
0 g
s
.57535 .65855 m .57105 .65034 L .56647 .64891 L p .586 .789 .976 r
F P
0 g
s
.43733 .6335 m .44651 .62148 L .44642 .61802 L p .639 .683 .876 r
F P
0 g
s
.5232 .49619 m .50843 .49646 L .50471 .49734 L p .412 0 0 r
F P
0 g
s
.71952 .63532 m .74615 .64654 L .75546 .64671 L p .675 .77 .922 r
F P
0 g
s
.75546 .64671 m .7174 .63063 L .71952 .63532 L p .675 .77 .922 r
F P
0 g
s
.76783 .63082 m .75272 .64208 L .75546 .64671 L p .675 .766 .92 r
F P
0 g
s
.75546 .64671 m .77705 .63067 L .76783 .63082 L p .675 .766 .92 r
F P
0 g
s
.7174 .63063 m .75546 .64671 L .75272 .64208 L p .68 .769 .918 r
F P
0 g
s
.57346 .48336 m .56795 .48787 L .56718 .48872 L p .097 0 0 r
F P
0 g
s
.76415 .37599 m .81745 .3637 L .83157 .35481 L p .753 .833 .913 r
F P
0 g
s
.57427 .4831 m .56877 .4876 L .56718 .48872 L p .044 0 0 r
F P
0 g
s
.43283 .63149 m .42053 .62613 L .41575 .62754 L p .657 .7 .878 r
F P
0 g
s
.39615 .62242 m .4096 .62915 L .41575 .62754 L p .661 .708 .882 r
F P
0 g
s
.6703 .65312 m .65518 .64354 L .64839 .64324 L p .678 .8 .94 r
F P
0 g
s
.31801 .61072 m .29014 .62482 L .28755 .63045 L p .68 .752 .905 r
F P
0 g
s
.28755 .63045 m .32732 .61036 L .31801 .61072 L p .68 .752 .905 r
F P
0 g
s
.26301 .61107 m .28755 .63045 L .29014 .62482 L p .681 .753 .906 r
F P
0 g
s
.32732 .61036 m .28755 .63045 L .29723 .62985 L p .678 .743 .9 r
F P
0 g
s
.29723 .62985 m .32506 .61583 L .32732 .61036 L p .678 .743 .9 r
F P
0 g
s
.58674 .64915 m .59356 .65656 L .59863 .6578 L p .575 .797 .983 r
F P
0 g
s
.59863 .6578 m .58893 .6472 L .58674 .64915 L p .575 .797 .983 r
F P
0 g
s
.61876 .65136 m .60075 .65544 L .59863 .6578 L p .619 .819 .977 r
F P
0 g
s
.59863 .6578 m .62431 .65199 L .61876 .65136 L p .619 .819 .977 r
F P
0 g
s
.58893 .6472 m .59863 .6578 L .60075 .65544 L p .617 .816 .977 r
F P
0 g
s
.57744 .48494 m .5859 .47837 L .58647 .47854 L p 0 0 0 r
F P
0 g
s
.59527 .47462 m .58647 .47854 L .5859 .47837 L p 0 0 0 r
F P
0 g
s
.5859 .47837 m .59846 .47279 L .59527 .47462 L p 0 0 0 r
F P
0 g
s
.57754 .48439 m .58347 .47978 L .5859 .47837 L p .012 0 0 r
F P
0 g
s
.5859 .47837 m .57744 .48494 L .57754 .48439 L p .012 0 0 r
F P
0 g
s
.4807 .50147 m .48172 .49486 L .47834 .49496 L p .717 .284 .22 r
F P
0 g
s
.46234 .49079 m .47834 .49496 L .48172 .49486 L p .715 .28 .216 r
F P
0 g
s
.48172 .49486 m .45889 .48891 L .46234 .49079 L p .715 .28 .216 r
F P
0 g
s
.48415 .50087 m .48485 .49624 L .48172 .49486 L p .628 .199 .207 r
F P
0 g
s
.48172 .49486 m .4807 .50147 L .48415 .50087 L p .628 .199 .207 r
F P
0 g
s
.50471 .49734 m .48172 .49486 L .48485 .49624 L p .628 .198 .207 r
F P
0 g
s
.57781 .48188 m .57219 .48634 L .56979 .48774 L p .009 0 0 r
F P
0 g
s
.50471 .49734 m .52585 .49695 L .5232 .49619 L p .412 0 0 r
F P
0 g
s
.50155 .50428 m .50471 .49734 L .50096 .49798 L p .628 .198 .206 r
F P
0 g
s
.48485 .49624 m .50096 .49798 L .50471 .49734 L p .628 .198 .207 r
F P
0 g
s
.50508 .50321 m .50728 .49835 L .50471 .49734 L p .536 .104 .166 r
F P
0 g
s
.50471 .49734 m .50155 .50428 L .50508 .50321 L p .536 .104 .166 r
F P
0 g
s
.52585 .49695 m .50471 .49734 L .50728 .49835 L p .536 .102 .163 r
F P
0 g
s
.41575 .62754 m .39652 .6179 L .39615 .62242 L p .661 .708 .882 r
F P
0 g
s
.42633 .61152 m .4154 .62357 L .41575 .62754 L p .663 .697 .872 r
F P
0 g
s
.41575 .62754 m .43138 .61035 L .42633 .61152 L p .663 .697 .872 r
F P
0 g
s
.39652 .6179 m .41575 .62754 L .4154 .62357 L p .674 .706 .871 r
F P
0 g
s
.43138 .61035 m .41575 .62754 L .42053 .62613 L p .656 .687 .867 r
F P
0 g
s
.54168 .4941 m .52933 .49573 L .52585 .49695 L p .297 0 0 r
F P
0 g
s
.42989 .47155 m .43495 .4765 L .43856 .47953 L p .562 .022 0 r
F P
0 g
s
.32506 .61583 m .3408 .62612 L .3498 .62512 L p .676 .74 .899 r
F P
0 g
s
.39709 .44798 m .40878 .45415 L .41309 .45823 L p .103 .413 .862 r
F P
0 g
s
.47834 .49496 m .47761 .49958 L .4807 .50147 L p .717 .284 .22 r
F P
0 g
s
.455 .48654 m .44078 .47997 L .43856 .47953 L p .649 .091 0 r
F P
0 g
s
.43856 .47953 m .45889 .48891 L .455 .48654 L p .649 .091 0 r
F P
0 g
s
.3498 .62512 m .32732 .61036 L .32506 .61583 L p .676 .74 .899 r
F P
0 g
s
.36962 .60714 m .35074 .62027 L .3498 .62512 L p .686 .737 .89 r
F P
0 g
s
.3498 .62512 m .37676 .60641 L .36962 .60714 L p .686 .737 .89 r
F P
0 g
s
.32732 .61036 m .3498 .62512 L .35074 .62027 L p .69 .741 .89 r
F P
0 g
s
.37676 .60641 m .3498 .62512 L .35707 .62414 L p .682 .725 .882 r
F P
0 g
s
.50096 .49798 m .49873 .50284 L .50155 .50428 L p .628 .198 .206 r
F P
0 g
s
.42053 .62613 m .43147 .61411 L .43138 .61035 L p .656 .687 .867 r
F P
0 g
s
.75518 .37238 m .83157 .35481 L .82042 .35068 L p .761 .809 .891 r
F P
0 g
s
.82151 .31354 m .82042 .35068 L .83157 .35481 L p .761 .809 .891 r
F P
0 g
s
.83157 .35481 m .83345 .30168 L .82151 .31354 L p .761 .809 .891 r
F P
0 g
s
.83157 .35481 m .75518 .37238 L .76415 .37599 L p .753 .833 .913 r
F P
0 g
s
.38069 .43055 m .35921 .42148 L .35226 .41601 L p .314 .553 .919 r
F P
0 g
s
.35707 .62414 m .37594 .61107 L .37676 .60641 L p .682 .725 .882 r
F P
0 g
s
.50728 .49835 m .52209 .49808 L .52585 .49695 L p .536 .102 .163 r
F P
0 g
s
.46026 .49556 m .45889 .48891 L .45623 .48855 L p .793 .341 .17 r
F P
0 g
s
.44199 .48199 m .45623 .48855 L .45889 .48891 L p .791 .338 .166 r
F P
0 g
s
.45889 .48891 m .43856 .47953 L .44199 .48199 L p .791 .338 .166 r
F P
0 g
s
.46331 .49545 m .46234 .49079 L .45889 .48891 L p .714 .277 .211 r
F P
0 g
s
.45889 .48891 m .46026 .49556 L .46331 .49545 L p .714 .277 .211 r
F P
0 g
s
.60304 .47068 m .61389 .46455 L .61397 .46402 L p .497 .902 .796 r
F P
0 g
s
.61397 .46402 m .59846 .47279 L .60304 .47068 L p .497 .902 .796 r
F P
0 g
s
.58647 .47854 m .58056 .48313 L .57744 .48494 L p 0 0 0 r
F P
0 g
s
.52114 .5044 m .52585 .49695 L .52209 .49808 L p .533 .098 .159 r
F P
0 g
s
.52444 .50296 m .52772 .49774 L .52585 .49695 L p .442 .004 .109 r
F P
0 g
s
.52585 .49695 m .52114 .5044 L .52444 .50296 L p .442 .004 .109 r
F P
0 g
s
.54351 .49462 m .52585 .49695 L .52772 .49774 L p .442 .003 .106 r
F P
0 g
s
.52585 .49695 m .54351 .49462 L .54168 .4941 L p .297 0 0 r
F P
0 g
s
.60075 .65544 m .59399 .648 L .58893 .6472 L p .617 .816 .977 r
F P
0 g
s
.75272 .64208 m .72608 .6308 L .7174 .63063 L p .68 .769 .918 r
F P
0 g
s
.4154 .62357 m .40193 .6168 L .39652 .6179 L p .674 .706 .871 r
F P
0 g
s
.38298 .42896 m .35226 .41601 L .35616 .41428 L p .408 .55 .886 r
F P
0 g
s
.35237 .39475 m .35616 .41428 L .35226 .41601 L p .408 .55 .886 r
F P
0 g
s
.35226 .41601 m .34677 .3881 L .35237 .39475 L p .408 .55 .886 r
F P
0 g
s
.35226 .41601 m .38298 .42896 L .38069 .43055 L p .314 .553 .919 r
F P
0 g
s
.34677 .3881 m .35226 .41601 L .3441 .40937 L p .489 .612 .901 r
F P
0 g
s
.29014 .62482 m .273 .61121 L .26301 .61107 L p .681 .753 .906 r
F P
0 g
s
.63086 .65284 m .64769 .64673 L .64839 .64324 L p .66 .799 .949 r
F P
0 g
s
.64839 .64324 m .62431 .65199 L .63086 .65284 L p .66 .799 .949 r
F P
0 g
s
.52209 .49808 m .51878 .50329 L .52114 .5044 L p .533 .098 .159 r
F P
0 g
s
.58939 .47965 m .59846 .47279 L .59936 .47254 L p 0 0 0 r
F P
0 g
s
.61023 .4664 m .59936 .47254 L .59846 .47279 L p 0 0 0 r
F P
0 g
s
.59846 .47279 m .61397 .46402 L .61023 .4664 L p 0 0 0 r
F P
0 g
s
.58892 .47944 m .59527 .47462 L .59846 .47279 L p 0 0 0 r
F P
0 g
s
.59846 .47279 m .58939 .47965 L .58892 .47944 L p 0 0 0 r
F P
0 g
s
.66551 .42733 m .68689 .42044 L .69402 .41589 L p .782 .952 .928 r
F P
0 g
s
.55562 .49127 m .54649 .49328 L .54351 .49462 L p .194 0 0 r
F P
0 g
s
.70425 .64499 m .71952 .63532 L .7174 .63063 L p .68 .772 .921 r
F P
0 g
s
.7174 .63063 m .69559 .64449 L .70425 .64499 L p .68 .772 .921 r
F P
0 g
s
.66345 .42573 m .69402 .41589 L .691 .41374 L p .823 .916 .9 r
F P
0 g
s
.69878 .39481 m .691 .41374 L .69402 .41589 L p .823 .916 .9 r
F P
0 g
s
.69402 .41589 m .70519 .38886 L .69878 .39481 L p .823 .916 .9 r
F P
0 g
s
.69402 .41589 m .66345 .42573 L .66551 .42733 L p .782 .952 .928 r
F P
0 g
s
.70519 .38886 m .69402 .41589 L .70295 .41 L p .785 .87 .911 r
F P
0 g
s
.49617 .63993 m .50569 .64274 L .50838 .64104 L p .562 .684 .922 r
F P
0 g
s
.50838 .64104 m .49475 .63702 L .49617 .63993 L p .562 .684 .922 r
F P
0 g
s
.65461 .44018 m .66551 .42733 L .66345 .42573 L p .782 .952 .928 r
F P
0 g
s
.66345 .42573 m .6479 .4441 L .65461 .44018 L p .782 .952 .928 r
F P
0 g
s
.48544 .63654 m .49234 .63891 L .49475 .63702 L p .574 .676 .909 r
F P
0 g
s
.51065 .64381 m .52241 .64654 L .52521 .64495 L p .548 .699 .939 r
F P
0 g
s
.52521 .64495 m .50838 .64104 L .51065 .64381 L p .548 .699 .939 r
F P
0 g
s
.45623 .48855 m .45718 .49321 L .46026 .49556 L p .793 .341 .17 r
F P
0 g
s
.4736 .63298 m .4746 .63356 L .47608 .6312 L p .569 .643 .883 r
F P
0 g
s
.49475 .63702 m .48487 .63364 L .48544 .63654 L p .574 .676 .909 r
F P
0 g
s
.47608 .6312 m .47465 .63037 L .4736 .63298 L p .569 .643 .883 r
F P
0 g
s
.47864 .63418 m .48284 .63575 L .48487 .63364 L p .584 .672 .9 r
F P
0 g
s
.46823 .63086 m .47239 .63252 L .47465 .63037 L p .597 .669 .89 r
F P
0 g
s
.63008 .45162 m .6479 .4441 L .64743 .44267 L p .78 .994 .874 r
F P
0 g
s
.65831 .4298 m .64743 .44267 L .6479 .4441 L p .78 .994 .874 r
F P
0 g
s
.6479 .4441 m .66345 .42573 L .65831 .4298 L p .78 .994 .874 r
F P
0 g
s
.63019 .45248 m .64267 .44721 L .6479 .4441 L p .646 .968 .846 r
F P
0 g
s
.6479 .4441 m .63008 .45162 L .63019 .45248 L p .646 .968 .846 r
F P
0 g
s
.47631 .63338 m .4774 .63378 L .47886 .63139 L p .566 .643 .886 r
F P
0 g
s
.47886 .63139 m .4773 .63083 L .47631 .63338 L p .566 .643 .886 r
F P
0 g
s
.3441 .40937 m .34018 .38983 L .34677 .3881 L p .489 .612 .901 r
F P
0 g
s
.48487 .63364 m .47886 .63139 L .47864 .63418 L p .584 .672 .9 r
F P
0 g
s
.52772 .49774 m .5401 .49611 L .54351 .49462 L p .442 .003 .106 r
F P
0 g
s
.47465 .63037 m .46871 .628 L .46823 .63086 L p .597 .669 .89 r
F P
0 g
s
.35074 .62027 m .33501 .60991 L .32732 .61036 L p .69 .741 .89 r
F P
0 g
s
.70295 .41 m .71083 .39109 L .70519 .38886 L p .785 .87 .911 r
F P
0 g
s
.45903 .62707 m .46571 .62992 L .46871 .628 L p .607 .668 .883 r
F P
0 g
s
.52835 .64742 m .54208 .64947 L .54485 .64787 L p .541 .722 .957 r
F P
0 g
s
.54485 .64787 m .52521 .64495 L .52835 .64742 L p .541 .722 .957 r
F P
0 g
s
.37594 .61107 m .38977 .61909 L .39652 .6179 L p .675 .719 .882 r
F P
0 g
s
.6702 .63576 m .68822 .64442 L .69559 .64449 L p .677 .793 .936 r
F P
0 g
s
.69559 .64449 m .66985 .6321 L .6702 .63576 L p .677 .793 .936 r
F P
0 g
s
.71001 .63095 m .69474 .64068 L .69559 .64449 L p .684 .788 .929 r
F P
0 g
s
.69559 .64449 m .7174 .63063 L .71001 .63095 L p .684 .788 .929 r
F P
0 g
s
.66985 .6321 m .69559 .64449 L .69474 .64068 L p .692 .793 .928 r
F P
0 g
s
.60947 .64465 m .61876 .65136 L .62431 .65199 L p .615 .819 .979 r
F P
0 g
s
.62431 .65199 m .61108 .64239 L .60947 .64465 L p .615 .819 .979 r
F P
0 g
s
.64255 .64319 m .62568 .64933 L .62431 .65199 L p .654 .829 .967 r
F P
0 g
s
.62431 .65199 m .64839 .64324 L .64255 .64319 L p .654 .829 .967 r
F P
0 g
s
.61108 .64239 m .62431 .65199 L .62568 .64933 L p .656 .832 .967 r
F P
0 g
s
.46871 .628 m .45916 .62391 L .45903 .62707 L p .607 .668 .883 r
F P
0 g
s
.538 .5025 m .54351 .49462 L .5401 .49611 L p .438 0 .101 r
F P
0 g
s
.54078 .5009 m .54462 .49538 L .54351 .49462 L p .36 0 .057 r
F P
0 g
s
.54351 .49462 m .538 .5025 L .54078 .5009 L p .36 0 .057 r
F P
0 g
s
.55656 .49175 m .54351 .49462 L .54462 .49538 L p .361 0 .055 r
F P
0 g
s
.54351 .49462 m .55656 .49175 L .55562 .49127 L p .194 0 0 r
F P
0 g
s
.39652 .6179 m .37676 .60641 L .37594 .61107 L p .675 .719 .882 r
F P
0 g
s
.40924 .6019 m .39649 .61373 L .39652 .6179 L p .683 .71 .869 r
F P
0 g
s
.39652 .6179 m .41474 .60102 L .40924 .6019 L p .683 .71 .869 r
F P
0 g
s
.37676 .60641 m .39652 .6179 L .39649 .61373 L p .692 .717 .869 r
F P
0 g
s
.41474 .60102 m .39652 .6179 L .40193 .6168 L p .675 .695 .861 r
F P
0 g
s
.44651 .62148 m .45542 .6256 L .45916 .62391 L p .623 .67 .875 r
F P
0 g
s
.28615 .36995 m .23204 .35354 L .21859 .3433 L p .545 .653 .906 r
F P
0 g
s
.49694 .6263 m .494 .63468 L .49475 .63702 L p .535 .656 .914 r
F P
0 g
s
.49475 .63702 m .49896 .62505 L .49694 .6263 L p .535 .656 .914 r
F P
0 g
s
.48487 .63364 m .49475 .63702 L .494 .63468 L p .566 .677 .914 r
F P
0 g
s
.50683 .63873 m .49728 .63592 L .49475 .63702 L p .546 .688 .932 r
F P
0 g
s
.49475 .63702 m .50838 .64104 L .50683 .63873 L p .546 .688 .932 r
F P
0 g
s
.49896 .62505 m .49475 .63702 L .49728 .63592 L p .541 .663 .916 r
F P
0 g
s
.48149 .61991 m .47687 .62911 L .47608 .6312 L p .544 .614 .873 r
F P
0 g
s
.47608 .6312 m .48269 .61806 L .48149 .61991 L p .544 .614 .873 r
F P
0 g
s
.47465 .63037 m .47608 .6312 L .47687 .62911 L p .57 .643 .883 r
F P
0 g
s
.50844 .63107 m .50683 .63873 L .50838 .64104 L p .505 .667 .935 r
F P
0 g
s
.50838 .64104 m .5107 .6301 L .50844 .63107 L p .505 .667 .935 r
F P
0 g
s
.52287 .64283 m .51108 .64009 L .50838 .64104 L p .52 .705 .955 r
F P
0 g
s
.50838 .64104 m .52521 .64495 L .52287 .64283 L p .52 .705 .955 r
F P
0 g
s
.5107 .6301 m .50838 .64104 L .51108 .64009 L p .519 .68 .939 r
F P
0 g
s
.47962 .61872 m .47484 .62802 L .47465 .63037 L p .577 .648 .884 r
F P
0 g
s
.47465 .63037 m .48149 .6171 L .47962 .61872 L p .577 .648 .884 r
F P
0 g
s
.46871 .628 m .47465 .63037 L .47484 .62802 L p .599 .669 .888 r
F P
0 g
s
.47687 .62911 m .47587 .62853 L .47465 .63037 L p .57 .643 .883 r
F P
0 g
s
.48149 .6171 m .47465 .63037 L .47587 .62853 L p .549 .614 .87 r
F P
0 g
s
.48874 .62256 m .48486 .6314 L .48487 .63364 L p .556 .651 .898 r
F P
0 g
s
.48487 .63364 m .49042 .62102 L .48874 .62256 L p .556 .651 .898 r
F P
0 g
s
.47886 .63139 m .48487 .63364 L .48486 .6314 L p .581 .672 .902 r
F P
0 g
s
.494 .63468 m .48707 .63231 L .48487 .63364 L p .566 .677 .914 r
F P
0 g
s
.49042 .62102 m .48487 .63364 L .48707 .63231 L p .558 .653 .899 r
F P
0 g
s
.54879 .64989 m .56389 .65061 L .56647 .64891 L p .546 .753 .973 r
F P
0 g
s
.56647 .64891 m .54485 .64787 L .54879 .64989 L p .546 .753 .973 r
F P
0 g
s
.56443 .48887 m .55888 .49047 L .55656 .49175 L p .112 0 0 r
F P
0 g
s
.40193 .6168 m .4147 .605 L .41474 .60102 L p .675 .695 .861 r
F P
0 g
s
.59936 .47254 m .59303 .47734 L .58939 .47965 L p 0 0 0 r
F P
0 g
s
.4796 .62936 m .4785 .62896 L .4773 .63083 L p .566 .643 .886 r
F P
0 g
s
.4773 .63083 m .47886 .63139 L .4796 .62936 L p .566 .643 .886 r
F P
0 g
s
.48392 .61768 m .4773 .63083 L .4785 .62896 L p .544 .614 .872 r
F P
0 g
s
.48407 .62025 m .4796 .62936 L .47886 .63139 L p .54 .614 .875 r
F P
0 g
s
.47886 .63139 m .48526 .61838 L .48407 .62025 L p .54 .614 .875 r
F P
0 g
s
.48486 .6314 m .48065 .62982 L .47886 .63139 L p .581 .672 .902 r
F P
0 g
s
.48526 .61838 m .47886 .63139 L .48065 .62982 L p .569 .649 .89 r
F P
0 g
s
.5401 .49611 m .53623 .50163 L .538 .5025 L p .438 0 .101 r
F P
0 g
s
.47386 .61579 m .46852 .62532 L .46871 .628 L p .589 .648 .877 r
F P
0 g
s
.46871 .628 m .47636 .61439 L .47386 .61579 L p .589 .648 .877 r
F P
0 g
s
.45916 .62391 m .46871 .628 L .46852 .62532 L p .613 .667 .878 r
F P
0 g
s
.47484 .62802 m .47068 .62635 L .46871 .628 L p .599 .669 .888 r
F P
0 g
s
.47636 .61439 m .46871 .628 L .47068 .62635 L p .588 .647 .876 r
F P
0 g
s
.45916 .62391 m .44642 .61802 L .44651 .62148 L p .623 .67 .875 r
F P
0 g
s
.52297 .63603 m .52287 .64283 L .52521 .64495 L p .472 .685 .96 r
F P
0 g
s
.52521 .64495 m .52537 .63525 L .52297 .63603 L p .472 .685 .96 r
F P
0 g
s
.54176 .64609 m .52798 .64404 L .52521 .64495 L p .499 .733 .977 r
F P
0 g
s
.52521 .64495 m .54485 .64787 L .54176 .64609 L p .499 .733 .977 r
F P
0 g
s
.52537 .63525 m .52521 .64495 L .52798 .64404 L p .5 .71 .965 r
F P
0 g
s
.35616 .41428 m .37771 .42334 L .38298 .42896 L p .408 .55 .886 r
F P
0 g
s
.46497 .611 m .45871 .62089 L .45916 .62391 L p .61 .651 .866 r
F P
0 g
s
.45916 .62391 m .46812 .60979 L .46497 .611 L p .61 .651 .866 r
F P
0 g
s
.44642 .61802 m .45916 .62391 L .45871 .62089 L p .632 .668 .866 r
F P
0 g
s
.46852 .62532 m .46183 .62246 L .45916 .62391 L p .613 .667 .878 r
F P
0 g
s
.46812 .60979 m .45916 .62391 L .46183 .62246 L p .606 .646 .864 r
F P
0 g
s
.49873 .50284 m .48415 .50087 L .4807 .50147 L p .628 .198 .206 r
F P
0 g
s
.43147 .61411 m .442 .61946 L .44642 .61802 L p .641 .674 .866 r
F P
0 g
s
.54462 .49538 m .55377 .49337 L .55656 .49175 L p .361 0 .055 r
F P
0 g
s
.55656 .49175 m .56449 .48947 L .56443 .48887 L p .112 0 0 r
F P
0 g
s
.47761 .49958 m .46331 .49545 L .46026 .49556 L p .717 .282 .216 r
F P
0 g
s
.46026 .49556 m .4807 .50147 L .47761 .49958 L p .717 .282 .216 r
F P
0 g
s
.43495 .4765 m .42409 .46804 L .42305 .46744 L p .563 .023 0 r
F P
0 g
s
.42305 .46744 m .43856 .47953 L .43495 .4765 L p .563 .023 0 r
F P
0 g
s
.44222 .48692 m .43856 .47953 L .43693 .47892 L p .824 .347 .002 r
F P
0 g
s
.42607 .47046 m .43693 .47892 L .43856 .47953 L p .822 .343 0 r
F P
0 g
s
.43856 .47953 m .42305 .46744 L .42607 .47046 L p .822 .343 0 r
F P
0 g
s
.44456 .48716 m .44199 .48199 L .43856 .47953 L p .791 .335 .161 r
F P
0 g
s
.43856 .47953 m .44222 .48692 L .44456 .48716 L p .791 .335 .161 r
F P
0 g
s
.47587 .62853 m .48065 .61924 L .48149 .6171 L p .549 .614 .87 r
F P
0 g
s
.49728 .63592 m .50023 .62754 L .49896 .62505 L p .541 .663 .916 r
F P
0 g
s
.48707 .63231 m .49097 .62349 L .49042 .62102 L p .558 .653 .899 r
F P
0 g
s
.39649 .61373 m .38266 .60567 L .37676 .60641 L p .692 .717 .869 r
F P
0 g
s
.56795 .48787 m .56607 .48839 L .56449 .48947 L p .121 0 0 r
F P
0 g
s
.64743 .44267 m .63496 .44793 L .63008 .45162 L p .78 .994 .874 r
F P
0 g
s
.62568 .64933 m .61643 .6426 L .61108 .64239 L p .656 .832 .967 r
F P
0 g
s
.42409 .46804 m .41712 .46159 L .41309 .45823 L p .563 .023 0 r
F P
0 g
s
.82042 .35068 m .76676 .36298 L .75518 .37238 L p .761 .809 .891 r
F P
0 g
s
.4785 .62896 m .48314 .61976 L .48392 .61768 L p .544 .614 .872 r
F P
0 g
s
.47068 .62635 m .47603 .61683 L .47636 .61439 L p .588 .647 .876 r
F P
0 g
s
.51108 .64009 m .51272 .63243 L .5107 .6301 L p .519 .68 .939 r
F P
0 g
s
.48065 .62982 m .48513 .62071 L .48526 .61838 L p .569 .649 .89 r
F P
0 g
s
.55086 .4998 m .55656 .49175 L .55377 .49337 L p .358 0 .052 r
F P
0 g
s
.55291 .49825 m .55689 .49261 L .55656 .49175 L p .3 0 .02 r
F P
0 g
s
.55656 .49175 m .55086 .4998 L .55291 .49825 L p .3 0 .02 r
F P
0 g
s
.56449 .48947 m .55656 .49175 L .55689 .49261 L p .3 0 .019 r
F P
0 g
s
.42305 .46744 m .42409 .46804 L p .42259 .46669 L .563 .023 0 r
F P
0 g
s
.41309 .45823 m .42305 .46744 L p .42259 .46669 L .563 .023 0 r
F P
0 g
s
.42305 .46744 m .42264 .46682 L p .42344 .46808 L .601 .181 0 r
F P
0 g
s
.42853 .47608 m .42305 .46744 L p .42344 .46808 L .601 .181 0 r
F P
0 g
s
.42305 .46744 m .41309 .45823 L .41313 .45735 L p 0 .159 .693 r
F P
0 g
s
.4057 .44579 m .41313 .45735 L .41309 .45823 L p 0 .16 .694 r
F P
0 g
s
.41309 .45823 m .40247 .44172 L .4057 .44579 L p 0 .16 .694 r
F P
0 g
s
.40247 .44172 m .41309 .45823 L .40878 .45415 L p .104 .413 .862 r
F P
0 g
s
.4807 .50147 m .50155 .50428 L .49873 .50284 L p .628 .198 .206 r
F P
0 g
s
.54015 .64023 m .54176 .64609 L .54485 .64787 L p .445 .715 .982 r
F P
0 g
s
.54485 .64787 m .54258 .63951 L .54015 .64023 L p .445 .715 .982 r
F P
0 g
s
.5627 .64759 m .54755 .64687 L .54485 .64787 L p .492 .769 .993 r
F P
0 g
s
.54485 .64787 m .56647 .64891 L .5627 .64759 L p .492 .769 .993 r
F P
0 g
s
.54258 .63951 m .54485 .64787 L .54755 .64687 L p .493 .752 .987 r
F P
0 g
s
.691 .41374 m .66957 .42061 L .66345 .42573 L p .823 .916 .9 r
F P
0 g
s
.69474 .64068 m .67672 .63198 L .66985 .6321 L p .692 .793 .928 r
F P
0 g
s
.56449 .48947 m .56718 .48872 L .56795 .48787 L p .121 0 0 r
F P
0 g
s
.61892 .46116 m .63019 .45248 L .63008 .45162 L p .646 .968 .846 r
F P
0 g
s
.63008 .45162 m .61397 .46402 L .61892 .46116 L p .646 .968 .846 r
F P
0 g
s
.56877 .4876 m .5706 .48692 L .56979 .48774 L p .01 0 0 r
F P
0 g
s
.56979 .48774 m .56718 .48872 L .56877 .4876 L p .01 0 0 r
F P
0 g
s
.4787 .50826 m .4807 .50147 L .47747 .50159 L p .749 .394 .381 r
F P
0 g
s
.46316 .49745 m .47747 .50159 L .4807 .50147 L p .748 .392 .378 r
F P
0 g
s
.4807 .50147 m .46026 .49556 L .46316 .49745 L p .748 .392 .378 r
F P
0 g
s
.482 .50771 m .4834 .50295 L .4807 .50147 L p .667 .309 .357 r
F P
0 g
s
.4807 .50147 m .4787 .50826 L .482 .50771 L p .667 .309 .357 r
F P
0 g
s
.50155 .50428 m .4807 .50147 L .4834 .50295 L p .667 .31 .358 r
F P
0 g
s
.40878 .45415 m .40134 .44259 L .40247 .44172 L p .104 .413 .862 r
F P
0 g
s
.46183 .62246 m .4681 .61257 L .46812 .60979 L p .606 .646 .864 r
F P
0 g
s
.51878 .50329 m .50508 .50321 L .50155 .50428 L p .533 .099 .162 r
F P
0 g
s
.44642 .61802 m .43138 .61035 L .43147 .61411 L p .641 .674 .866 r
F P
0 g
s
.45329 .60451 m .44589 .61469 L .44642 .61802 L p .635 .658 .855 r
F P
0 g
s
.44642 .61802 m .45701 .60349 L .45329 .60451 L p .635 .658 .855 r
F P
0 g
s
.43138 .61035 m .44642 .61802 L .44589 .61469 L p .655 .672 .854 r
F P
0 g
s
.45871 .62089 m .44979 .61676 L .44642 .61802 L p .632 .668 .866 r
F P
0 g
s
.45701 .60349 m .44642 .61802 L .44979 .61676 L p .629 .648 .85 r
F P
0 g
s
.52798 .64404 m .52811 .63725 L .52537 .63525 L p .5 .71 .965 r
F P
0 g
s
.57105 .65034 m .58674 .64915 L .58893 .6472 L p .571 .788 .981 r
F P
0 g
s
.58893 .6472 m .56647 .64891 L .57105 .65034 L p .571 .788 .981 r
F P
0 g
s
.55377 .49337 m .54977 .49901 L .55086 .4998 L p .358 0 .052 r
F P
0 g
s
.60331 .47155 m .61023 .4664 L .61397 .46402 L p 0 0 0 r
F P
0 g
s
.61397 .46402 m .6041 .47138 L .60331 .47155 L p 0 0 0 r
F P
0 g
s
.6041 .47138 m .61397 .46402 L .61483 .46333 L p .444 .822 .578 r
F P
0 g
s
.62611 .45464 m .61483 .46333 L .61397 .46402 L p .444 .821 .577 r
F P
0 g
s
.61397 .46402 m .63008 .45162 L .62611 .45464 L p .444 .821 .577 r
F P
0 g
s
.57219 .48634 m .57754 .48439 L .57744 .48494 L p .014 0 0 r
F P
0 g
s
.57744 .48494 m .56979 .48774 L .57219 .48634 L p .014 0 0 r
F P
0 g
s
.45718 .49321 m .44456 .48716 L .44222 .48692 L p .793 .339 .165 r
F P
0 g
s
.44222 .48692 m .46026 .49556 L .45718 .49321 L p .793 .339 .165 r
F P
0 g
s
.29616 .36679 m .21859 .3433 L .23096 .34048 L p .57 .644 .884 r
F P
0 g
s
.23504 .30566 m .23096 .34048 L .21859 .3433 L p .57 .644 .884 r
F P
0 g
s
.21859 .3433 m .22411 .29344 L .23504 .30566 L p .57 .644 .884 r
F P
0 g
s
.21859 .3433 m .29616 .36679 L .28615 .36995 L p .545 .653 .906 r
F P
0 g
s
.47747 .50159 m .47606 .50634 L .4787 .50826 L p .749 .394 .381 r
F P
0 g
s
.4979 .51174 m .50155 .50428 L .498 .50492 L p .668 .312 .36 r
F P
0 g
s
.4834 .50295 m .498 .50492 L .50155 .50428 L p .667 .31 .358 r
F P
0 g
s
.5013 .5107 m .50384 .50547 L .50155 .50428 L p .586 .223 .319 r
F P
0 g
s
.50155 .50428 m .4979 .51174 L .5013 .5107 L p .586 .223 .319 r
F P
0 g
s
.52114 .5044 m .50155 .50428 L .50384 .50547 L p .586 .221 .316 r
F P
0 g
s
.50155 .50428 m .52114 .5044 L .51878 .50329 L p .533 .099 .162 r
F P
0 g
s
.5588 .49758 m .56449 .48947 L .56245 .49101 L p .299 0 .019 r
F P
0 g
s
.55689 .49261 m .56245 .49101 L .56449 .48947 L p .3 0 .019 r
F P
0 g
s
.56006 .49623 m .56404 .49055 L .56449 .48947 L p .285 0 .011 r
F P
0 g
s
.56449 .48947 m .5588 .49758 L .56006 .49623 L p .285 0 .011 r
F P
0 g
s
.56718 .48872 m .56449 .48947 L .56404 .49055 L p .299 0 .016 r
F P
0 g
s
.44979 .61676 m .45721 .6066 L .45701 .60349 L p .629 .648 .85 r
F P
0 g
s
.43693 .47892 m .43948 .48409 L .44222 .48692 L p .824 .347 .002 r
F P
0 g
s
.45996 .50223 m .46026 .49556 L .45764 .49528 L p .831 .468 .369 r
F P
0 g
s
.445 .48923 m .45764 .49528 L .46026 .49556 L p .829 .463 .363 r
F P
0 g
s
.46026 .49556 m .44222 .48692 L .445 .48923 L p .829 .463 .363 r
F P
0 g
s
.46295 .50212 m .46316 .49745 L .46026 .49556 L p .748 .391 .376 r
F P
0 g
s
.46026 .49556 m .45996 .50223 L .46295 .50212 L p .748 .391 .376 r
F P
0 g
s
.4147 .605 m .42633 .61152 L .43138 .61035 L p .663 .685 .861 r
F P
0 g
s
.44589 .61469 m .43535 .60931 L .43138 .61035 L p .655 .672 .854 r
F P
0 g
s
.54755 .64687 m .54598 .64102 L .54258 .63951 L p .493 .752 .987 r
F P
0 g
s
.65518 .64354 m .6702 .63576 L .66985 .6321 L p .682 .797 .936 r
F P
0 g
s
.66985 .6321 m .64839 .64324 L .65518 .64354 L p .682 .797 .936 r
F P
0 g
s
.56148 .49672 m .56718 .48872 L .56672 .48977 L p .234 0 0 r
F P
0 g
s
.56855 .48908 m .56672 .48977 L .56718 .48872 L p .219 0 0 r
F P
0 g
s
.56718 .48872 m .56979 .48774 L .56855 .48908 L p .219 0 0 r
F P
0 g
s
.56148 .49672 m .56718 .48872 L .56593 .49003 L p .28 0 .002 r
F P
0 g
s
.56404 .49055 m .56593 .49003 L .56718 .48872 L p .299 0 .016 r
F P
0 g
s
.498 .50492 m .49544 .51014 L .4979 .51174 L p .668 .312 .36 r
F P
0 g
s
.55926 .64258 m .5627 .64759 L .56647 .64891 L p .445 .757 .995 r
F P
0 g
s
.56647 .64891 m .56158 .64174 L .55926 .64258 L p .445 .757 .995 r
F P
0 g
s
.58465 .64647 m .56891 .64767 L .56647 .64891 L p .516 .812 .999 r
F P
0 g
s
.56647 .64891 m .58893 .6472 L .58465 .64647 L p .516 .812 .999 r
F P
0 g
s
.56158 .64174 m .56647 .64891 L .56891 .64767 L p .516 .8 .997 r
F P
0 g
s
.73838 .62087 m .76783 .63082 L .77705 .63067 L p .678 .762 .915 r
F P
0 g
s
.77705 .63067 m .73496 .61642 L .73838 .62087 L p .678 .762 .915 r
F P
0 g
s
.78461 .61578 m .77303 .62643 L .77705 .63067 L p .675 .76 .915 r
F P
0 g
s
.77705 .63067 m .79362 .6155 L .78461 .61578 L p .675 .76 .915 r
F P
0 g
s
.73496 .61642 m .77705 .63067 L .77303 .62643 L p .681 .761 .912 r
F P
0 g
s
.71083 .39109 m .74575 .37956 L .75518 .37238 L p .785 .87 .911 r
F P
0 g
s
.41313 .45735 m .4201 .46379 L .42305 .46744 L p 0 .159 .693 r
F P
0 g
s
.43138 .61035 m .41474 .60102 L .4147 .605 L p .663 .685 .861 r
F P
0 g
s
.43952 .59639 m .43088 .60676 L .43138 .61035 L p .664 .671 .847 r
F P
0 g
s
.43138 .61035 m .44374 .59555 L .43952 .59639 L p .664 .671 .847 r
F P
0 g
s
.41474 .60102 m .43138 .61035 L .43088 .60676 L p .68 .683 .846 r
F P
0 g
s
.44374 .59555 m .43138 .61035 L .43535 .60931 L p .654 .655 .839 r
F P
0 g
s
.56414 .49584 m .56979 .48774 L .5701 .48852 L p .225 0 0 r
F P
0 g
s
.57546 .48656 m .5701 .48852 L .56979 .48774 L p .224 0 0 r
F P
0 g
s
.56979 .48774 m .57744 .48494 L .57546 .48656 L p .224 0 0 r
F P
0 g
s
.5646 .49476 m .56855 .48908 L .56979 .48774 L p .24 0 0 r
F P
0 g
s
.56979 .48774 m .56414 .49584 L .5646 .49476 L p .24 0 0 r
F P
0 g
s
.50384 .50547 m .51756 .50556 L .52114 .5044 L p .586 .221 .316 r
F P
0 g
s
.56245 .49101 m .55846 .49669 L .5588 .49758 L p .299 0 .019 r
F P
0 g
s
.45764 .49528 m .45742 .49995 L .45996 .50223 L p .831 .468 .369 r
F P
0 g
s
.53623 .50163 m .52444 .50296 L .52114 .5044 L p .438 0 .104 r
F P
0 g
s
.63089 .63713 m .64255 .64319 L .64839 .64324 L p .657 .828 .965 r
F P
0 g
s
.64839 .64324 m .63175 .63456 L .63089 .63713 L p .657 .828 .965 r
F P
0 g
s
.6639 .63253 m .64887 .64035 L .64839 .64324 L p .685 .826 .951 r
F P
0 g
s
.64839 .64324 m .66985 .6321 L .6639 .63253 L p .685 .826 .951 r
F P
0 g
s
.63175 .63456 m .64839 .64324 L .64887 .64035 L p .692 .833 .951 r
F P
0 g
s
.58056 .48313 m .58892 .47944 L .58939 .47965 L p 0 0 0 r
F P
0 g
s
.58939 .47965 m .57744 .48494 L .58056 .48313 L p 0 0 0 r
F P
0 g
s
.40134 .44259 m .38772 .43366 L .38298 .42896 L p .104 .413 .862 r
F P
0 g
s
.43535 .60931 m .44401 .59896 L .44374 .59555 L p .654 .655 .839 r
F P
0 g
s
.56593 .49003 m .56193 .49563 L .56148 .49672 L p .28 0 .002 r
F P
0 g
s
.33501 .60991 m .35645 .59802 L .35796 .59333 L p .692 .737 .886 r
F P
0 g
s
.35796 .59333 m .32732 .61036 L .33501 .60991 L p .692 .737 .886 r
F P
0 g
s
.30398 .59926 m .31801 .61072 L .32732 .61036 L p .681 .751 .904 r
F P
0 g
s
.32732 .61036 m .30731 .59395 L .30398 .59926 L p .681 .751 .904 r
F P
0 g
s
.35062 .59362 m .32915 .60556 L .32732 .61036 L p .695 .752 .895 r
F P
0 g
s
.32732 .61036 m .35796 .59333 L .35062 .59362 L p .695 .752 .895 r
F P
0 g
s
.30731 .59395 m .32732 .61036 L .32915 .60556 L p .697 .754 .896 r
F P
0 g
s
.56672 .48977 m .56273 .49537 L .56148 .49672 L p .234 0 0 r
F P
0 g
s
.61483 .46333 m .60793 .46847 L .6041 .47138 L p .444 .822 .578 r
F P
0 g
s
.35645 .59802 m .36962 .60714 L .37676 .60641 L p .688 .733 .885 r
F P
0 g
s
.37676 .60641 m .35796 .59333 L .35645 .59802 L p .688 .733 .885 r
F P
0 g
s
.39191 .59084 m .37727 .60215 L .37676 .60641 L p .701 .729 .872 r
F P
0 g
s
.37676 .60641 m .39767 .59028 L .39191 .59084 L p .701 .729 .872 r
F P
0 g
s
.35796 .59333 m .37676 .60641 L .37727 .60215 L p .707 .734 .872 r
F P
0 g
s
.39767 .59028 m .37676 .60641 L .38266 .60567 L p .693 .709 .861 r
F P
0 g
s
.51627 .51267 m .52114 .5044 L .51756 .50556 L p .583 .216 .311 r
F P
0 g
s
.5195 .51118 m .5229 .50539 L .52114 .5044 L p .504 .131 .266 r
F P
0 g
s
.52114 .5044 m .51627 .51267 L .5195 .51118 L p .504 .131 .266 r
F P
0 g
s
.538 .5025 m .52114 .5044 L .5229 .50539 L p .506 .129 .26 r
F P
0 g
s
.52114 .5044 m .538 .5025 L .53623 .50163 L p .438 0 .104 r
F P
0 g
s
.59399 .648 m .60947 .64465 L .61108 .64239 L p .613 .816 .978 r
F P
0 g
s
.61108 .64239 m .58893 .6472 L .59399 .648 L p .613 .816 .978 r
F P
0 g
s
.70519 .38886 m .75518 .37238 L .74778 .3698 L p .794 .835 .882 r
F P
0 g
s
.74786 .34269 m .74778 .3698 L .75518 .37238 L p .794 .834 .882 r
F P
0 g
s
.75518 .37238 m .75543 .33362 L .74786 .34269 L p .794 .834 .882 r
F P
0 g
s
.75518 .37238 m .70519 .38886 L .71083 .39109 L p .785 .87 .911 r
F P
0 g
s
.75543 .33362 m .75518 .37238 L .76676 .36298 L p .761 .809 .891 r
F P
0 g
s
.43088 .60676 m .41923 .60022 L .41474 .60102 L p .68 .683 .846 r
F P
0 g
s
.38266 .60567 m .39729 .59439 L .39767 .59028 L p .693 .709 .861 r
F P
0 g
s
.40247 .44172 m .38298 .42896 L .38548 .42799 L p .293 .457 .853 r
F P
0 g
s
.38312 .4129 m .38548 .42799 L .38298 .42896 L p .293 .457 .852 r
F P
0 g
s
.38298 .42896 m .37958 .4074 L .38312 .4129 L p .293 .457 .852 r
F P
0 g
s
.38298 .42896 m .40247 .44172 L .40134 .44259 L p .104 .413 .862 r
F P
0 g
s
.37958 .4074 m .38298 .42896 L .37771 .42334 L p .407 .55 .886 r
F P
0 g
s
.56891 .64767 m .5655 .64265 L .56158 .64174 L p .516 .8 .997 r
F P
0 g
s
.5701 .48852 m .56616 .49419 L .56414 .49584 L p .225 0 0 r
F P
0 g
s
.57191 .49297 m .57744 .48494 L .57841 .48534 L p .155 0 0 r
F P
0 g
s
.58679 .48163 m .57841 .48534 L .57744 .48494 L p .155 0 0 r
F P
0 g
s
.57744 .48494 m .58939 .47965 L .58679 .48163 L p .155 0 0 r
F P
0 g
s
.57159 .49218 m .57546 .48656 L .57744 .48494 L p .225 0 0 r
F P
0 g
s
.57744 .48494 m .57191 .49297 L .57159 .49218 L p .225 0 0 r
F P
0 g
s
.51756 .50556 m .51414 .51134 L .51627 .51267 L p .583 .216 .311 r
F P
0 g
s
.72608 .6308 m .73838 .62087 L .73496 .61642 L p .684 .765 .912 r
F P
0 g
s
.73496 .61642 m .7174 .63063 L .72608 .6308 L p .684 .765 .912 r
F P
0 g
s
.37771 .42334 m .37529 .40824 L .37958 .4074 L p .407 .55 .886 r
F P
0 g
s
.34018 .38983 m .30485 .37493 L .29616 .36679 L p .489 .612 .901 r
F P
0 g
s
.77303 .62643 m .74355 .61642 L .73496 .61642 L p .681 .761 .912 r
F P
0 g
s
.47606 .50634 m .46295 .50212 L .45996 .50223 L p .749 .393 .379 r
F P
0 g
s
.45996 .50223 m .4787 .50826 L .47606 .50634 L p .749 .393 .379 r
F P
0 g
s
.57942 .64224 m .58465 .64647 L .58893 .6472 L p .485 .806 1 r
F P
0 g
s
.58893 .6472 m .58149 .64116 L .57942 .64224 L p .485 .806 1 r
F P
0 g
s
.60645 .64227 m .59093 .64565 L .58893 .6472 L p .572 .852 .996 r
F P
0 g
s
.58893 .6472 m .61108 .64239 L .60645 .64227 L p .572 .852 .996 r
F P
0 g
s
.58149 .64116 m .58893 .6472 L .59093 .64565 L p .571 .848 .996 r
F P
0 g
s
.49544 .51014 m .482 .50771 L .4787 .50826 L p .668 .311 .359 r
F P
0 g
s
.273 .61121 m .30398 .59926 L .30731 .59395 L p .681 .752 .905 r
F P
0 g
s
.30731 .59395 m .26301 .61107 L .273 .61121 L p .681 .752 .905 r
F P
0 g
s
.5229 .50539 m .53471 .50407 L .538 .5025 L p .506 .129 .26 r
F P
0 g
s
.39729 .59439 m .40924 .6019 L .41474 .60102 L p .684 .701 .86 r
F P
0 g
s
.68937 .6231 m .71001 .63095 L .7174 .63063 L p .689 .783 .922 r
F P
0 g
s
.7174 .63063 m .68792 .61939 L .68937 .6231 L p .689 .783 .922 r
F P
0 g
s
.72769 .61696 m .71541 .62693 L .7174 .63063 L p .689 .777 .918 r
F P
0 g
s
.7174 .63063 m .73496 .61642 L .72769 .61696 L p .689 .777 .918 r
F P
0 g
s
.68792 .61939 m .7174 .63063 L .71541 .62693 L p .698 .781 .915 r
F P
0 g
s
.64887 .64035 m .63723 .63426 L .63175 .63456 L p .692 .833 .951 r
F P
0 g
s
.44354 .49382 m .44222 .48692 L .44047 .4864 L p .906 .521 .278 r
F P
0 g
s
.43088 .47881 m .44047 .4864 L .44222 .48692 L p .906 .519 .275 r
F P
0 g
s
.44222 .48692 m .42853 .47608 L .43088 .47881 L p .906 .519 .275 r
F P
0 g
s
.44593 .49407 m .445 .48923 L .44222 .48692 L p .829 .459 .354 r
F P
0 g
s
.44222 .48692 m .44354 .49382 L .44593 .49407 L p .829 .459 .354 r
F P
0 g
s
.42853 .47608 m .44222 .48692 L .43948 .48409 L p .822 .343 0 r
F P
0 g
s
.29789 .59368 m .26684 .60569 L .26301 .61107 L p .682 .761 .911 r
F P
0 g
s
.26301 .61107 m .30731 .59395 L .29789 .59368 L p .682 .761 .911 r
F P
0 g
s
.24243 .59018 m .26301 .61107 L .26684 .60569 L p .681 .76 .911 r
F P
0 g
s
.43948 .48409 m .42991 .47651 L .42853 .47608 L p .822 .343 0 r
F P
0 g
s
.4763 .51455 m .4787 .50826 L .47563 .50827 L p .756 .456 .477 r
F P
0 g
s
.46251 .50405 m .47563 .50827 L .4787 .50826 L p .755 .452 .471 r
F P
0 g
s
.4787 .50826 m .45996 .50223 L .46251 .50405 L p .755 .452 .471 r
F P
0 g
s
.47945 .51418 m .48111 .50978 L .4787 .50826 L p .682 .374 .447 r
F P
0 g
s
.4787 .50826 m .4763 .51455 L .47945 .51418 L p .682 .374 .447 r
F P
0 g
s
.4979 .51174 m .4787 .50826 L .48111 .50978 L p .681 .375 .45 r
F P
0 g
s
.4787 .50826 m .4979 .51174 L .49544 .51014 L p .668 .311 .359 r
F P
0 g
s
.41474 .60102 m .39767 .59028 L .39729 .59439 L p .684 .701 .86 r
F P
0 g
s
.42443 .58694 m .41447 .59725 L .41474 .60102 L p .693 .691 .844 r
F P
0 g
s
.41474 .60102 m .42898 .5863 L .42443 .58694 L p .693 .691 .844 r
F P
0 g
s
.39767 .59028 m .41474 .60102 L .41447 .59725 L p .704 .699 .843 r
F P
0 g
s
.42898 .5863 m .41474 .60102 L .41923 .60022 L p .68 .669 .832 r
F P
0 g
s
.37727 .60215 m .36412 .59298 L .35796 .59333 L p .707 .734 .872 r
F P
0 g
s
.54977 .49901 m .54078 .5009 L .538 .5025 L p .357 0 .053 r
F P
0 g
s
.23096 .34048 m .28544 .35696 L .29616 .36679 L p .57 .644 .884 r
F P
0 g
s
.48065 .61924 m .48149 .61991 L .48269 .61806 L p .52 .581 .857 r
F P
0 g
s
.48269 .61806 m .48149 .6171 L .48065 .61924 L p .52 .581 .857 r
F P
0 g
s
.47603 .61683 m .47962 .61872 L .48149 .6171 L p .564 .624 .87 r
F P
0 g
s
.48149 .6171 m .47636 .61439 L .47603 .61683 L p .564 .624 .87 r
F P
0 g
s
.4681 .61257 m .47386 .61579 L .47636 .61439 L p .581 .625 .86 r
F P
0 g
s
.57841 .48534 m .57455 .49095 L .57191 .49297 L p .155 0 0 r
F P
0 g
s
.32915 .60556 m .31517 .59405 L .30731 .59395 L p .697 .754 .896 r
F P
0 g
s
.41923 .60022 m .4292 .58992 L .42898 .5863 L p .68 .669 .832 r
F P
0 g
s
.59303 .47734 m .60331 .47155 L .6041 .47138 L p 0 0 0 r
F P
0 g
s
.6041 .47138 m .58939 .47965 L .59303 .47734 L p 0 0 0 r
F P
0 g
s
.47636 .61439 m .46812 .60979 L .4681 .61257 L p .581 .625 .86 r
F P
0 g
s
.48314 .61976 m .48407 .62025 L .48526 .61838 L p .515 .581 .859 r
F P
0 g
s
.48526 .61838 m .48392 .61768 L .48314 .61976 L p .515 .581 .859 r
F P
0 g
s
.45742 .49995 m .44593 .49407 L .44354 .49382 L p .831 .465 .361 r
F P
0 g
s
.44354 .49382 m .45996 .50223 L .45742 .49995 L p .831 .465 .361 r
F P
0 g
s
.47563 .50827 m .47395 .51267 L .4763 .51455 L p .756 .456 .477 r
F P
0 g
s
.48513 .62071 m .48874 .62256 L .49042 .62102 L p .542 .625 .884 r
F P
0 g
s
.49042 .62102 m .48526 .61838 L .48513 .62071 L p .542 .625 .884 r
F P
0 g
s
.49097 .62349 m .49694 .6263 L .49896 .62505 L p .524 .629 .897 r
F P
0 g
s
.49896 .62505 m .49042 .62102 L .49097 .62349 L p .524 .629 .897 r
F P
0 g
s
.45721 .6066 m .46497 .611 L .46812 .60979 L p .605 .63 .849 r
F P
0 g
s
.76676 .36298 m .7671 .33582 L .75543 .33362 L p .761 .809 .891 r
F P
0 g
s
.48111 .50978 m .49457 .51222 L .4979 .51174 L p .681 .375 .45 r
F P
0 g
s
.45884 .50816 m .45996 .50223 L .45742 .50187 L p .835 .531 .475 r
F P
0 g
s
.44592 .49599 m .45742 .50187 L .45996 .50223 L p .834 .527 .471 r
F P
0 g
s
.45996 .50223 m .44354 .49382 L .44592 .49599 L p .834 .527 .471 r
F P
0 g
s
.46173 .5082 m .46251 .50405 L .45996 .50223 L p .756 .45 .466 r
F P
0 g
s
.45996 .50223 m .45884 .50816 L .46173 .5082 L p .756 .45 .466 r
F P
0 g
s
.42991 .47651 m .42607 .47046 L .42305 .46744 L p .82 .339 0 r
F P
0 g
s
.50023 .62754 m .50844 .63107 L .5107 .6301 L p .499 .639 .917 r
F P
0 g
s
.5107 .6301 m .49896 .62505 L .50023 .62754 L p .499 .639 .917 r
F P
0 g
s
.46812 .60979 m .45701 .60349 L .45721 .6066 L p .605 .63 .849 r
F P
0 g
s
.51414 .51134 m .5013 .5107 L .4979 .51174 L p .583 .217 .314 r
F P
0 g
s
.41425 .45362 m .42305 .46744 L .4201 .46379 L p 0 .16 .694 r
F P
0 g
s
.41648 .45715 m .42264 .46682 L .42305 .46744 L p .604 .185 0 r
F P
0 g
s
.42305 .46744 m .41425 .45362 L .41648 .45715 L p .604 .185 0 r
F P
0 g
s
.42305 .46744 m .42853 .47608 L .42991 .47651 L p .82 .339 0 r
F P
0 g
s
.53271 .51137 m .538 .5025 L .53471 .50407 L p .498 .118 .25 r
F P
0 g
s
.53546 .50964 m .53916 .50343 L .538 .5025 L p .435 .053 .214 r
F P
0 g
s
.538 .5025 m .53271 .51137 L .53546 .50964 L p .435 .053 .214 r
F P
0 g
s
.55086 .4998 m .538 .5025 L .53916 .50343 L p .437 .052 .21 r
F P
0 g
s
.538 .5025 m .55086 .4998 L .54977 .49901 L p .357 0 .053 r
F P
0 g
s
.38548 .42799 m .39914 .43692 L .40247 .44172 L p .293 .457 .853 r
F P
0 g
s
.51272 .63243 m .52297 .63603 L .52537 .63525 L p .47 .658 .943 r
F P
0 g
s
.52537 .63525 m .5107 .6301 L .51272 .63243 L p .47 .658 .943 r
F P
0 g
s
.44401 .59896 m .45329 .60451 L .45701 .60349 L p .633 .639 .839 r
F P
0 g
s
.44047 .4864 m .44138 .49123 L .44354 .49382 L p .906 .521 .278 r
F P
0 g
s
.59093 .64565 m .58574 .64141 L .58149 .64116 L p .571 .848 .996 r
F P
0 g
s
.41447 .59725 m .40251 .58972 L .39767 .59028 L p .704 .699 .843 r
F P
0 g
s
.58401 .48755 m .58939 .47965 L .59079 .47958 L p .041 0 0 r
F P
0 g
s
.60109 .47379 m .59079 .47958 L .58939 .47965 L p .041 0 0 r
F P
0 g
s
.58939 .47965 m .6041 .47138 L .60109 .47379 L p .041 0 0 r
F P
0 g
s
.58301 .48716 m .58679 .48163 L .58939 .47965 L p .159 0 0 r
F P
0 g
s
.58939 .47965 m .58401 .48755 L .58301 .48716 L p .159 0 0 r
F P
0 g
s
.34677 .3881 m .29616 .36679 L .30459 .36533 L p .53 .606 .873 r
F P
0 g
s
.30903 .34018 m .30459 .36533 L .29616 .36679 L p .53 .605 .873 r
F P
0 g
s
.29616 .36679 m .30235 .3308 L .30903 .34018 L p .53 .605 .873 r
F P
0 g
s
.29616 .36679 m .34677 .3881 L .34018 .38983 L p .489 .612 .901 r
F P
0 g
s
.30235 .3308 m .29616 .36679 L .28544 .35696 L p .57 .644 .884 r
F P
0 g
s
.49419 .51881 m .4979 .51174 L .49457 .51222 L p .682 .378 .453 r
F P
0 g
s
.49741 .51796 m .5 .51302 L .4979 .51174 L p .604 .29 .411 r
F P
0 g
s
.4979 .51174 m .49419 .51881 L .49741 .51796 L p .604 .29 .411 r
F P
0 g
s
.51627 .51267 m .4979 .51174 L .5 .51302 L p .605 .289 .408 r
F P
0 g
s
.4979 .51174 m .51627 .51267 L .51414 .51134 L p .583 .217 .314 r
F P
0 g
s
.64459 .43682 m .65831 .4298 L .66345 .42573 L p .78 .994 .874 r
F P
0 g
s
.4201 .46379 m .41394 .45412 L .41425 .45362 L p 0 .16 .694 r
F P
0 g
s
.64384 .43574 m .66345 .42573 L .66184 .42423 L p .861 .964 .867 r
F P
0 g
s
.66832 .40898 m .66184 .42423 L .66345 .42573 L p .861 .964 .867 r
F P
0 g
s
.66345 .42573 m .67272 .40394 L .66832 .40898 L p .861 .964 .867 r
F P
0 g
s
.66345 .42573 m .64384 .43574 L .64459 .43682 L p .78 .994 .874 r
F P
0 g
s
.67272 .40394 m .66345 .42573 L .66957 .42061 L p .823 .916 .9 r
F P
0 g
s
.48714 .60874 m .48334 .61629 L .48269 .61806 L p .478 .533 .835 r
F P
0 g
s
.48269 .61806 m .48811 .60728 L .48714 .60874 L p .478 .533 .835 r
F P
0 g
s
.48149 .6171 m .48269 .61806 L .48334 .61629 L p .522 .582 .856 r
F P
0 g
s
.48067 .60391 m .47616 .61194 L .47636 .61439 L p .557 .598 .85 r
F P
0 g
s
.47636 .61439 m .4828 .60292 L .48067 .60391 L p .557 .598 .85 r
F P
0 g
s
.46812 .60979 m .47636 .61439 L .47616 .61194 L p .59 .624 .854 r
F P
0 g
s
.48163 .61502 m .47803 .61312 L .47636 .61439 L p .568 .623 .867 r
F P
0 g
s
.47636 .61439 m .48149 .6171 L .48163 .61502 L p .568 .623 .867 r
F P
0 g
s
.4828 .60292 m .47636 .61439 L .47803 .61312 L p .553 .594 .848 r
F P
0 g
s
.48563 .60733 m .48163 .61502 L .48149 .6171 L p .535 .594 .86 r
F P
0 g
s
.48149 .6171 m .48721 .60611 L .48563 .60733 L p .535 .594 .86 r
F P
0 g
s
.48334 .61629 m .4825 .61562 L .48149 .6171 L p .522 .582 .856 r
F P
0 g
s
.48721 .60611 m .48149 .6171 L .4825 .61562 L p .488 .536 .832 r
F P
0 g
s
.53471 .50407 m .531 .51027 L .53271 .51137 L p .498 .118 .25 r
F P
0 g
s
.45742 .50187 m .45663 .50603 L .45884 .50816 L p .835 .531 .475 r
F P
0 g
s
.47288 .5985 m .46767 .60699 L .46812 .60979 L p .588 .606 .837 r
F P
0 g
s
.46812 .60979 m .47558 .59767 L .47288 .5985 L p .588 .606 .837 r
F P
0 g
s
.45701 .60349 m .46812 .60979 L .46767 .60699 L p .619 .628 .838 r
F P
0 g
s
.47616 .61194 m .47039 .60872 L .46812 .60979 L p .59 .624 .854 r
F P
0 g
s
.47558 .59767 m .46812 .60979 L .47039 .60872 L p .582 .597 .833 r
F P
0 g
s
.49457 .51222 m .49196 .51716 L .49419 .51881 L p .682 .378 .453 r
F P
0 g
s
.48585 .61668 m .48491 .61619 L .48392 .61768 L p .514 .581 .86 r
F P
0 g
s
.48392 .61768 m .48526 .61838 L .48585 .61668 L p .514 .581 .86 r
F P
0 g
s
.48936 .60689 m .48392 .61768 L .48491 .61619 L p .478 .533 .835 r
F P
0 g
s
.63496 .44793 m .64459 .43682 L .64384 .43574 L p .78 .994 .874 r
F P
0 g
s
.64384 .43574 m .63008 .45162 L .63496 .44793 L p .78 .994 .874 r
F P
0 g
s
.48946 .60922 m .48585 .61668 L .48526 .61838 L p .47 .533 .84 r
F P
0 g
s
.48526 .61838 m .49042 .60773 L .48946 .60922 L p .47 .533 .84 r
F P
0 g
s
.49036 .61908 m .48675 .61723 L .48526 .61838 L p .536 .625 .887 r
F P
0 g
s
.48526 .61838 m .49042 .62102 L .49036 .61908 L p .536 .625 .887 r
F P
0 g
s
.49042 .60773 m .48526 .61838 L .48675 .61723 L p .52 .593 .868 r
F P
0 g
s
.66957 .42061 m .67609 .40537 L .67272 .40394 L p .823 .916 .9 r
F P
0 g
s
.49345 .61201 m .49036 .61908 L .49042 .62102 L p .497 .592 .88 r
F P
0 g
s
.49042 .62102 m .49484 .61092 L .49345 .61201 L p .497 .592 .88 r
F P
0 g
s
.49825 .62301 m .49227 .62019 L .49042 .62102 L p .51 .63 .905 r
F P
0 g
s
.49042 .62102 m .49896 .62505 L .49825 .62301 L p .51 .63 .905 r
F P
0 g
s
.49484 .61092 m .49042 .62102 L .49227 .62019 L p .501 .597 .882 r
F P
0 g
s
.61923 .45977 m .63008 .45162 L .63044 .45057 L p .693 .957 .701 r
F P
0 g
s
.64007 .43945 m .63044 .45057 L .63008 .45162 L p .693 .957 .701 r
F P
0 g
s
.63008 .45162 m .64384 .43574 L .64007 .43945 L p .693 .957 .701 r
F P
0 g
s
.61851 .46035 m .62611 .45464 L .63008 .45162 L p .442 .82 .575 r
F P
0 g
s
.63008 .45162 m .61923 .45977 L .61851 .46035 L p .442 .82 .575 r
F P
0 g
s
.52811 .63725 m .54015 .64023 L .54258 .63951 L p .447 .691 .97 r
F P
0 g
s
.54258 .63951 m .52537 .63525 L .52811 .63725 L p .447 .691 .97 r
F P
0 g
s
.45701 .60349 m .44374 .59555 L .44401 .59896 L p .633 .639 .839 r
F P
0 g
s
.46257 .59142 m .45643 .60036 L .45701 .60349 L p .626 .62 .824 r
F P
0 g
s
.45701 .60349 m .46579 .59071 L .46257 .59142 L p .626 .62 .824 r
F P
0 g
s
.44374 .59555 m .45701 .60349 L .45643 .60036 L p .651 .637 .823 r
F P
0 g
s
.46767 .60699 m .45989 .60257 L .45701 .60349 L p .619 .628 .838 r
F P
0 g
s
.46579 .59071 m .45701 .60349 L .45989 .60257 L p .614 .604 .817 r
F P
0 g
s
.50052 .61664 m .49825 .62301 L .49896 .62505 L p .457 .594 .901 r
F P
0 g
s
.49896 .62505 m .50221 .61595 L .50052 .61664 L p .457 .594 .901 r
F P
0 g
s
.50931 .62808 m .50108 .62454 L .49896 .62505 L p .467 .639 .931 r
F P
0 g
s
.49896 .62505 m .5107 .6301 L .50931 .62808 L p .467 .639 .931 r
F P
0 g
s
.50221 .61595 m .49896 .62505 L .50108 .62454 L p .468 .606 .905 r
F P
0 g
s
.74778 .3698 m .71269 .38134 L .70519 .38886 L p .794 .835 .882 r
F P
0 g
s
.61643 .6426 m .63089 .63713 L .63175 .63456 L p .66 .831 .965 r
F P
0 g
s
.63175 .63456 m .61108 .64239 L .61643 .6426 L p .66 .831 .965 r
F P
0 g
s
.71541 .62693 m .69477 .61904 L .68792 .61939 L p .698 .781 .915 r
F P
0 g
s
.55846 .49669 m .55291 .49825 L .55086 .4998 L p .299 0 .019 r
F P
0 g
s
.5 .51302 m .51287 .51366 L .51627 .51267 L p .605 .289 .408 r
F P
0 g
s
.53916 .50343 m .54817 .50154 L .55086 .4998 L p .437 .052 .21 r
F P
0 g
s
.47803 .61312 m .48255 .60509 L .4828 .60292 L p .553 .594 .848 r
F P
0 g
s
.51045 .62263 m .50931 .62808 L .5107 .6301 L p .394 .598 .928 r
F P
0 g
s
.5107 .6301 m .51235 .62232 L .51045 .62263 L p .394 .598 .928 r
F P
0 g
s
.52328 .63343 m .513 .62982 L .5107 .6301 L p .409 .656 .96 r
F P
0 g
s
.5107 .6301 m .52537 .63525 L .52328 .63343 L p .409 .656 .96 r
F P
0 g
s
.51235 .62232 m .5107 .6301 L .513 .62982 L p .421 .626 .938 r
F P
0 g
s
.4825 .61562 m .48651 .60793 L .48721 .60611 L p .488 .536 .832 r
F P
0 g
s
.47039 .60872 m .47561 .60024 L .47558 .59767 L p .582 .597 .833 r
F P
0 g
s
.4292 .58992 m .43952 .59639 L .44374 .59555 L p .664 .656 .832 r
F P
0 g
s
.67672 .63198 m .68937 .6231 L .68792 .61939 L p .697 .787 .92 r
F P
0 g
s
.68792 .61939 m .66985 .6321 L .67672 .63198 L p .697 .787 .92 r
F P
0 g
s
.48491 .61619 m .48872 .60863 L .48936 .60689 L p .478 .533 .835 r
F P
0 g
s
.45989 .60257 m .46604 .59363 L .46579 .59071 L p .614 .604 .817 r
F P
0 g
s
.42264 .46682 m .42648 .47287 L .42853 .47608 L p .601 .181 0 r
F P
0 g
s
.48675 .61723 m .49036 .60977 L .49042 .60773 L p .52 .593 .868 r
F P
0 g
s
.47395 .51267 m .46173 .5082 L .45884 .50816 L p .758 .455 .472 r
F P
0 g
s
.45884 .50816 m .4763 .51455 L .47395 .51267 L p .758 .455 .472 r
F P
0 g
s
.45643 .60036 m .44714 .5948 L .44374 .59555 L p .651 .637 .823 r
F P
0 g
s
.26684 .60569 m .25248 .59104 L .24243 .59018 L p .681 .76 .911 r
F P
0 g
s
.52189 .83867 m .51742 .90109 L .50832 .89102 L p .705 .701 .843 r
F P
0 g
s
.45562 .88651 m .50832 .89102 L .51742 .90109 L p .705 .701 .843 r
F P
0 g
s
.51742 .90109 m .44236 .89471 L .45562 .88651 L p .705 .701 .843 r
F P
0 g
s
.5318 .84782 m .52852 .89154 L .51742 .90109 L p .683 .682 .842 r
F P
0 g
s
.51742 .90109 m .52189 .83867 L .5318 .84782 L p .683 .682 .842 r
F P
0 g
s
.5976 .89818 m .51742 .90109 L .52852 .89154 L p .683 .682 .842 r
F P
0 g
s
.49227 .62019 m .49537 .61313 L .49484 .61092 L p .501 .597 .882 r
F P
0 g
s
.49196 .51716 m .47945 .51418 L .4763 .51455 L p .683 .377 .451 r
F P
0 g
s
.5994 .63865 m .60645 .64227 L .61108 .64239 L p .563 .851 .997 r
F P
0 g
s
.61108 .64239 m .60102 .63721 L .5994 .63865 L p .563 .851 .997 r
F P
0 g
s
.62695 .63501 m .61247 .6405 L .61108 .64239 L p .642 .874 .984 r
F P
0 g
s
.61108 .64239 m .63175 .63456 L .62695 .63501 L p .642 .874 .984 r
F P
0 g
s
.60102 .63721 m .61108 .64239 L .61247 .6405 L p .644 .878 .984 r
F P
0 g
s
.44374 .59555 m .42898 .5863 L .4292 .58992 L p .664 .656 .832 r
F P
0 g
s
.45019 .583 m .44313 .59221 L .44374 .59555 L p .665 .641 .816 r
F P
0 g
s
.44374 .59555 m .45383 .58241 L .45019 .583 L p .665 .641 .816 r
F P
0 g
s
.42898 .5863 m .44374 .59555 L .44313 .59221 L p .684 .653 .814 r
F P
0 g
s
.45383 .58241 m .44374 .59555 L .44714 .5948 L p .649 .617 .804 r
F P
0 g
s
.59079 .47958 m .58703 .48511 L .58401 .48755 L p .041 0 0 r
F P
0 g
s
.54598 .64102 m .55926 .64258 L .56158 .64174 L p .446 .738 .99 r
F P
0 g
s
.56158 .64174 m .54258 .63951 L .54598 .64102 L p .446 .738 .99 r
F P
0 g
s
.52315 .62907 m .52328 .63343 L .52537 .63525 L p .312 .609 .953 r
F P
0 g
s
.52537 .63525 m .5252 .62902 L .52315 .62907 L p .312 .609 .953 r
F P
0 g
s
.53984 .63806 m .52777 .63507 L .52537 .63525 L p .346 .683 .979 r
F P
0 g
s
.52537 .63525 m .54258 .63951 L .53984 .63806 L p .346 .683 .979 r
F P
0 g
s
.5252 .62902 m .52537 .63525 L .52777 .63507 L p .368 .661 .97 r
F P
0 g
s
.55086 .4998 m .5588 .49758 L .55846 .49669 L p .299 0 .019 r
F P
0 g
s
.50108 .62454 m .50336 .61818 L .50221 .61595 L p .468 .606 .905 r
F P
0 g
s
.64997 .62701 m .6639 .63253 L .66985 .6321 L p .691 .821 .945 r
F P
0 g
s
.66985 .6321 m .64996 .62419 L .64997 .62701 L p .691 .821 .945 r
F P
0 g
s
.68202 .62016 m .66937 .62908 L .66985 .6321 L p .704 .812 .932 r
F P
0 g
s
.66985 .6321 m .68792 .61939 L .68202 .62016 L p .704 .812 .932 r
F P
0 g
s
.64996 .62419 m .66985 .6321 L .66937 .62908 L p .716 .819 .93 r
F P
0 g
s
.47402 .51978 m .4763 .51455 L .47342 .51435 L p .756 .493 .535 r
F P
0 g
s
.46119 .50988 m .47342 .51435 L .4763 .51455 L p .755 .488 .528 r
F P
0 g
s
.4763 .51455 m .45884 .50816 L .46119 .50988 L p .755 .488 .528 r
F P
0 g
s
.47696 .51969 m .47856 .51602 L .4763 .51455 L p .686 .413 .503 r
F P
0 g
s
.4763 .51455 m .47402 .51978 L .47696 .51969 L p .686 .413 .503 r
F P
0 g
s
.49419 .51881 m .4763 .51455 L .47856 .51602 L p .685 .415 .508 r
F P
0 g
s
.4763 .51455 m .49419 .51881 L .49196 .51716 L p .683 .377 .451 r
F P
0 g
s
.54588 .50884 m .55086 .4998 L .54817 .50154 L p .428 .041 .2 r
F P
0 g
s
.54786 .50713 m .55134 .50081 L .55086 .4998 L p .387 0 .178 r
F P
0 g
s
.55086 .4998 m .54588 .50884 L .54786 .50713 L p .387 0 .178 r
F P
0 g
s
.5588 .49758 m .55086 .4998 L .55134 .50081 L p .388 .001 .178 r
F P
0 g
s
.56193 .49563 m .56006 .49623 L .5588 .49758 L p .265 0 0 r
F P
0 g
s
.44714 .5948 m .45421 .58561 L .45383 .58241 L p .649 .617 .804 r
F P
0 g
s
.47342 .51435 m .47181 .51801 L .47402 .51978 L p .756 .493 .535 r
F P
0 g
s
.45663 .50603 m .4459 .50025 L .4435 .49991 L p .836 .53 .471 r
F P
0 g
s
.4435 .49991 m .45884 .50816 L .45663 .50603 L p .836 .53 .471 r
F P
0 g
s
.513 .62982 m .51417 .62438 L .51235 .62232 L p .421 .626 .938 r
F P
0 g
s
.4459 .50025 m .44592 .49599 L .44354 .49382 L p .835 .526 .466 r
F P
0 g
s
.45748 .51303 m .45884 .50816 L .45639 .50766 L p .83 .565 .538 r
F P
0 g
s
.44565 .50188 m .45639 .50766 L .45884 .50816 L p .83 .563 .536 r
F P
0 g
s
.45884 .50816 m .4435 .49991 L .44565 .50188 L p .83 .563 .536 r
F P
0 g
s
.46024 .51328 m .46119 .50988 L .45884 .50816 L p .758 .486 .522 r
F P
0 g
s
.45884 .50816 m .45748 .51303 L .46024 .51328 L p .758 .486 .522 r
F P
0 g
s
.4435 .49991 m .44354 .49382 L .44173 .49328 L p .918 .605 .435 r
F P
0 g
s
.433 .4863 m .44173 .49328 L .44354 .49382 L p .918 .605 .435 r
F P
0 g
s
.44354 .49382 m .43108 .48385 L .433 .4863 L p .918 .605 .435 r
F P
0 g
s
.44354 .49382 m .4435 .49991 L .4459 .50025 L p .835 .526 .466 r
F P
0 g
s
.43108 .48385 m .44354 .49382 L .44138 .49123 L p .906 .519 .274 r
F P
0 g
s
.531 .51027 m .5195 .51118 L .51627 .51267 L p .497 .12 .255 r
F P
0 g
s
.41394 .45412 m .4057 .44579 L .40247 .44172 L p 0 .16 .694 r
F P
0 g
s
.47856 .51602 m .49108 .51901 L .49419 .51881 L p .685 .415 .508 r
F P
0 g
s
.44313 .59221 m .4328 .58572 L .42898 .5863 L p .684 .653 .814 r
F P
0 g
s
.5588 .49758 m .56148 .49672 L .56193 .49563 L p .265 0 0 r
F P
0 g
s
.28544 .35696 m .28962 .33171 L .30235 .3308 L p .57 .644 .884 r
F P
0 g
s
.54817 .50154 m .54467 .50787 L .54588 .50884 L p .428 .041 .2 r
F P
0 g
s
.44138 .49123 m .43267 .48425 L .43108 .48385 L p .906 .519 .274 r
F P
0 g
s
.56273 .49537 m .5646 .49476 L .56414 .49584 L p .255 0 0 r
F P
0 g
s
.56414 .49584 m .56148 .49672 L .56273 .49537 L p .255 0 0 r
F P
0 g
s
.66184 .42423 m .6481 .43123 L .64384 .43574 L p .861 .964 .867 r
F P
0 g
s
.3806 .58257 m .39191 .59084 L .39767 .59028 L p .703 .724 .866 r
F P
0 g
s
.39767 .59028 m .38152 .57845 L .3806 .58257 L p .703 .724 .866 r
F P
0 g
s
.40917 .57645 m .39781 .58645 L .39767 .59028 L p .719 .718 .848 r
F P
0 g
s
.39767 .59028 m .4139 .57601 L .40917 .57645 L p .719 .718 .848 r
F P
0 g
s
.38152 .57845 m .39767 .59028 L .39781 .58645 L p .726 .724 .848 r
F P
0 g
s
.4139 .57601 m .39767 .59028 L .40251 .58972 L p .705 .69 .833 r
F P
0 g
s
.51136 .52079 m .51627 .51267 L .51287 .51366 L p .603 .286 .405 r
F P
0 g
s
.51452 .51945 m .51795 .51376 L .51627 .51267 L p .527 .2 .357 r
F P
0 g
s
.51627 .51267 m .51136 .52079 L .51452 .51945 L p .527 .2 .357 r
F P
0 g
s
.53271 .51137 m .51627 .51267 L .51795 .51376 L p .529 .198 .35 r
F P
0 g
s
.51627 .51267 m .53271 .51137 L .531 .51027 L p .497 .12 .255 r
F P
0 g
s
.63044 .45057 m .62284 .45627 L .61923 .45977 L p .693 .957 .701 r
F P
0 g
s
.40251 .58972 m .41387 .57975 L .4139 .57601 L p .705 .69 .833 r
F P
0 g
s
.53838 .63477 m .53984 .63806 L .54258 .63951 L p .231 .629 .957 r
F P
0 g
s
.54258 .63951 m .54052 .63482 L .53838 .63477 L p .231 .629 .957 r
F P
0 g
s
.5583 .64081 m .54498 .63924 L .54258 .63951 L p .308 .722 .976 r
F P
0 g
s
.54258 .63951 m .56158 .64174 L .5583 .64081 L p .308 .722 .976 r
F P
0 g
s
.54052 .63482 m .54258 .63951 L .54498 .63924 L p .331 .71 .983 r
F P
0 g
s
.51287 .51366 m .50943 .51935 L .51136 .52079 L p .603 .286 .405 r
F P
0 g
s
.45639 .50766 m .45544 .51106 L .45748 .51303 L p .83 .565 .538 r
F P
0 g
s
.41425 .45362 m .40247 .44172 L .40398 .44118 L p .129 .315 .783 r
F P
0 g
s
.40256 .42921 m .40398 .44118 L .40247 .44172 L p .129 .314 .782 r
F P
0 g
s
.40247 .44172 m .40042 .4246 L .40256 .42921 L p .129 .314 .782 r
F P
0 g
s
.40247 .44172 m .41425 .45362 L .41394 .45412 L p 0 .16 .694 r
F P
0 g
s
.40042 .4246 m .40247 .44172 L .39914 .43692 L p .292 .457 .853 r
F P
0 g
s
.52777 .63507 m .52767 .63072 L .5252 .62902 L p .368 .661 .97 r
F P
0 g
s
.60793 .46847 m .61851 .46035 L .61923 .45977 L p .442 .82 .576 r
F P
0 g
s
.61923 .45977 m .6041 .47138 L .60793 .46847 L p .442 .82 .576 r
F P
0 g
s
.55134 .50081 m .5569 .49925 L .5588 .49758 L p .388 .001 .178 r
F P
0 g
s
.30459 .36533 m .34012 .38026 L .34677 .3881 L p .53 .606 .873 r
F P
0 g
s
.56616 .49419 m .57159 .49218 L .57191 .49297 L p .225 0 0 r
F P
0 g
s
.57191 .49297 m .56414 .49584 L .56616 .49419 L p .225 0 0 r
F P
0 g
s
.55433 .50654 m .5588 .49758 L .5569 .49925 L p .385 0 .175 r
F P
0 g
s
.55543 .50505 m .55855 .49878 L .5588 .49758 L p .364 0 .164 r
F P
0 g
s
.5588 .49758 m .55433 .50654 L .55543 .50505 L p .364 0 .164 r
F P
0 g
s
.56148 .49672 m .5588 .49758 L .55855 .49878 L p .364 0 .164 r
F P
0 g
s
.41387 .57975 m .42443 .58694 L .42898 .5863 L p .694 .68 .833 r
F P
0 g
s
.36412 .59298 m .3806 .58257 L .38152 .57845 L p .708 .729 .867 r
F P
0 g
s
.38152 .57845 m .35796 .59333 L .36412 .59298 L p .708 .729 .867 r
F P
0 g
s
.37529 .40824 m .35237 .39475 L .34677 .3881 L p .407 .55 .886 r
F P
0 g
s
.50943 .51935 m .49741 .51796 L .49419 .51881 L p .602 .286 .407 r
F P
0 g
s
.44173 .49328 m .4417 .49754 L .4435 .49991 L p .918 .605 .435 r
F P
0 g
s
.61247 .6405 m .60544 .63686 L .60102 .63721 L p .644 .878 .984 r
F P
0 g
s
.49085 .52478 m .49419 .51881 L .49108 .51901 L p .686 .419 .513 r
F P
0 g
s
.49383 .52426 m .49617 .52008 L .49419 .51881 L p .61 .331 .468 r
F P
0 g
s
.49419 .51881 m .49085 .52478 L .49383 .52426 L p .61 .331 .468 r
F P
0 g
s
.51136 .52079 m .49419 .51881 L .49617 .52008 L p .61 .331 .468 r
F P
0 g
s
.49419 .51881 m .51136 .52079 L .50943 .51935 L p .602 .286 .407 r
F P
0 g
s
.42898 .5863 m .4139 .57601 L .41387 .57975 L p .694 .68 .833 r
F P
0 g
s
.43643 .57363 m .4285 .58283 L .42898 .5863 L p .703 .668 .813 r
F P
0 g
s
.42898 .5863 m .44032 .57317 L .43643 .57363 L p .703 .668 .813 r
F P
0 g
s
.4139 .57601 m .42898 .5863 L .4285 .58283 L p .716 .678 .812 r
F P
0 g
s
.44032 .57317 m .42898 .5863 L .4328 .58572 L p .684 .638 .798 r
F P
0 g
s
.67609 .40537 m .69878 .39481 L .70519 .38886 L p .823 .916 .9 r
F P
0 g
s
.33892 .58376 m .35062 .59362 L .35796 .59333 L p .696 .751 .894 r
F P
0 g
s
.35796 .59333 m .34127 .57922 L .33892 .58376 L p .696 .751 .894 r
F P
0 g
s
.37568 .5787 m .35918 .58914 L .35796 .59333 L p .716 .752 .881 r
F P
0 g
s
.35796 .59333 m .38152 .57845 L .37568 .5787 L p .716 .752 .881 r
F P
0 g
s
.34127 .57922 m .35796 .59333 L .35918 .58914 L p .718 .754 .881 r
F P
0 g
s
.49108 .51901 m .48874 .52318 L .49085 .52478 L p .686 .419 .513 r
F P
0 g
s
.5655 .64265 m .57942 .64224 L .58149 .64116 L p .483 .794 .999 r
F P
0 g
s
.58149 .64116 m .56158 .64174 L .5655 .64265 L p .483 .794 .999 r
F P
0 g
s
.5987 .47914 m .6041 .47138 L .60552 .47081 L p 0 0 0 r
F P
0 g
s
.61612 .46269 m .60552 .47081 L .6041 .47138 L p 0 0 0 r
F P
0 g
s
.6041 .47138 m .61923 .45977 L .61612 .46269 L p 0 0 0 r
F P
0 g
s
.5973 .47922 m .60109 .47379 L .6041 .47138 L p .05 0 0 r
F P
0 g
s
.6041 .47138 m .5987 .47914 L .5973 .47922 L p .05 0 0 r
F P
0 g
s
.47181 .51801 m .46024 .51328 L .45748 .51303 L p .759 .492 .529 r
F P
0 g
s
.45748 .51303 m .47402 .51978 L .47181 .51801 L p .759 .492 .529 r
F P
0 g
s
.75293 .60701 m .78461 .61578 L .79362 .6155 L p .678 .755 .909 r
F P
0 g
s
.79362 .6155 m .74833 .60293 L .75293 .60701 L p .678 .755 .909 r
F P
0 g
s
.79674 .60263 m .78848 .6118 L .79362 .6155 L p .674 .754 .911 r
F P
0 g
s
.79362 .6155 m .80545 .60243 L .79674 .60263 L p .674 .754 .911 r
F P
0 g
s
.74833 .60293 m .79362 .6155 L .78848 .6118 L p .68 .754 .907 r
F P
0 g
s
.43267 .48425 m .43088 .47881 L .42853 .47608 L p .905 .517 .271 r
F P
0 g
s
.4328 .58572 m .44074 .57654 L .44032 .57317 L p .684 .638 .798 r
F P
0 g
s
.39914 .43692 m .39768 .42494 L .40042 .4246 L p .292 .457 .853 r
F P
0 g
s
.55722 .50563 m .56148 .49672 L .56126 .49791 L p .356 0 .161 r
F P
0 g
s
.56313 .4973 m .56126 .49791 L .56148 .49672 L p .356 0 .161 r
F P
0 g
s
.56148 .49672 m .56414 .49584 L .56313 .4973 L p .356 0 .161 r
F P
0 g
s
.55722 .50563 m .56148 .49672 L .56043 .49818 L p .364 0 .164 r
F P
0 g
s
.55855 .49878 m .56043 .49818 L .56148 .49672 L p .364 0 .164 r
F P
0 g
s
.58193 .83672 m .5976 .89818 L .58481 .88947 L p .683 .682 .842 r
F P
0 g
s
.52852 .89154 m .58481 .88947 L .5976 .89818 L p .683 .682 .842 r
F P
0 g
s
.59466 .84427 m .6055 .88737 L .5976 .89818 L p .658 .665 .846 r
F P
0 g
s
.5976 .89818 m .58193 .83672 L .59466 .84427 L p .658 .665 .846 r
F P
0 g
s
.67666 .88472 m .5976 .89818 L .6055 .88737 L p .658 .665 .846 r
F P
0 g
s
.48874 .52318 m .47696 .51969 L .47402 .51978 L p .687 .418 .509 r
F P
0 g
s
.51795 .51376 m .52946 .51286 L .53271 .51137 L p .529 .198 .35 r
F P
0 g
s
.47217 .52366 m .47402 .51978 L .47131 .51933 L p .754 .517 .572 r
F P
0 g
s
.45973 .5146 m .47131 .51933 L .47402 .51978 L p .754 .512 .566 r
F P
0 g
s
.47402 .51978 m .45748 .51303 L .45973 .5146 L p .754 .512 .566 r
F P
0 g
s
.47492 .52387 m .47621 .52115 L .47402 .51978 L p .687 .438 .54 r
F P
0 g
s
.47402 .51978 m .47217 .52366 L .47492 .52387 L p .687 .438 .54 r
F P
0 g
s
.49085 .52478 m .47402 .51978 L .47621 .52115 L p .685 .44 .545 r
F P
0 g
s
.47402 .51978 m .49085 .52478 L .48874 .52318 L p .687 .418 .509 r
F P
0 g
s
.66937 .62908 m .65545 .62352 L .64996 .62419 L p .716 .819 .93 r
F P
0 g
s
.43108 .48385 m .42853 .47608 L .42782 .47557 L p .868 .487 .005 r
F P
0 g
s
.42247 .46727 m .42782 .47557 L .42853 .47608 L p .869 .489 .008 r
F P
0 g
s
.42853 .47608 m .42089 .46423 L .42247 .46727 L p .869 .489 .008 r
F P
0 g
s
.42853 .47608 m .43108 .48385 L .43267 .48425 L p .905 .517 .271 r
F P
0 g
s
.42089 .46423 m .42853 .47608 L .42648 .47287 L p .61 .188 0 r
F P
0 g
s
.39781 .58645 m .38651 .57816 L .38152 .57845 L p .726 .724 .848 r
F P
0 g
s
.5569 .49925 m .55377 .50553 L .55433 .50654 L p .385 0 .175 r
F P
0 g
s
.47131 .51933 m .47001 .52204 L .47217 .52366 L p .754 .517 .572 r
F P
0 g
s
.45624 .51661 m .45748 .51303 L .45513 .51232 L p .824 .587 .58 r
F P
0 g
s
.44485 .50653 m .45513 .51232 L .45748 .51303 L p .824 .584 .575 r
F P
0 g
s
.45748 .51303 m .4428 .50475 L .44485 .50653 L p .824 .584 .575 r
F P
0 g
s
.45886 .51711 m .45973 .5146 L .45748 .51303 L p .756 .509 .559 r
F P
0 g
s
.45748 .51303 m .45624 .51661 L .45886 .51711 L p .756 .509 .559 r
F P
0 g
s
.4428 .50475 m .45748 .51303 L .45544 .51106 L p .831 .565 .536 r
F P
0 g
s
.54498 .63924 m .54355 .63597 L .54052 .63482 L p .331 .71 .983 r
F P
0 g
s
.56012 .50467 m .56414 .49584 L .56475 .49671 L p .334 0 .151 r
F P
0 g
s
.5702 .49469 m .56475 .49671 L .56414 .49584 L p .332 0 .151 r
F P
0 g
s
.56414 .49584 m .57191 .49297 L .5702 .49469 L p .332 0 .151 r
F P
0 g
s
.56031 .50348 m .56313 .4973 L .56414 .49584 L p .356 0 .161 r
F P
0 g
s
.56414 .49584 m .56012 .50467 L .56031 .50348 L p .356 0 .161 r
F P
0 g
s
.45544 .51106 m .44516 .50526 L .4428 .50475 L p .831 .565 .536 r
F P
0 g
s
.49617 .52008 m .50819 .52148 L .51136 .52079 L p .61 .331 .468 r
F P
0 g
s
.4285 .58283 m .41794 .57562 L .4139 .57601 L p .716 .678 .812 r
F P
0 g
s
.47621 .52115 m .48799 .52465 L .49085 .52478 L p .685 .44 .545 r
F P
0 g
s
.67272 .40394 m .70519 .38886 L .70037 .38719 L p .835 .864 .866 r
F P
0 g
s
.70031 .3666 m .70037 .38719 L .70519 .38886 L p .835 .864 .866 r
F P
0 g
s
.70519 .38886 m .70516 .35942 L .70031 .3666 L p .835 .864 .866 r
F P
0 g
s
.70519 .38886 m .67272 .40394 L .67609 .40537 L p .823 .916 .9 r
F P
0 g
s
.70516 .35942 m .70519 .38886 L .71269 .38134 L p .794 .835 .883 r
F P
0 g
s
.42648 .47287 m .42113 .46457 L .42089 .46423 L p .61 .188 0 r
F P
0 g
s
.55558 .63847 m .5583 .64081 L .56158 .64174 L p .199 .669 .938 r
F P
0 g
s
.56158 .64174 m .55772 .63841 L .55558 .63847 L p .199 .669 .938 r
F P
0 g
s
.57779 .64082 m .56384 .64123 L .56158 .64174 L p .334 .777 .961 r
F P
0 g
s
.56158 .64174 m .58149 .64116 L .57779 .64082 L p .334 .777 .961 r
F P
0 g
s
.55772 .63841 m .56158 .64174 L .56384 .64123 L p .347 .773 .974 r
F P
0 g
s
.56043 .49818 m .55745 .50442 L .55722 .50563 L p .364 0 .164 r
F P
0 g
s
.45513 .51232 m .45426 .51483 L .45624 .51661 L p .824 .587 .58 r
F P
0 g
s
.46604 .59363 m .47288 .5985 L .47558 .59767 L p .583 .58 .814 r
F P
0 g
s
.47558 .59767 m .46579 .59071 L .46604 .59363 L p .583 .58 .814 r
F P
0 g
s
.37958 .4074 m .34677 .3881 L .35256 .38746 L p .479 .554 .854 r
F P
0 g
s
.35696 .36874 m .35256 .38746 L .34677 .3881 L p .479 .554 .854 r
F P
0 g
s
.34677 .3881 m .35298 .36132 L .35696 .36874 L p .479 .554 .854 r
F P
0 g
s
.34677 .3881 m .37958 .4074 L .37529 .40824 L p .407 .55 .886 r
F P
0 g
s
.35298 .36132 m .34677 .3881 L .34012 .38026 L p .53 .605 .873 r
F P
0 g
s
.57455 .49095 m .58301 .48716 L .58401 .48755 L p .16 0 0 r
F P
0 g
s
.58401 .48755 m .57191 .49297 L .57455 .49095 L p .16 0 0 r
F P
0 g
s
.44516 .50526 m .44565 .50188 L .4435 .49991 L p .831 .562 .533 r
F P
0 g
s
.45421 .58561 m .46257 .59142 L .46579 .59071 L p .624 .598 .804 r
F P
0 g
s
.56126 .49791 m .55828 .50415 L .55722 .50563 L p .356 0 .161 r
F P
0 g
s
.46579 .59071 m .45383 .58241 L .45421 .58561 L p .624 .598 .804 r
F P
0 g
s
.4428 .50475 m .4435 .49991 L .44169 .49924 L p .912 .648 .525 r
F P
0 g
s
.43347 .49257 m .44169 .49924 L .4435 .49991 L p .912 .644 .52 r
F P
0 g
s
.4435 .49991 m .43177 .49039 L .43347 .49257 L p .912 .644 .52 r
F P
0 g
s
.4435 .49991 m .4428 .50475 L .44516 .50526 L p .831 .562 .533 r
F P
0 g
s
.43177 .49039 m .4435 .49991 L .4417 .49754 L p .918 .605 .435 r
F P
0 g
s
.47001 .52204 m .45886 .51711 L .45624 .51661 L p .757 .515 .567 r
F P
0 g
s
.45624 .51661 m .47217 .52366 L .47001 .52204 L p .757 .515 .567 r
F P
0 g
s
.47561 .60024 m .48067 .60391 L .4828 .60292 L p .547 .568 .828 r
F P
0 g
s
.4828 .60292 m .47558 .59767 L .47561 .60024 L p .547 .568 .828 r
F P
0 g
s
.40398 .44118 m .41224 .44952 L .41425 .45362 L p .129 .315 .783 r
F P
0 g
s
.74355 .61642 m .75293 .60701 L .74833 .60293 L p .685 .756 .906 r
F P
0 g
s
.74833 .60293 m .73496 .61642 L .74355 .61642 L p .685 .756 .906 r
F P
0 g
s
.63723 .63426 m .64997 .62701 L .64996 .62419 L p .699 .827 .944 r
F P
0 g
s
.64996 .62419 m .63175 .63456 L .63723 .63426 L p .699 .827 .944 r
F P
0 g
s
.50832 .89102 m .5113 .84729 L .52189 .83867 L p .705 .701 .843 r
F P
0 g
s
.47099 .52604 m .47217 .52366 L .46963 .52295 L p .752 .53 .594 r
F P
0 g
s
.45847 .51801 m .46963 .52295 L .47217 .52366 L p .752 .526 .589 r
F P
0 g
s
.47217 .52366 m .45624 .51661 L .45847 .51801 L p .752 .526 .589 r
F P
0 g
s
.47355 .52654 m .47437 .52488 L .47217 .52366 L p .687 .453 .561 r
F P
0 g
s
.47217 .52366 m .47099 .52604 L .47355 .52654 L p .687 .453 .561 r
F P
0 g
s
.48827 .52924 m .47217 .52366 L .47437 .52488 L p .685 .455 .568 r
F P
0 g
s
.48618 .52777 m .47492 .52387 L .47217 .52366 L p .688 .443 .547 r
F P
0 g
s
.47217 .52366 m .48827 .52924 L .48618 .52777 L p .688 .443 .547 r
F P
0 g
s
.44074 .57654 m .45019 .583 L .45383 .58241 L p .665 .624 .799 r
F P
0 g
s
.4417 .49754 m .43349 .49088 L .43177 .49039 L p .918 .605 .435 r
F P
0 g
s
.46963 .52295 m .4688 .52461 L .47099 .52604 L p .752 .53 .594 r
F P
0 g
s
.48255 .60509 m .48563 .60733 L .48721 .60611 L p .518 .561 .838 r
F P
0 g
s
.48721 .60611 m .4828 .60292 L .48255 .60509 L p .518 .561 .838 r
F P
0 g
s
.35918 .58914 m .34751 .57925 L .34127 .57922 L p .718 .754 .881 r
F P
0 g
s
.54467 .50787 m .53546 .50964 L .53271 .51137 L p .426 .042 .204 r
F P
0 g
s
.45535 .51881 m .45624 .51661 L .45399 .51569 L p .819 .601 .607 r
F P
0 g
s
.44402 .50986 m .45399 .51569 L .45624 .51661 L p .82 .596 .599 r
F P
0 g
s
.45624 .51661 m .44199 .50828 L .44402 .50986 L p .82 .596 .599 r
F P
0 g
s
.45785 .51955 m .45847 .51801 L .45624 .51661 L p .754 .524 .583 r
F P
0 g
s
.45624 .51661 m .45535 .51881 L .45785 .51955 L p .754 .524 .583 r
F P
0 g
s
.44199 .50828 m .45624 .51661 L .45426 .51483 L p .826 .585 .575 r
F P
0 g
s
.60552 .47081 m .60175 .47624 L .5987 .47914 L p 0 0 0 r
F P
0 g
s
.42782 .47557 m .42961 .48101 L .43108 .48385 L p .868 .487 .005 r
F P
0 g
s
.47043 .5796 m .46518 .58771 L .46579 .59071 L p .616 .576 .787 r
F P
0 g
s
.46579 .59071 m .4733 .57912 L .47043 .5796 L p .616 .576 .787 r
F P
0 g
s
.45383 .58241 m .46579 .59071 L .46518 .58771 L p .645 .596 .785 r
F P
0 g
s
.47516 .59495 m .4683 .59007 L .46579 .59071 L p .602 .579 .8 r
F P
0 g
s
.46579 .59071 m .47558 .59767 L .47516 .59495 L p .602 .579 .8 r
F P
0 g
s
.4733 .57912 m .46579 .59071 L .4683 .59007 L p .597 .551 .774 r
F P
0 g
s
.47437 .52488 m .48564 .52878 L .48827 .52924 L p .685 .455 .568 r
F P
0 g
s
.48651 .60793 m .48714 .60874 L .48811 .60728 L p .438 .479 .805 r
F P
0 g
s
.48811 .60728 m .48721 .60611 L .48651 .60793 L p .438 .479 .805 r
F P
0 g
s
.70491 .60989 m .72769 .61696 L .73496 .61642 L p .694 .77 .91 r
F P
0 g
s
.73496 .61642 m .70241 .60629 L .70491 .60989 L p .694 .77 .91 r
F P
0 g
s
.74128 .60353 m .73193 .61298 L .73496 .61642 L p .689 .765 .909 r
F P
0 g
s
.73496 .61642 m .74833 .60293 L .74128 .60353 L p .689 .765 .909 r
F P
0 g
s
.70241 .60629 m .73496 .61642 L .73193 .61298 L p .699 .768 .905 r
F P
0 g
s
.56475 .49671 m .56194 .50289 L .56012 .50467 L p .334 0 .151 r
F P
0 g
s
.45426 .51483 m .44428 .509 L .44199 .50828 L p .826 .585 .575 r
F P
0 g
s
.48799 .52465 m .48618 .52777 L .48827 .52924 L p .686 .445 .552 r
F P
0 g
s
.48827 .52924 m .49085 .52478 L .48799 .52465 L p .686 .445 .552 r
F P
0 g
s
.45383 .58241 m .44032 .57317 L .44074 .57654 L p .665 .624 .799 r
F P
0 g
s
.45895 .57095 m .4531 .57926 L .45383 .58241 L p .667 .608 .779 r
F P
0 g
s
.45383 .58241 m .46219 .57054 L .45895 .57095 L p .667 .608 .779 r
F P
0 g
s
.44032 .57317 m .45383 .58241 L .4531 .57926 L p .687 .62 .776 r
F P
0 g
s
.46518 .58771 m .45681 .5819 L .45383 .58241 L p .645 .596 .785 r
F P
0 g
s
.46219 .57054 m .45383 .58241 L .45681 .5819 L p .643 .574 .762 r
F P
0 g
s
.31517 .59405 m .33892 .58376 L .34127 .57922 L p .697 .753 .894 r
F P
0 g
s
.34127 .57922 m .30731 .59395 L .31517 .59405 L p .697 .753 .894 r
F P
0 g
s
.56855 .50151 m .57191 .49297 L .57329 .49339 L p .29 0 .136 r
F P
0 g
s
.58176 .4896 m .57329 .49339 L .57191 .49297 L p .29 0 .142 r
F P
0 g
s
.57191 .49297 m .58401 .48755 L .58176 .4896 L p .29 0 .142 r
F P
0 g
s
.56784 .50067 m .5702 .49469 L .57191 .49297 L p .336 0 .154 r
F P
0 g
s
.57191 .49297 m .56855 .50151 L .56784 .50067 L p .336 0 .154 r
F P
0 g
s
.49098 .52911 m .49278 .52598 L .49085 .52478 L p .612 .356 .506 r
F P
0 g
s
.49085 .52478 m .48827 .52924 L .49098 .52911 L p .612 .356 .506 r
F P
0 g
s
.50685 .52792 m .49085 .52478 L .49278 .52598 L p .611 .357 .508 r
F P
0 g
s
.50503 .52646 m .49383 .52426 L .49085 .52478 L p .61 .33 .468 r
F P
0 g
s
.49085 .52478 m .50685 .52792 L .50503 .52646 L p .61 .33 .468 r
F P
0 g
s
.4688 .52461 m .45785 .51955 L .45535 .51881 L p .754 .528 .589 r
F P
0 g
s
.45535 .51881 m .47099 .52604 L .4688 .52461 L p .754 .528 .589 r
F P
0 g
s
.47059 .52683 m .47099 .52604 L .4686 .52507 L p .751 .535 .603 r
F P
0 g
s
.45765 .52001 m .4686 .52507 L .47099 .52604 L p .752 .531 .596 r
F P
0 g
s
.47099 .52604 m .45535 .51881 L .45765 .52001 L p .752 .531 .596 r
F P
0 g
s
.47299 .52761 m .47327 .52705 L .47099 .52604 L p .687 .459 .57 r
F P
0 g
s
.47099 .52604 m .47059 .52683 L .47299 .52761 L p .687 .459 .57 r
F P
0 g
s
.48666 .53196 m .47099 .52604 L .47327 .52705 L p .685 .463 .579 r
F P
0 g
s
.48451 .53069 m .47355 .52654 L .47099 .52604 L p .687 .458 .569 r
F P
0 g
s
.47099 .52604 m .48666 .53196 L .48451 .53069 L p .687 .458 .569 r
F P
0 g
s
.61808 .63182 m .62695 .63501 L .63175 .63456 L p .648 .872 .982 r
F P
0 g
s
.63175 .63456 m .61909 .63 L .61808 .63182 L p .648 .872 .982 r
F P
0 g
s
.64514 .62509 m .63239 .63236 L .63175 .63456 L p .701 .871 .962 r
F P
0 g
s
.63175 .63456 m .64996 .62419 L .64514 .62509 L p .701 .871 .962 r
F P
0 g
s
.61909 .63 m .63175 .63456 L .63239 .63236 L p .71 .88 .96 r
F P
0 g
s
.48872 .60863 m .48946 .60922 L .49042 .60773 L p .427 .476 .808 r
F P
0 g
s
.49042 .60773 m .48936 .60689 L .48872 .60863 L p .427 .476 .808 r
F P
0 g
s
.4797 .58731 m .47516 .59495 L .47558 .59767 L p .562 .55 .799 r
F P
0 g
s
.47558 .59767 m .48208 .58676 L .4797 .58731 L p .562 .55 .799 r
F P
0 g
s
.48262 .60056 m .47756 .59689 L .47558 .59767 L p .56 .569 .82 r
F P
0 g
s
.47558 .59767 m .4828 .60292 L .48262 .60056 L p .56 .569 .82 r
F P
0 g
s
.48208 .58676 m .47558 .59767 L .47756 .59689 L p .55 .535 .791 r
F P
0 g
s
.78848 .6118 m .75676 .60298 L .74833 .60293 L p .68 .754 .907 r
F P
0 g
s
.45399 .51569 m .45337 .51723 L .45535 .51881 L p .819 .601 .607 r
F P
0 g
s
.4686 .52507 m .46831 .52562 L .47059 .52683 L p .751 .535 .603 r
F P
0 g
s
.71269 .38134 m .71276 .36072 L .70516 .35942 L p .794 .835 .883 r
F P
0 g
s
.44169 .49924 m .44119 .50262 L .4428 .50475 L p .912 .648 .525 r
F P
0 g
s
.52721 .52049 m .53271 .51137 L .52946 .51286 L p .52 .183 .336 r
F P
0 g
s
.53005 .51877 m .5339 .51238 L .53271 .51137 L p .461 .119 .3 r
F P
0 g
s
.53271 .51137 m .52721 .52049 L .53005 .51877 L p .461 .119 .3 r
F P
0 g
s
.54588 .50884 m .53271 .51137 L .5339 .51238 L p .466 .118 .292 r
F P
0 g
s
.53271 .51137 m .54588 .50884 L .54467 .50787 L p .426 .042 .204 r
F P
0 g
s
.47012 .52779 m .47059 .52683 L .4682 .52587 L p .751 .537 .606 r
F P
0 g
s
.45733 .52077 m .4682 .52587 L .47059 .52683 L p .752 .534 .601 r
F P
0 g
s
.47059 .52683 m .45507 .51954 L .45733 .52077 L p .752 .534 .601 r
F P
0 g
s
.4725 .52856 m .47283 .52789 L .47059 .52683 L p .688 .462 .574 r
F P
0 g
s
.47059 .52683 m .47012 .52779 L .4725 .52856 L p .688 .462 .574 r
F P
0 g
s
.48611 .53287 m .47059 .52683 L .47283 .52789 L p .685 .467 .584 r
F P
0 g
s
.45507 .51954 m .47059 .52683 L .46831 .52562 L p .753 .532 .596 r
F P
0 g
s
.48385 .53184 m .47299 .52761 L .47059 .52683 L p .686 .464 .579 r
F P
0 g
s
.47059 .52683 m .48611 .53287 L .48385 .53184 L p .686 .464 .579 r
F P
0 g
s
.56384 .64123 m .56115 .63889 L .55772 .63841 L p .347 .773 .974 r
F P
0 g
s
.46831 .52562 m .45745 .52052 L .45507 .51954 L p .753 .532 .596 r
F P
0 g
s
.46558 .83315 m .44236 .89471 L .43737 .88386 L p .723 .721 .848 r
F P
0 g
s
.39178 .87447 m .43737 .88386 L .44236 .89471 L p .723 .721 .848 r
F P
0 g
s
.44236 .89471 m .37737 .88141 L .39178 .87447 L p .723 .721 .848 r
F P
0 g
s
.472 .84346 m .45562 .88651 L .44236 .89471 L p .705 .701 .843 r
F P
0 g
s
.44236 .89471 m .46558 .83315 L .472 .84346 L p .705 .701 .843 r
F P
0 g
s
.45745 .52052 m .45765 .52001 L .45535 .51881 L p .754 .527 .588 r
F P
0 g
s
.49036 .60977 m .49345 .61201 L .49484 .61092 L p .478 .556 .857 r
F P
0 g
s
.49484 .61092 m .49042 .60773 L .49036 .60977 L p .478 .556 .857 r
F P
0 g
s
.45507 .51954 m .45535 .51881 L .45323 .51766 L p .819 .604 .611 r
F P
0 g
s
.44346 .51179 m .45323 .51766 L .45535 .51881 L p .821 .599 .602 r
F P
0 g
s
.45535 .51881 m .44139 .51042 L .44346 .51179 L p .821 .599 .602 r
F P
0 g
s
.45535 .51881 m .45507 .51954 L .45745 .52052 L p .754 .527 .588 r
F P
0 g
s
.44139 .51042 m .45535 .51881 L .45337 .51723 L p .822 .598 .6 r
F P
0 g
s
.45681 .5819 m .46267 .57359 L .46219 .57054 L p .643 .574 .762 r
F P
0 g
s
.4682 .52587 m .46787 .52655 L .47012 .52779 L p .751 .537 .606 r
F P
0 g
s
.58574 .64141 m .5994 .63865 L .60102 .63721 L p .561 .847 .997 r
F P
0 g
s
.60102 .63721 m .58149 .64116 L .58574 .64141 L p .561 .847 .997 r
F P
0 g
s
.4531 .57926 m .44364 .57279 L .44032 .57317 L p .687 .62 .776 r
F P
0 g
s
.47327 .52705 m .48423 .5312 L .48666 .53196 L p .685 .463 .579 r
F P
0 g
s
.4683 .59007 m .47356 .58196 L .4733 .57912 L p .597 .551 .774 r
F P
0 g
s
.52946 .51286 m .52561 .51924 L .52721 .52049 L p .52 .183 .336 r
F P
0 g
s
.48649 .59348 m .48262 .60056 L .4828 .60292 L p .512 .531 .812 r
F P
0 g
s
.4828 .60292 m .48834 .59281 L .48649 .59348 L p .512 .531 .812 r
F P
0 g
s
.48733 .60417 m .48424 .60194 L .4828 .60292 L p .524 .561 .835 r
F P
0 g
s
.4828 .60292 m .48721 .60611 L .48733 .60417 L p .524 .561 .835 r
F P
0 g
s
.48834 .59281 m .4828 .60292 L .48424 .60194 L p .506 .523 .808 r
F P
0 g
s
.28629 .58156 m .29789 .59368 L .30731 .59395 L p .681 .762 .912 r
F P
0 g
s
.30731 .59395 m .29079 .5766 L .28629 .58156 L p .681 .762 .912 r
F P
0 g
s
.33394 .57906 m .31014 .58939 L .30731 .59395 L p .699 .768 .905 r
F P
0 g
s
.30731 .59395 m .34127 .57922 L .33394 .57906 L p .699 .768 .905 r
F P
0 g
s
.29079 .5766 m .30731 .59395 L .31014 .58939 L p .698 .767 .905 r
F P
0 g
s
.46858 .5307 m .47012 .52779 L .4676 .5271 L p .748 .546 .621 r
F P
0 g
s
.45681 .52195 m .4676 .5271 L .47012 .52779 L p .749 .54 .613 r
F P
0 g
s
.47012 .52779 m .4547 .52043 L .45681 .52195 L p .749 .54 .613 r
F P
0 g
s
.47107 .53122 m .47215 .52918 L .47012 .52779 L p .688 .472 .588 r
F P
0 g
s
.47012 .52779 m .46858 .5307 L .47107 .53122 L p .688 .472 .588 r
F P
0 g
s
.48545 .53398 m .47012 .52779 L .47215 .52918 L p .684 .474 .597 r
F P
0 g
s
.4547 .52043 m .47012 .52779 L .46787 .52655 L p .752 .535 .601 r
F P
0 g
s
.48323 .53289 m .4725 .52856 L .47012 .52779 L p .686 .468 .585 r
F P
0 g
s
.47012 .52779 m .48545 .53398 L .48323 .53289 L p .686 .468 .585 r
F P
0 g
s
.46787 .52655 m .45707 .52139 L .4547 .52043 L p .752 .535 .601 r
F P
0 g
s
.45707 .52139 m .45733 .52077 L .45507 .51954 L p .753 .532 .596 r
F P
0 g
s
.4547 .52043 m .45507 .51954 L .45294 .51841 L p .817 .608 .62 r
F P
0 g
s
.44323 .51252 m .45294 .51841 L .45507 .51954 L p .819 .605 .614 r
F P
0 g
s
.45507 .51954 m .4412 .51112 L .44323 .51252 L p .819 .605 .614 r
F P
0 g
s
.45507 .51954 m .4547 .52043 L .45707 .52139 L p .753 .532 .596 r
F P
0 g
s
.45323 .51766 m .45303 .51817 L .45507 .51954 L p .819 .604 .611 r
F P
0 g
s
.4412 .51112 m .45507 .51954 L .45303 .51817 L p .822 .6 .602 r
F P
0 g
s
.45337 .51723 m .4436 .51135 L .44139 .51042 L p .822 .598 .6 r
F P
0 g
s
.47283 .52789 m .4837 .53212 L .48611 .53287 L p .685 .467 .584 r
F P
0 g
s
.49537 .61313 m .50052 .61664 L .50221 .61595 L p .448 .558 .875 r
F P
0 g
s
.50221 .61595 m .49484 .61092 L .49537 .61313 L p .448 .558 .875 r
F P
0 g
s
.4676 .5271 m .46653 .52914 L .46858 .5307 L p .748 .546 .621 r
F P
0 g
s
.58481 .88947 m .5737 .84647 L .58193 .83672 L p .683 .682 .842 r
F P
0 g
s
.49278 .52598 m .50398 .52818 L .50685 .52792 L p .611 .357 .508 r
F P
0 g
s
.49074 .59756 m .48733 .60417 L .48721 .60611 L p .476 .518 .822 r
F P
0 g
s
.48721 .60611 m .49208 .59667 L .49074 .59756 L p .476 .518 .822 r
F P
0 g
s
.48869 .60571 m .48806 .60489 L .48721 .60611 L p .44 .48 .805 r
F P
0 g
s
.48721 .60611 m .48811 .60728 L .48869 .60571 L p .44 .48 .805 r
F P
0 g
s
.49208 .59667 m .48721 .60611 L .48806 .60489 L p .393 .418 .767 r
F P
0 g
s
.45354 .52311 m .4547 .52043 L .45248 .51956 L p .815 .613 .629 r
F P
0 g
s
.44283 .51365 m .45248 .51956 L .4547 .52043 L p .815 .611 .626 r
F P
0 g
s
.4547 .52043 m .44092 .51199 L .44283 .51365 L p .815 .611 .626 r
F P
0 g
s
.456 .52383 m .45681 .52195 L .4547 .52043 L p .753 .538 .604 r
F P
0 g
s
.4547 .52043 m .45354 .52311 L .456 .52383 L p .753 .538 .604 r
F P
0 g
s
.45294 .51841 m .45268 .51903 L .4547 .52043 L p .817 .608 .62 r
F P
0 g
s
.44092 .51199 m .4547 .52043 L .45268 .51903 L p .819 .606 .614 r
F P
0 g
s
.44428 .509 m .44485 .50653 L .4428 .50475 L p .826 .582 .57 r
F P
0 g
s
.41794 .57562 m .42663 .56672 L .42631 .56329 L p .717 .667 .799 r
F P
0 g
s
.42631 .56329 m .4139 .57601 L .41794 .57562 L p .717 .667 .799 r
F P
0 g
s
.42663 .56672 m .43643 .57363 L .44032 .57317 L p .703 .657 .801 r
F P
0 g
s
.34012 .38026 m .34438 .36149 L .35298 .36132 L p .53 .605 .873 r
F P
0 g
s
.49194 .59924 m .48869 .60571 L .48811 .60728 L p .377 .41 .768 r
F P
0 g
s
.48811 .60728 m .49276 .59804 L .49194 .59924 L p .377 .41 .768 r
F P
0 g
s
.39909 .56883 m .40917 .57645 L .4139 .57601 L p .72 .711 .841 r
F P
0 g
s
.4139 .57601 m .3995 .56511 L .39909 .56883 L p .72 .711 .841 r
F P
0 g
s
.42238 .56362 m .41369 .57253 L .4139 .57601 L p .738 .704 .819 r
F P
0 g
s
.4139 .57601 m .42631 .56329 L .42238 .56362 L p .738 .704 .819 r
F P
0 g
s
.3995 .56511 m .4139 .57601 L .41369 .57253 L p .746 .71 .818 r
F P
0 g
s
.45303 .51817 m .44332 .51228 L .4412 .51112 L p .822 .6 .602 r
F P
0 g
s
.47756 .59689 m .48211 .58925 L .48208 .58676 L p .55 .535 .791 r
F P
0 g
s
.44032 .57317 m .42631 .56329 L .42663 .56672 L p .703 .657 .801 r
F P
0 g
s
.44589 .56175 m .4396 .56997 L .44032 .57317 L p .713 .644 .779 r
F P
0 g
s
.44032 .57317 m .44931 .56144 L .44589 .56175 L p .713 .644 .779 r
F P
0 g
s
.42631 .56329 m .44032 .57317 L .4396 .56997 L p .726 .653 .776 r
F P
0 g
s
.44931 .56144 m .44032 .57317 L .44364 .57279 L p .686 .604 .759 r
F P
0 g
s
.47215 .52918 m .48288 .53352 L .48545 .53398 L p .684 .474 .597 r
F P
0 g
s
.50819 .52148 m .50503 .52646 L .50685 .52792 L p .61 .33 .468 r
F P
0 g
s
.50685 .52792 m .51136 .52079 L .50819 .52148 L p .61 .33 .468 r
F P
0 g
s
.44199 .50828 m .4428 .50475 L .44102 .50391 L p .904 .669 .573 r
F P
0 g
s
.43319 .49744 m .44102 .50391 L .4428 .50475 L p .904 .669 .572 r
F P
0 g
s
.4428 .50475 m .43161 .49551 L .43319 .49744 L p .904 .669 .572 r
F P
0 g
s
.4428 .50475 m .44199 .50828 L .44428 .509 L p .826 .582 .57 r
F P
0 g
s
.43161 .49551 m .4428 .50475 L .44119 .50262 L p .914 .647 .519 r
F P
0 g
s
.52561 .51924 m .51452 .51945 L .51136 .52079 L p .517 .184 .342 r
F P
0 g
s
.44364 .57279 m .44994 .56458 L .44931 .56144 L p .686 .604 .759 r
F P
0 g
s
.49094 .60624 m .49019 .60566 L .48936 .60689 L p .426 .476 .809 r
F P
0 g
s
.48936 .60689 m .49042 .60773 L .49094 .60624 L p .426 .476 .809 r
F P
0 g
s
.49401 .59765 m .48936 .60689 L .49019 .60566 L p .377 .41 .768 r
F P
0 g
s
.50981 .52691 m .51297 .52192 L .51136 .52079 L p .529 .237 .414 r
F P
0 g
s
.51136 .52079 m .50685 .52792 L .50981 .52691 L p .529 .237 .414 r
F P
0 g
s
.52721 .52049 m .51136 .52079 L .51297 .52192 L p .533 .234 .406 r
F P
0 g
s
.51136 .52079 m .52721 .52049 L .52561 .51924 L p .517 .184 .342 r
F P
0 g
s
.45268 .51903 m .44304 .51312 L .44092 .51199 L p .819 .606 .614 r
F P
0 g
s
.50336 .61818 m .51045 .62263 L .51235 .62232 L p .397 .563 .901 r
F P
0 g
s
.51235 .62232 m .50221 .61595 L .50336 .61818 L p .397 .563 .901 r
F P
0 g
s
.46653 .52914 m .456 .52383 L .45354 .52311 L p .752 .544 .614 r
F P
0 g
s
.45354 .52311 m .46858 .5307 L .46653 .52914 L p .752 .544 .614 r
F P
0 g
s
.48564 .52878 m .48451 .53069 L .48666 .53196 L p .685 .46 .575 r
F P
0 g
s
.48666 .53196 m .48827 .52924 L .48564 .52878 L p .685 .46 .575 r
F P
0 g
s
.46588 .53559 m .46858 .5307 L .46596 .53026 L p .745 .559 .643 r
F P
0 g
s
.45543 .52495 m .46596 .53026 L .46858 .5307 L p .745 .553 .635 r
F P
0 g
s
.46858 .5307 m .45354 .52311 L .45543 .52495 L p .745 .553 .635 r
F P
0 g
s
.46846 .5359 m .47035 .53247 L .46858 .5307 L p .688 .488 .611 r
F P
0 g
s
.46858 .5307 m .46588 .53559 L .46846 .5359 L p .688 .488 .611 r
F P
0 g
s
.48343 .53732 m .46858 .5307 L .47035 .53247 L p .681 .488 .619 r
F P
0 g
s
.48146 .53585 m .47107 .53122 L .46858 .5307 L p .687 .479 .599 r
F P
0 g
s
.46858 .5307 m .48343 .53732 L .48146 .53585 L p .687 .479 .599 r
F P
0 g
s
.43349 .49088 m .433 .4863 L .43108 .48385 L p .918 .605 .435 r
F P
0 g
s
.57379 .63917 m .57779 .64082 L .58149 .64116 L p .266 .745 .932 r
F P
0 g
s
.58149 .64116 m .57579 .63881 L .57379 .63917 L p .266 .745 .932 r
F P
0 g
s
.59711 .6375 m .58342 .64027 L .58149 .64116 L p .445 .854 .964 r
F P
0 g
s
.58149 .64116 m .60102 .63721 L .59711 .6375 L p .445 .854 .964 r
F P
0 g
s
.57579 .63881 m .58149 .64116 L .58342 .64027 L p .447 .852 .969 r
F P
0 g
s
.42113 .46457 m .41648 .45715 L .41425 .45362 L p .612 .192 0 r
F P
0 g
s
.45248 .51956 m .45167 .52144 L .45354 .52311 L p .815 .613 .629 r
F P
0 g
s
.49401 .59997 m .49094 .60624 L .49042 .60773 L p .363 .406 .772 r
F P
0 g
s
.49042 .60773 m .49482 .59877 L .49401 .59997 L p .363 .406 .772 r
F P
0 g
s
.49478 .60916 m .49169 .60692 L .49042 .60773 L p .47 .555 .86 r
F P
0 g
s
.49042 .60773 m .49484 .61092 L .49478 .60916 L p .47 .555 .86 r
F P
0 g
s
.49482 .59877 m .49042 .60773 L .49169 .60692 L p .451 .513 .831 r
F P
0 g
s
.4891 .53221 m .49023 .5303 L .48827 .52924 L p .612 .372 .529 r
F P
0 g
s
.48827 .52924 m .48666 .53196 L .4891 .53221 L p .612 .372 .529 r
F P
0 g
s
.50328 .53332 m .48827 .52924 L .49023 .5303 L p .61 .374 .534 r
F P
0 g
s
.50148 .53196 m .49098 .52911 L .48827 .52924 L p .612 .359 .51 r
F P
0 g
s
.48827 .52924 m .50328 .53332 L .50148 .53196 L p .612 .359 .51 r
F P
0 g
s
.48424 .60194 m .48812 .59486 L .48834 .59281 L p .506 .523 .808 r
F P
0 g
s
.46596 .53026 m .46407 .53369 L .46588 .53559 L p .745 .559 .643 r
F P
0 g
s
.57329 .49339 m .57094 .49937 L .56855 .50151 L p .29 0 .136 r
F P
0 g
s
.4396 .56997 m .4298 .56305 L .42631 .56329 L p .726 .653 .776 r
F P
0 g
s
.44119 .50262 m .43336 .49615 L .43161 .49551 L p .914 .647 .519 r
F P
0 g
s
.45132 .52764 m .45354 .52311 L .45121 .5225 L p .807 .625 .655 r
F P
0 g
s
.4417 .51655 m .45121 .5225 L .45354 .52311 L p .808 .621 .648 r
F P
0 g
s
.45354 .52311 m .43996 .51461 L .4417 .51655 L p .808 .621 .648 r
F P
0 g
s
.45388 .52812 m .45543 .52495 L .45354 .52311 L p .75 .553 .629 r
F P
0 g
s
.45354 .52311 m .45132 .52764 L .45388 .52812 L p .75 .553 .629 r
F P
0 g
s
.43996 .51461 m .45354 .52311 L .45167 .52144 L p .816 .612 .626 r
F P
0 g
s
.5339 .51238 m .54312 .51061 L .54588 .50884 L p .466 .118 .292 r
F P
0 g
s
.43177 .49039 m .43108 .48385 L .43018 .48331 L p .971 .661 .284 r
F P
0 g
s
.4253 .47588 m .43018 .48331 L .43108 .48385 L p .97 .661 .284 r
F P
0 g
s
.43108 .48385 m .42411 .47323 L .4253 .47588 L p .97 .661 .284 r
F P
0 g
s
.43108 .48385 m .43177 .49039 L .43349 .49088 L p .918 .605 .435 r
F P
0 g
s
.42411 .47323 m .43108 .48385 L .42961 .48101 L p .871 .491 .012 r
F P
0 g
s
.47035 .53247 m .48074 .53711 L .48343 .53732 L p .681 .488 .619 r
F P
0 g
s
.58703 .48511 m .5973 .47922 L .5987 .47914 L p .049 0 0 r
F P
0 g
s
.5987 .47914 m .58401 .48755 L .58703 .48511 L p .049 0 0 r
F P
0 g
s
.69477 .61904 m .70491 .60989 L .70241 .60629 L p .703 .773 .906 r
F P
0 g
s
.70241 .60629 m .68792 .61939 L .69477 .61904 L p .703 .773 .906 r
F P
0 g
s
.49737 .60341 m .49478 .60916 L .49484 .61092 L p .409 .503 .843 r
F P
0 g
s
.49484 .61092 m .49853 .60271 L .49737 .60341 L p .409 .503 .843 r
F P
0 g
s
.50156 .61407 m .4964 .61055 L .49484 .61092 L p .421 .554 .883 r
F P
0 g
s
.49484 .61092 m .50221 .61595 L .50156 .61407 L p .421 .554 .883 r
F P
0 g
s
.49853 .60271 m .49484 .61092 L .4964 .61055 L p .417 .512 .848 r
F P
0 g
s
.48806 .60489 m .49147 .59828 L .49208 .59667 L p .393 .418 .767 r
F P
0 g
s
.70037 .38719 m .6776 .39775 L .67272 .40394 L p .835 .864 .866 r
F P
0 g
s
.35256 .38746 m .37558 .40099 L .37958 .4074 L p .479 .554 .854 r
F P
0 g
s
.45167 .52144 m .44216 .51549 L .43996 .51461 L p .816 .612 .626 r
F P
0 g
s
.48423 .5312 m .48385 .53184 L .48611 .53287 L p .684 .467 .586 r
F P
0 g
s
.48611 .53287 m .48666 .53196 L .48423 .5312 L p .684 .467 .586 r
F P
0 g
s
.51417 .62438 m .52315 .62907 L .5252 .62902 L p .331 .579 .933 r
F P
0 g
s
.5252 .62902 m .51235 .62232 L .51417 .62438 L p .331 .579 .933 r
F P
0 g
s
.41369 .57253 m .40361 .56489 L .3995 .56511 L p .746 .71 .818 r
F P
0 g
s
.44102 .50391 m .44046 .50638 L .44199 .50828 L p .904 .669 .573 r
F P
0 g
s
.41425 .45362 m .42089 .46423 L .42113 .46457 L p .612 .192 0 r
F P
0 g
s
.42089 .46423 m .41425 .45362 L .41508 .45329 L p 0 .11 .652 r
F P
0 g
s
.41422 .44353 m .41508 .45329 L .41425 .45362 L p 0 .108 .65 r
F P
0 g
s
.41425 .45362 m .41301 .43966 L .41422 .44353 L p 0 .108 .65 r
F P
0 g
s
.41301 .43966 m .41425 .45362 L .41224 .44952 L p .126 .313 .782 r
F P
0 g
s
.4436 .51135 m .44402 .50986 L .44199 .50828 L p .823 .594 .591 r
F P
0 g
s
.73193 .61298 m .70914 .60588 L .70241 .60629 L p .699 .768 .905 r
F P
0 g
s
.4837 .53212 m .48323 .53289 L .48545 .53398 L p .684 .472 .593 r
F P
0 g
s
.48545 .53398 m .48611 .53287 L .4837 .53212 L p .684 .472 .593 r
F P
0 g
s
.49019 .60566 m .49345 .59919 L .49401 .59765 L p .377 .41 .768 r
F P
0 g
s
.63239 .63236 m .62353 .62916 L .61909 .63 L p .71 .88 .96 r
F P
0 g
s
.45121 .5225 m .44965 .52567 L .45132 .52764 L p .807 .625 .655 r
F P
0 g
s
.46407 .53369 m .45388 .52812 L .45132 .52764 L p .749 .558 .637 r
F P
0 g
s
.45132 .52764 m .46588 .53559 L .46407 .53369 L p .749 .558 .637 r
F P
0 g
s
.48833 .53345 m .48871 .53281 L .48666 .53196 L p .612 .38 .541 r
F P
0 g
s
.48666 .53196 m .48611 .53287 L .48833 .53345 L p .612 .38 .541 r
F P
0 g
s
.50106 .53665 m .48666 .53196 L .48871 .53281 L p .611 .383 .547 r
F P
0 g
s
.49918 .53549 m .4891 .53221 L .48666 .53196 L p .613 .377 .536 r
F P
0 g
s
.48666 .53196 m .50106 .53665 L .49918 .53549 L p .613 .377 .536 r
F P
0 g
s
.49023 .5303 m .50074 .53316 L .50328 .53332 L p .61 .374 .534 r
F P
0 g
s
.66604 .61508 m .68202 .62016 L .68792 .61939 L p .71 .802 .922 r
F P
0 g
s
.68792 .61939 m .6651 .6121 L .66604 .61508 L p .71 .802 .922 r
F P
0 g
s
.69664 .60721 m .6865 .61639 L .68792 .61939 L p .712 .792 .914 r
F P
0 g
s
.68792 .61939 m .70241 .60629 L .69664 .60721 L p .712 .792 .914 r
F P
0 g
s
.6651 .6121 m .68792 .61939 L .6865 .61639 L p .725 .799 .91 r
F P
0 g
s
.46185 .54245 m .46588 .53559 L .46314 .53539 L p .739 .576 .672 r
F P
0 g
s
.45295 .52982 m .46314 .53539 L .46588 .53559 L p .739 .569 .662 r
F P
0 g
s
.46588 .53559 m .45132 .52764 L .45295 .52982 L p .739 .569 .662 r
F P
0 g
s
.46452 .54257 m .46734 .53777 L .46588 .53559 L p .688 .511 .642 r
F P
0 g
s
.46588 .53559 m .46185 .54245 L .46452 .54257 L p .688 .511 .642 r
F P
0 g
s
.48002 .54286 m .46588 .53559 L .46734 .53777 L p .677 .508 .649 r
F P
0 g
s
.47836 .54099 m .46846 .5359 L .46588 .53559 L p .688 .497 .623 r
F P
0 g
s
.46588 .53559 m .48002 .54286 L .47836 .54099 L p .688 .497 .623 r
F P
0 g
s
.42961 .48101 m .42473 .47357 L .42411 .47323 L p .871 .491 .012 r
F P
0 g
s
.50328 .60927 m .50156 .61407 L .50221 .61595 L p .328 .488 .866 r
F P
0 g
s
.50221 .61595 m .50467 .6091 L .50328 .60927 L p .328 .488 .866 r
F P
0 g
s
.51109 .62047 m .50398 .61601 L .50221 .61595 L p .33 .548 .912 r
F P
0 g
s
.50221 .61595 m .51235 .62232 L .51109 .62047 L p .33 .548 .912 r
F P
0 g
s
.50467 .6091 m .50221 .61595 L .50398 .61601 L p .35 .513 .879 r
F P
0 g
s
.44139 .51042 m .44199 .50828 L .44028 .50724 L p .898 .68 .6 r
F P
0 g
s
.43263 .50088 m .44028 .50724 L .44199 .50828 L p .898 .678 .596 r
F P
0 g
s
.44199 .50828 m .43106 .49919 L .43263 .50088 L p .898 .678 .596 r
F P
0 g
s
.44199 .50828 m .44139 .51042 L .4436 .51135 L p .823 .594 .591 r
F P
0 g
s
.43106 .49919 m .44199 .50828 L .44046 .50638 L p .904 .669 .572 r
F P
0 g
s
.51297 .52192 m .52407 .52171 L .52721 .52049 L p .533 .234 .406 r
F P
0 g
s
.38651 .57816 m .39909 .56883 L .3995 .56511 L p .728 .718 .841 r
F P
0 g
s
.3995 .56511 m .38152 .57845 L .38651 .57816 L p .728 .718 .841 r
F P
0 g
s
.46267 .57359 m .47043 .5796 L .4733 .57912 L p .613 .553 .763 r
F P
0 g
s
.4733 .57912 m .46219 .57054 L .46267 .57359 L p .613 .553 .763 r
F P
0 g
s
.48765 .53456 m .48812 .53379 L .48611 .53287 L p .612 .385 .548 r
F P
0 g
s
.48611 .53287 m .48545 .53398 L .48765 .53456 L p .612 .385 .548 r
F P
0 g
s
.50031 .53776 m .48611 .53287 L .48812 .53379 L p .61 .388 .555 r
F P
0 g
s
.49827 .53687 m .48833 .53345 L .48611 .53287 L p .612 .384 .548 r
F P
0 g
s
.48611 .53287 m .50031 .53776 L .49827 .53687 L p .612 .384 .548 r
F P
0 g
s
.44994 .56458 m .45895 .57095 L .46219 .57054 L p .666 .591 .761 r
F P
0 g
s
.55377 .50553 m .54786 .50713 L .54588 .50884 L p .384 0 .175 r
F P
0 g
s
.49169 .60692 m .49476 .60065 L .49482 .59877 L p .451 .513 .831 r
F P
0 g
s
.48288 .53352 m .48146 .53585 L .48343 .53732 L p .683 .48 .606 r
F P
0 g
s
.48343 .53732 m .48545 .53398 L .48288 .53352 L p .683 .48 .606 r
F P
0 g
s
.46314 .53539 m .46032 .54019 L .46185 .54245 L p .739 .576 .672 r
F P
0 g
s
.46219 .57054 m .44931 .56144 L .44994 .56458 L p .666 .591 .761 r
F P
0 g
s
.6055 .88737 m .66096 .87786 L .67666 .88472 L p .658 .665 .846 r
F P
0 g
s
.58153 .49557 m .58401 .48755 L .58587 .48744 L p .221 0 .125 r
F P
0 g
s
.59616 .48155 m .58587 .48744 L .58401 .48755 L p .223 0 .134 r
F P
0 g
s
.58401 .48755 m .5987 .47914 L .59616 .48155 L p .223 0 .134 r
F P
0 g
s
.58002 .49521 m .58176 .4896 L .58401 .48755 L p .301 0 .153 r
F P
0 g
s
.58401 .48755 m .58153 .49557 L .58002 .49521 L p .301 0 .153 r
F P
0 g
s
.63177 .44613 m .64007 .43945 L .64384 .43574 L p .693 .957 .701 r
F P
0 g
s
.63198 .44528 m .64384 .43574 L .64327 .43456 L p .877 .994 .776 r
F P
0 g
s
.64905 .42166 m .64327 .43456 L .64384 .43574 L p .876 .994 .776 r
F P
0 g
s
.64384 .43574 m .65212 .41731 L .64905 .42166 L p .876 .994 .776 r
F P
0 g
s
.64384 .43574 m .63198 .44528 L .63177 .44613 L p .693 .957 .701 r
F P
0 g
s
.65212 .41731 m .64384 .43574 L .6481 .43123 L p .861 .964 .867 r
F P
0 g
s
.46734 .53777 m .47724 .54286 L .48002 .54286 L p .677 .508 .649 r
F P
0 g
s
.44788 .53399 m .45132 .52764 L .44886 .52727 L p .8 .639 .683 r
F P
0 g
s
.43963 .52121 m .44886 .52727 L .45132 .52764 L p .8 .634 .676 r
F P
0 g
s
.45132 .52764 m .43814 .51898 L .43963 .52121 L p .8 .634 .676 r
F P
0 g
s
.45054 .53427 m .45295 .52982 L .45132 .52764 L p .747 .57 .655 r
F P
0 g
s
.45132 .52764 m .44788 .53399 L .45054 .53427 L p .747 .57 .655 r
F P
0 g
s
.43814 .51898 m .45132 .52764 L .44965 .52567 L p .812 .625 .65 r
F P
0 g
s
.39768 .42494 m .38312 .4129 L .37958 .4074 L p .292 .456 .852 r
F P
0 g
s
.48576 .53764 m .48718 .5353 L .48545 .53398 L p .614 .395 .561 r
F P
0 g
s
.48545 .53398 m .48343 .53732 L .48576 .53764 L p .614 .395 .561 r
F P
0 g
s
.4994 .53911 m .48545 .53398 L .48718 .5353 L p .609 .397 .568 r
F P
0 g
s
.49742 .53815 m .48765 .53456 L .48545 .53398 L p .612 .39 .556 r
F P
0 g
s
.48545 .53398 m .4994 .53911 L .49742 .53815 L p .612 .39 .556 r
F P
0 g
s
.44332 .51228 m .44346 .51179 L .44139 .51042 L p .824 .595 .592 r
F P
0 g
s
.36575 .57004 m .37568 .5787 L .38152 .57845 L p .717 .75 .879 r
F P
0 g
s
.38152 .57845 m .36736 .56605 L .36575 .57004 L p .717 .75 .879 r
F P
0 g
s
.39482 .56535 m .38222 .5747 L .38152 .57845 L p .741 .751 .86 r
F P
0 g
s
.38152 .57845 m .3995 .56511 L .39482 .56535 L p .741 .751 .86 r
F P
0 g
s
.36736 .56605 m .38152 .57845 L .38222 .5747 L p .743 .753 .861 r
F P
0 g
s
.46626 .56012 m .46132 .56761 L .46219 .57054 L p .67 .575 .74 r
F P
0 g
s
.46219 .57054 m .46925 .55985 L .46626 .56012 L p .67 .575 .74 r
F P
0 g
s
.44931 .56144 m .46219 .57054 L .46132 .56761 L p .688 .586 .736 r
F P
0 g
s
.47267 .57623 m .4649 .57022 L .46219 .57054 L p .637 .552 .741 r
F P
0 g
s
.46219 .57054 m .4733 .57912 L .47267 .57623 L p .637 .552 .741 r
F P
0 g
s
.46925 .55985 m .46219 .57054 L .4649 .57022 L p .635 .529 .717 r
F P
0 g
s
.44139 .51042 m .4412 .51112 L .44332 .51228 L p .824 .595 .592 r
F P
0 g
s
.41224 .44952 m .41136 .43974 L .41301 .43966 L p .126 .313 .782 r
F P
0 g
s
.43644 .55512 m .44589 .56175 L .44931 .56144 L p .713 .632 .766 r
F P
0 g
s
.44931 .56144 m .43579 .55196 L .43644 .55512 L p .713 .632 .766 r
F P
0 g
s
.45329 .5513 m .44834 .55851 L .44931 .56144 L p .723 .62 .742 r
F P
0 g
s
.44931 .56144 m .45638 .55114 L .45329 .5513 L p .723 .62 .742 r
F P
0 g
s
.43579 .55196 m .44931 .56144 L .44834 .55851 L p .735 .626 .738 r
F P
0 g
s
.46132 .56761 m .4523 .56123 L .44931 .56144 L p .688 .586 .736 r
F P
0 g
s
.45638 .55114 m .44931 .56144 L .4523 .56123 L p .687 .57 .718 r
F P
0 g
s
.48871 .53281 m .4988 .53609 L .50106 .53665 L p .611 .383 .547 r
F P
0 g
s
.4964 .61055 m .49899 .60481 L .49853 .60271 L p .417 .512 .848 r
F P
0 g
s
.44965 .52567 m .44042 .51961 L .43814 .51898 L p .812 .625 .65 r
F P
0 g
s
.44046 .50638 m .43281 .50002 L .43106 .49919 L p .904 .669 .572 r
F P
0 g
s
.44304 .51312 m .44323 .51252 L .4412 .51112 L p .821 .603 .607 r
F P
0 g
s
.6481 .43123 m .65391 .41834 L .65212 .41731 L p .861 .964 .867 r
F P
0 g
s
.62284 .45627 m .63177 .44613 L .63198 .44528 L p .693 .957 .701 r
F P
0 g
s
.63198 .44528 m .61923 .45977 L .62284 .45627 L p .693 .957 .701 r
F P
0 g
s
.52767 .63072 m .53838 .63477 L .54052 .63482 L p .263 .612 .956 r
F P
0 g
s
.54052 .63482 m .5252 .62902 L .52767 .63072 L p .263 .612 .956 r
F P
0 g
s
.4523 .56123 m .45725 .55402 L .45638 .55114 L p .687 .57 .718 r
F P
0 g
s
.31014 .58939 m .29861 .57722 L .29079 .5766 L p .698 .767 .905 r
F P
0 g
s
.4412 .51112 m .44139 .51042 L .43976 .50917 L p .898 .681 .6 r
F P
0 g
s
.43222 .50285 m .43976 .50917 L .44139 .51042 L p .897 .682 .603 r
F P
0 g
s
.44139 .51042 m .43062 .50138 L .43222 .50285 L p .897 .682 .603 r
F P
0 g
s
.44028 .50724 m .43986 .50874 L .44139 .51042 L p .898 .68 .6 r
F P
0 g
s
.43062 .50138 m .44139 .51042 L .43986 .50874 L p .899 .679 .596 r
F P
0 g
s
.58342 .64027 m .57945 .63862 L .57579 .63881 L p .447 .852 .969 r
F P
0 g
s
.46032 .54019 m .45054 .53427 L .44788 .53399 L p .746 .578 .666 r
F P
0 g
s
.44788 .53399 m .46185 .54245 L .46032 .54019 L p .746 .578 .666 r
F P
0 g
s
.4412 .51112 m .44092 .51199 L .44304 .51312 L p .821 .603 .607 r
F P
0 g
s
.48812 .53379 m .49806 .53721 L .50031 .53776 L p .61 .388 .555 r
F P
0 g
s
.51176 .61692 m .51109 .62047 L .51235 .62232 L p .186 .459 .882 r
F P
0 g
s
.51235 .62232 m .51332 .61724 L .51176 .61692 L p .186 .459 .882 r
F P
0 g
s
.5233 .6274 m .5143 .6227 L .51235 .62232 L p .188 .538 .926 r
F P
0 g
s
.51235 .62232 m .5252 .62902 L .5233 .6274 L p .188 .538 .926 r
F P
0 g
s
.51332 .61724 m .51235 .62232 L .5143 .6227 L p .242 .52 .913 r
F P
0 g
s
.45638 .55114 m .46185 .54245 L .45897 .54244 L p .732 .597 .706 r
F P
0 g
s
.44919 .53652 m .45897 .54244 L .46185 .54245 L p .732 .588 .695 r
F P
0 g
s
.46185 .54245 m .44788 .53399 L .44919 .53652 L p .732 .588 .695 r
F P
0 g
s
.45917 .55109 m .463 .54501 L .46185 .54245 L p .688 .539 .678 r
F P
0 g
s
.46185 .54245 m .45638 .55114 L .45917 .55109 L p .688 .539 .678 r
F P
0 g
s
.47526 .55049 m .46185 .54245 L .463 .54501 L p .672 .532 .685 r
F P
0 g
s
.4739 .54819 m .46452 .54257 L .46185 .54245 L p .688 .522 .656 r
F P
0 g
s
.46185 .54245 m .47526 .55049 L .4739 .54819 L p .688 .522 .656 r
F P
0 g
s
.44834 .55851 m .43888 .55188 L .43579 .55196 L p .735 .626 .738 r
F P
0 g
s
.48074 .53711 m .47836 .54099 L .48002 .54286 L p .681 .496 .63 r
F P
0 g
s
.48002 .54286 m .48343 .53732 L .48074 .53711 L p .681 .496 .63 r
F P
0 g
s
.61344 .4677 m .61923 .45977 L .62022 .45884 L p 0 0 0 r
F P
0 g
s
.62915 .44869 m .62022 .45884 L .61923 .45977 L p 0 0 0 r
F P
0 g
s
.61923 .45977 m .63198 .44528 L .62915 .44869 L p 0 0 0 r
F P
0 g
s
.61206 .46824 m .61612 .46269 L .61923 .45977 L p 0 0 0 r
F P
0 g
s
.61923 .45977 m .61344 .4677 L .61206 .46824 L p 0 0 0 r
F P
0 g
s
.43018 .48331 m .43066 .48789 L .43177 .49039 L p .971 .661 .284 r
F P
0 g
s
.44886 .52727 m .44645 .53172 L .44788 .53399 L p .8 .639 .683 r
F P
0 g
s
.4649 .57022 m .46984 .56274 L .46925 .55985 L p .635 .529 .717 r
F P
0 g
s
.44216 .51549 m .44283 .51365 L .44092 .51199 L p .817 .61 .623 r
F P
0 g
s
.47356 .58196 m .4797 .58731 L .48208 .58676 L p .557 .521 .771 r
F P
0 g
s
.48208 .58676 m .4733 .57912 L .47356 .58196 L p .557 .521 .771 r
F P
0 g
s
.44092 .51199 m .4412 .51112 L .43955 .50991 L p .892 .687 .62 r
F P
0 g
s
.43203 .5036 m .43955 .50991 L .4412 .51112 L p .891 .688 .622 r
F P
0 g
s
.4412 .51112 m .43045 .50211 L .43203 .5036 L p .891 .688 .622 r
F P
0 g
s
.43976 .50917 m .43962 .50967 L .4412 .51112 L p .898 .681 .6 r
F P
0 g
s
.43045 .50211 m .4412 .51112 L .43962 .50967 L p .897 .682 .603 r
F P
0 g
s
.45897 .54244 m .45514 .54853 L .45638 .55114 L p .732 .597 .706 r
F P
0 g
s
.4298 .56305 m .43644 .55512 L .43579 .55196 L p .727 .641 .763 r
F P
0 g
s
.43579 .55196 m .42631 .56329 L .4298 .56305 L p .727 .641 .763 r
F P
0 g
s
.463 .54501 m .47238 .55063 L .47526 .55049 L p .672 .532 .685 r
F P
0 g
s
.48244 .54298 m .48482 .5391 L .48343 .53732 L p .616 .415 .587 r
F P
0 g
s
.48343 .53732 m .48002 .54286 L .48244 .54298 L p .616 .415 .587 r
F P
0 g
s
.49668 .54315 m .48343 .53732 L .48482 .5391 L p .606 .414 .595 r
F P
0 g
s
.49504 .54172 m .48576 .53764 L .48343 .53732 L p .614 .402 .572 r
F P
0 g
s
.48343 .53732 m .49668 .54315 L .49504 .54172 L p .614 .402 .572 r
F P
0 g
s
.54091 .51832 m .54588 .50884 L .54312 .51061 L p .451 .098 .274 r
F P
0 g
s
.54301 .51654 m .54648 .50989 L .54588 .50884 L p .421 .068 .258 r
F P
0 g
s
.54588 .50884 m .54091 .51832 L .54301 .51654 L p .421 .068 .258 r
F P
0 g
s
.55433 .50654 m .54588 .50884 L .54648 .50989 L p .425 .07 .256 r
F P
0 g
s
.54588 .50884 m .55433 .50654 L .55377 .50553 L p .384 0 .175 r
F P
0 g
s
.48718 .5353 m .49695 .53889 L .4994 .53911 L p .609 .397 .568 r
F P
0 g
s
.45725 .55402 m .46626 .56012 L .46925 .55985 L p .669 .559 .723 r
F P
0 g
s
.46925 .55985 m .45638 .55114 L .45725 .55402 L p .669 .559 .723 r
F P
0 g
s
.41312 .55646 m .42238 .56362 L .42631 .56329 L p .739 .697 .811 r
F P
0 g
s
.42631 .56329 m .41308 .55306 L .41312 .55646 L p .739 .697 .811 r
F P
0 g
s
.43243 .55217 m .42579 .56011 L .42631 .56329 L p .756 .688 .786 r
F P
0 g
s
.42631 .56329 m .43579 .55196 L .43243 .55217 L p .756 .688 .786 r
F P
0 g
s
.41308 .55306 m .42631 .56329 L .42579 .56011 L p .764 .694 .784 r
F P
0 g
s
.44383 .545 m .45329 .5513 L .45638 .55114 L p .723 .61 .73 r
F P
0 g
s
.45638 .55114 m .44287 .54214 L .44383 .545 L p .723 .61 .73 r
F P
0 g
s
.44287 .54214 m .45638 .55114 L .45514 .54853 L p .742 .602 .701 r
F P
0 g
s
.46818 .55719 m .45917 .55109 L .45638 .55114 L p .688 .553 .695 r
F P
0 g
s
.45638 .55114 m .46925 .55985 L .46818 .55719 L p .688 .553 .695 r
F P
0 g
s
.50398 .61601 m .50571 .61122 L .50467 .6091 L p .35 .513 .879 r
F P
0 g
s
.45514 .54853 m .44568 .54222 L .44287 .54214 L p .742 .602 .701 r
F P
0 g
s
.43996 .51461 m .44092 .51199 L .43919 .51104 L p .886 .695 .64 r
F P
0 g
s
.43169 .50475 m .43919 .51104 L .44092 .51199 L p .887 .692 .633 r
F P
0 g
s
.44092 .51199 m .4302 .50301 L .43169 .50475 L p .887 .692 .633 r
F P
0 g
s
.44092 .51199 m .43996 .51461 L .44216 .51549 L p .817 .61 .623 r
F P
0 g
s
.43955 .50991 m .43936 .51051 L .44092 .51199 L p .892 .687 .62 r
F P
0 g
s
.4302 .50301 m .44092 .51199 L .43936 .51051 L p .891 .688 .622 r
F P
0 g
s
.43986 .50874 m .43232 .50242 L .43062 .50138 L p .899 .679 .596 r
F P
0 g
s
.50398 .52818 m .50148 .53196 L .50328 .53332 L p .612 .36 .511 r
F P
0 g
s
.50328 .53332 m .50685 .52792 L .50398 .52818 L p .612 .36 .511 r
F P
0 g
s
.44568 .54222 m .44919 .53652 L .44788 .53399 L p .742 .592 .689 r
F P
0 g
s
.47749 .56867 m .47267 .57623 L .4733 .57912 L p .608 .532 .743 r
F P
0 g
s
.4733 .57912 m .48019 .56833 L .47749 .56867 L p .608 .532 .743 r
F P
0 g
s
.48174 .58403 m .47559 .57869 L .4733 .57912 L p .582 .523 .753 r
F P
0 g
s
.4733 .57912 m .48208 .58676 L .48174 .58403 L p .582 .523 .753 r
F P
0 g
s
.48019 .56833 m .4733 .57912 L .47559 .57869 L p .577 .492 .722 r
F P
0 g
s
.44287 .54214 m .44788 .53399 L .44522 .53386 L p .788 .655 .715 r
F P
0 g
s
.43626 .52762 m .44522 .53386 L .44788 .53399 L p .788 .65 .709 r
F P
0 g
s
.44788 .53399 m .43507 .52508 L .43626 .52762 L p .788 .65 .709 r
F P
0 g
s
.44788 .53399 m .44287 .54214 L .44568 .54222 L p .742 .592 .689 r
F P
0 g
s
.43507 .52508 m .44788 .53399 L .44645 .53172 L p .805 .64 .678 r
F P
0 g
s
.54312 .51061 m .53964 .51725 L .54091 .51832 L p .451 .098 .274 r
F P
0 g
s
.43336 .49615 m .43347 .49257 L .43177 .49039 L p .914 .643 .513 r
F P
0 g
s
.40042 .4246 m .37958 .4074 L .38358 .40723 L p .416 .486 .824 r
F P
0 g
s
.38784 .39284 m .38358 .40723 L .37958 .4074 L p .416 .486 .824 r
F P
0 g
s
.37958 .4074 m .38563 .38681 L .38784 .39284 L p .416 .486 .824 r
F P
0 g
s
.37958 .4074 m .40042 .4246 L .39768 .42494 L p .292 .456 .852 r
F P
0 g
s
.38563 .38681 m .37958 .4074 L .37558 .40099 L p .479 .554 .854 r
F P
0 g
s
.47724 .54286 m .4739 .54819 L .47526 .55049 L p .678 .518 .663 r
F P
0 g
s
.47526 .55049 m .48002 .54286 L .47724 .54286 L p .678 .518 .663 r
F P
0 g
s
.43962 .50967 m .4321 .50336 L .43045 .50211 L p .897 .682 .603 r
F P
0 g
s
.44645 .53172 m .43749 .52548 L .43507 .52508 L p .805 .64 .678 r
F P
0 g
s
.44042 .51961 m .4417 .51655 L .43996 .51461 L p .813 .62 .642 r
F P
0 g
s
.41508 .45329 m .41974 .46073 L .42089 .46423 L p 0 .11 .652 r
F P
0 g
s
.48482 .5391 m .4941 .54318 L .49668 .54315 L p .606 .414 .595 r
F P
0 g
s
.60544 .63686 m .61808 .63182 L .61909 .63 L p .651 .876 .982 r
F P
0 g
s
.61909 .63 m .60102 .63721 L .60544 .63686 L p .651 .876 .982 r
F P
0 g
s
.50591 .53278 m .5084 .52899 L .50685 .52792 L p .524 .255 .45 r
F P
0 g
s
.50685 .52792 m .50328 .53332 L .50591 .53278 L p .524 .255 .45 r
F P
0 g
s
.52156 .529 m .50685 .52792 L .5084 .52899 L p .527 .254 .444 r
F P
0 g
s
.52011 .52766 m .50981 .52691 L .50685 .52792 L p .52 .22 .397 r
F P
0 g
s
.50685 .52792 m .52156 .529 L .52011 .52766 L p .52 .22 .397 r
F P
0 g
s
.52287 .62514 m .5233 .6274 L .5252 .62902 L p 0 .413 .852 r
F P
0 g
s
.5252 .62902 m .5246 .62581 L .52287 .62514 L p 0 .413 .852 r
F P
0 g
s
.53804 .63359 m .5273 .62953 L .5252 .62902 L p .02 .514 .873 r
F P
0 g
s
.5252 .62902 m .54052 .63482 L .53804 .63359 L p .02 .514 .873 r
F P
0 g
s
.5246 .62581 m .5252 .62902 L .5273 .62953 L p .097 .526 .909 r
F P
0 g
s
.55745 .50442 m .55543 .50505 L .55433 .50654 L p .364 0 .164 r
F P
0 g
s
.47238 .55063 m .46818 .55719 L .46925 .55985 L p .673 .545 .701 r
F P
0 g
s
.47773 .55045 m .48107 .54511 L .48002 .54286 L p .621 .446 .625 r
F P
0 g
s
.48002 .54286 m .47526 .55049 L .47773 .55045 L p .621 .446 .625 r
F P
0 g
s
.49226 .54973 m .48002 .54286 L .48107 .54511 L p .603 .438 .631 r
F P
0 g
s
.49101 .54778 m .48244 .54298 L .48002 .54286 L p .617 .427 .603 r
F P
0 g
s
.48002 .54286 m .49226 .54973 L .49101 .54778 L p .617 .427 .603 r
F P
0 g
s
.42579 .56011 m .41654 .55294 L .41308 .55306 L p .764 .694 .784 r
F P
0 g
s
.58587 .48744 m .58415 .49305 L .58153 .49557 L p .221 0 .125 r
F P
0 g
s
.43936 .51051 m .43186 .50423 L .4302 .50301 L p .891 .688 .622 r
F P
0 g
s
.48019 .56833 m .46925 .55985 L .46984 .56274 L p .605 .509 .719 r
F P
0 g
s
.46925 .55985 m .47526 .55049 L .47238 .55063 L p .673 .545 .701 r
F P
0 g
s
.47947 .56561 m .47182 .55967 L .46925 .55985 L p .63 .506 .693 r
F P
0 g
s
.46925 .55985 m .48019 .56833 L .47947 .56561 L p .63 .506 .693 r
F P
0 g
s
.47526 .55049 m .46925 .55985 L .47182 .55967 L p .627 .485 .669 r
F P
0 g
s
.46984 .56274 m .47749 .56867 L .48019 .56833 L p .605 .509 .719 r
F P
0 g
s
.38222 .5747 m .37232 .56601 L .36736 .56605 L p .743 .753 .861 r
F P
0 g
s
.43814 .51898 m .43996 .51461 L .43813 .51393 L p .878 .704 .662 r
F P
0 g
s
.43078 .50765 m .43813 .51393 L .43996 .51461 L p .878 .703 .661 r
F P
0 g
s
.43996 .51461 m .42946 .50564 L .43078 .50765 L p .878 .703 .661 r
F P
0 g
s
.43996 .51461 m .43814 .51898 L .44042 .51961 L p .813 .62 .642 r
F P
0 g
s
.43919 .51104 m .43852 .51288 L .43996 .51461 L p .886 .695 .64 r
F P
0 g
s
.42946 .50564 m .43996 .51461 L .43852 .51288 L p .889 .694 .633 r
F P
0 g
s
.44522 .53386 m .44171 .53956 L .44287 .54214 L p .788 .655 .715 r
F P
0 g
s
.43888 .55188 m .44383 .545 L .44287 .54214 L p .735 .616 .726 r
F P
0 g
s
.44287 .54214 m .43579 .55196 L .43888 .55188 L p .735 .616 .726 r
F P
0 g
s
.43161 .49551 m .43177 .49039 L .43078 .48974 L p .99 .73 .424 r
F P
0 g
s
.42621 .4829 m .43078 .48974 L .43177 .49039 L p .991 .736 .433 r
F P
0 g
s
.43177 .49039 m .42524 .48062 L .42621 .4829 L p .991 .736 .433 r
F P
0 g
s
.43177 .49039 m .43161 .49551 L .43336 .49615 L p .914 .643 .513 r
F P
0 g
s
.42524 .48062 m .43177 .49039 L .43066 .48789 L p .97 .661 .284 r
F P
0 g
s
.54355 .63597 m .55558 .63847 L .55772 .63841 L p .23 .663 .957 r
F P
0 g
s
.55772 .63841 m .54052 .63482 L .54355 .63597 L p .23 .663 .957 r
F P
0 g
s
.5143 .6227 m .51498 .61915 L .51332 .61724 L p .242 .52 .913 r
F P
0 g
s
.47559 .57869 m .48042 .57113 L .48019 .56833 L p .577 .492 .722 r
F P
0 g
s
.48211 .58925 m .48649 .59348 L .48834 .59281 L p .501 .495 .781 r
F P
0 g
s
.48834 .59281 m .48208 .58676 L .48211 .58925 L p .501 .495 .781 r
F P
0 g
s
.6865 .61639 m .67052 .61128 L .6651 .6121 L p .725 .799 .91 r
F P
0 g
s
.43579 .55196 m .44287 .54214 L .43991 .54219 L p .773 .671 .752 r
F P
0 g
s
.43104 .53573 m .43991 .54219 L .44287 .54214 L p .773 .665 .743 r
F P
0 g
s
.44287 .54214 m .4302 .5329 L .43104 .53573 L p .773 .665 .743 r
F P
0 g
s
.4302 .5329 m .44287 .54214 L .44171 .53956 L p .793 .657 .712 r
F P
0 g
s
.55433 .50654 m .55722 .50563 L .55745 .50442 L p .364 0 .164 r
F P
0 g
s
.42353 .5454 m .43243 .55217 L .43579 .55196 L p .757 .681 .778 r
F P
0 g
s
.43579 .55196 m .42308 .54228 L .42353 .5454 L p .757 .681 .778 r
F P
0 g
s
.43991 .54219 m .43496 .54907 L .43579 .55196 L p .773 .671 .752 r
F P
0 g
s
.42308 .54228 m .43579 .55196 L .43496 .54907 L p .78 .676 .748 r
F P
0 g
s
.47182 .55967 m .47602 .55312 L .47526 .55049 L p .627 .485 .669 r
F P
0 g
s
.48658 .55837 m .47526 .55049 L .47602 .55312 L p .601 .47 .674 r
F P
0 g
s
.48566 .55596 m .47773 .55045 L .47526 .55049 L p .623 .463 .645 r
F P
0 g
s
.47526 .55049 m .48658 .55837 L .48566 .55596 L p .623 .463 .645 r
F P
0 g
s
.54648 .50989 m .5524 .50829 L .55433 .50654 L p .425 .07 .256 r
F P
0 g
s
.55828 .50415 m .56031 .50348 L .56012 .50467 L p .356 0 .161 r
F P
0 g
s
.56012 .50467 m .55722 .50563 L .55828 .50415 L p .356 0 .161 r
F P
0 g
s
.48107 .54511 m .48963 .54992 L .49226 .54973 L p .603 .438 .631 r
F P
0 g
s
.44171 .53956 m .43285 .53309 L .4302 .5329 L p .793 .657 .712 r
F P
0 g
s
.65545 .62352 m .66604 .61508 L .6651 .6121 L p .722 .809 .919 r
F P
0 g
s
.6651 .6121 m .64996 .62419 L .65545 .62352 L p .722 .809 .919 r
F P
0 g
s
.59186 .63637 m .59711 .6375 L .60102 .63721 L p .423 .847 .955 r
F P
0 g
s
.60102 .63721 m .59354 .63558 L .59186 .63637 L p .423 .847 .955 r
F P
0 g
s
.61512 .63086 m .60246 .63592 L .60102 .63721 L p .593 .917 .973 r
F P
0 g
s
.60102 .63721 m .61909 .63 L .61512 .63086 L p .593 .917 .973 r
F P
0 g
s
.59354 .63558 m .60102 .63721 L .60246 .63592 L p .594 .921 .97 r
F P
0 g
s
.43852 .51288 m .43117 .5066 L .42946 .50564 L p .889 .694 .633 r
F P
0 g
s
.47602 .55312 m .48395 .55863 L .48658 .55837 L p .601 .47 .674 r
F P
0 g
s
.43737 .88386 m .45353 .84069 L .46558 .83315 L p .723 .721 .848 r
F P
0 g
s
.43066 .48789 m .42609 .48105 L .42524 .48062 L p .97 .661 .284 r
F P
0 g
s
.43496 .54907 m .42606 .54229 L .42308 .54228 L p .78 .676 .748 r
F P
0 g
s
.48608 .57681 m .48174 .58403 L .48208 .58676 L p .535 .488 .75 r
F P
0 g
s
.48208 .58676 m .48828 .57644 L .48608 .57681 L p .535 .488 .75 r
F P
0 g
s
.48825 .59043 m .48387 .58619 L .48208 .58676 L p .523 .499 .771 r
F P
0 g
s
.48208 .58676 m .48834 .59281 L .48825 .59043 L p .523 .499 .771 r
F P
0 g
s
.48828 .57644 m .48208 .58676 L .48387 .58619 L p .512 .458 .734 r
F P
0 g
s
.43749 .52548 m .43963 .52121 L .43814 .51898 L p .806 .635 .671 r
F P
0 g
s
.64327 .43456 m .63496 .44124 L .63198 .44528 L p .877 .994 .776 r
F P
0 g
s
.43813 .51393 m .43685 .51698 L .43814 .51898 L p .878 .704 .662 r
F P
0 g
s
.50074 .53316 m .49918 .53549 L .50106 .53665 L p .611 .378 .54 r
F P
0 g
s
.50106 .53665 m .50328 .53332 L .50074 .53316 L p .611 .378 .54 r
F P
0 g
s
.5084 .52899 m .5187 .52976 L .52156 .529 L p .527 .254 .444 r
F P
0 g
s
.25248 .59104 m .28629 .58156 L .29079 .5766 L p .681 .761 .912 r
F P
0 g
s
.29079 .5766 m .24243 .59018 L .25248 .59104 L p .681 .761 .912 r
F P
0 g
s
.55041 .51585 m .55433 .50654 L .5524 .50829 L p .416 .058 .247 r
F P
0 g
s
.55147 .5143 m .55422 .50778 L .55433 .50654 L p .406 .049 .243 r
F P
0 g
s
.55433 .50654 m .55041 .51585 L .55147 .5143 L p .406 .049 .243 r
F P
0 g
s
.55722 .50563 m .55433 .50654 L .55422 .50778 L p .407 .049 .243 r
F P
0 g
s
.62022 .45884 m .61617 .46438 L .61344 .4677 L p 0 0 0 r
F P
0 g
s
.65391 .41834 m .66832 .40898 L .67272 .40394 L p .861 .964 .867 r
F P
0 g
s
.37558 .40099 m .37977 .38655 L .38563 .38681 L p .479 .554 .854 r
F P
0 g
s
.43507 .52508 m .43814 .51898 L .43614 .51855 L p .864 .714 .694 r
F P
0 g
s
.42888 .5123 m .43614 .51855 L .43814 .51898 L p .865 .712 .692 r
F P
0 g
s
.43814 .51898 m .42777 .51004 L .42888 .5123 L p .865 .712 .692 r
F P
0 g
s
.43814 .51898 m .43507 .52508 L .43749 .52548 L p .806 .635 .671 r
F P
0 g
s
.42777 .51004 m .43814 .51898 L .43685 .51698 L p .879 .704 .661 r
F P
0 g
s
.42473 .47357 m .42247 .46727 L .42089 .46423 L p .873 .494 .015 r
F P
0 g
s
.53663 .63247 m .53804 .63359 L .54052 .63482 L p 0 .363 .737 r
F P
0 g
s
.54052 .63482 m .53853 .63322 L .53663 .63247 L p 0 .363 .737 r
F P
0 g
s
.55476 .63772 m .54271 .63521 L .54052 .63482 L p 0 .496 .755 r
F P
0 g
s
.54052 .63482 m .55772 .63841 L .55476 .63772 L p 0 .496 .755 r
F P
0 g
s
.53853 .63322 m .54052 .63482 L .54271 .63521 L p 0 .531 .828 r
F P
0 g
s
.5273 .62953 m .52689 .62728 L .5246 .62581 L p .097 .526 .909 r
F P
0 g
s
.63447 .62215 m .64514 .62509 L .64996 .62419 L p .71 .862 .954 r
F P
0 g
s
.64996 .62419 m .63472 .61997 L .63447 .62215 L p .71 .862 .954 r
F P
0 g
s
.66037 .61331 m .64977 .62178 L .64996 .62419 L p .734 .846 .933 r
F P
0 g
s
.64996 .62419 m .6651 .6121 L .66037 .61331 L p .734 .846 .933 r
F P
0 g
s
.63472 .61997 m .64996 .62419 L .64977 .62178 L p .749 .857 .929 r
F P
0 g
s
.56194 .50289 m .56784 .50067 L .56855 .50151 L p .337 0 .153 r
F P
0 g
s
.56855 .50151 m .56012 .50467 L .56194 .50289 L p .337 0 .153 r
F P
0 g
s
.48812 .59486 m .49074 .59756 L .49208 .59667 L p .456 .477 .792 r
F P
0 g
s
.49208 .59667 m .48834 .59281 L .48812 .59486 L p .456 .477 .792 r
F P
0 g
s
.53964 .51725 m .53005 .51877 L .52721 .52049 L p .446 .099 .281 r
F P
0 g
s
.76347 .5949 m .79674 .60263 L .80545 .60243 L p .677 .749 .905 r
F P
0 g
s
.80545 .60243 m .75789 .59136 L .76347 .5949 L p .677 .749 .905 r
F P
0 g
s
.8049 .59227 m .79942 .59936 L .80545 .60243 L p .672 .749 .909 r
F P
0 g
s
.80545 .60243 m .81331 .59232 L .8049 .59227 L p .672 .749 .909 r
F P
0 g
s
.75789 .59136 m .80545 .60243 L .79942 .59936 L p .678 .749 .905 r
F P
0 g
s
.40361 .56489 m .41312 .55646 L .41308 .55306 L p .747 .703 .81 r
F P
0 g
s
.41308 .55306 m .3995 .56511 L .40361 .56489 L p .747 .703 .81 r
F P
0 g
s
.43281 .50002 m .43319 .49744 L .43161 .49551 L p .904 .669 .571 r
F P
0 g
s
.60175 .47624 m .61206 .46824 L .61344 .4677 L p 0 0 0 r
F P
0 g
s
.61344 .4677 m .5987 .47914 L .60175 .47624 L p 0 0 0 r
F P
0 g
s
.52407 .52171 m .52011 .52766 L .52156 .529 L p .525 .219 .391 r
F P
0 g
s
.52156 .529 m .52721 .52049 L .52407 .52171 L p .525 .219 .391 r
F P
0 g
s
.43078 .48974 m .43067 .49332 L .43161 .49551 L p .99 .73 .424 r
F P
0 g
s
.5033 .5366 m .50486 .53427 L .50328 .53332 L p .518 .267 .473 r
F P
0 g
s
.50328 .53332 m .50106 .53665 L .5033 .5366 L p .518 .267 .473 r
F P
0 g
s
.5166 .53586 m .50328 .53332 L .50486 .53427 L p .519 .266 .471 r
F P
0 g
s
.51523 .53455 m .50591 .53278 L .50328 .53332 L p .519 .245 .439 r
F P
0 g
s
.50328 .53332 m .5166 .53586 L .51523 .53455 L p .519 .245 .439 r
F P
0 g
s
.34751 .57925 m .36575 .57004 L .36736 .56605 L p .718 .752 .879 r
F P
0 g
s
.36736 .56605 m .34127 .57922 L .34751 .57925 L p .718 .752 .879 r
F P
0 g
s
.52445 .52746 m .52841 .52151 L .52721 .52049 L p .457 .143 .344 r
F P
0 g
s
.52721 .52049 m .52156 .529 L .52445 .52746 L p .457 .143 .344 r
F P
0 g
s
.54091 .51832 m .52721 .52049 L .52841 .52151 L p .465 .141 .33 r
F P
0 g
s
.52721 .52049 m .54091 .51832 L .53964 .51725 L p .446 .099 .281 r
F P
0 g
s
.55377 .51481 m .55722 .50563 L .55718 .50685 L p .401 .044 .24 r
F P
0 g
s
.5592 .50617 m .55718 .50685 L .55722 .50563 L p .401 .044 .24 r
F P
0 g
s
.55722 .50563 m .56012 .50467 L .5592 .50617 L p .401 .044 .24 r
F P
0 g
s
.55377 .51481 m .55722 .50563 L .55624 .50715 L p .406 .049 .242 r
F P
0 g
s
.55422 .50778 m .55624 .50715 L .55722 .50563 L p .407 .049 .243 r
F P
0 g
s
.48387 .58619 m .48821 .57897 L .48828 .57644 L p .512 .458 .734 r
F P
0 g
s
.43685 .51698 m .4296 .51073 L .42777 .51004 L p .879 .704 .661 r
F P
0 g
s
.4988 .53609 m .49827 .53687 L .50031 .53776 L p .61 .387 .553 r
F P
0 g
s
.50031 .53776 m .50106 .53665 L .4988 .53609 L p .61 .387 .553 r
F P
0 g
s
.5524 .50829 m .54965 .5148 L .55041 .51585 L p .416 .058 .247 r
F P
0 g
s
.65212 .41731 m .67272 .40394 L .66971 .40275 L p .882 .896 .836 r
F P
0 g
s
.66978 .38637 m .66971 .40275 L .67272 .40394 L p .882 .896 .837 r
F P
0 g
s
.67272 .40394 m .67287 .38054 L .66978 .38637 L p .882 .896 .837 r
F P
0 g
s
.67272 .40394 m .65212 .41731 L .65391 .41834 L p .861 .964 .867 r
F P
0 g
s
.67287 .38054 m .67272 .40394 L .6776 .39775 L p .835 .864 .866 r
F P
0 g
s
.38614 .55759 m .39482 .56535 L .3995 .56511 L p .742 .749 .858 r
F P
0 g
s
.3995 .56511 m .38711 .55401 L .38614 .55759 L p .742 .749 .858 r
F P
0 g
s
.40928 .55328 m .39977 .56172 L .3995 .56511 L p .768 .748 .835 r
F P
0 g
s
.3995 .56511 m .41308 .55306 L .40928 .55328 L p .768 .748 .835 r
F P
0 g
s
.38711 .55401 m .3995 .56511 L .39977 .56172 L p .771 .751 .834 r
F P
0 g
s
.49147 .59828 m .49194 .59924 L .49276 .59804 L p .326 .342 .724 r
F P
0 g
s
.49276 .59804 m .49208 .59667 L .49147 .59828 L p .326 .342 .724 r
F P
0 g
s
.42089 .46423 m .42411 .47323 L .42473 .47357 L p .873 .494 .015 r
F P
0 g
s
.42411 .47323 m .42089 .46423 L .42125 .46396 L p 0 0 .44 r
F P
0 g
s
.42067 .45577 m .42125 .46396 L .42089 .46423 L p 0 0 .433 r
F P
0 g
s
.42089 .46423 m .42005 .45253 L .42067 .45577 L p 0 0 .433 r
F P
0 g
s
.42005 .45253 m .42089 .46423 L .41974 .46073 L p 0 .104 .648 r
F P
0 g
s
.59672 .48656 m .5987 .47914 L .60059 .47851 L p .1 0 .104 r
F P
0 g
s
.61092 .4705 m .60059 .47851 L .5987 .47914 L p .103 0 .11 r
F P
0 g
s
.5987 .47914 m .61344 .4677 L .61092 .4705 L p .103 0 .11 r
F P
0 g
s
.59477 .48675 m .59616 .48155 L .5987 .47914 L p .239 0 .149 r
F P
0 g
s
.5987 .47914 m .59672 .48656 L .59477 .48675 L p .239 0 .149 r
F P
0 g
s
.43106 .49919 m .43161 .49551 L .43058 .4947 L p .987 .771 .525 r
F P
0 g
s
.4261 .4882 m .43058 .4947 L .43161 .49551 L p .987 .771 .526 r
F P
0 g
s
.43161 .49551 m .42521 .48622 L .4261 .4882 L p .987 .771 .526 r
F P
0 g
s
.43161 .49551 m .43106 .49919 L .43281 .50002 L p .904 .669 .571 r
F P
0 g
s
.42521 .48622 m .43161 .49551 L .43067 .49332 L p .99 .734 .437 r
F P
0 g
s
.49806 .53721 m .49742 .53815 L .4994 .53911 L p .61 .392 .561 r
F P
0 g
s
.4994 .53911 m .50031 .53776 L .49806 .53721 L p .61 .392 .561 r
F P
0 g
s
.48395 .55863 m .47947 .56561 L .48019 .56833 L p .604 .49 .697 r
F P
0 g
s
.49191 .58384 m .48825 .59043 L .48834 .59281 L p .456 .444 .756 r
F P
0 g
s
.48834 .59281 m .49356 .5834 L .49191 .58384 L p .456 .444 .756 r
F P
0 g
s
.49225 .59475 m .48962 .59204 L .48834 .59281 L p .468 .48 .788 r
F P
0 g
s
.48834 .59281 m .49208 .59667 L .49225 .59475 L p .468 .48 .788 r
F P
0 g
s
.49356 .5834 m .48834 .59281 L .48962 .59204 L p .445 .43 .748 r
F P
0 g
s
.56115 .63889 m .57379 .63917 L .57579 .63881 L p .281 .743 .95 r
F P
0 g
s
.57579 .63881 m .55772 .63841 L .56115 .63889 L p .281 .743 .95 r
F P
0 g
s
.43614 .51855 m .43399 .52283 L .43507 .52508 L p .864 .714 .694 r
F P
0 g
s
.43285 .53309 m .43626 .52762 L .43507 .52508 L p .794 .652 .706 r
F P
0 g
s
.28148 .57573 m .24757 .58527 L .24243 .59018 L p .68 .769 .919 r
F P
0 g
s
.24243 .59018 m .29079 .5766 L .28148 .57573 L p .68 .769 .919 r
F P
0 g
s
.22691 .56868 m .24243 .59018 L .24757 .58527 L p .678 .766 .918 r
F P
0 g
s
.48042 .57113 m .48608 .57681 L .48828 .57644 L p .53 .456 .717 r
F P
0 g
s
.48828 .57644 m .48019 .56833 L .48042 .57113 L p .53 .456 .717 r
F P
0 g
s
.38358 .40723 m .39819 .41929 L .40042 .4246 L p .416 .486 .824 r
F P
0 g
s
.48019 .56833 m .48658 .55837 L .48395 .55863 L p .604 .49 .697 r
F P
0 g
s
.48802 .57372 m .48235 .56804 L .48019 .56833 L p .561 .46 .697 r
F P
0 g
s
.48019 .56833 m .48828 .57644 L .48802 .57372 L p .561 .46 .697 r
F P
0 g
s
.48658 .55837 m .48019 .56833 L .48235 .56804 L p .556 .428 .662 r
F P
0 g
s
.55715 .51368 m .56012 .50467 L .56104 .5055 L p .392 .036 .237 r
F P
0 g
s
.56695 .50328 m .56104 .5055 L .56012 .50467 L p .389 .036 .241 r
F P
0 g
s
.56012 .50467 m .56855 .50151 L .56695 .50328 L p .389 .036 .241 r
F P
0 g
s
.55713 .51248 m .5592 .50617 L .56012 .50467 L p .401 .045 .241 r
F P
0 g
s
.56012 .50467 m .55715 .51368 L .55713 .51248 L p .401 .045 .241 r
F P
0 g
s
.49695 .53889 m .49504 .54172 L .49668 .54315 L p .609 .403 .577 r
F P
0 g
s
.49668 .54315 m .4994 .53911 L .49695 .53889 L p .609 .403 .577 r
F P
0 g
s
.32447 .56887 m .33394 .57906 L .34127 .57922 L p .698 .769 .907 r
F P
0 g
s
.34127 .57922 m .32778 .56465 L .32447 .56887 L p .698 .769 .907 r
F P
0 g
s
.3616 .56602 m .34332 .57526 L .34127 .57922 L p .723 .777 .896 r
F P
0 g
s
.34127 .57922 m .36736 .56605 L .3616 .56602 L p .723 .777 .896 r
F P
0 g
s
.32778 .56465 m .34127 .57922 L .34332 .57526 L p .721 .775 .895 r
F P
0 g
s
.49345 .59919 m .49401 .59997 L .49482 .59877 L p .308 .334 .725 r
F P
0 g
s
.49482 .59877 m .49401 .59765 L .49345 .59919 L p .308 .334 .725 r
F P
0 g
s
.50223 .53815 m .50275 .53737 L .50106 .53665 L p .516 .273 .485 r
F P
0 g
s
.50106 .53665 m .50031 .53776 L .50223 .53815 L p .516 .273 .485 r
F P
0 g
s
.51332 .54019 m .50106 .53665 L .50275 .53737 L p .516 .273 .486 r
F P
0 g
s
.51189 .53908 m .5033 .5366 L .50106 .53665 L p .518 .264 .47 r
F P
0 g
s
.50106 .53665 m .51332 .54019 L .51189 .53908 L p .518 .264 .47 r
F P
0 g
s
.4302 .5329 m .43507 .52508 L .43281 .5249 L p .844 .726 .733 r
F P
0 g
s
.42565 .51861 m .43281 .5249 L .43507 .52508 L p .844 .724 .73 r
F P
0 g
s
.43507 .52508 m .42484 .5161 L .42565 .51861 L p .844 .724 .73 r
F P
0 g
s
.43507 .52508 m .4302 .5329 L .43285 .53309 L p .794 .652 .706 r
F P
0 g
s
.42484 .5161 m .43507 .52508 L .43399 .52283 L p .866 .715 .692 r
F P
0 g
s
.60246 .63592 m .59723 .63477 L .59354 .63558 L p .594 .921 .97 r
F P
0 g
s
.43232 .50242 m .43263 .50088 L .43106 .49919 L p .9 .677 .592 r
F P
0 g
s
.54271 .63521 m .54133 .6341 L .53853 .63322 L p 0 .531 .828 r
F P
0 g
s
.50128 .53952 m .50192 .53857 L .50031 .53776 L p .515 .277 .492 r
F P
0 g
s
.50031 .53776 m .4994 .53911 L .50128 .53952 L p .515 .277 .492 r
F P
0 g
s
.51221 .54165 m .50031 .53776 L .50192 .53857 L p .514 .278 .495 r
F P
0 g
s
.51055 .54087 m .50223 .53815 L .50031 .53776 L p .516 .274 .486 r
F P
0 g
s
.50031 .53776 m .51221 .54165 L .51055 .54087 L p .516 .274 .486 r
F P
0 g
s
.50486 .53427 m .51418 .53605 L .5166 .53586 L p .519 .266 .471 r
F P
0 g
s
.55624 .50715 m .55382 .51358 L .55377 .51481 L p .406 .049 .242 r
F P
0 g
s
.41974 .46073 m .41915 .45253 L .42005 .45253 L p 0 .104 .648 r
F P
0 g
s
.75676 .60298 m .76347 .5949 L .75789 .59136 L p .684 .749 .901 r
F P
0 g
s
.75789 .59136 m .74833 .60293 L .75676 .60298 L p .684 .749 .901 r
F P
0 g
s
.43067 .49332 m .42619 .48682 L .42521 .48622 L p .99 .734 .437 r
F P
0 g
s
.49476 .60065 m .49737 .60341 L .49853 .60271 L p .389 .457 .81 r
F P
0 g
s
.49853 .60271 m .49482 .59877 L .49476 .60065 L p .389 .457 .81 r
F P
0 g
s
.49536 .58873 m .49225 .59475 L .49208 .59667 L p .393 .412 .761 r
F P
0 g
s
.49208 .59667 m .49653 .58808 L .49536 .58873 L p .393 .412 .761 r
F P
0 g
s
.4933 .59657 m .49283 .59562 L .49208 .59667 L p .33 .344 .724 r
F P
0 g
s
.49208 .59667 m .49276 .59804 L .4933 .59657 L p .33 .344 .724 r
F P
0 g
s
.49653 .58808 m .49208 .59667 L .49283 .59562 L p .265 .258 .664 r
F P
0 g
s
.49871 .54328 m .50061 .54044 L .4994 .53911 L p .516 .289 .509 r
F P
0 g
s
.4994 .53911 m .49668 .54315 L .49871 .54328 L p .516 .289 .509 r
F P
0 g
s
.51086 .54342 m .4994 .53911 L .50061 .54044 L p .51 .289 .514 r
F P
0 g
s
.5093 .54253 m .50128 .53952 L .4994 .53911 L p .515 .279 .495 r
F P
0 g
s
.4994 .53911 m .51086 .54342 L .5093 .54253 L p .515 .279 .495 r
F P
0 g
s
.55718 .50685 m .55476 .51327 L .55377 .51481 L p .401 .044 .24 r
F P
0 g
s
.4941 .54318 m .49101 .54778 L .49226 .54973 L p .608 .424 .608 r
F P
0 g
s
.49226 .54973 m .49668 .54315 L .4941 .54318 L p .608 .424 .608 r
F P
0 g
s
.48235 .56804 m .48682 .56107 L .48658 .55837 L p .556 .428 .662 r
F P
0 g
s
.43399 .52283 m .42683 .51654 L .42484 .5161 L p .866 .715 .692 r
F P
0 g
s
.48962 .59204 m .49328 .58545 L .49356 .5834 L p .445 .43 .748 r
F P
0 g
s
.43106 .49919 m .43062 .50138 L .43232 .50242 L p .9 .677 .592 r
F P
0 g
s
.41654 .55294 m .42353 .5454 L .42308 .54228 L p .765 .687 .776 r
F P
0 g
s
.42308 .54228 m .41308 .55306 L .41654 .55294 L p .765 .687 .776 r
F P
0 g
s
.52841 .52151 m .538 .51999 L .54091 .51832 L p .465 .141 .33 r
F P
0 g
s
.55251 .63748 m .55476 .63772 L .55772 .63841 L p .242 0 0 r
F P
0 g
s
.55772 .63841 m .55453 .63806 L .55251 .63748 L p .242 0 0 r
F P
0 g
s
.57252 .63876 m .55986 .63848 L .55772 .63841 L p .041 0 0 r
F P
0 g
s
.55772 .63841 m .57579 .63881 L .57252 .63876 L p .041 0 0 r
F P
0 g
s
.55453 .63806 m .55772 .63841 L .55986 .63848 L p 0 .571 .736 r
F P
0 g
s
.42606 .54229 m .43104 .53573 L .4302 .5329 L p .781 .669 .74 r
F P
0 g
s
.6776 .39775 m .67775 .38136 L .67287 .38054 L p .835 .864 .866 r
F P
0 g
s
.39977 .56172 m .3911 .55394 L .38711 .55401 L p .771 .751 .834 r
F P
0 g
s
.49621 .59079 m .4933 .59657 L .49276 .59804 L p .235 .24 .66 r
F P
0 g
s
.49276 .59804 m .49692 .58977 L .49621 .59079 L p .235 .24 .66 r
F P
0 g
s
.57094 .49937 m .58002 .49521 L .58153 .49557 L p .302 0 .146 r
F P
0 g
s
.58153 .49557 m .56855 .50151 L .57094 .49937 L p .302 0 .146 r
F P
0 g
s
.41136 .43974 m .40256 .42921 L .40042 .4246 L p .126 .313 .781 r
F P
0 g
s
.4321 .50336 m .43222 .50285 L .43062 .50138 L p .896 .683 .606 r
F P
0 g
s
.71682 .59719 m .74128 .60353 L .74833 .60293 L p .693 .757 .901 r
F P
0 g
s
.74833 .60293 m .71338 .59386 L .71682 .59719 L p .693 .757 .901 r
F P
0 g
s
.75109 .59181 m .74442 .59993 L .74833 .60293 L p .687 .754 .903 r
F P
0 g
s
.74833 .60293 m .75789 .59136 L .75109 .59181 L p .687 .754 .903 r
F P
0 g
s
.71338 .59386 m .74833 .60293 L .74442 .59993 L p .696 .756 .897 r
F P
0 g
s
.48963 .54992 m .48566 .55596 L .48658 .55837 L p .605 .454 .65 r
F P
0 g
s
.43062 .50138 m .43106 .49919 L .43006 .49819 L p .982 .782 .559 r
F P
0 g
s
.42565 .49188 m .43006 .49819 L .43106 .49919 L p .982 .785 .565 r
F P
0 g
s
.43106 .49919 m .42477 .49019 L .42565 .49188 L p .982 .785 .565 r
F P
0 g
s
.43058 .4947 m .43019 .49727 L .43106 .49919 L p .987 .771 .525 r
F P
0 g
s
.42477 .49019 m .43106 .49919 L .43019 .49727 L p .987 .771 .526 r
F P
0 g
s
.43062 .50138 m .43045 .50211 L .4321 .50336 L p .896 .683 .606 r
F P
0 g
s
.64977 .62178 m .63911 .61881 L .63472 .61997 L p .749 .857 .929 r
F P
0 g
s
.4953 .59739 m .49473 .59661 L .49401 .59765 L p .305 .333 .726 r
F P
0 g
s
.49401 .59765 m .49482 .59877 L .4953 .59739 L p .305 .333 .726 r
F P
0 g
s
.49818 .58938 m .49401 .59765 L .49473 .59661 L p .236 .24 .66 r
F P
0 g
s
.43281 .5249 m .4294 .53037 L .4302 .5329 L p .844 .726 .733 r
F P
0 g
s
.43186 .50423 m .43203 .5036 L .43045 .50211 L p .89 .689 .623 r
F P
0 g
s
.48658 .55837 m .49226 .54973 L .48963 .54992 L p .605 .454 .65 r
F P
0 g
s
.4302 .5329 m .42308 .54228 L .42606 .54229 L p .781 .669 .74 r
F P
0 g
s
.50275 .53737 m .51133 .53985 L .51332 .54019 L p .516 .273 .486 r
F P
0 g
s
.42308 .54228 m .4302 .5329 L .42758 .53291 L p .822 .735 .769 r
F P
0 g
s
.42039 .52651 m .42758 .53291 L .4302 .5329 L p .822 .733 .766 r
F P
0 g
s
.4302 .5329 m .41993 .52375 L .42039 .52651 L p .822 .733 .766 r
F P
0 g
s
.41993 .52375 m .4302 .5329 L .4294 .53037 L p .846 .727 .731 r
F P
0 g
s
.49899 .60481 m .50328 .60927 L .50467 .6091 L p .328 .445 .828 r
F P
0 g
s
.50467 .6091 m .49853 .60271 L .49899 .60481 L p .328 .445 .828 r
F P
0 g
s
.79942 .59936 m .76611 .5916 L .75789 .59136 L p .678 .749 .905 r
F P
0 g
s
.49434 .54968 m .49744 .54507 L .49668 .54315 L p .522 .319 .545 r
F P
0 g
s
.49668 .54315 m .49226 .54973 L .49434 .54968 L p .522 .319 .545 r
F P
0 g
s
.50691 .54865 m .49668 .54315 L .49744 .54507 L p .503 .309 .55 r
F P
0 g
s
.50587 .54713 m .49871 .54328 L .49668 .54315 L p .517 .297 .519 r
F P
0 g
s
.49668 .54315 m .50691 .54865 L .50587 .54713 L p .517 .297 .519 r
F P
0 g
s
.43045 .50211 m .4302 .50301 L .43186 .50423 L p .89 .689 .623 r
F P
0 g
s
.40139 .54617 m .40928 .55328 L .41308 .55306 L p .769 .745 .831 r
F P
0 g
s
.41308 .55306 m .40182 .5429 L .40139 .54617 L p .769 .745 .831 r
F P
0 g
s
.41995 .54242 m .41295 .54997 L .41308 .55306 L p .796 .743 .803 r
F P
0 g
s
.41308 .55306 m .42308 .54228 L .41995 .54242 L p .796 .743 .803 r
F P
0 g
s
.40182 .5429 m .41308 .55306 L .41295 .54997 L p .799 .745 .803 r
F P
0 g
s
.7671 .33582 m .82151 .31354 L .83345 .30168 L p .761 .809 .891 r
F P
0 g
s
.50192 .53857 m .51025 .5413 L .51221 .54165 L p .514 .278 .495 r
F P
0 g
s
.56104 .5055 m .55897 .5118 L .55715 .51368 L p .392 .036 .237 r
F P
0 g
s
.49457 .56637 m .48658 .55837 L .48682 .56107 L p .507 .392 .657 r
F P
0 g
s
.49428 .5638 m .48868 .5582 L .48658 .55837 L p .541 .395 .632 r
F P
0 g
s
.48658 .55837 m .49457 .56637 L .49428 .5638 L p .541 .395 .632 r
F P
0 g
s
.49226 .54973 m .48658 .55837 L .48868 .5582 L p .536 .367 .6 r
F P
0 g
s
.43117 .5066 m .43169 .50475 L .4302 .50301 L p .891 .69 .625 r
F P
0 g
s
.60059 .47851 m .59922 .48371 L .59672 .48656 L p .1 0 .104 r
F P
0 g
s
.49283 .59562 m .49594 .5896 L .49653 .58808 L p .265 .258 .664 r
F P
0 g
s
.498 .59183 m .4953 .59739 L .49482 .59877 L p .208 .226 .66 r
F P
0 g
s
.49482 .59877 m .49868 .59083 L .498 .59183 L p .208 .226 .66 r
F P
0 g
s
.49849 .60102 m .49588 .59825 L .49482 .59877 L p .37 .451 .814 r
F P
0 g
s
.49482 .59877 m .49853 .60271 L .49849 .60102 L p .37 .451 .814 r
F P
0 g
s
.49868 .59083 m .49482 .59877 L .49588 .59825 L p .348 .395 .768 r
F P
0 g
s
.42125 .46396 m .42351 .47026 L .42411 .47323 L p 0 0 .44 r
F P
0 g
s
.43045 .50211 m .43062 .50138 L .42966 .50017 L p .978 .79 .582 r
F P
0 g
s
.42526 .49398 m .42966 .50017 L .43062 .50138 L p .979 .788 .577 r
F P
0 g
s
.43062 .50138 m .42434 .49253 L .42526 .49398 L p .979 .788 .577 r
F P
0 g
s
.43006 .49819 m .42975 .49972 L .43062 .50138 L p .982 .782 .559 r
F P
0 g
s
.42434 .49253 m .43062 .50138 L .42975 .49972 L p .981 .784 .566 r
F P
0 g
s
.50061 .54044 m .50863 .54346 L .51086 .54342 L p .51 .289 .514 r
F P
0 g
s
.48868 .5582 m .49266 .55214 L .49226 .54973 L p .536 .367 .6 r
F P
0 g
s
.50104 .55674 m .49226 .54973 L .49266 .55214 L p .498 .341 .599 r
F P
0 g
s
.50049 .55459 m .49434 .54968 L .49226 .54973 L p .525 .337 .568 r
F P
0 g
s
.49226 .54973 m .50104 .55674 L .50049 .55459 L p .525 .337 .568 r
F P
0 g
s
.41256 .53575 m .41995 .54242 L .42308 .54228 L p .796 .74 .801 r
F P
0 g
s
.42308 .54228 m .41253 .53274 L .41256 .53575 L p .796 .74 .801 r
F P
0 g
s
.42758 .53291 m .42259 .53948 L .42308 .54228 L p .822 .735 .769 r
F P
0 g
s
.41253 .53274 m .42308 .54228 L .42259 .53948 L p .825 .737 .768 r
F P
0 g
s
.56702 .50992 m .56855 .50151 L .57038 .5018 L p .372 .025 .242 r
F P
0 g
s
.57947 .49764 m .57038 .5018 L .56855 .50151 L p .372 .033 .255 r
F P
0 g
s
.56855 .50151 m .58153 .49557 L .57947 .49764 L p .372 .033 .255 r
F P
0 g
s
.56588 .50917 m .56695 .50328 L .56855 .50151 L p .398 .047 .249 r
F P
0 g
s
.56855 .50151 m .56702 .50992 L .56588 .50917 L p .398 .047 .249 r
F P
0 g
s
.48682 .56107 m .49241 .56667 L .49457 .56637 L p .507 .392 .657 r
F P
0 g
s
.43019 .49727 m .42579 .49097 L .42477 .49019 L p .987 .771 .526 r
F P
0 g
s
.4294 .53037 m .42221 .52396 L .41993 .52375 L p .846 .727 .731 r
F P
0 g
s
.4302 .50301 m .43045 .50211 L .42949 .50093 L p .972 .798 .608 r
F P
0 g
s
.42511 .49477 m .42949 .50093 L .43045 .50211 L p .973 .797 .606 r
F P
0 g
s
.43045 .50211 m .4242 .49331 L .42511 .49477 L p .973 .797 .606 r
F P
0 g
s
.42966 .50017 m .42954 .50068 L .43045 .50211 L p .978 .79 .582 r
F P
0 g
s
.4242 .49331 m .43045 .50211 L .42954 .50068 L p .979 .788 .577 r
F P
0 g
s
.41301 .43966 m .40042 .4246 L .40318 .42469 L p .338 .399 .778 r
F P
0 g
s
.40739 .41337 m .40318 .42469 L .40042 .4246 L p .338 .399 .777 r
F P
0 g
s
.40042 .4246 m .40641 .40842 L .40739 .41337 L p .338 .399 .777 r
F P
0 g
s
.40042 .4246 m .41301 .43966 L .41136 .43974 L p .126 .313 .781 r
F P
0 g
s
.40641 .40842 m .40042 .4246 L .39819 .41929 L p .416 .486 .824 r
F P
0 g
s
.4302 .50301 m .42946 .50564 L .43117 .5066 L p .891 .69 .625 r
F P
0 g
s
.49473 .59661 m .49765 .59082 L .49818 .58938 L p .236 .24 .66 r
F P
0 g
s
.42609 .48105 m .4253 .47588 L .42411 .47323 L p .97 .661 .284 r
F P
0 g
s
.42946 .50564 m .4302 .50301 L .42916 .5021 L p .971 .798 .612 r
F P
0 g
s
.4248 .49597 m .42916 .5021 L .4302 .50301 L p .969 .802 .623 r
F P
0 g
s
.4302 .50301 m .42398 .49424 L .4248 .49597 L p .969 .802 .623 r
F P
0 g
s
.42949 .50093 m .42931 .50156 L .4302 .50301 L p .972 .798 .608 r
F P
0 g
s
.42398 .49424 m .4302 .50301 L .42931 .50156 L p .973 .797 .605 r
F P
0 g
s
.62353 .62916 m .63447 .62215 L .63472 .61997 L p .721 .871 .952 r
F P
0 g
s
.63472 .61997 m .61909 .63 L .62353 .62916 L p .721 .871 .952 r
F P
0 g
s
.50056 .59622 m .49849 .60102 L .49853 .60271 L p .263 .358 .773 r
F P
0 g
s
.49853 .60271 m .5015 .59586 L .50056 .59622 L p .263 .358 .773 r
F P
0 g
s
.50409 .60726 m .49979 .60278 L .49853 .60271 L p .267 .422 .832 r
F P
0 g
s
.49853 .60271 m .50467 .6091 L .50409 .60726 L p .267 .422 .832 r
F P
0 g
s
.5015 .59586 m .49853 .60271 L .49979 .60278 L p .28 .378 .785 r
F P
0 g
s
.83345 .30168 m .75543 .33362 L .7671 .33582 L p .761 .809 .891 r
F P
0 g
s
.34332 .57526 m .3339 .56504 L .32778 .56465 L p .721 .775 .895 r
F P
0 g
s
.50571 .61122 m .51176 .61692 L .51332 .61724 L p .225 .431 .853 r
F P
0 g
s
.51332 .61724 m .50467 .6091 L .50571 .61122 L p .225 .431 .853 r
F P
0 g
s
.70914 .60588 m .71682 .59719 L .71338 .59386 L p .704 .759 .895 r
F P
0 g
s
.71338 .59386 m .70241 .60629 L .70914 .60588 L p .704 .759 .895 r
F P
0 g
s
.49744 .54507 m .5046 .54893 L .50691 .54865 L p .503 .309 .55 r
F P
0 g
s
.41295 .54997 m .40507 .54286 L .40182 .5429 L p .799 .745 .803 r
F P
0 g
s
.55986 .63848 m .55764 .63824 L .55453 .63806 L p 0 .571 .736 r
F P
0 g
s
.4296 .51073 m .43078 .50765 L .42946 .50564 L p .879 .703 .66 r
F P
0 g
s
.48821 .57897 m .49191 .58384 L .49356 .5834 L p .446 .402 .716 r
F P
0 g
s
.49356 .5834 m .48828 .57644 L .48821 .57897 L p .446 .402 .716 r
F P
0 g
s
.49266 .55214 m .4988 .55706 L .50104 .55674 L p .498 .341 .599 r
F P
0 g
s
.42259 .53948 m .41521 .5328 L .41253 .53274 L p .825 .737 .768 r
F P
0 g
s
.49588 .59825 m .49859 .5927 L .49868 .59083 L p .348 .395 .768 r
F P
0 g
s
.66971 .40275 m .65526 .41211 L .65212 .41731 L p .882 .896 .836 r
F P
0 g
s
.42975 .49972 m .42535 .49352 L .42434 .49253 L p .981 .784 .566 r
F P
0 g
s
.57945 .63862 m .59186 .63637 L .59354 .63558 L p .425 .844 .961 r
F P
0 g
s
.59354 .63558 m .57579 .63881 L .57945 .63862 L p .425 .844 .961 r
F P
0 g
s
.67891 .60248 m .69664 .60721 L .70241 .60629 L p .716 .78 .902 r
F P
0 g
s
.70241 .60629 m .67709 .59952 L .67891 .60248 L p .716 .78 .902 r
F P
0 g
s
.70779 .59476 m .70012 .60347 L .70241 .60629 L p .711 .772 .9 r
F P
0 g
s
.70241 .60629 m .71338 .59386 L .70779 .59476 L p .711 .772 .9 r
F P
0 g
s
.67709 .59952 m .70241 .60629 L .70012 .60347 L p .725 .776 .893 r
F P
0 g
s
.49241 .56667 m .48802 .57372 L .48828 .57644 L p .513 .424 .692 r
F P
0 g
s
.6407 .82635 m .67666 .88472 L .66096 .87786 L p .658 .665 .846 r
F P
0 g
s
.65532 .83203 m .68043 .87301 L .67666 .88472 L p .629 .653 .855 r
F P
0 g
s
.67666 .88472 m .6407 .82635 L .65532 .83203 L p .629 .653 .855 r
F P
0 g
s
.74768 .86092 m .67666 .88472 L .68043 .87301 L p .63 .653 .855 r
F P
0 g
s
.48828 .57644 m .49457 .56637 L .49241 .56667 L p .513 .424 .692 r
F P
0 g
s
.49364 .5809 m .48994 .57603 L .48828 .57644 L p .479 .413 .705 r
F P
0 g
s
.48828 .57644 m .49356 .5834 L .49364 .5809 L p .479 .413 .705 r
F P
0 g
s
.49457 .56637 m .48828 .57644 L .48994 .57603 L p .467 .366 .657 r
F P
0 g
s
.60853 .62997 m .61512 .63086 L .61909 .63 L p .607 .918 .976 r
F P
0 g
s
.61909 .63 m .6097 .62872 L .60853 .62997 L p .607 .918 .976 r
F P
0 g
s
.63082 .62129 m .61988 .62832 L .61909 .63 L p .715 .929 .961 r
F P
0 g
s
.61909 .63 m .63472 .61997 L .63082 .62129 L p .715 .929 .961 r
F P
0 g
s
.6097 .62872 m .61909 .63 L .61988 .62832 L p .725 .94 .955 r
F P
0 g
s
.42411 .47323 m .42524 .48062 L .42609 .48105 L p .97 .661 .284 r
F P
0 g
s
.42524 .48062 m .42411 .47323 L .42417 .47292 L p 0 0 .165 r
F P
0 g
s
.42364 .46592 m .42417 .47292 L .42411 .47323 L p 0 0 .156 r
F P
0 g
s
.42411 .47323 m .42336 .46322 L .42364 .46592 L p 0 0 .156 r
F P
0 g
s
.42336 .46322 m .42411 .47323 L .42351 .47026 L p 0 0 .42 r
F P
0 g
s
.42954 .50068 m .42517 .49452 L .4242 .49331 L p .979 .788 .577 r
F P
0 g
s
.42777 .51004 m .42946 .50564 L .42826 .50503 L p .953 .81 .663 r
F P
0 g
s
.42385 .499 m .42826 .50503 L .42946 .50564 L p .953 .811 .665 r
F P
0 g
s
.42946 .50564 m .42315 .49703 L .42385 .499 L p .953 .811 .665 r
F P
0 g
s
.42946 .50564 m .42777 .51004 L .4296 .51073 L p .879 .703 .66 r
F P
0 g
s
.42916 .5021 m .42864 .50395 L .42946 .50564 L p .971 .798 .612 r
F P
0 g
s
.42315 .49703 m .42946 .50564 L .42864 .50395 L p .967 .8 .623 r
F P
0 g
s
.5187 .52976 m .51523 .53455 L .5166 .53586 L p .523 .245 .435 r
F P
0 g
s
.5166 .53586 m .52156 .529 L .5187 .52976 L p .523 .245 .435 r
F P
0 g
s
.24757 .58527 m .23677 .57019 L .22691 .56868 L p .678 .766 .918 r
F P
0 g
s
.54965 .5148 m .54301 .51654 L .54091 .51832 L p .413 .058 .25 r
F P
0 g
s
.74442 .59993 m .71994 .59356 L .71338 .59386 L p .696 .756 .897 r
F P
0 g
s
.42931 .50156 m .42495 .49542 L .42398 .49424 L p .973 .797 .605 r
F P
0 g
s
.39819 .41929 m .40236 .40794 L .40641 .40842 L p .416 .486 .824 r
F P
0 g
s
.50517 .60374 m .50409 .60726 L .50467 .6091 L p .087 .287 .769 r
F P
0 g
s
.50467 .6091 m .50622 .60408 L .50517 .60374 L p .087 .287 .769 r
F P
0 g
s
.51214 .61544 m .50608 .60973 L .50467 .6091 L p .065 .361 .832 r
F P
0 g
s
.50467 .6091 m .51332 .61724 L .51214 .61544 L p .065 .361 .832 r
F P
0 g
s
.50622 .60408 m .50467 .6091 L .50608 .60973 L p .141 .35 .809 r
F P
0 g
s
.57038 .5018 m .56932 .50768 L .56702 .50992 L p .372 .025 .242 r
F P
0 g
s
.51498 .61915 m .52287 .62514 L .5246 .62581 L p .071 .415 .864 r
F P
0 g
s
.5246 .62581 m .51332 .61724 L .51498 .61915 L p .071 .415 .864 r
F P
0 g
s
.49979 .60278 m .50187 .59799 L .5015 .59586 L p .28 .378 .785 r
F P
0 g
s
.56952 .63913 m .57252 .63876 L .57579 .63881 L p .14 0 0 r
F P
0 g
s
.57579 .63881 m .57151 .63933 L .56952 .63913 L p .14 0 0 r
F P
0 g
s
.59015 .63618 m .57772 .63844 L .57579 .63881 L p .142 .684 .713 r
F P
0 g
s
.57579 .63881 m .59354 .63558 L .59015 .63618 L p .142 .684 .713 r
F P
0 g
s
.57151 .63933 m .57579 .63881 L .57772 .63844 L p .151 .692 .73 r
F P
0 g
s
.42683 .51654 m .42888 .5123 L .42777 .51004 L p .867 .713 .689 r
F P
0 g
s
.37232 .56601 m .38614 .55759 L .38711 .55401 L p .744 .751 .858 r
F P
0 g
s
.38711 .55401 m .36736 .56605 L .37232 .56601 L p .744 .751 .858 r
F P
0 g
s
.58415 .49305 m .59477 .48675 L .59672 .48656 L p .236 0 .138 r
F P
0 g
s
.59672 .48656 m .58153 .49557 L .58415 .49305 L p .236 0 .138 r
F P
0 g
s
.51925 .53476 m .52273 .52996 L .52156 .529 L p .428 .135 .363 r
F P
0 g
s
.52156 .529 m .5166 .53586 L .51925 .53476 L p .428 .135 .363 r
F P
0 g
s
.53519 .52773 m .52156 .529 L .52273 .52996 L p .442 .132 .343 r
F P
0 g
s
.53399 .52657 m .52445 .52746 L .52156 .529 L p .431 .104 .308 r
F P
0 g
s
.52156 .529 m .53519 .52773 L .53399 .52657 L p .431 .104 .308 r
F P
0 g
s
.48994 .57603 m .49435 .56898 L .49457 .56637 L p .467 .366 .657 r
F P
0 g
s
.42351 .47026 m .42298 .46325 L .42336 .46322 L p 0 0 .42 r
F P
0 g
s
.53519 .52773 m .54091 .51832 L .538 .51999 L p .44 .103 .297 r
F P
0 g
s
.53759 .52593 m .54159 .51934 L .54091 .51832 L p .416 .078 .282 r
F P
0 g
s
.54091 .51832 m .53519 .52773 L .53759 .52593 L p .416 .078 .282 r
F P
0 g
s
.55041 .51585 m .54091 .51832 L .54159 .51934 L p .425 .081 .275 r
F P
0 g
s
.54091 .51832 m .55041 .51585 L .54965 .5148 L p .413 .058 .25 r
F P
0 g
s
.42864 .50395 m .42422 .49792 L .42315 .49703 L p .967 .8 .623 r
F P
0 g
s
.538 .51999 m .53399 .52657 L .53519 .52773 L p .44 .103 .297 r
F P
0 g
s
.71276 .36072 m .74786 .34269 L .75543 .33362 L p .795 .835 .882 r
F P
0 g
s
.42484 .5161 m .42777 .51004 L .42638 .50969 L p .934 .817 .705 r
F P
0 g
s
.42195 .50378 m .42638 .50969 L .42777 .51004 L p .934 .819 .708 r
F P
0 g
s
.42777 .51004 m .42145 .50159 L .42195 .50378 L p .934 .819 .708 r
F P
0 g
s
.42777 .51004 m .42484 .5161 L .42683 .51654 L p .867 .713 .689 r
F P
0 g
s
.42826 .50503 m .42708 .50811 L .42777 .51004 L p .953 .81 .663 r
F P
0 g
s
.42145 .50159 m .42777 .51004 L .42708 .50811 L p .953 .81 .665 r
F P
0 g
s
.62466 .45469 m .62915 .44869 L .63198 .44528 L p 0 0 0 r
F P
0 g
s
.62557 .45384 m .62466 .45469 L p .62548 .45364 L 0 0 0 r
F P
0 g
s
.63198 .44528 m .62557 .45384 L p .62548 .45364 L 0 0 0 r
F P
0 g
s
.62557 .45384 m .63198 .44528 L .63214 .44418 L p .802 .93 .557 r
F P
0 g
s
.62557 .45384 m .62621 .45266 L p .62566 .45403 L 0 0 0 r
F P
0 g
s
.62284 .46104 m .62557 .45384 L p .62566 .45403 L 0 0 0 r
F P
0 g
s
.63755 .43263 m .63214 .44418 L .63198 .44528 L p .802 .931 .562 r
F P
0 g
s
.63198 .44528 m .63971 .42878 L .63755 .43263 L p .802 .931 .562 r
F P
0 g
s
.63971 .42878 m .63198 .44528 L .63496 .44124 L p .877 .993 .777 r
F P
0 g
s
.40318 .42469 m .41201 .43524 L .41301 .43966 L p .338 .399 .778 r
F P
0 g
s
.35366 .55737 m .3616 .56602 L .36736 .56605 L p .722 .779 .898 r
F P
0 g
s
.36736 .56605 m .35605 .55368 L .35366 .55737 L p .722 .779 .898 r
F P
0 g
s
.38259 .55409 m .36875 .56253 L .36736 .56605 L p .754 .789 .881 r
F P
0 g
s
.36736 .56605 m .38711 .55401 L .38259 .55409 L p .754 .789 .881 r
F P
0 g
s
.35605 .55368 m .36736 .56605 L .36875 .56253 L p .752 .786 .881 r
F P
0 g
s
.58156 .50297 m .58153 .49557 L .58385 .49526 L p .336 .016 .267 r
F P
0 g
s
.59449 .48895 m .58385 .49526 L .58153 .49557 L p .34 .028 .281 r
F P
0 g
s
.58153 .49557 m .59672 .48656 L .59449 .48895 L p .34 .028 .281 r
F P
0 g
s
.57949 .50282 m .57947 .49764 L .58153 .49557 L p .392 .056 .273 r
F P
0 g
s
.58153 .49557 m .58156 .50297 L .57949 .50282 L p .392 .056 .273 r
F P
0 g
s
.66096 .87786 m .6357 .83708 L .6407 .82635 L p .658 .665 .846 r
F P
0 g
s
.51216 .61349 m .51214 .61544 L .51332 .61724 L p 0 .159 .696 r
F P
0 g
s
.51332 .61724 m .51335 .61446 L .51216 .61349 L p 0 .159 .696 r
F P
0 g
s
.52283 .62427 m .51492 .61826 L .51332 .61724 L p 0 .245 .72 r
F P
0 g
s
.51332 .61724 m .5246 .62581 L .52283 .62427 L p 0 .245 .72 r
F P
0 g
s
.51335 .61446 m .51332 .61724 L .51492 .61826 L p 0 .29 .784 r
F P
0 g
s
.63496 .44124 m .64038 .42969 L .63971 .42878 L p .877 .993 .777 r
F P
0 g
s
.49328 .58545 m .49536 .58873 L .49653 .58808 L p .369 .359 .717 r
F P
0 g
s
.49653 .58808 m .49356 .5834 L .49328 .58545 L p .369 .359 .717 r
F P
0 g
s
.42619 .48682 m .42621 .4829 L .42524 .48062 L p .99 .74 .445 r
F P
0 g
s
.67052 .61128 m .67891 .60248 L .67709 .59952 L p .73 .785 .896 r
F P
0 g
s
.67709 .59952 m .6651 .6121 L .67052 .61128 L p .73 .785 .896 r
F P
0 g
s
.50608 .60973 m .50717 .60623 L .50622 .60408 L p .141 .35 .809 r
F P
0 g
s
.61617 .46438 m .62466 .45469 L .62557 .45384 L p 0 0 0 r
F P
0 g
s
.62557 .45384 m .61344 .4677 L .61617 .46438 L p 0 0 0 r
F P
0 g
s
.52689 .62728 m .53663 .63247 L .53853 .63322 L p 0 .401 .814 r
F P
0 g
s
.53853 .63322 m .5246 .62581 L .52689 .62728 L p 0 .401 .814 r
F P
0 g
s
.42417 .47292 m .42496 .4781 L .42524 .48062 L p 0 0 .165 r
F P
0 g
s
.61127 .47481 m .61344 .4677 L .61488 .4667 L p 0 0 .024 r
F P
0 g
s
.62338 .457 m .61488 .4667 L .61344 .4677 L p 0 0 .02 r
F P
0 g
s
.61344 .4677 m .62557 .45384 L .62338 .457 L p 0 0 .02 r
F P
0 g
s
.60939 .47549 m .61092 .4705 L .61344 .4677 L p .113 0 .12 r
F P
0 g
s
.61344 .4677 m .61127 .47481 L .60939 .47549 L p .113 0 .12 r
F P
0 g
s
.70012 .60347 m .68239 .59872 L .67709 .59952 L p .725 .776 .893 r
F P
0 g
s
.42221 .52396 m .42565 .51861 L .42484 .5161 L p .847 .725 .729 r
F P
0 g
s
.61988 .62832 m .61331 .62742 L .6097 .62872 L p .725 .94 .955 r
F P
0 g
s
.42708 .50811 m .42266 .50219 L .42145 .50159 L p .953 .81 .665 r
F P
0 g
s
.64805 .61053 m .66037 .61331 L .6651 .6121 L p .741 .831 .92 r
F P
0 g
s
.6651 .6121 m .6475 .60812 L .64805 .61053 L p .741 .831 .92 r
F P
0 g
s
.67249 .60082 m .66411 .60963 L .6651 .6121 L p .744 .813 .906 r
F P
0 g
s
.6651 .6121 m .67709 .59952 L .67249 .60082 L p .744 .813 .906 r
F P
0 g
s
.6475 .60812 m .6651 .6121 L .66411 .60963 L p .762 .822 .899 r
F P
0 g
s
.52273 .52996 m .53227 .52907 L .53519 .52773 L p .442 .132 .343 r
F P
0 g
s
.41915 .45253 m .41422 .44353 L .41301 .43966 L p 0 .102 .646 r
F P
0 g
s
.57772 .63844 m .57473 .6388 L .57151 .63933 L p .151 .692 .73 r
F P
0 g
s
.41702 .82223 m .37737 .88141 L .37652 .87044 L p .736 .741 .855 r
F P
0 g
s
.34014 .85852 m .37652 .87044 L .37737 .88141 L p .737 .741 .855 r
F P
0 g
s
.37737 .88141 m .32545 .86453 L .34014 .85852 L p .737 .741 .855 r
F P
0 g
s
.4196 .83312 m .39178 .87447 L .37737 .88141 L p .723 .721 .848 r
F P
0 g
s
.37737 .88141 m .41702 .82223 L .4196 .83312 L p .723 .721 .848 r
F P
0 g
s
.51418 .53605 m .51189 .53908 L .51332 .54019 L p .519 .264 .468 r
F P
0 g
s
.51332 .54019 m .5166 .53586 L .51418 .53605 L p .519 .264 .468 r
F P
0 g
s
.49742 .57436 m .49364 .5809 L .49356 .5834 L p .391 .338 .679 r
F P
0 g
s
.49356 .5834 m .49897 .57406 L .49742 .57436 L p .391 .338 .679 r
F P
0 g
s
.49682 .58606 m .49474 .58278 L .49356 .5834 L p .392 .369 .714 r
F P
0 g
s
.49356 .5834 m .49653 .58808 L .49682 .58606 L p .392 .369 .714 r
F P
0 g
s
.49897 .57406 m .49356 .5834 L .49474 .58278 L p .361 .302 .656 r
F P
0 g
s
.54159 .51934 m .54825 .51761 L .55041 .51585 L p .425 .081 .275 r
F P
0 g
s
.28962 .33171 m .23504 .30566 L .22411 .29344 L p .57 .644 .884 r
F P
0 g
s
.22411 .29344 m .30235 .3308 L .28962 .33171 L p .57 .644 .884 r
F P
0 g
s
.42638 .50969 m .42432 .51394 L .42484 .5161 L p .934 .817 .705 r
F P
0 g
s
.4988 .55706 m .49428 .5638 L .49457 .56637 L p .504 .368 .629 r
F P
0 g
s
.42521 .48622 m .42524 .48062 L .42511 .48017 L p .801 .644 .089 r
F P
0 g
s
.42455 .4739 m .42511 .48017 L .42524 .48062 L p .803 .65 .097 r
F P
0 g
s
.42444 .47165 m .42524 .48062 L .42496 .4781 L p 0 0 .141 r
F P
0 g
s
.42496 .4781 m .4244 .47181 L .42444 .47165 L p 0 0 .141 r
F P
0 g
s
.42524 .48062 m .42444 .47165 L .42455 .4739 L p .803 .65 .097 r
F P
0 g
s
.42524 .48062 m .42521 .48622 L .42619 .48682 L p .99 .74 .445 r
F P
0 g
s
.41993 .52375 m .42484 .5161 L .42311 .51599 L p .903 .82 .756 r
F P
0 g
s
.41857 .51016 m .42311 .51599 L .42484 .5161 L p .902 .823 .759 r
F P
0 g
s
.42484 .5161 m .41835 .50776 L .41857 .51016 L p .902 .823 .759 r
F P
0 g
s
.42484 .5161 m .41993 .52375 L .42221 .52396 L p .847 .725 .729 r
F P
0 g
s
.41835 .50776 m .42484 .5161 L .42432 .51394 L p .932 .816 .708 r
F P
0 g
s
.55382 .51358 m .55147 .5143 L .55041 .51585 L p .405 .048 .242 r
F P
0 g
s
.29861 .57722 m .32447 .56887 L .32778 .56465 L p .697 .767 .906 r
F P
0 g
s
.32778 .56465 m .29079 .5766 L .29861 .57722 L p .697 .767 .906 r
F P
0 g
s
.52201 .62378 m .52283 .62427 L .5246 .62581 L p .518 0 0 r
F P
0 g
s
.5246 .62581 m .52344 .62512 L .52201 .62378 L p .518 0 0 r
F P
0 g
s
.53621 .63212 m .52645 .62693 L .5246 .62581 L p .469 0 0 r
F P
0 g
s
.5246 .62581 m .53853 .63322 L .53621 .63212 L p .469 0 0 r
F P
0 g
s
.52344 .62512 m .5246 .62581 L .52645 .62693 L p .368 0 0 r
F P
0 g
s
.75543 .33362 m .83345 .30168 L .81901 .29961 L p .76 .781 .87 r
F P
0 g
s
.80379 .26178 m .81901 .29961 L .83345 .30168 L p .76 .781 .87 r
F P
0 g
s
.83345 .30168 m .81201 .24746 L .80379 .26178 L p .76 .781 .87 r
F P
0 g
s
.49594 .5896 m .49621 .59079 L .49692 .58977 L p .168 .15 .593 r
F P
0 g
s
.49692 .58977 m .49653 .58808 L .49594 .5896 L p .168 .15 .593 r
F P
0 g
s
.51492 .61826 m .51495 .61633 L .51335 .61446 L p 0 .29 .784 r
F P
0 g
s
.77046 .58538 m .8049 .59227 L .81331 .59232 L p .675 .745 .903 r
F P
0 g
s
.81331 .59232 m .76409 .58245 L .77046 .58538 L p .675 .745 .903 r
F P
0 g
s
.80962 .5855 m .80656 .58996 L .81331 .59232 L p .67 .746 .907 r
F P
0 g
s
.81331 .59232 m .8177 .58596 L .80962 .5855 L p .67 .746 .907 r
F P
0 g
s
.76409 .58245 m .81331 .59232 L .80656 .58996 L p .675 .744 .903 r
F P
0 g
s
.58385 .49526 m .58388 .50044 L .58156 .50297 L p .336 .016 .267 r
F P
0 g
s
.49897 .57406 m .49457 .56637 L .49435 .56898 L p .38 .291 .629 r
F P
0 g
s
.49457 .56637 m .50104 .55674 L .4988 .55706 L p .504 .368 .629 r
F P
0 g
s
.49925 .57145 m .49617 .56607 L .49457 .56637 L p .431 .312 .617 r
F P
0 g
s
.49457 .56637 m .49897 .57406 L .49925 .57145 L p .431 .312 .617 r
F P
0 g
s
.50104 .55674 m .49457 .56637 L .49617 .56607 L p .417 .262 .561 r
F P
0 g
s
.49435 .56898 m .49742 .57436 L .49897 .57406 L p .38 .291 .629 r
F P
0 g
s
.3911 .55394 m .40139 .54617 L .40182 .5429 L p .772 .748 .831 r
F P
0 g
s
.40182 .5429 m .38711 .55401 L .3911 .55394 L p .772 .748 .831 r
F P
0 g
s
.54133 .6341 m .55251 .63748 L .55453 .63806 L p 0 .407 .704 r
F P
0 g
s
.55453 .63806 m .53853 .63322 L .54133 .6341 L p 0 .407 .704 r
F P
0 g
s
.41521 .5328 m .42039 .52651 L .41993 .52375 L p .825 .735 .765 r
F P
0 g
s
.51544 .53973 m .51773 .53669 L .5166 .53586 L p .39 .112 .366 r
F P
0 g
s
.5166 .53586 m .51332 .54019 L .51544 .53973 L p .39 .112 .366 r
F P
0 g
s
.52859 .53626 m .5166 .53586 L .51773 .53669 L p .403 .107 .346 r
F P
0 g
s
.52765 .53504 m .51925 .53476 L .5166 .53586 L p .397 .081 .308 r
F P
0 g
s
.5166 .53586 m .52859 .53626 L .52765 .53504 L p .397 .081 .308 r
F P
0 g
s
.55041 .51585 m .55377 .51481 L .55382 .51358 L p .405 .048 .242 r
F P
0 g
s
.51133 .53985 m .51055 .54087 L .51221 .54165 L p .516 .274 .487 r
F P
0 g
s
.51221 .54165 m .51332 .54019 L .51133 .53985 L p .516 .274 .487 r
F P
0 g
s
.36875 .56253 m .36085 .55387 L .35605 .55368 L p .752 .786 .881 r
F P
0 g
s
.42005 .45253 m .41301 .43966 L .41493 .43985 L p .245 .29 .711 r
F P
0 g
s
.41911 .43084 m .41493 .43985 L .41301 .43966 L p .245 .288 .709 r
F P
0 g
s
.41301 .43966 m .41896 .42677 L .41911 .43084 L p .245 .288 .709 r
F P
0 g
s
.41301 .43966 m .42005 .45253 L .41915 .45253 L p 0 .102 .646 r
F P
0 g
s
.41896 .42677 m .41301 .43966 L .41201 .43524 L p .337 .398 .777 r
F P
0 g
s
.49474 .58278 m .49852 .57624 L .49897 .57406 L p .361 .302 .656 r
F P
0 g
s
.34438 .36149 m .30903 .34018 L .30235 .3308 L p .53 .605 .873 r
F P
0 g
s
.42579 .49097 m .4261 .4882 L .42521 .48622 L p .987 .772 .527 r
F P
0 g
s
.55476 .51327 m .55713 .51248 L .55715 .51368 L p .402 .045 .241 r
F P
0 g
s
.55715 .51368 m .55377 .51481 L .55476 .51327 L p .402 .045 .241 r
F P
0 g
s
.42432 .51394 m .41979 .5081 L .41835 .50776 L p .932 .816 .708 r
F P
0 g
s
.51025 .5413 m .5093 .54253 L .51086 .54342 L p .514 .28 .497 r
F P
0 g
s
.51086 .54342 m .51221 .54165 L .51025 .5413 L p .514 .28 .497 r
F P
0 g
s
.59723 .63477 m .60853 .62997 L .6097 .62872 L p .609 .922 .973 r
F P
0 g
s
.6097 .62872 m .59354 .63558 L .59723 .63477 L p .609 .922 .973 r
F P
0 g
s
.75543 .33362 m .70516 .35942 L .71276 .36072 L p .795 .835 .882 r
F P
0 g
s
.64038 .42969 m .64905 .42166 L .65212 .41731 L p .877 .993 .777 r
F P
0 g
s
.49765 .59082 m .498 .59183 L .49868 .59083 L p .136 .131 .587 r
F P
0 g
s
.49868 .59083 m .49818 .58938 L .49765 .59082 L p .136 .131 .587 r
F P
0 g
s
.54625 .52505 m .55041 .51585 L .54825 .51761 L p .402 .051 .251 r
F P
0 g
s
.54745 .52349 m .55036 .51705 L .55041 .51585 L p .408 .057 .254 r
F P
0 g
s
.55041 .51585 m .54625 .52505 L .54745 .52349 L p .408 .057 .254 r
F P
0 g
s
.55377 .51481 m .55041 .51585 L .55036 .51705 L p .412 .06 .255 r
F P
0 g
s
.49988 .58024 m .49682 .58606 L .49653 .58808 L p .271 .256 .659 r
F P
0 g
s
.49653 .58808 m .50091 .57976 L .49988 .58024 L p .271 .256 .659 r
F P
0 g
s
.49748 .58831 m .49721 .58712 L .49653 .58808 L p .177 .156 .595 r
F P
0 g
s
.49653 .58808 m .49692 .58977 L .49748 .58831 L p .177 .156 .595 r
F P
0 g
s
.50091 .57976 m .49653 .58808 L .49721 .58712 L p .085 .035 .497 r
F P
0 g
s
.63214 .44418 m .62765 .45017 L .62557 .45384 L p .802 .93 .557 r
F P
0 g
s
.30235 .3308 m .35298 .36132 L .34438 .36149 L p .53 .605 .873 r
F P
0 g
s
.50863 .54346 m .50587 .54713 L .50691 .54865 L p .512 .295 .522 r
F P
0 g
s
.50691 .54865 m .51086 .54342 L .50863 .54346 L p .512 .295 .522 r
F P
0 g
s
.41993 .52375 m .41253 .53274 L .41521 .5328 L p .825 .735 .765 r
F P
0 g
s
.61488 .4667 m .61337 .47167 L .61127 .47481 L p 0 0 .024 r
F P
0 g
s
.40507 .54286 m .41256 .53575 L .41253 .53274 L p .799 .742 .8 r
F P
0 g
s
.42311 .51599 m .41967 .52135 L .41993 .52375 L p .903 .82 .756 r
F P
0 g
s
.27289 .56348 m .28148 .57573 L .29079 .5766 L p .677 .771 .922 r
F P
0 g
s
.29079 .5766 m .2786 .55906 L .27289 .56348 L p .677 .771 .922 r
F P
0 g
s
.3206 .56407 m .29467 .57245 L .29079 .5766 L p .696 .782 .918 r
F P
0 g
s
.29079 .5766 m .32778 .56465 L .3206 .56407 L p .696 .782 .918 r
F P
0 g
s
.2786 .55906 m .29079 .5766 L .29467 .57245 L p .693 .778 .916 r
F P
0 g
s
.41253 .53274 m .41993 .52375 L .41776 .52381 L p .868 .818 .797 r
F P
0 g
s
.41297 .51792 m .41776 .52381 L .41993 .52375 L p .867 .821 .8 r
F P
0 g
s
.41993 .52375 m .4131 .51532 L .41297 .51792 L p .867 .821 .8 r
F P
0 g
s
.4131 .51532 m .41993 .52375 L .41967 .52135 L p .9 .819 .758 r
F P
0 g
s
.5046 .54893 m .50049 .55459 L .50104 .55674 L p .507 .326 .569 r
F P
0 g
s
.37584 .54661 m .38259 .55409 L .38711 .55401 L p .753 .791 .884 r
F P
0 g
s
.38711 .55401 m .37749 .54331 L .37584 .54661 L p .753 .791 .884 r
F P
0 g
s
.39828 .54305 m .38798 .55084 L .38711 .55401 L p .791 .801 .861 r
F P
0 g
s
.38711 .55401 m .40182 .5429 L .39828 .54305 L p .791 .801 .861 r
F P
0 g
s
.37749 .54331 m .38711 .55401 L .38798 .55084 L p .787 .797 .861 r
F P
0 g
s
.41253 .53274 m .40182 .5429 L .40507 .54286 L p .799 .742 .8 r
F P
0 g
s
.52645 .62693 m .52565 .62645 L .52344 .62512 L p .368 0 0 r
F P
0 g
s
.53478 .63271 m .53621 .63212 L .53853 .63322 L p .629 .065 0 r
F P
0 g
s
.53853 .63322 m .5365 .63406 L .53478 .63271 L p .629 .065 0 r
F P
0 g
s
.55178 .63754 m .54058 .63415 L .53853 .63322 L p .501 0 0 r
F P
0 g
s
.53853 .63322 m .55453 .63806 L .55178 .63754 L p .501 0 0 r
F P
0 g
s
.5365 .63406 m .53853 .63322 L .54058 .63415 L p .46 0 0 r
F P
0 g
s
.49617 .56607 m .50071 .55933 L .50104 .55674 L p .417 .262 .561 r
F P
0 g
s
.70516 .35942 m .75543 .33362 L .74571 .33246 L p .79 .795 .856 r
F P
0 g
s
.73373 .30536 m .74571 .33246 L .75543 .33362 L p .79 .795 .856 r
F P
0 g
s
.75543 .33362 m .73847 .29481 L .73373 .30536 L p .79 .795 .856 r
F P
0 g
s
.81901 .29961 m .76421 .32204 L .75543 .33362 L p .76 .781 .87 r
F P
0 g
s
.73847 .29481 m .75543 .33362 L .76421 .32204 L p .76 .781 .87 r
F P
0 g
s
.63971 .42878 m .65212 .41731 L .65036 .41631 L p .931 .926 .781 r
F P
0 g
s
.65067 .40265 m .65036 .41631 L .65212 .41731 L p .931 .926 .781 r
F P
0 g
s
.65212 .41731 m .65259 .3978 L .65067 .40265 L p .931 .926 .781 r
F P
0 g
s
.65212 .41731 m .63971 .42878 L .64038 .42969 L p .877 .993 .777 r
F P
0 g
s
.65259 .3978 m .65212 .41731 L .65526 .41211 L p .882 .896 .836 r
F P
0 g
s
.42511 .48017 m .42509 .4841 L .42521 .48622 L p .801 .644 .089 r
F P
0 g
s
.50025 .5828 m .49748 .58831 L .49692 .58977 L p .03 0 .478 r
F P
0 g
s
.49692 .58977 m .50088 .5819 L .50025 .5828 L p .03 0 .478 r
F P
0 g
s
.42521 .48622 m .42477 .49019 L .42579 .49097 L p .987 .772 .527 r
F P
0 g
s
.50104 .55674 m .50691 .54865 L .5046 .54893 L p .507 .326 .569 r
F P
0 g
s
.58635 .63689 m .59015 .63618 L .59354 .63558 L p 0 0 0 r
F P
0 g
s
.59505 .63472 m .59126 .63543 L .58812 .6366 L p .433 .872 .818 r
F P
0 g
s
.58812 .6366 m .58973 .63603 L p .58908 .63645 L 0 0 0 r
F P
0 g
s
.5844 .63943 m .58812 .6366 L p .58908 .63645 L 0 0 0 r
F P
0 g
s
.58812 .6366 m .58635 .63689 L p .58706 .63676 L 0 0 0 r
F P
0 g
s
.59354 .63558 m .58812 .6366 L p .58706 .63676 L 0 0 0 r
F P
0 g
s
.60637 .62992 m .59505 .63472 L .59354 .63558 L p .438 .876 .831 r
F P
0 g
s
.59354 .63558 m .6097 .62872 L .60637 .62992 L p .438 .876 .831 r
F P
0 g
s
.58812 .6366 m .59354 .63558 L .59505 .63472 L p .433 .872 .818 r
F P
0 g
s
.66411 .60963 m .65179 .60684 L .6475 .60812 L p .762 .822 .899 r
F P
0 g
s
.59922 .48371 m .60939 .47549 L .61127 .47481 L p .11 0 .112 r
F P
0 g
s
.61127 .47481 m .59672 .48656 L .59922 .48371 L p .11 0 .112 r
F P
0 g
s
.51377 .5418 m .51455 .54078 L .51332 .54019 L p .367 .097 .366 r
F P
0 g
s
.51332 .54019 m .51221 .54165 L .51377 .5418 L p .367 .097 .366 r
F P
0 g
s
.52314 .54233 m .51332 .54019 L .51455 .54078 L p .372 .09 .35 r
F P
0 g
s
.52231 .54123 m .51544 .53973 L .51332 .54019 L p .373 .073 .321 r
F P
0 g
s
.51332 .54019 m .52314 .54233 L .52231 .54123 L p .373 .073 .321 r
F P
0 g
s
.49859 .5927 m .50056 .59622 L .5015 .59586 L p .244 .3 .723 r
F P
0 g
s
.5015 .59586 m .49868 .59083 L .49859 .5927 L p .244 .3 .723 r
F P
0 g
s
.42477 .49019 m .42521 .48622 L .425 .48562 L p .885 .757 .254 r
F P
0 g
s
.42439 .47985 m .425 .48562 L .42521 .48622 L p .889 .769 .271 r
F P
0 g
s
.42521 .48622 m .42434 .47797 L .42439 .47985 L p .889 .769 .271 r
F P
0 g
s
.42434 .47797 m .42521 .48622 L .42509 .4841 L p .812 .656 .106 r
F P
0 g
s
.54825 .51761 m .54533 .52405 L .54625 .52505 L p .402 .051 .251 r
F P
0 g
s
.55897 .5118 m .56588 .50917 L .56702 .50992 L p .4 .046 .245 r
F P
0 g
s
.56702 .50992 m .55715 .51368 L .55897 .5118 L p .4 .046 .245 r
F P
0 g
s
.41201 .43524 m .41617 .42621 L .41896 .42677 L p .337 .398 .777 r
F P
0 g
s
.49917 .58947 m .49881 .58846 L .49818 .58938 L p .128 .126 .586 r
F P
0 g
s
.49818 .58938 m .49868 .59083 L .49917 .58947 L p .128 .126 .586 r
F P
0 g
s
.50214 .58151 m .49818 .58938 L .49881 .58846 L p .031 0 .478 r
F P
0 g
s
.42535 .49352 m .42565 .49188 L .42477 .49019 L p .98 .786 .571 r
F P
0 g
s
.51232 .54364 m .51326 .5424 L .51221 .54165 L p .358 .093 .369 r
F P
0 g
s
.51221 .54165 m .51086 .54342 L .51232 .54364 L p .358 .093 .369 r
F P
0 g
s
.52116 .54448 m .51221 .54165 L .51326 .5424 L p .362 .091 .362 r
F P
0 g
s
.52004 .54379 m .51377 .5418 L .51221 .54165 L p .365 .082 .344 r
F P
0 g
s
.51221 .54165 m .52116 .54448 L .52004 .54379 L p .365 .082 .344 r
F P
0 g
s
.55053 .52374 m .55377 .51481 L .55387 .51595 L p .412 .059 .254 r
F P
0 g
s
.55624 .51516 m .55387 .51595 L .55377 .51481 L p .409 .057 .254 r
F P
0 g
s
.55377 .51481 m .55715 .51368 L .55624 .51516 L p .409 .057 .254 r
F P
0 g
s
.55053 .52374 m .55377 .51481 L .55271 .51632 L p .407 .054 .251 r
F P
0 g
s
.55036 .51705 m .55271 .51632 L .55377 .51481 L p .412 .06 .255 r
F P
0 g
s
.51773 .53669 m .52612 .53698 L .52859 .53626 L p .403 .107 .346 r
F P
0 g
s
.63911 .61881 m .64805 .61053 L .6475 .60812 L p .756 .84 .915 r
F P
0 g
s
.6475 .60812 m .63472 .61997 L .63911 .61881 L p .756 .84 .915 r
F P
0 g
s
.80656 .58996 m .77209 .58304 L .76409 .58245 L p .675 .744 .903 r
F P
0 g
s
.49721 .58712 m .50028 .5813 L .50091 .57976 L p .085 .035 .497 r
F P
0 g
s
.59729 .49302 m .59672 .48656 L .59895 .48573 L p .262 0 .294 r
F P
0 g
s
.60914 .4775 m .59895 .48573 L .59672 .48656 L p .264 0 .299 r
F P
0 g
s
.59672 .48656 m .61127 .47481 L .60914 .4775 L p .264 0 .299 r
F P
0 g
s
.59488 .49347 m .59449 .48895 L .59672 .48656 L p .359 .05 .299 r
F P
0 g
s
.59672 .48656 m .59729 .49302 L .59488 .49347 L p .359 .05 .299 r
F P
0 g
s
.76611 .5916 m .77046 .58538 L .76409 .58245 L p .681 .744 .898 r
F P
0 g
s
.76409 .58245 m .75789 .59136 L .76611 .5916 L p .681 .744 .898 r
F P
0 g
s
.50851 .54858 m .51127 .54491 L .51086 .54342 L p .355 .107 .393 r
F P
0 g
s
.51086 .54342 m .50691 .54865 L .50851 .54858 L p .355 .107 .393 r
F P
0 g
s
.51879 .5471 m .51086 .54342 L .51127 .54491 L p .345 .101 .394 r
F P
0 g
s
.51787 .54622 m .51232 .54364 L .51086 .54342 L p .358 .086 .358 r
F P
0 g
s
.51086 .54342 m .51879 .5471 L .51787 .54622 L p .358 .086 .358 r
F P
0 g
s
.41967 .52135 m .4149 .51545 L .4131 .51532 L p .9 .819 .758 r
F P
0 g
s
.40182 .5429 m .41253 .53274 L .40975 .5329 L p .829 .811 .833 r
F P
0 g
s
.40454 .52676 m .40975 .5329 L .41253 .53274 L p .828 .814 .836 r
F P
0 g
s
.41253 .53274 m .4051 .52397 L .40454 .52676 L p .828 .814 .836 r
F P
0 g
s
.41776 .52381 m .41257 .53011 L .41253 .53274 L p .868 .818 .797 r
F P
0 g
s
.4051 .52397 m .41253 .53274 L .41257 .53011 L p .865 .816 .799 r
F P
0 g
s
.50515 .56433 m .50104 .55674 L .50071 .55933 L p .321 .178 .525 r
F P
0 g
s
.50552 .56184 m .50264 .55654 L .50104 .55674 L p .385 .203 .508 r
F P
0 g
s
.50104 .55674 m .50515 .56433 L .50552 .56184 L p .385 .203 .508 r
F P
0 g
s
.50691 .54865 m .50104 .55674 L .50264 .55654 L p .374 .164 .46 r
F P
0 g
s
.37977 .38655 m .35696 .36874 L .35298 .36132 L p .479 .554 .854 r
F P
0 g
s
.42477 .49019 m .42434 .49253 L .42535 .49352 L p .98 .786 .571 r
F P
0 g
s
.39245 .53639 m .39828 .54305 L .40182 .5429 L p .789 .804 .864 r
F P
0 g
s
.40182 .5429 m .39351 .53337 L .39245 .53639 L p .789 .804 .864 r
F P
0 g
s
.40975 .5329 m .40225 .54001 L .40182 .5429 L p .829 .811 .833 r
F P
0 g
s
.39351 .53337 m .40182 .5429 L .40225 .54001 L p .826 .809 .834 r
F P
0 g
s
.55764 .63824 m .56952 .63913 L .57151 .63933 L p .107 0 0 r
F P
0 g
s
.57151 .63933 m .55453 .63806 L .55764 .63824 L p .107 0 0 r
F P
0 g
s
.65526 .41211 m .65561 .39845 L .65259 .3978 L p .882 .896 .836 r
F P
0 g
s
.42517 .49452 m .42526 .49398 L .42434 .49253 L p .98 .787 .573 r
F P
0 g
s
.50164 .58431 m .49917 .58947 L .49868 .59083 L p 0 0 .463 r
F P
0 g
s
.49868 .59083 m .50221 .58345 L .50164 .58431 L p 0 0 .463 r
F P
0 g
s
.50151 .59413 m .49953 .5906 L .49868 .59083 L p .202 .278 .72 r
F P
0 g
s
.49868 .59083 m .5015 .59586 L .50151 .59413 L p .202 .278 .72 r
F P
0 g
s
.50221 .58345 m .49868 .59083 L .49953 .5906 L p .183 .207 .651 r
F P
0 g
s
.50264 .55654 m .50675 .55087 L .50691 .54865 L p .374 .164 .46 r
F P
0 g
s
.5124 .55453 m .50691 .54865 L .50675 .55087 L p .31 .112 .442 r
F P
0 g
s
.51235 .55269 m .50851 .54858 L .50691 .54865 L p .357 .116 .405 r
F P
0 g
s
.50691 .54865 m .5124 .55453 L .51235 .55269 L p .357 .116 .405 r
F P
0 g
s
.62286 .62049 m .63082 .62129 L .63472 .61997 L p .731 .918 .957 r
F P
0 g
s
.63472 .61997 m .62336 .61881 L .62286 .62049 L p .731 .918 .957 r
F P
0 g
s
.64373 .60971 m .63478 .61801 L .63472 .61997 L p .774 .893 .929 r
F P
0 g
s
.63472 .61997 m .6475 .60812 L .64373 .60971 L p .774 .893 .929 r
F P
0 g
s
.62336 .61881 m .63472 .61997 L .63478 .61801 L p .793 .907 .92 r
F P
0 g
s
.72538 .5861 m .75109 .59181 L .75789 .59136 L p .691 .746 .894 r
F P
0 g
s
.75789 .59136 m .72114 .58319 L .72538 .5861 L p .691 .746 .894 r
F P
0 g
s
.75757 .58262 m .75325 .58887 L .75789 .59136 L p .683 .746 .899 r
F P
0 g
s
.75789 .59136 m .76409 .58245 L .75757 .58262 L p .683 .746 .899 r
F P
0 g
s
.72114 .58319 m .75789 .59136 L .75325 .58887 L p .692 .746 .893 r
F P
0 g
s
.42434 .49253 m .4242 .49331 L .42517 .49452 L p .98 .787 .573 r
F P
0 g
s
.42495 .49542 m .42511 .49477 L .4242 .49331 L p .974 .797 .603 r
F P
0 g
s
.54058 .63415 m .53916 .63474 L .5365 .63406 L p .46 0 0 r
F P
0 g
s
.55494 .52227 m .55715 .51368 L .55849 .51432 L p .419 .067 .258 r
F P
0 g
s
.56541 .51168 m .55849 .51432 L .55715 .51368 L p .416 .072 .272 r
F P
0 g
s
.55715 .51368 m .56702 .50992 L .56541 .51168 L p .416 .072 .272 r
F P
0 g
s
.55468 .52117 m .55624 .51516 L .55715 .51368 L p .414 .062 .257 r
F P
0 g
s
.55715 .51368 m .55494 .52227 L .55468 .52117 L p .414 .062 .257 r
F P
0 g
s
.50071 .55933 m .50358 .56464 L .50515 .56433 L p .321 .178 .525 r
F P
0 g
s
.41493 .43985 m .41987 .44887 L .42005 .45253 L p .245 .29 .711 r
F P
0 g
s
.38798 .55084 m .38125 .54334 L .37749 .54331 L p .787 .797 .861 r
F P
0 g
s
.42509 .4841 m .42448 .47832 L .42434 .47797 L p .812 .656 .106 r
F P
0 g
s
.50187 .59799 m .50517 .60374 L .50622 .60408 L p .125 .254 .727 r
F P
0 g
s
.50622 .60408 m .5015 .59586 L .50187 .59799 L p .125 .254 .727 r
F P
0 g
s
.49881 .58846 m .50159 .58295 L .50214 .58151 L p .031 0 .478 r
F P
0 g
s
.4242 .49331 m .42398 .49424 L .42495 .49542 L p .974 .797 .603 r
F P
0 g
s
.67775 .38136 m .70031 .3666 L .70516 .35942 L p .835 .864 .866 r
F P
0 g
s
.42434 .49253 m .42477 .49019 L .42454 .48939 L p .926 .817 .356 r
F P
0 g
s
.42383 .48391 m .42454 .48939 L .42477 .49019 L p .932 .834 .385 r
F P
0 g
s
.42477 .49019 m .42375 .48236 L .42383 .48391 L p .932 .834 .385 r
F P
0 g
s
.425 .48562 m .42469 .48839 L .42477 .49019 L p .885 .757 .254 r
F P
0 g
s
.42375 .48236 m .42477 .49019 L .42469 .48839 L p .899 .774 .283 r
F P
0 g
s
.55271 .51632 m .55044 .52257 L .55053 .52374 L p .407 .054 .251 r
F P
0 g
s
.42422 .49792 m .4248 .49597 L .42398 .49424 L p .965 .804 .634 r
F P
0 g
s
.51455 .54078 m .52143 .54228 L .52314 .54233 L p .372 .09 .35 r
F P
0 g
s
.42298 .46325 m .42067 .45577 L .42005 .45253 L p 0 0 .414 r
F P
0 g
s
.5499 .63883 m .55178 .63754 L .55453 .63806 L p .586 .035 0 r
F P
0 g
s
.55453 .63806 m .55186 .63991 L .5499 .63883 L p .586 .035 0 r
F P
0 g
s
.56853 .63947 m .55663 .63858 L .55453 .63806 L p .41 0 0 r
F P
0 g
s
.55453 .63806 m .57151 .63933 L .56853 .63947 L p .41 0 0 r
F P
0 g
s
.55186 .63991 m .55453 .63806 L .55663 .63858 L p .389 0 0 r
F P
0 g
s
.41257 .53011 m .40738 .52396 L .4051 .52397 L p .865 .816 .799 r
F P
0 g
s
.55387 .51595 m .5516 .5222 L .55053 .52374 L p .412 .059 .254 r
F P
0 g
s
.51326 .5424 m .51953 .54439 L .52116 .54448 L p .362 .091 .362 r
F P
0 g
s
.68043 .87301 m .73018 .85622 L .74768 .86092 L p .63 .653 .855 r
F P
0 g
s
.40225 .54001 m .39644 .53334 L .39351 .53337 L p .826 .809 .834 r
F P
0 g
s
.42398 .49424 m .42315 .49703 L .42422 .49792 L p .965 .804 .634 r
F P
0 g
s
.51127 .54491 m .51681 .5475 L .51879 .5471 L p .345 .101 .394 r
F P
0 g
s
.4242 .49331 m .42434 .49253 L .42414 .49152 L p .932 .821 .365 r
F P
0 g
s
.42333 .48621 m .42414 .49152 L .42434 .49253 L p .941 .842 .404 r
F P
0 g
s
.42434 .49253 m .42318 .48494 L .42333 .48621 L p .941 .842 .404 r
F P
0 g
s
.42454 .48939 m .42424 .49103 L .42434 .49253 L p .926 .817 .356 r
F P
0 g
s
.42318 .48494 m .42434 .49253 L .42424 .49103 L p .939 .837 .395 r
F P
0 g
s
.50675 .55087 m .51059 .55499 L .5124 .55453 L p .31 .112 .442 r
F P
0 g
s
.59895 .48573 m .59936 .49025 L .59729 .49302 L p .262 0 .294 r
F P
0 g
s
.56932 .50768 m .57949 .50282 L .58156 .50297 L p .39 .047 .258 r
F P
0 g
s
.58156 .50297 m .56702 .50992 L .56932 .50768 L p .39 .047 .258 r
F P
0 g
s
.49953 .5906 m .50201 .58544 L .50221 .58345 L p .183 .207 .651 r
F P
0 g
s
.35298 .36132 m .38563 .38681 L .37977 .38655 L p .479 .554 .854 r
F P
0 g
s
.50305 .59008 m .50151 .59413 L .5015 .59586 L p 0 .095 .61 r
F P
0 g
s
.5015 .59586 m .50371 .59008 L .50305 .59008 L p 0 .095 .61 r
F P
0 g
s
.50571 .60218 m .50241 .59642 L .5015 .59586 L p 0 .171 .693 r
F P
0 g
s
.5015 .59586 m .50622 .60408 L .50571 .60218 L p 0 .171 .693 r
F P
0 g
s
.50371 .59008 m .5015 .59586 L .50241 .59642 L p .048 .154 .654 r
F P
0 g
s
.71994 .59356 m .72538 .5861 L .72114 .58319 L p .701 .747 .888 r
F P
0 g
s
.72114 .58319 m .71338 .59386 L .71994 .59356 L p .701 .747 .888 r
F P
0 g
s
.42398 .49424 m .4242 .49331 L .42398 .49233 L p .95 .855 .432 r
F P
0 g
s
.42312 .48706 m .42398 .49233 L .4242 .49331 L p .953 .868 .456 r
F P
0 g
s
.4242 .49331 m .42298 .48578 L .42312 .48706 L p .953 .868 .456 r
F P
0 g
s
.42414 .49152 m .42404 .49206 L .4242 .49331 L p .932 .821 .365 r
F P
0 g
s
.42298 .48578 m .4242 .49331 L .42404 .49206 L p .944 .843 .408 r
F P
0 g
s
.42266 .50219 m .42385 .499 L .42315 .49703 L p .952 .811 .667 r
F P
0 g
s
.35298 .36132 m .30235 .3308 L .31237 .33127 L p .565 .605 .852 r
F P
0 g
s
.32512 .30921 m .31237 .33127 L .30235 .3308 L p .565 .605 .852 r
F P
0 g
s
.30235 .3308 m .32044 .29919 L .32512 .30921 L p .565 .605 .852 r
F P
0 g
s
.23877 .29343 m .29369 .31966 L .30235 .3308 L p .593 .641 .867 r
F P
0 g
s
.30235 .3308 m .22411 .29344 L .23877 .29343 L p .593 .641 .867 r
F P
0 g
s
.32044 .29919 m .30235 .3308 L .29369 .31966 L p .593 .641 .867 r
F P
0 g
s
.29467 .57245 m .28617 .56016 L .2786 .55906 L p .693 .778 .916 r
F P
0 g
s
.42469 .48839 m .42398 .48291 L .42375 .48236 L p .899 .774 .283 r
F P
0 g
s
.42315 .49703 m .42398 .49424 L .42366 .49356 L p .962 .886 .498 r
F P
0 g
s
.42276 .48835 m .42366 .49356 L .42398 .49424 L p .962 .89 .507 r
F P
0 g
s
.42398 .49424 m .4227 .48679 L .42276 .48835 L p .962 .89 .507 r
F P
0 g
s
.42398 .49233 m .42383 .49298 L .42398 .49424 L p .95 .855 .432 r
F P
0 g
s
.4227 .48679 m .42398 .49424 L .42383 .49298 L p .955 .868 .459 r
F P
0 g
s
.49852 .57624 m .49988 .58024 L .50091 .57976 L p .243 .189 .595 r
F P
0 g
s
.50091 .57976 m .49897 .57406 L .49852 .57624 L p .243 .189 .595 r
F P
0 g
s
.68867 .59038 m .70779 .59476 L .71338 .59386 L p .715 .759 .887 r
F P
0 g
s
.71338 .59386 m .68605 .5876 L .68867 .59038 L p .715 .759 .887 r
F P
0 g
s
.71578 .58388 m .71036 .59136 L .71338 .59386 L p .706 .755 .89 r
F P
0 g
s
.71338 .59386 m .72114 .58319 L .71578 .58388 L p .706 .755 .89 r
F P
0 g
s
.68605 .5876 m .71338 .59386 L .71036 .59136 L p .719 .756 .882 r
F P
0 g
s
.53227 .52907 m .52765 .53504 L .52859 .53626 L p .412 .084 .296 r
F P
0 g
s
.52859 .53626 m .53519 .52773 L .53227 .52907 L p .412 .084 .296 r
F P
0 g
s
.42336 .46322 m .42005 .45253 L .42138 .45272 L p .136 .156 .617 r
F P
0 g
s
.42543 .4455 m .42138 .45272 L .42005 .45253 L p .136 .155 .616 r
F P
0 g
s
.42005 .45253 m .42582 .44219 L .42543 .4455 L p .136 .155 .616 r
F P
0 g
s
.42005 .45253 m .42336 .46322 L .42298 .46325 L p 0 0 .414 r
F P
0 g
s
.42582 .44219 m .42005 .45253 L .41987 .44887 L p .24 .285 .709 r
F P
0 g
s
.54533 .52405 m .53759 .52593 L .53519 .52773 L p .396 .051 .259 r
F P
0 g
s
.55849 .51432 m .55695 .52033 L .55494 .52227 L p .419 .067 .258 r
F P
0 g
s
.65036 .41631 m .64166 .42434 L .63971 .42878 L p .931 .926 .781 r
F P
0 g
s
.50717 .60623 m .51216 .61349 L .51335 .61446 L p 0 .184 .715 r
F P
0 g
s
.51335 .61446 m .50622 .60408 L .50717 .60623 L p 0 .184 .715 r
F P
0 g
s
.50358 .56464 m .49925 .57145 L .49897 .57406 L p .335 .228 .582 r
F P
0 g
s
.5737 .84647 m .5318 .84782 L .52189 .83867 L p .683 .682 .842 r
F P
0 g
s
.75325 .58887 m .72751 .58314 L .72114 .58319 L p .692 .746 .893 r
F P
0 g
s
.49897 .57406 m .50515 .56433 L .50358 .56464 L p .335 .228 .582 r
F P
0 g
s
.50143 .57753 m .50007 .57354 L .49897 .57406 L p .292 .217 .598 r
F P
0 g
s
.49897 .57406 m .50091 .57976 L .50143 .57753 L p .292 .217 .598 r
F P
0 g
s
.50515 .56433 m .49897 .57406 L .50007 .57354 L p .25 .126 .509 r
F P
0 g
s
.55663 .63858 m .55477 .63987 L .55186 .63991 L p .389 0 0 r
F P
0 g
s
.53131 .53459 m .53592 .52861 L .53519 .52773 L p .365 .031 .26 r
F P
0 g
s
.53519 .52773 m .52859 .53626 L .53131 .53459 L p .365 .031 .26 r
F P
0 g
s
.54625 .52505 m .53519 .52773 L .53592 .52861 L p .387 .034 .239 r
F P
0 g
s
.53519 .52773 m .54625 .52505 L .54533 .52405 L p .396 .051 .259 r
F P
0 g
s
.63478 .61801 m .62683 .6172 L .62336 .61881 L p .793 .907 .92 r
F P
0 g
s
.38563 .38681 m .35298 .36132 L .35997 .36205 L p .533 .561 .83 r
F P
0 g
s
.37067 .34561 m .35997 .36205 L .35298 .36132 L p .533 .561 .83 r
F P
0 g
s
.35298 .36132 m .3682 .33778 L .37067 .34561 L p .533 .561 .83 r
F P
0 g
s
.31237 .33127 m .34789 .35268 L .35298 .36132 L p .565 .605 .852 r
F P
0 g
s
.3682 .33778 m .35298 .36132 L .34789 .35268 L p .566 .605 .852 r
F P
0 g
s
.56746 .51738 m .56702 .50992 L .56939 .50989 L p .422 .087 .29 r
F P
0 g
s
.57958 .50502 m .56939 .50989 L .56702 .50992 L p .428 .107 .317 r
F P
0 g
s
.56702 .50992 m .58156 .50297 L .57958 .50502 L p .428 .107 .317 r
F P
0 g
s
.56571 .51691 m .56541 .51168 L .56702 .50992 L p .438 .098 .29 r
F P
0 g
s
.56702 .50992 m .56746 .51738 L .56571 .51691 L p .438 .098 .29 r
F P
0 g
s
.42315 .49703 m .42145 .50159 L .42266 .50219 L p .952 .811 .667 r
F P
0 g
s
.77453 .57913 m .80962 .5855 L .8177 .58596 L p .673 .742 .902 r
F P
0 g
s
.8177 .58596 m .76756 .57685 L .77453 .57913 L p .673 .742 .902 r
F P
0 g
s
.81138 .58309 m .81041 .58435 L .8177 .58596 L p .671 .743 .904 r
F P
0 g
s
.8177 .58596 m .8191 .58416 L .81138 .58309 L p .671 .743 .904 r
F P
0 g
s
.76756 .57685 m .8177 .58596 L .81041 .58435 L p .677 .74 .898 r
F P
0 g
s
.5113 .84729 m .472 .84346 L .46558 .83315 L p .705 .701 .843 r
F P
0 g
s
.46558 .83315 m .52189 .83867 L .5113 .84729 L p .705 .701 .843 r
F P
0 g
s
.42424 .49103 m .42343 .48572 L .42318 .48494 L p .939 .837 .395 r
F P
0 g
s
.42145 .50159 m .42315 .49703 L .42266 .49665 L p .971 .913 .574 r
F P
0 g
s
.4217 .49158 m .42266 .49665 L .42315 .49703 L p .967 .923 .593 r
F P
0 g
s
.42315 .49703 m .42177 .48979 L .4217 .49158 L p .967 .923 .593 r
F P
0 g
s
.42366 .49356 m .42308 .49552 L .42315 .49703 L p .962 .886 .498 r
F P
0 g
s
.42177 .48979 m .42315 .49703 L .42308 .49552 L p .964 .891 .511 r
F P
0 g
s
.40236 .40794 m .38784 .39284 L .38563 .38681 L p .416 .487 .824 r
F P
0 g
s
.3339 .56504 m .35366 .55737 L .35605 .55368 L p .72 .777 .897 r
F P
0 g
s
.35605 .55368 m .32778 .56465 L .3339 .56504 L p .72 .777 .897 r
F P
0 g
s
.67287 .38054 m .70516 .35942 L .69858 .35875 L p .825 .808 .834 r
F P
0 g
s
.68914 .33851 m .69858 .35875 L .70516 .35942 L p .825 .808 .834 r
F P
0 g
s
.70516 .35942 m .69176 .33046 L .68914 .33851 L p .825 .808 .834 r
F P
0 g
s
.70516 .35942 m .67287 .38054 L .67775 .38136 L p .835 .864 .866 r
F P
0 g
s
.74571 .33246 m .71042 .35056 L .70516 .35942 L p .79 .795 .856 r
F P
0 g
s
.69176 .33046 m .70516 .35942 L .71042 .35056 L p .79 .794 .856 r
F P
0 g
s
.50241 .59642 m .50396 .59238 L .50371 .59008 L p .048 .154 .654 r
F P
0 g
s
.37652 .87044 m .40423 .82892 L .41702 .82223 L p .736 .741 .855 r
F P
0 g
s
.41979 .5081 m .42195 .50378 L .42145 .50159 L p .931 .818 .712 r
F P
0 g
s
.57473 .6388 m .58635 .63689 L .58812 .6366 L p .119 .667 .702 r
F P
0 g
s
.58812 .6366 m .57151 .63933 L .57473 .6388 L p .119 .667 .702 r
F P
0 g
s
.42404 .49206 m .42319 .48679 L .42298 .48578 L p .944 .843 .408 r
F P
0 g
s
.41987 .44887 m .4239 .44163 L .42582 .44219 L p .24 .285 .709 r
F P
0 g
s
.50601 .59993 m .50571 .60218 L .50622 .60408 L p 0 0 .489 r
F P
0 g
s
.50622 .60408 m .50666 .60088 L .50601 .59993 L p 0 0 .489 r
F P
0 g
s
.51224 .61262 m .50725 .60535 L .50622 .60408 L p 0 0 .542 r
F P
0 g
s
.50622 .60408 m .51335 .61446 L .51224 .61262 L p 0 0 .542 r
F P
0 g
s
.50666 .60088 m .50622 .60408 L .50725 .60535 L p 0 .04 .609 r
F P
0 g
s
.42383 .49298 m .42293 .48777 L .4227 .48679 L p .955 .868 .459 r
F P
0 g
s
.68239 .59872 m .68867 .59038 L .68605 .5876 L p .729 .762 .879 r
F P
0 g
s
.68605 .5876 m .67709 .59952 L .68239 .59872 L p .729 .762 .879 r
F P
0 g
s
.61331 .62742 m .62286 .62049 L .62336 .61881 L p .742 .929 .951 r
F P
0 g
s
.62336 .61881 m .6097 .62872 L .61331 .62742 L p .742 .929 .951 r
F P
0 g
s
.51495 .61633 m .52201 .62378 L .52344 .62512 L p 0 .086 .612 r
F P
0 g
s
.52344 .62512 m .51335 .61446 L .51495 .61633 L p 0 .086 .612 r
F P
0 g
s
.50007 .57354 m .50441 .56672 L .50515 .56433 L p .25 .126 .509 r
F P
0 g
s
.65867 .59804 m .67249 .60082 L .67709 .59952 L p .748 .794 .89 r
F P
0 g
s
.67709 .59952 m .65734 .59554 L .65867 .59804 L p .748 .794 .89 r
F P
0 g
s
.68162 .58879 m .67535 .59714 L .67709 .59952 L p .741 .781 .885 r
F P
0 g
s
.67709 .59952 m .68605 .5876 L .68162 .58879 L p .741 .781 .885 r
F P
0 g
s
.65734 .59554 m .67709 .59952 L .67535 .59714 L p .759 .786 .875 r
F P
0 g
s
.5663 .64122 m .56853 .63947 L .57151 .63933 L p .466 0 0 r
F P
0 g
s
.57151 .63933 m .56834 .64184 L .5663 .64122 L p .466 0 0 r
F P
0 g
s
.58511 .63741 m .57348 .63932 L .57151 .63933 L p .218 0 0 r
F P
0 g
s
.57151 .63933 m .58812 .6366 L .58511 .63741 L p .218 0 0 r
F P
0 g
s
.56834 .64184 m .57151 .63933 L .57348 .63932 L p .21 0 0 r
F P
0 g
s
.52189 .83867 m .58193 .83672 L .5737 .84647 L p .683 .682 .842 r
F P
0 g
s
.58388 .50044 m .59488 .49347 L .59729 .49302 L p .353 .037 .282 r
F P
0 g
s
.59729 .49302 m .58156 .50297 L .58388 .50044 L p .353 .037 .282 r
F P
0 g
s
.4244 .47181 m .42364 .46592 L .42336 .46322 L p 0 0 .133 r
F P
0 g
s
.76421 .32204 m .75249 .29478 L .73847 .29481 L p .76 .781 .87 r
F P
0 g
s
.25441 .26253 m .23877 .29343 L .22411 .29344 L p .593 .641 .867 r
F P
0 g
s
.22411 .29344 m .24622 .24912 L .25441 .26253 L p .593 .641 .867 r
F P
0 g
s
.77639 .57637 m .81169 .58257 L .8191 .58416 L p .676 .739 .898 r
F P
0 g
s
.8191 .58416 m .76868 .5753 L .77639 .57637 L p .676 .739 .898 r
F P
0 g
s
.82003 .58227 m .8191 .58416 L .81169 .58257 L p .671 .742 .904 r
F P
0 g
s
.77609 .57689 m .81138 .58309 L .8191 .58416 L p .676 .739 .898 r
F P
0 g
s
.8191 .58416 m .76868 .5753 L .77609 .57689 L p .676 .739 .898 r
F P
0 g
s
.81041 .58435 m .7753 .57797 L .76756 .57685 L p .677 .74 .898 r
F P
0 g
s
.56939 .50989 m .5697 .51511 L .56746 .51738 L p .422 .087 .29 r
F P
0 g
s
.41835 .50776 m .42145 .50159 L .42069 .50149 L p .967 .936 .673 r
F P
0 g
s
.41947 .49661 m .42069 .50149 L .42145 .50159 L p .961 .944 .687 r
F P
0 g
s
.42145 .50159 m .41971 .49462 L .41947 .49661 L p .961 .944 .687 r
F P
0 g
s
.42145 .50159 m .41835 .50776 L .41979 .5081 L p .931 .818 .712 r
F P
0 g
s
.42266 .49665 m .42147 .49985 L .42145 .50159 L p .971 .913 .574 r
F P
0 g
s
.41971 .49462 m .42145 .50159 L .42147 .49985 L p .973 .921 .604 r
F P
0 g
s
.71036 .59136 m .69122 .58697 L .68605 .5876 L p .719 .756 .882 r
F P
0 g
s
.60168 .63079 m .60637 .62992 L .6097 .62872 L p .463 .89 .849 r
F P
0 g
s
.60302 .62996 m .60409 .62888 L p .60331 .62944 L .571 .905 .668 r
F P
0 g
s
.59126 .63543 m .60168 .63079 L .60302 .62996 L p .459 .887 .837 r
F P
0 g
s
.60302 .62996 m .58812 .6366 L .59126 .63543 L p .459 .887 .837 r
F P
0 g
s
.58812 .6366 m .60302 .62996 L .60017 .63138 L p 0 0 0 r
F P
0 g
s
.59705 .63341 m .60017 .63138 L .60302 .62996 L p 0 0 0 r
F P
0 g
s
.59857 .63285 m .59705 .63341 L p .59828 .6327 L 0 0 0 r
F P
0 g
s
.60302 .62996 m .59857 .63285 L p .59828 .6327 L 0 0 0 r
F P
0 g
s
.59857 .63285 m .59978 .63187 L p .59884 .63299 L 0 0 0 r
F P
0 g
s
.59583 .63655 m .59857 .63285 L p .59884 .63299 L 0 0 0 r
F P
0 g
s
.59857 .63285 m .60302 .62996 L p .60331 .62944 L .571 .905 .668 r
F P
0 g
s
.60302 .62996 m .60168 .63079 L p .60269 .63053 L .463 .89 .849 r
F P
0 g
s
.6097 .62872 m .60302 .62996 L p .60269 .63053 L .463 .89 .849 r
F P
0 g
s
.6202 .62048 m .61063 .62742 L .6097 .62872 L p .7 .977 .911 r
F P
0 g
s
.6097 .62872 m .62336 .61881 L .6202 .62048 L p .7 .977 .911 r
F P
0 g
s
.60302 .62996 m .6097 .62872 L .61063 .62742 L p .704 .982 .891 r
F P
0 g
s
.42308 .49552 m .42211 .49044 L .42177 .48979 L p .964 .891 .511 r
F P
0 g
s
.62147 .46204 m .62338 .457 L .62557 .45384 L p 0 0 .014 r
F P
0 g
s
.42138 .45272 m .42371 .46022 L .42336 .46322 L p .136 .156 .617 r
F P
0 g
s
.53592 .52861 m .54367 .52675 L .54625 .52505 L p .387 .034 .239 r
F P
0 g
s
.63283 .43841 m .62557 .45384 L .62765 .45017 L p .808 .934 .566 r
F P
0 g
s
.63129 .44186 m .62621 .45266 L .62557 .45384 L p 0 0 0 r
F P
0 g
s
.62557 .45384 m .63283 .43841 L .63129 .44186 L p 0 0 0 r
F P
0 g
s
.62557 .45384 m .62284 .46104 L .62147 .46204 L p 0 0 .014 r
F P
0 g
s
.31368 .55407 m .3206 .56407 L .32778 .56465 L p .692 .785 .922 r
F P
0 g
s
.32778 .56465 m .31794 .55034 L .31368 .55407 L p .692 .785 .922 r
F P
0 g
s
.35049 .55339 m .33068 .56108 L .32778 .56465 L p .72 .802 .915 r
F P
0 g
s
.32778 .56465 m .35605 .55368 L .35049 .55339 L p .72 .802 .915 r
F P
0 g
s
.31794 .55034 m .32778 .56465 L .33068 .56108 L p .716 .795 .913 r
F P
0 g
s
.50028 .5813 m .50025 .5828 L .50088 .5819 L p 0 0 .378 r
F P
0 g
s
.50088 .5819 m .50091 .57976 L .50028 .5813 L p 0 0 .378 r
F P
0 g
s
.61337 .47167 m .62147 .46204 L .62284 .46104 L p 0 0 .018 r
F P
0 g
s
.62284 .46104 m .61127 .47481 L .61337 .47167 L p 0 0 .018 r
F P
0 g
s
.62765 .45017 m .63273 .43937 L .63283 .43841 L p .808 .934 .566 r
F P
0 g
s
.61148 .48073 m .61127 .47481 L .61298 .47363 L p .098 0 .278 r
F P
0 g
s
.62109 .46398 m .61298 .47363 L .61127 .47481 L p .094 0 .272 r
F P
0 g
s
.61127 .47481 m .62284 .46104 L .62109 .46398 L p .094 0 .272 r
F P
0 g
s
.60929 .48164 m .60914 .4775 L .61127 .47481 L p .271 0 .305 r
F P
0 g
s
.61127 .47481 m .61148 .48073 L .60929 .48164 L p .271 0 .305 r
F P
0 g
s
.4149 .51545 m .41857 .51016 L .41835 .50776 L p .899 .821 .761 r
F P
0 g
s
.50725 .60535 m .50756 .60311 L .50666 .60088 L p 0 .04 .609 r
F P
0 g
s
.52565 .62645 m .53478 .63271 L .5365 .63406 L p .559 0 0 r
F P
0 g
s
.5365 .63406 m .52344 .62512 L .52565 .62645 L p .559 0 0 r
F P
0 g
s
.51155 .61218 m .51224 .61262 L .51335 .61446 L p .718 .308 0 r
F P
0 g
s
.51335 .61446 m .51237 .61385 L .51155 .61218 L p .718 .308 0 r
F P
0 g
s
.52173 .62357 m .51466 .6161 L .51335 .61446 L p .714 .204 0 r
F P
0 g
s
.51335 .61446 m .52344 .62512 L .52173 .62357 L p .714 .204 0 r
F P
0 g
s
.51237 .61385 m .51335 .61446 L .51466 .6161 L p .607 .126 0 r
F P
0 g
s
.40641 .40842 m .38563 .38681 L .39063 .38766 L p .496 .51 .801 r
F P
0 g
s
.40004 .37515 m .39063 .38766 L .38563 .38681 L p .496 .51 .801 r
F P
0 g
s
.38563 .38681 m .39902 .3689 L .40004 .37515 L p .496 .51 .801 r
F P
0 g
s
.38563 .38681 m .40641 .40842 L .40236 .40794 L p .416 .487 .824 r
F P
0 g
s
.35997 .36205 m .38287 .37992 L .38563 .38681 L p .533 .561 .83 r
F P
0 g
s
.39902 .3689 m .38563 .38681 L .38287 .37992 L p .533 .561 .83 r
F P
0 g
s
.58371 .50904 m .58156 .50297 L .58423 .50232 L p .415 .122 .357 r
F P
0 g
s
.59525 .49535 m .58423 .50232 L .58156 .50297 L p .421 .137 .373 r
F P
0 g
s
.58156 .50297 m .59729 .49302 L .59525 .49535 L p .421 .137 .373 r
F P
0 g
s
.58107 .50928 m .57958 .50502 L .58156 .50297 L p .459 .145 .345 r
F P
0 g
s
.58156 .50297 m .58371 .50904 L .58107 .50928 L p .459 .145 .345 r
F P
0 g
s
.42444 .47165 m .42336 .46322 L .42431 .46332 L p .024 .016 .507 r
F P
0 g
s
.42816 .45736 m .42431 .46332 L .42336 .46322 L p .025 .011 .501 r
F P
0 g
s
.42336 .46322 m .42886 .45471 L .42816 .45736 L p .025 .011 .501 r
F P
0 g
s
.42336 .46322 m .42444 .47165 L .4244 .47181 L p 0 0 .133 r
F P
0 g
s
.42886 .45471 m .42336 .46322 L .42371 .46022 L p .13 .151 .614 r
F P
0 g
s
.50477 .57147 m .50143 .57753 L .50091 .57976 L p .095 .028 .483 r
F P
0 g
s
.50091 .57976 m .50567 .57111 L .50477 .57147 L p .095 .028 .483 r
F P
0 g
s
.50154 .58034 m .50156 .57884 L .50091 .57976 L p 0 0 .387 r
F P
0 g
s
.50091 .57976 m .50088 .5819 L .50154 .58034 L p 0 0 .387 r
F P
0 g
s
.50567 .57111 m .50091 .57976 L .50156 .57884 L p 0 0 .225 r
F P
0 g
s
.42147 .49985 m .42026 .49496 L .41971 .49462 L p .973 .921 .604 r
F P
0 g
s
.57348 .63932 m .57127 .64108 L .56834 .64184 L p .21 0 0 r
F P
0 g
s
.81169 .58257 m .81234 .58125 L .82003 .58227 L p .671 .742 .904 r
F P
0 g
s
.50159 .58295 m .50164 .58431 L .50221 .58345 L p 0 0 .354 r
F P
0 g
s
.50221 .58345 m .50214 .58151 L .50159 .58295 L p 0 0 .354 r
F P
0 g
s
.77748 .57404 m .81298 .58007 L .82003 .58227 L p .672 .74 .902 r
F P
0 g
s
.82003 .58227 m .76933 .57366 L .77748 .57404 L p .672 .74 .902 r
F P
0 g
s
.82389 .57575 m .82003 .58227 L .81298 .58007 L p .667 .742 .906 r
F P
0 g
s
.76933 .57366 m .82003 .58227 L .81234 .58125 L p .676 .738 .898 r
F P
0 g
s
.34789 .35268 m .35848 .33616 L .3682 .33778 L p .566 .605 .852 r
F P
0 g
s
.4131 .51532 m .41835 .50776 L .41718 .50787 L p .938 .941 .767 r
F P
0 g
s
.4156 .50313 m .41718 .50787 L .41835 .50776 L p .932 .948 .777 r
F P
0 g
s
.41835 .50776 m .41609 .50098 L .4156 .50313 L p .932 .948 .777 r
F P
0 g
s
.41835 .50776 m .4131 .51532 L .4149 .51545 L p .899 .821 .761 r
F P
0 g
s
.42069 .50149 m .41852 .50581 L .41835 .50776 L p .967 .936 .673 r
F P
0 g
s
.41609 .50098 m .41835 .50776 L .41852 .50581 L p .964 .937 .696 r
F P
0 g
s
.52051 .62443 m .52173 .62357 L .52344 .62512 L p .837 .369 .005 r
F P
0 g
s
.52344 .62512 m .52171 .62636 L .52051 .62443 L p .837 .369 .005 r
F P
0 g
s
.53426 .633 m .52512 .62674 L .52344 .62512 L p .751 .243 .004 r
F P
0 g
s
.52344 .62512 m .5365 .63406 L .53426 .633 L p .751 .243 .004 r
F P
0 g
s
.52171 .62636 m .52344 .62512 L .52512 .62674 L p .727 .197 0 r
F P
0 g
s
.67535 .59714 m .66153 .59434 L .65734 .59554 L p .759 .786 .875 r
F P
0 g
s
.65179 .60684 m .65867 .59804 L .65734 .59554 L p .766 .801 .882 r
F P
0 g
s
.65734 .59554 m .6475 .60812 L .65179 .60684 L p .766 .801 .882 r
F P
0 g
s
.53916 .63474 m .5499 .63883 L .55186 .63991 L p .56 0 0 r
F P
0 g
s
.55186 .63991 m .5365 .63406 L .53916 .63474 L p .56 0 0 r
F P
0 g
s
.50435 .57474 m .50154 .58034 L .50088 .5819 L p 0 0 .17 r
F P
0 g
s
.50088 .5819 m .5049 .57391 L .50435 .57474 L p 0 0 .17 r
F P
0 g
s
.51466 .6161 m .51398 .61568 L .51237 .61385 L p .607 .126 0 r
F P
0 g
s
.77209 .58304 m .77453 .57913 L .76756 .57685 L p .679 .74 .897 r
F P
0 g
s
.76756 .57685 m .76409 .58245 L .77209 .58304 L p .679 .74 .897 r
F P
0 g
s
.61063 .62742 m .60596 .62828 L .60302 .62996 L p .704 .982 .891 r
F P
0 g
s
.55044 .52257 m .54745 .52349 L .54625 .52505 L p .404 .052 .251 r
F P
0 g
s
.36085 .55387 m .37584 .54661 L .37749 .54331 L p .75 .788 .883 r
F P
0 g
s
.37749 .54331 m .35605 .55368 L .36085 .55387 L p .75 .788 .883 r
F P
0 g
s
.41617 .42621 m .40739 .41337 L .40641 .40842 L p .337 .398 .777 r
F P
0 g
s
.58423 .50232 m .58574 .50656 L .58371 .50904 L p .415 .122 .357 r
F P
0 g
s
.40738 .52396 m .41297 .51792 L .4131 .51532 L p .864 .818 .802 r
F P
0 g
s
.71042 .35056 m .70112 .33024 L .69176 .33046 L p .79 .794 .856 r
F P
0 g
s
.51059 .55499 m .50552 .56184 L .50515 .56433 L p .324 .151 .485 r
F P
0 g
s
.6357 .83708 m .59466 .84427 L .58193 .83672 L p .658 .665 .846 r
F P
0 g
s
.52612 .53698 m .52231 .54123 L .52314 .54233 L p .387 .076 .311 r
F P
0 g
s
.52314 .54233 m .52859 .53626 L .52612 .53698 L p .387 .076 .311 r
F P
0 g
s
.63273 .43937 m .63755 .43263 L .63971 .42878 L p .808 .936 .57 r
F P
0 g
s
.65561 .39845 m .66978 .38637 L .67287 .38054 L p .881 .896 .837 r
F P
0 g
s
.50156 .57884 m .50489 .57278 L .50567 .57111 L p 0 0 .225 r
F P
0 g
s
.42448 .47832 m .42455 .4739 L .42444 .47165 L p .814 .662 .113 r
F P
0 g
s
.63431 .60876 m .64373 .60971 L .6475 .60812 L p .78 .87 .914 r
F P
0 g
s
.6475 .60812 m .63405 .60675 L .63431 .60876 L p .78 .87 .914 r
F P
0 g
s
.6537 .59719 m .64682 .60601 L .6475 .60812 L p .787 .84 .892 r
F P
0 g
s
.6475 .60812 m .65734 .59554 L .6537 .59719 L p .787 .84 .892 r
F P
0 g
s
.63405 .60675 m .6475 .60812 L .64682 .60601 L p .81 .851 .88 r
F P
0 g
s
.29369 .31966 m .30622 .29744 L .32044 .29919 L p .593 .641 .867 r
F P
0 g
s
.50274 .58202 m .50269 .58066 L .50214 .58151 L p 0 0 .345 r
F P
0 g
s
.50214 .58151 m .50221 .58345 L .50274 .58202 L p 0 0 .345 r
F P
0 g
s
.50617 .57351 m .50214 .58151 L .50269 .58066 L p 0 0 .171 r
F P
0 g
s
.61298 .47363 m .61313 .47777 L .61148 .48073 L p .098 0 .278 r
F P
0 g
s
.52571 .79033 m .52189 .83867 L .51503 .8307 L p .715 .68 .814 r
F P
0 g
s
.47555 .82682 m .51503 .8307 L .52189 .83867 L p .716 .68 .814 r
F P
0 g
s
.52189 .83867 m .46558 .83315 L .47555 .82682 L p .716 .68 .814 r
F P
0 g
s
.53312 .79743 m .53038 .83127 L .52189 .83867 L p .689 .656 .813 r
F P
0 g
s
.52189 .83867 m .52571 .79033 L .53312 .79743 L p .689 .656 .813 r
F P
0 g
s
.58193 .83672 m .52189 .83867 L .53038 .83127 L p .689 .656 .813 r
F P
0 g
s
.42371 .46022 m .42755 .45425 L .42886 .45471 L p .13 .151 .614 r
F P
0 g
s
.81234 .58125 m .77686 .57523 L .76933 .57366 L p .676 .738 .898 r
F P
0 g
s
.62621 .45266 m .6243 .4577 L .62284 .46104 L p 0 0 0 r
F P
0 g
s
.50201 .58544 m .50305 .59008 L .50371 .59008 L p 0 .036 .543 r
F P
0 g
s
.50371 .59008 m .50221 .58345 L .50201 .58544 L p 0 .036 .543 r
F P
0 g
s
.69858 .35875 m .67592 .37355 L .67287 .38054 L p .825 .808 .834 r
F P
0 g
s
.33068 .56108 m .32382 .55105 L .31794 .55034 L p .716 .795 .913 r
F P
0 g
s
.73103 .57743 m .75757 .58262 L .76409 .58245 L p .687 .739 .891 r
F P
0 g
s
.76409 .58245 m .72615 .57503 L .73103 .57743 L p .687 .739 .891 r
F P
0 g
s
.76131 .57662 m .75889 .58054 L .76409 .58245 L p .68 .741 .897 r
F P
0 g
s
.76409 .58245 m .76756 .57685 L .76131 .57662 L p .68 .741 .897 r
F P
0 g
s
.72615 .57503 m .76409 .58245 L .75889 .58054 L p .687 .739 .89 r
F P
0 g
s
.59936 .49025 m .60929 .48164 L .61148 .48073 L p .268 0 .299 r
F P
0 g
s
.61148 .48073 m .59729 .49302 L .59936 .49025 L p .268 0 .299 r
F P
0 g
s
.53281 .6347 m .53426 .633 L .5365 .63406 L p .799 .336 .137 r
F P
0 g
s
.5365 .63406 m .53443 .63651 L .53281 .6347 L p .799 .336 .137 r
F P
0 g
s
.54924 .63945 m .53849 .63536 L .5365 .63406 L p .683 .208 .116 r
F P
0 g
s
.5365 .63406 m .55186 .63991 L .54924 .63945 L p .683 .208 .116 r
F P
0 g
s
.53443 .63651 m .5365 .63406 L .53849 .63536 L p .678 .178 .05 r
F P
0 g
s
.63283 .43841 m .63971 .42878 L .6388 .42781 L p .967 .936 .675 r
F P
0 g
s
.63928 .41591 m .6388 .42781 L .63971 .42878 L p .967 .936 .677 r
F P
0 g
s
.63971 .42878 m .64041 .41179 L .63928 .41591 L p .967 .936 .677 r
F P
0 g
s
.63971 .42878 m .63283 .43841 L .63273 .43937 L p .808 .936 .57 r
F P
0 g
s
.64041 .41179 m .63971 .42878 L .64166 .42434 L p .931 .925 .781 r
F P
0 g
s
.41852 .50581 m .41694 .50106 L .41609 .50098 L p .964 .937 .696 r
F P
0 g
s
.50441 .56672 m .50477 .57147 L .50567 .57111 L p .062 0 .391 r
F P
0 g
s
.50567 .57111 m .50515 .56433 L .50441 .56672 L p .062 0 .391 r
F P
0 g
s
.52512 .62674 m .5239 .62761 L .52171 .62636 L p .727 .197 0 r
F P
0 g
s
.38287 .37992 m .39222 .36736 L .39902 .3689 L p .533 .561 .83 r
F P
0 g
s
.50515 .56433 m .5124 .55453 L .51059 .55499 L p .324 .151 .485 r
F P
0 g
s
.50658 .56863 m .50622 .56388 L .50515 .56433 L p .165 .013 .416 r
F P
0 g
s
.50515 .56433 m .50567 .57111 L .50658 .56863 L p .165 .013 .416 r
F P
0 g
s
.5124 .55453 m .50515 .56433 L .50622 .56388 L p .113 0 .289 r
F P
0 g
s
.54625 .52505 m .55053 .52374 L .55044 .52257 L p .404 .052 .251 r
F P
0 g
s
.4131 .51532 m .4051 .52397 L .40738 .52396 L p .864 .818 .802 r
F P
0 g
s
.42431 .46332 m .42507 .46922 L .42444 .47165 L p .024 .016 .507 r
F P
0 g
s
.4051 .52397 m .4131 .51532 L .4114 .51556 L p .896 .924 .831 r
F P
0 g
s
.40937 .51078 m .4114 .51556 L .4131 .51532 L p .887 .933 .843 r
F P
0 g
s
.4131 .51532 m .41021 .50848 L .40937 .51078 L p .887 .933 .843 r
F P
0 g
s
.41718 .50787 m .4135 .51317 L .4131 .51532 L p .938 .941 .767 r
F P
0 g
s
.41021 .50848 m .4131 .51532 L .4135 .51317 L p .932 .936 .78 r
F P
0 g
s
.54062 .53376 m .54625 .52505 L .54367 .52675 L p .324 0 .165 r
F P
0 g
s
.54225 .5322 m .54619 .52611 L .54625 .52505 L p .358 0 .186 r
F P
0 g
s
.54625 .52505 m .54062 .53376 L .54225 .5322 L p .358 0 .186 r
F P
0 g
s
.55053 .52374 m .54625 .52505 L .54619 .52611 L p .37 0 .187 r
F P
0 g
s
.59941 .4981 m .59729 .49302 L .59968 .4919 L p .366 .124 .41 r
F P
0 g
s
.60962 .48329 m .59968 .4919 L .59729 .49302 L p .366 .125 .41 r
F P
0 g
s
.59729 .49302 m .61148 .48073 L .60962 .48329 L p .366 .125 .41 r
F P
0 g
s
.59672 .4989 m .59525 .49535 L .59729 .49302 L p .439 .159 .389 r
F P
0 g
s
.59729 .49302 m .59941 .4981 L .59672 .4989 L p .439 .159 .389 r
F P
0 g
s
.39063 .38766 m .4052 .40281 L .40641 .40842 L p .496 .51 .801 r
F P
0 g
s
.81298 .58007 m .81567 .5755 L .82389 .57575 L p .667 .742 .906 r
F P
0 g
s
.39644 .53334 m .40454 .52676 L .4051 .52397 L p .825 .811 .837 r
F P
0 g
s
.5516 .5222 m .55468 .52117 L .55494 .52227 L p .416 .064 .256 r
F P
0 g
s
.55494 .52227 m .55053 .52374 L .5516 .5222 L p .416 .064 .256 r
F P
0 g
s
.505 .57697 m .50274 .58202 L .50221 .58345 L p 0 0 .116 r
F P
0 g
s
.50221 .58345 m .50544 .57623 L .505 .57697 L p 0 0 .116 r
F P
0 g
s
.50381 .58821 m .50275 .58356 L .50221 .58345 L p 0 0 .501 r
F P
0 g
s
.50221 .58345 m .50371 .59008 L .50381 .58821 L p 0 0 .501 r
F P
0 g
s
.50544 .57623 m .50221 .58345 L .50275 .58356 L p 0 0 .416 r
F P
0 g
s
.52551 .54118 m .52932 .53692 L .52859 .53626 L p .24 0 .184 r
F P
0 g
s
.52859 .53626 m .52314 .54233 L .52551 .54118 L p .24 0 .184 r
F P
0 g
s
.54062 .53376 m .52859 .53626 L .52932 .53692 L p .284 0 .13 r
F P
0 g
s
.53972 .53283 m .53131 .53459 L .52859 .53626 L p .306 0 .184 r
F P
0 g
s
.52859 .53626 m .54062 .53376 L .53972 .53283 L p .306 0 .184 r
F P
0 g
s
.54367 .52675 m .53972 .53283 L .54062 .53376 L p .324 0 .165 r
F P
0 g
s
.34489 .54519 m .35049 .55339 L .35605 .55368 L p .715 .806 .922 r
F P
0 g
s
.35605 .55368 m .34809 .54196 L .34489 .54519 L p .715 .806 .922 r
F P
0 g
s
.37322 .54327 m .35819 .55054 L .35605 .55368 L p .753 .828 .909 r
F P
0 g
s
.35605 .55368 m .37749 .54331 L .37322 .54327 L p .753 .828 .909 r
F P
0 g
s
.34809 .54196 m .35605 .55368 L .35819 .55054 L p .747 .818 .908 r
F P
0 g
s
.42444 .47165 m .42434 .47797 L .42448 .47832 L p .814 .662 .113 r
F P
0 g
s
.50269 .58066 m .50551 .57506 L .50617 .57351 L p 0 0 .171 r
F P
0 g
s
.42434 .47797 m .42444 .47165 L .42515 .4716 L p 0 0 .384 r
F P
0 g
s
.42869 .46662 m .42515 .4716 L .42444 .47165 L p 0 0 .372 r
F P
0 g
s
.42444 .47165 m .42951 .46453 L .42869 .46662 L p 0 0 .372 r
F P
0 g
s
.42951 .46453 m .42444 .47165 L .42507 .46922 L p .007 0 .494 r
F P
0 g
s
.5825 .63939 m .58511 .63741 L .58812 .6366 L p .242 0 0 r
F P
0 g
s
.58812 .6366 m .5844 .63943 L .5825 .63939 L p .242 0 0 r
F P
0 g
s
.60017 .63138 m .58973 .63603 L .58812 .6366 L p 0 0 0 r
F P
0 g
s
.64166 .42434 m .64216 .41244 L .64041 .41179 L p .931 .925 .781 r
F P
0 g
s
.55477 .63987 m .5663 .64122 L .56834 .64184 L p .45 0 0 r
F P
0 g
s
.56834 .64184 m .55186 .63991 L .55477 .63987 L p .45 0 0 r
F P
0 g
s
.38125 .54334 m .39245 .53639 L .39351 .53337 L p .786 .8 .864 r
F P
0 g
s
.39351 .53337 m .37749 .54331 L .38125 .54334 L p .786 .8 .864 r
F P
0 g
s
.41896 .42677 m .40641 .40842 L .41005 .4093 L p .454 .448 .762 r
F P
0 g
s
.41862 .39951 m .41005 .4093 L .40641 .40842 L p .454 .448 .762 r
F P
0 g
s
.40641 .40842 m .41862 .39441 L .41862 .39951 L p .454 .448 .762 r
F P
0 g
s
.40641 .40842 m .41896 .42677 L .41617 .42621 L p .337 .398 .777 r
F P
0 g
s
.41862 .39441 m .40641 .40842 L .4052 .40281 L p .496 .509 .801 r
F P
0 g
s
.4051 .52397 m .39351 .53337 L .39644 .53334 L p .825 .811 .837 r
F P
0 g
s
.65259 .3978 m .67287 .38054 L .66842 .38007 L p .864 .82 .803 r
F P
0 g
s
.66096 .36426 m .66842 .38007 L .67287 .38054 L p .864 .82 .803 r
F P
0 g
s
.67287 .38054 m .66226 .35792 L .66096 .36426 L p .864 .82 .803 r
F P
0 g
s
.67287 .38054 m .65259 .3978 L .65561 .39845 L p .881 .896 .837 r
F P
0 g
s
.66226 .35792 m .67287 .38054 L .67592 .37355 L p .825 .808 .834 r
F P
0 g
s
.53849 .63536 m .53704 .63707 L .53443 .63651 L p .678 .178 .05 r
F P
0 g
s
.42398 .48291 m .42439 .47985 L .42434 .47797 L p .902 .785 .298 r
F P
0 g
s
.52143 .54228 m .52004 .54379 L .52116 .54448 L p .37 .079 .334 r
F P
0 g
s
.52116 .54448 m .52314 .54233 L .52143 .54228 L p .37 .079 .334 r
F P
0 g
s
.72751 .58314 m .73103 .57743 L .72615 .57503 L p .696 .738 .883 r
F P
0 g
s
.72615 .57503 m .72114 .58319 L .72751 .58314 L p .696 .738 .883 r
F P
0 g
s
.75889 .58054 m .73233 .57534 L .72615 .57503 L p .687 .739 .89 r
F P
0 g
s
.54771 .64169 m .54924 .63945 L .55186 .63991 L p .713 .268 .194 r
F P
0 g
s
.55186 .63991 m .54969 .64311 L .54771 .64169 L p .713 .268 .194 r
F P
0 g
s
.56554 .64205 m .55399 .6407 L .55186 .63991 L p .577 .125 .142 r
F P
0 g
s
.55186 .63991 m .56834 .64184 L .56554 .64205 L p .577 .125 .142 r
F P
0 g
s
.54969 .64311 m .55186 .63991 L .55399 .6407 L p .573 .108 .112 r
F P
0 g
s
.64682 .60601 m .6374 .60504 L .63405 .60675 L p .81 .851 .88 r
F P
0 g
s
.50622 .56388 m .5113 .55702 L .5124 .55453 L p .113 0 .289 r
F P
0 g
s
.23677 .57019 m .27289 .56348 L .2786 .55906 L p .676 .768 .92 r
F P
0 g
s
.2786 .55906 m .22691 .56868 L .23677 .57019 L p .676 .768 .92 r
F P
0 g
s
.51681 .5475 m .51235 .55269 L .5124 .55453 L p .348 .109 .403 r
F P
0 g
s
.4135 .51317 m .41148 .50838 L .41021 .50848 L p .932 .936 .78 r
F P
0 g
s
.51953 .54439 m .51787 .54622 L .51879 .5471 L p .361 .086 .354 r
F P
0 g
s
.51879 .5471 m .52116 .54448 L .51953 .54439 L p .361 .086 .354 r
F P
0 g
s
.50396 .59238 m .50601 .59993 L .50666 .60088 L p 0 0 .499 r
F P
0 g
s
.50666 .60088 m .50371 .59008 L .50396 .59238 L p 0 0 .499 r
F P
0 g
s
.55695 .52033 m .56571 .51691 L .56746 .51738 L p .438 .09 .276 r
F P
0 g
s
.56746 .51738 m .55494 .52227 L .55695 .52033 L p .438 .09 .276 r
F P
0 g
s
.54685 .53184 m .55053 .52374 L .55082 .52467 L p .389 .007 .189 r
F P
0 g
s
.55391 .52364 m .55082 .52467 L .55053 .52374 L p .38 .003 .191 r
F P
0 g
s
.55053 .52374 m .55494 .52227 L .55391 .52364 L p .38 .003 .191 r
F P
0 g
s
.54685 .53184 m .55053 .52374 L .54919 .52519 L p .35 0 .171 r
F P
0 g
s
.54619 .52611 m .54919 .52519 L .55053 .52374 L p .37 0 .187 r
F P
0 g
s
.59968 .4919 m .60116 .49545 L .59941 .4981 L p .366 .124 .41 r
F P
0 g
s
.39351 .53337 m .4051 .52397 L .4027 .52422 L p .845 .893 .873 r
F P
0 g
s
.39997 .51912 m .4027 .52422 L .4051 .52397 L p .836 .902 .885 r
F P
0 g
s
.4051 .52397 m .40121 .51668 L .39997 .51912 L p .836 .902 .885 r
F P
0 g
s
.4114 .51556 m .40579 .52162 L .4051 .52397 L p .896 .924 .831 r
F P
0 g
s
.40121 .51668 m .4051 .52397 L .40579 .52162 L p .885 .913 .839 r
F P
0 g
s
.69568 .57974 m .71578 .58388 L .72114 .58319 L p .709 .742 .877 r
F P
0 g
s
.72114 .58319 m .69241 .57726 L .69568 .57974 L p .709 .742 .877 r
F P
0 g
s
.72103 .57539 m .71753 .58111 L .72114 .58319 L p .699 .742 .884 r
F P
0 g
s
.72114 .58319 m .72615 .57503 L .72103 .57539 L p .699 .742 .884 r
F P
0 g
s
.69241 .57726 m .72114 .58319 L .71753 .58111 L p .711 .741 .875 r
F P
0 g
s
.5124 .55453 m .51879 .5471 L .51681 .5475 L p .348 .109 .403 r
F P
0 g
s
.57182 .78928 m .58193 .83672 L .57248 .82989 L p .689 .656 .813 r
F P
0 g
s
.53038 .83127 m .57248 .82989 L .58193 .83672 L p .689 .656 .813 r
F P
0 g
s
.58111 .79507 m .58813 .82832 L .58193 .83672 L p .658 .636 .817 r
F P
0 g
s
.58193 .83672 m .57182 .78928 L .58111 .79507 L p .658 .636 .817 r
F P
0 g
s
.6407 .82635 m .58193 .83672 L .58813 .82832 L p .658 .636 .817 r
F P
0 g
s
.58193 .83672 m .6407 .82635 L .6357 .83708 L p .658 .665 .846 r
F P
0 g
s
.50275 .58356 m .50501 .57851 L .50544 .57623 L p 0 0 .416 r
F P
0 g
s
.42507 .46922 m .42861 .46423 L .42951 .46453 L p .007 0 .494 r
F P
0 g
s
.42434 .47797 m .42375 .48236 L .42398 .48291 L p .902 .785 .298 r
F P
0 g
s
.62683 .6172 m .63431 .60876 L .63405 .60675 L p .8 .882 .905 r
F P
0 g
s
.63405 .60675 m .62336 .61881 L .62683 .6172 L p .8 .882 .905 r
F P
0 g
s
.36876 .53647 m .37322 .54327 L .37749 .54331 L p .746 .834 .918 r
F P
0 g
s
.37749 .54331 m .37115 .53359 L .36876 .53647 L p .746 .834 .918 r
F P
0 g
s
.39026 .53352 m .37904 .54049 L .37749 .54331 L p .795 .859 .897 r
F P
0 g
s
.37749 .54331 m .39351 .53337 L .39026 .53352 L p .795 .859 .897 r
F P
0 g
s
.37115 .53359 m .37749 .54331 L .37904 .54049 L p .787 .848 .897 r
F P
0 g
s
.42343 .48572 m .42383 .48391 L .42375 .48236 L p .943 .852 .421 r
F P
0 g
s
.45353 .84069 m .4196 .83312 L .41702 .82223 L p .723 .721 .848 r
F P
0 g
s
.41702 .82223 m .46558 .83315 L .45353 .84069 L p .723 .721 .848 r
F P
0 g
s
.52932 .53692 m .53774 .53517 L .54062 .53376 L p .284 0 .13 r
F P
0 g
s
.38671 .52778 m .39026 .53352 L .39351 .53337 L p .788 .867 .908 r
F P
0 g
s
.39351 .53337 m .38845 .52516 L .38671 .52778 L p .788 .867 .908 r
F P
0 g
s
.4027 .52422 m .39458 .53081 L .39351 .53337 L p .845 .893 .873 r
F P
0 g
s
.38845 .52516 m .39351 .53337 L .39458 .53081 L p .835 .881 .876 r
F P
0 g
s
.58973 .63603 m .58713 .63801 L .5844 .63943 L p 0 0 0 r
F P
0 g
s
.4052 .40281 m .41374 .39298 L .41862 .39441 L p .496 .509 .801 r
F P
0 g
s
.50453 .58498 m .50381 .58821 L .50371 .59008 L p 0 0 .207 r
F P
0 g
s
.50371 .59008 m .50475 .58548 L .50453 .58498 L p 0 0 .207 r
F P
0 g
s
.50622 .59883 m .50416 .59126 L .50371 .59008 L p 0 0 .313 r
F P
0 g
s
.50371 .59008 m .50666 .60088 L .50622 .59883 L p 0 0 .313 r
F P
0 g
s
.50475 .58548 m .50371 .59008 L .50416 .59126 L p 0 0 .361 r
F P
0 g
s
.42375 .48236 m .42434 .47797 L .42491 .47775 L p 0 0 .257 r
F P
0 g
s
.42812 .47343 m .42491 .47775 L .42434 .47797 L p 0 0 .238 r
F P
0 g
s
.42434 .47797 m .42893 .47179 L .42812 .47343 L p 0 0 .238 r
F P
0 g
s
.42515 .4716 m .42508 .47603 L .42434 .47797 L p 0 0 .384 r
F P
0 g
s
.42893 .47179 m .42434 .47797 L .42508 .47603 L p 0 0 .357 r
F P
0 g
s
.4239 .44163 m .41911 .43084 L .41896 .42677 L p .241 .284 .707 r
F P
0 g
s
.61447 .62127 m .6202 .62048 L .62336 .61881 L p .733 .975 .925 r
F P
0 g
s
.62336 .61881 m .61518 .61994 L .61447 .62127 L p .733 .975 .925 r
F P
0 g
s
.63109 .6087 m .6236 .61715 L .62336 .61881 L p .821 .947 .905 r
F P
0 g
s
.62336 .61881 m .63405 .60675 L .63109 .6087 L p .821 .947 .905 r
F P
0 g
s
.61518 .61994 m .62336 .61881 L .6236 .61715 L p .84 .961 .886 r
F P
0 g
s
.6388 .42781 m .63397 .43455 L .63283 .43841 L p .967 .936 .675 r
F P
0 g
s
.35819 .55054 m .35264 .54232 L .34809 .54196 L p .747 .818 .908 r
F P
0 g
s
.55399 .6407 m .55248 .64294 L .54969 .64311 L p .573 .108 .112 r
F P
0 g
s
.52252 .54417 m .52391 .54267 L .52314 .54233 L p .087 0 .075 r
F P
0 g
s
.52314 .54233 m .52116 .54448 L .52252 .54417 L p .087 0 .075 r
F P
0 g
s
.53191 .54156 m .52314 .54233 L .52391 .54267 L p .118 0 0 r
F P
0 g
s
.53165 .54063 m .52551 .54118 L .52314 .54233 L p .116 0 0 r
F P
0 g
s
.52314 .54233 m .53191 .54156 L .53165 .54063 L p .116 0 0 r
F P
0 g
s
.5537 .52958 m .55494 .52227 L .55692 .5225 L p .419 .039 .208 r
F P
0 g
s
.5657 .51908 m .55692 .5225 L .55494 .52227 L p .426 .07 .256 r
F P
0 g
s
.55494 .52227 m .56746 .51738 L .5657 .51908 L p .426 .07 .256 r
F P
0 g
s
.55304 .52876 m .55391 .52364 L .55494 .52227 L p .397 .021 .203 r
F P
0 g
s
.55494 .52227 m .5537 .52958 L .55304 .52876 L p .397 .021 .203 r
F P
0 g
s
.42318 .48494 m .42343 .48572 L p .42374 .48254 L .943 .852 .421 r
F P
0 g
s
.42318 .48494 m .42373 .48428 L p .42299 .48576 L 0 0 .119 r
F P
0 g
s
.42298 .48578 m .42319 .48679 L p .42318 .485 L .95 .862 .443 r
F P
0 g
s
.42318 .48494 m .42298 .48578 L p .42318 .485 L .95 .862 .443 r
F P
0 g
s
.42298 .48578 m .4235 .48516 L p .42273 .48673 L 0 0 .077 r
F P
0 g
s
.4227 .48679 m .42293 .48777 L p .42297 .48586 L .958 .879 .481 r
F P
0 g
s
.42298 .48578 m .4227 .48679 L p .42297 .48586 L .958 .879 .481 r
F P
0 g
s
.42211 .49044 m .42276 .48835 L .4227 .48679 L p .964 .895 .52 r
F P
0 g
s
.4227 .48679 m .42177 .48979 L .42211 .49044 L p .964 .895 .52 r
F P
0 g
s
.4227 .48679 m .4231 .4865 L p .42194 .48938 L 0 0 .02 r
F P
0 g
s
.42177 .48979 m .4227 .48679 L p .42194 .48938 L 0 0 .02 r
F P
0 g
s
.4227 .48679 m .42298 .48578 L p .42273 .48673 L 0 0 .077 r
F P
0 g
s
.42298 .48578 m .42318 .48494 L p .42299 .48576 L 0 0 .119 r
F P
0 g
s
.42375 .48236 m .42318 .48494 L p .42374 .48254 L .943 .852 .421 r
F P
0 g
s
.54919 .52519 m .54661 .53086 L .54685 .53184 L p .35 0 .171 r
F P
0 g
s
.51503 .8307 m .51764 .79685 L .52571 .79033 L p .715 .68 .814 r
F P
0 g
s
.7753 .57797 m .77609 .57689 L .76868 .5753 L p .682 .735 .891 r
F P
0 g
s
.76868 .5753 m .76756 .57685 L .7753 .57797 L p .682 .735 .891 r
F P
0 g
s
.69122 .58697 m .69568 .57974 L .69241 .57726 L p .722 .743 .868 r
F P
0 g
s
.69241 .57726 m .68605 .5876 L .69122 .58697 L p .722 .743 .868 r
F P
0 g
s
.42319 .48679 m .42333 .48621 L .42318 .48494 L p .95 .862 .443 r
F P
0 g
s
.51163 .56141 m .5124 .55453 L .5113 .55702 L p 0 0 .116 r
F P
0 g
s
.5129 .559 m .51343 .5542 L .5124 .55453 L p .029 0 .161 r
F P
0 g
s
.5124 .55453 m .51163 .56141 L .5129 .559 L p .029 0 .161 r
F P
0 g
s
.51879 .5471 m .5124 .55453 L .51343 .5542 L p .003 0 .076 r
F P
0 g
s
.40579 .52162 m .40308 .51651 L .40121 .51668 L p .885 .913 .839 r
F P
0 g
s
.41005 .4093 m .41885 .42216 L .41896 .42677 L p .454 .448 .762 r
F P
0 g
s
.51968 .54704 m .52135 .54521 L .52116 .54448 L p 0 0 .006 r
F P
0 g
s
.52116 .54448 m .51879 .5471 L .51968 .54704 L p 0 0 .006 r
F P
0 g
s
.52666 .54542 m .52116 .54448 L .52135 .54521 L p .028 0 0 r
F P
0 g
s
.52637 .54483 m .52252 .54417 L .52116 .54448 L p .04 0 0 r
F P
0 g
s
.52116 .54448 m .52666 .54542 L .52637 .54483 L p .04 0 0 r
F P
0 g
s
.42293 .48777 m .42312 .48706 L .42298 .48578 L p .958 .879 .481 r
F P
0 g
s
.6666 .58593 m .68162 .58879 L .68605 .5876 L p .742 .761 .868 r
F P
0 g
s
.68605 .5876 m .66459 .58351 L .6666 .58593 L p .742 .761 .868 r
F P
0 g
s
.68815 .5782 m .6837 .58544 L .68605 .5876 L p .73 .754 .871 r
F P
0 g
s
.68605 .5876 m .69241 .57726 L .68815 .5782 L p .73 .754 .871 r
F P
0 g
s
.66459 .58351 m .68605 .5876 L .6837 .58544 L p .747 .756 .859 r
F P
0 g
s
.55082 .52467 m .54825 .53034 L .54685 .53184 L p .389 .007 .189 r
F P
0 g
s
.67592 .37355 m .66853 .35769 L .66226 .35792 L p .825 .808 .834 r
F P
0 g
s
.5697 .51511 m .58107 .50928 L .58371 .50904 L p .45 .121 .315 r
F P
0 g
s
.58371 .50904 m .56746 .51738 L .5697 .51511 L p .45 .121 .315 r
F P
0 g
s
.51343 .5542 m .51791 .54899 L .51879 .5471 L p .003 0 .076 r
F P
0 g
s
.52056 .55061 m .51879 .5471 L .51791 .54899 L p 0 0 .008 r
F P
0 g
s
.52093 .54949 m .51968 .54704 L .51879 .5471 L p 0 0 0 r
F P
0 g
s
.51879 .5471 m .52056 .55061 L .52093 .54949 L p 0 0 0 r
F P
0 g
s
.57127 .64108 m .5825 .63939 L .5844 .63943 L p .235 0 0 r
F P
0 g
s
.5844 .63943 m .56834 .64184 L .57127 .64108 L p .235 0 0 r
F P
0 g
s
.71753 .58111 m .69742 .57695 L .69241 .57726 L p .711 .741 .875 r
F P
0 g
s
.5113 .55702 m .51075 .56184 L .51163 .56141 L p 0 0 .116 r
F P
0 g
s
.26951 .55768 m .23326 .56443 L .22691 .56868 L p .673 .775 .926 r
F P
0 g
s
.22691 .56868 m .2786 .55906 L .26951 .55768 L p .673 .775 .926 r
F P
0 g
s
.21666 .54761 m .22691 .56868 L .23326 .56443 L p .672 .77 .924 r
F P
0 g
s
.50756 .60311 m .51155 .61218 L .51237 .61385 L p 0 0 .379 r
F P
0 g
s
.51237 .61385 m .50666 .60088 L .50756 .60311 L p 0 0 .379 r
F P
0 g
s
.42318 .48494 m .42375 .48236 L .42428 .48193 L p 0 0 .149 r
F P
0 g
s
.42721 .47801 m .42428 .48193 L .42375 .48236 L p 0 0 .126 r
F P
0 g
s
.42375 .48236 m .42794 .47675 L .42721 .47801 L p 0 0 .126 r
F P
0 g
s
.42491 .47775 m .4245 .48082 L .42375 .48236 L p 0 0 .257 r
F P
0 g
s
.42794 .47675 m .42375 .48236 L .4245 .48082 L p 0 0 .22 r
F P
0 g
s
.78085 .56759 m .81694 .57306 L .82389 .57575 L p .67 .738 .901 r
F P
0 g
s
.82389 .57575 m .77237 .56793 L .78085 .56759 L p .67 .738 .901 r
F P
0 g
s
.82943 .56489 m .82389 .57575 L .81694 .57306 L p .665 .739 .906 r
F P
0 g
s
.77237 .56793 m .82389 .57575 L .81567 .5755 L p .671 .738 .901 r
F P
0 g
s
.42508 .47603 m .42829 .4717 L .42893 .47179 L p 0 0 .357 r
F P
0 g
s
.39458 .53081 m .39105 .52505 L .38845 .52516 L p .835 .881 .876 r
F P
0 g
s
.37904 .54049 m .37462 .53367 L .37115 .53359 L p .787 .848 .897 r
F P
0 g
s
.7343 .57173 m .76131 .57662 L .76756 .57685 L p .684 .735 .889 r
F P
0 g
s
.76756 .57685 m .72895 .56987 L .7343 .57173 L p .684 .735 .889 r
F P
0 g
s
.76272 .5745 m .76194 .57559 L .76756 .57685 L p .682 .735 .891 r
F P
0 g
s
.76756 .57685 m .76868 .5753 L .76272 .5745 L p .682 .735 .891 r
F P
0 g
s
.72895 .56987 m .76756 .57685 L .76194 .57559 L p .69 .73 .881 r
F P
0 g
s
.42582 .44219 m .41896 .42677 L .42167 .42763 L p .412 .38 .713 r
F P
0 g
s
.42976 .41995 m .42167 .42763 L .41896 .42677 L p .412 .38 .713 r
F P
0 g
s
.41896 .42677 m .43051 .41579 L .42976 .41995 L p .412 .38 .713 r
F P
0 g
s
.41896 .42677 m .42582 .44219 L .4239 .44163 L p .241 .284 .707 r
F P
0 g
s
.43051 .41579 m .41896 .42677 L .41885 .42216 L p .454 .448 .762 r
F P
0 g
s
.56393 .64454 m .56554 .64205 L .56834 .64184 L p .595 .158 .179 r
F P
0 g
s
.56834 .64184 m .56605 .64539 L .56393 .64454 L p .595 .158 .179 r
F P
0 g
s
.58163 .64034 m .57039 .64202 L .56834 .64184 L p .414 0 .091 r
F P
0 g
s
.56834 .64184 m .5844 .63943 L .58163 .64034 L p .414 0 .091 r
F P
0 g
s
.56605 .64539 m .56834 .64184 L .57039 .64202 L p .41 0 .078 r
F P
0 g
s
.61313 .47777 m .62078 .46805 L .62241 .46683 L p .088 0 .27 r
F P
0 g
s
.62241 .46683 m .61148 .48073 L .61313 .47777 L p .088 0 .27 r
F P
0 g
s
.50416 .59126 m .50488 .58805 L .50475 .58548 L p 0 0 .361 r
F P
0 g
s
.77686 .57523 m .77639 .57637 L .76868 .5753 L p .682 .734 .89 r
F P
0 g
s
.50489 .57278 m .50435 .57474 L .5049 .57391 L p 0 0 .031 r
F P
0 g
s
.5049 .57391 m .50567 .57111 L .50489 .57278 L p 0 0 .031 r
F P
0 g
s
.61293 .48526 m .61148 .48073 L .61328 .47932 L p .24 .059 .424 r
F P
0 g
s
.62093 .46959 m .61328 .47932 L .61148 .48073 L p .232 .048 .413 r
F P
0 g
s
.61148 .48073 m .62241 .46683 L .62093 .46959 L p .232 .048 .413 r
F P
0 g
s
.61062 .48647 m .60962 .48329 L .61148 .48073 L p .366 .126 .411 r
F P
0 g
s
.61148 .48073 m .61293 .48526 L .61062 .48647 L p .366 .126 .411 r
F P
0 g
s
.62078 .46805 m .62109 .46398 L .62284 .46104 L p .083 0 .262 r
F P
0 g
s
.81567 .5755 m .77962 .57004 L .77237 .56793 L p .671 .738 .901 r
F P
0 g
s
.57248 .82989 m .56535 .79669 L .57182 .78928 L p .689 .656 .813 r
F P
0 g
s
.62241 .46683 m .62284 .46104 L .62376 .45972 L p 0 0 .149 r
F P
0 g
s
.62853 .44936 m .62376 .45972 L .62284 .46104 L p 0 0 .133 r
F P
0 g
s
.62284 .46104 m .62966 .44624 L .62853 .44936 L p 0 0 .133 r
F P
0 g
s
.62284 .46104 m .62241 .46683 L .62078 .46805 L p .083 0 .262 r
F P
0 g
s
.62966 .44624 m .62284 .46104 L .6243 .4577 L p 0 0 0 r
F P
0 g
s
.66842 .38007 m .65419 .39216 L .65259 .3978 L p .864 .82 .803 r
F P
0 g
s
.55692 .5225 m .55606 .52762 L .5537 .52958 L p .419 .039 .208 r
F P
0 g
s
.58574 .50656 m .59672 .4989 L .59941 .4981 L p .431 .141 .37 r
F P
0 g
s
.59941 .4981 m .58371 .50904 L .58574 .50656 L p .431 .141 .37 r
F P
0 g
s
.42026 .49496 m .4217 .49158 L .42177 .48979 L p .969 .929 .62 r
F P
0 g
s
.4265 .48056 m .42373 .48428 L .42318 .48494 L p 0 0 .082 r
F P
0 g
s
.42318 .48494 m .42714 .47962 L .4265 .48056 L p 0 0 .082 r
F P
0 g
s
.42428 .48193 m .42387 .48374 L .42318 .48494 L p 0 0 .149 r
F P
0 g
s
.42714 .47962 m .42318 .48494 L .42387 .48374 L p 0 0 .114 r
F P
0 g
s
.6243 .4577 m .62907 .44734 L .62966 .44624 L p 0 0 0 r
F P
0 g
s
.57022 .52296 m .56746 .51738 L .57034 .51687 L p .461 .128 .314 r
F P
0 g
s
.58172 .51103 m .57034 .51687 L .56746 .51738 L p .477 .163 .355 r
F P
0 g
s
.56746 .51738 m .58371 .50904 L .58172 .51103 L p .477 .163 .355 r
F P
0 g
s
.56762 .52299 m .5657 .51908 L .56746 .51738 L p .48 .136 .305 r
F P
0 g
s
.56746 .51738 m .57022 .52296 L .56762 .52299 L p .48 .136 .305 r
F P
0 g
s
.50553 .59797 m .50622 .59883 L .50666 .60088 L p .833 .586 .036 r
F P
0 g
s
.50666 .60088 m .50567 .59967 L .50553 .59797 L p .833 .586 .036 r
F P
0 g
s
.51131 .6119 m .5073 .60282 L .50666 .60088 L p .856 .475 0 r
F P
0 g
s
.50666 .60088 m .51237 .61385 L .51131 .6119 L p .856 .475 0 r
F P
0 g
s
.50567 .59967 m .50666 .60088 L .5073 .60282 L p .754 .414 0 r
F P
0 g
s
.6236 .61715 m .61788 .61794 L .61518 .61994 L p .84 .961 .886 r
F P
0 g
s
.51398 .61568 m .52051 .62443 L .52171 .62636 L p .778 .311 0 r
F P
0 g
s
.52171 .62636 m .51237 .61385 L .51398 .61568 L p .778 .311 0 r
F P
0 g
s
.42621 .48151 m .4235 .48516 L .42298 .48578 L p 0 0 .052 r
F P
0 g
s
.42298 .48578 m .42684 .48056 L .42621 .48151 L p 0 0 .052 r
F P
0 g
s
.42373 .48428 m .42359 .48487 L .42298 .48578 L p 0 0 .119 r
F P
0 g
s
.42684 .48056 m .42298 .48578 L .42359 .48487 L p 0 0 .076 r
F P
0 g
s
.52391 .54267 m .53004 .54213 L .53191 .54156 L p .118 0 0 r
F P
0 g
s
.66153 .59434 m .6666 .58593 L .66459 .58351 L p .76 .765 .857 r
F P
0 g
s
.66459 .58351 m .65734 .59554 L .66153 .59434 L p .76 .765 .857 r
F P
0 g
s
.76868 .5753 m .76933 .57366 L .77686 .57523 L p .682 .734 .89 r
F P
0 g
s
.51075 .56184 m .50658 .56863 L .50567 .57111 L p 0 0 .232 r
F P
0 g
s
.50567 .57111 m .51163 .56141 L .51075 .56184 L p 0 0 .232 r
F P
0 g
s
.50579 .57211 m .50632 .57015 L .50567 .57111 L p 0 0 .065 r
F P
0 g
s
.50567 .57111 m .5049 .57391 L .50579 .57211 L p 0 0 .065 r
F P
0 g
s
.50632 .57015 m .5105 .56336 L .51163 .56141 L p 0 0 0 r
F P
0 g
s
.50927 .56521 m .50885 .56603 L p .50722 .56928 L 0 0 0 r
F P
0 g
s
.5049 .57391 m .50708 .56957 L p .50722 .56928 L 0 0 0 r
F P
0 g
s
.50708 .56957 m .50927 .56521 L p .50722 .56928 L 0 0 0 r
F P
0 g
s
.50567 .57111 m .50632 .57015 L p .50851 .56656 L 0 0 0 r
F P
0 g
s
.51163 .56141 m .50864 .56627 L p .50851 .56656 L 0 0 0 r
F P
0 g
s
.50864 .56627 m .50567 .57111 L p .50851 .56656 L 0 0 0 r
F P
0 g
s
.48234 .78518 m .46558 .83315 L .46167 .82453 L p .738 .705 .82 r
F P
0 g
s
.42764 .81684 m .46167 .82453 L .46558 .83315 L p .738 .705 .82 r
F P
0 g
s
.46558 .83315 m .41702 .82223 L .42764 .81684 L p .738 .705 .82 r
F P
0 g
s
.48733 .79326 m .47555 .82682 L .46558 .83315 L p .716 .68 .814 r
F P
0 g
s
.46558 .83315 m .48234 .78518 L .48733 .79326 L p .716 .68 .814 r
F P
0 g
s
.42574 .48292 m .4231 .4865 L .4227 .48679 L p 0 0 0 r
F P
0 g
s
.4227 .48679 m .42648 .48167 L .42574 .48292 L p 0 0 0 r
F P
0 g
s
.4235 .48516 m .42331 .48587 L .4227 .48679 L p 0 0 .077 r
F P
0 g
s
.42648 .48167 m .4227 .48679 L .42331 .48587 L p 0 0 .047 r
F P
0 g
s
.51791 .54899 m .51914 .55145 L .52056 .55061 L p 0 0 .008 r
F P
0 g
s
.6837 .58544 m .66867 .58257 L .66459 .58351 L p .747 .756 .859 r
F P
0 g
s
.73579 .56927 m .76296 .57405 L .76868 .5753 L p .689 .729 .881 r
F P
0 g
s
.76868 .5753 m .72987 .56848 L .73579 .56927 L p .689 .729 .881 r
F P
0 g
s
.76933 .57366 m .76868 .5753 L .76296 .57405 L p .681 .734 .89 r
F P
0 g
s
.73556 .56973 m .76272 .5745 L .76868 .5753 L p .689 .729 .881 r
F P
0 g
s
.76868 .5753 m .72987 .56848 L .73556 .56973 L p .689 .729 .881 r
F P
0 g
s
.76194 .57559 m .73492 .5707 L .72895 .56987 L p .69 .73 .881 r
F P
0 g
s
.60596 .62828 m .61447 .62127 L .61518 .61994 L p .741 .983 .908 r
F P
0 g
s
.61518 .61994 m .60302 .62996 L .60596 .62828 L p .741 .983 .908 r
F P
0 g
s
.5239 .62761 m .53281 .6347 L .53443 .63651 L p .792 .303 .04 r
F P
0 g
s
.53443 .63651 m .52171 .62636 L .5239 .62761 L p .792 .303 .04 r
F P
0 g
s
.4245 .48082 m .42743 .4769 L .42794 .47675 L p 0 0 .22 r
F P
0 g
s
.52135 .54521 m .52519 .54587 L .52666 .54542 L p .028 0 0 r
F P
0 g
s
.58696 .51333 m .58371 .50904 L .58649 .50799 L p .475 .204 .423 r
F P
0 g
s
.59748 .50032 m .58649 .50799 L .58371 .50904 L p .481 .215 .433 r
F P
0 g
s
.58371 .50904 m .59941 .4981 L .59748 .50032 L p .481 .215 .433 r
F P
0 g
s
.58399 .51404 m .58172 .51103 L .58371 .50904 L p .516 .212 .39 r
F P
0 g
s
.58371 .50904 m .58696 .51333 L .58399 .51404 L p .516 .212 .39 r
F P
0 g
s
.6429 .59596 m .6537 .59719 L .65734 .59554 L p .787 .812 .872 r
F P
0 g
s
.65734 .59554 m .64191 .59377 L .6429 .59596 L p .787 .812 .872 r
F P
0 g
s
.66107 .58501 m .65599 .59344 L .65734 .59554 L p .778 .79 .863 r
F P
0 g
s
.65734 .59554 m .66459 .58351 L .66107 .58501 L p .778 .79 .863 r
F P
0 g
s
.64191 .59377 m .65734 .59554 L .65599 .59344 L p .8 .797 .849 r
F P
0 g
s
.42177 .48979 m .41971 .49462 L .42026 .49496 L p .969 .929 .62 r
F P
0 g
s
.41885 .42216 m .42692 .41446 L .43051 .41579 L p .454 .448 .762 r
F P
0 g
s
.57039 .64202 m .56879 .6445 L .56605 .64539 L p .41 0 .078 r
F P
0 g
s
.64216 .41244 m .65067 .40265 L .65259 .3978 L p .931 .925 .782 r
F P
0 g
s
.61261 .62187 m .60409 .62888 L .60302 .62996 L p .59 .926 .719 r
F P
0 g
s
.60302 .62996 m .61518 .61994 L .61261 .62187 L p .59 .926 .719 r
F P
0 g
s
.61328 .47932 m .61429 .48248 L .61293 .48526 L p .24 .059 .424 r
F P
0 g
s
.57034 .51687 m .57229 .52077 L .57022 .52296 L p .461 .128 .314 r
F P
0 g
s
.53704 .63707 m .54771 .64169 L .54969 .64311 L p .712 .243 .135 r
F P
0 g
s
.54969 .64311 m .53443 .63651 L .53704 .63707 L p .712 .243 .135 r
F P
0 g
s
.42755 .45425 m .42543 .4455 L .42582 .44219 L p .131 .15 .613 r
F P
0 g
s
.51003 .6127 m .51131 .6119 L .51237 .61385 L p .946 .602 .199 r
F P
0 g
s
.51237 .61385 m .51056 .61499 L .51003 .6127 L p .946 .602 .199 r
F P
0 g
s
.52002 .62475 m .51349 .61599 L .51237 .61385 L p .895 .477 .175 r
F P
0 g
s
.51237 .61385 m .52171 .62636 L .52002 .62475 L p .895 .477 .175 r
F P
0 g
s
.51056 .61499 m .51237 .61385 L .51349 .61599 L p .884 .454 .084 r
F P
0 g
s
.41694 .50106 m .41947 .49661 L .41971 .49462 L p .958 .944 .709 r
F P
0 g
s
.41971 .49462 m .42177 .48979 L .42193 .48981 L p 0 0 0 r
F P
0 g
s
.42431 .48643 m .42193 .48981 L .42177 .48979 L p 0 0 0 r
F P
0 g
s
.42177 .48979 m .42517 .48495 L .42431 .48643 L p 0 0 0 r
F P
0 g
s
.4231 .4865 m .42245 .4886 L .42177 .48979 L p 0 0 .02 r
F P
0 g
s
.42517 .48495 m .42177 .48979 L .42245 .4886 L p 0 0 0 r
F P
0 g
s
.50551 .57506 m .505 .57697 L .50544 .57623 L p 0 0 0 r
F P
0 g
s
.50544 .57623 m .50617 .57351 L .50551 .57506 L p 0 0 0 r
F P
0 g
s
.77962 .57004 m .77748 .57404 L .76933 .57366 L p .676 .736 .895 r
F P
0 g
s
.60116 .49545 m .61062 .48647 L .61293 .48526 L p .366 .125 .41 r
F P
0 g
s
.61293 .48526 m .59941 .4981 L .60116 .49545 L p .366 .125 .41 r
F P
0 g
s
.5073 .60282 m .50661 .60198 L .50567 .59967 L p .754 .414 0 r
F P
0 g
s
.42387 .48374 m .42664 .48002 L .42714 .47962 L p 0 0 .114 r
F P
0 g
s
.58813 .82832 m .62932 .82101 L .6407 .82635 L p .658 .636 .817 r
F P
0 g
s
.81694 .57306 m .82079 .56546 L .82943 .56489 L p .665 .739 .906 r
F P
0 g
s
.58649 .50799 m .58877 .51099 L .58696 .51333 L p .475 .204 .423 r
F P
0 g
s
.51862 .62646 m .52002 .62475 L .52171 .62636 L p .915 .537 .286 r
F P
0 g
s
.52171 .62636 m .51971 .6288 L .51862 .62646 L p .915 .537 .286 r
F P
0 g
s
.53223 .63541 m .52332 .6283 L .52171 .62636 L p .828 .418 .266 r
F P
0 g
s
.52171 .62636 m .53443 .63651 L .53223 .63541 L p .828 .418 .266 r
F P
0 g
s
.51971 .6288 m .52171 .62636 L .52332 .6283 L p .834 .403 .212 r
F P
0 g
s
.42167 .42763 m .42648 .43843 L .42582 .44219 L p .412 .38 .713 r
F P
0 g
s
.76296 .57405 m .76342 .5729 L .76933 .57366 L p .681 .734 .89 r
F P
0 g
s
.62376 .45972 m .62345 .46377 L .62241 .46683 L p 0 0 .149 r
F P
0 g
s
.6019 .50163 m .59941 .4981 L .60174 .49668 L p .431 .213 .481 r
F P
0 g
s
.61121 .48768 m .60174 .49668 L .59941 .4981 L p .428 .209 .477 r
F P
0 g
s
.59941 .4981 m .61293 .48526 L .61121 .48768 L p .428 .209 .477 r
F P
0 g
s
.59923 .5028 m .59748 .50032 L .59941 .4981 L p .492 .228 .443 r
F P
0 g
s
.59941 .4981 m .6019 .50163 L .59923 .5028 L p .492 .228 .443 r
F P
0 g
s
.42359 .48487 m .4263 .48121 L .42684 .48056 L p 0 0 .076 r
F P
0 g
s
.76933 .57366 m .77237 .56793 L .77962 .57004 L p .676 .736 .895 r
F P
0 g
s
.73659 .56719 m .76392 .57185 L .76933 .57366 L p .682 .732 .888 r
F P
0 g
s
.76933 .57366 m .73031 .56701 L .73659 .56719 L p .682 .732 .888 r
F P
0 g
s
.77237 .56793 m .76933 .57366 L .76392 .57185 L p .675 .735 .895 r
F P
0 g
s
.73031 .56701 m .76933 .57366 L .76342 .5729 L p .688 .728 .88 r
F P
0 g
s
.62907 .44734 m .63129 .44186 L .63283 .43841 L p 0 0 0 r
F P
0 g
s
.50885 .56603 m .50579 .57211 L .5049 .57391 L p 0 0 0 r
F P
0 g
s
.53087 .63761 m .53223 .63541 L .53443 .63651 L p .838 .457 .329 r
F P
0 g
s
.53443 .63651 m .5325 .63966 L .53087 .63761 L p .838 .457 .329 r
F P
0 g
s
.54713 .64262 m .53644 .638 L .53443 .63651 L p .74 .346 .305 r
F P
0 g
s
.53443 .63651 m .54969 .64311 L .54713 .64262 L p .74 .346 .305 r
F P
0 g
s
.5325 .63966 m .53443 .63651 L .53644 .638 L p .743 .332 .271 r
F P
0 g
s
.42331 .48587 m .42595 .48229 L .42648 .48167 L p 0 0 .047 r
F P
0 g
s
.73233 .57534 m .7343 .57173 L .72895 .56987 L p .692 .732 .881 r
F P
0 g
s
.72895 .56987 m .72615 .57503 L .73233 .57534 L p .692 .732 .881 r
F P
0 g
s
.64041 .41179 m .65259 .3978 L .64959 .39736 L p .907 .829 .758 r
F P
0 g
s
.64352 .38452 m .64959 .39736 L .65259 .3978 L p .907 .829 .758 r
F P
0 g
s
.65259 .3978 m .64394 .37944 L .64352 .38452 L p .907 .829 .758 r
F P
0 g
s
.65259 .3978 m .64041 .41179 L .64216 .41244 L p .931 .925 .782 r
F P
0 g
s
.64394 .37944 m .65259 .3978 L .65419 .39216 L p .865 .82 .803 r
F P
0 g
s
.50606 .57464 m .50657 .57273 L .50617 .57351 L p 0 0 0 r
F P
0 g
s
.50617 .57351 m .50544 .57623 L .50606 .57464 L p 0 0 0 r
F P
0 g
s
.50606 .57464 m .50544 .57623 L p .50683 .57238 L .743 .835 .382 r
F P
0 g
s
.50781 .56966 m .50694 .57216 L p .50683 .57238 L .743 .835 .382 r
F P
0 g
s
.50694 .57216 m .50606 .57464 L p .50683 .57238 L .743 .835 .382 r
F P
0 g
s
.50617 .57351 m .50657 .57273 L p .50821 .56948 L 0 0 0 r
F P
0 g
s
.51055 .56481 m .50835 .56917 L p .50821 .56948 L 0 0 0 r
F P
0 g
s
.50835 .56917 m .50617 .57351 L p .50821 .56948 L 0 0 0 r
F P
0 g
s
.51349 .61599 m .51222 .6168 L .51056 .61499 L p .884 .454 .084 r
F P
0 g
s
.28617 .56016 m .31368 .55407 L .31794 .55034 L p .69 .78 .92 r
F P
0 g
s
.31794 .55034 m .2786 .55906 L .28617 .56016 L p .69 .78 .92 r
F P
0 g
s
.62966 .44624 m .62907 .44734 L p .63002 .44508 L 0 0 0 r
F P
0 g
s
.63283 .43841 m .62966 .44624 L p .63002 .44508 L 0 0 0 r
F P
0 g
s
.62966 .44624 m .62961 .44503 L p .62933 .4473 L .82 .723 .193 r
F P
0 g
s
.62787 .4536 m .62853 .44936 L .62966 .44624 L p 0 0 .108 r
F P
0 g
s
.62871 .4523 m .62787 .4536 L p .62854 .45083 L 0 0 .108 r
F P
0 g
s
.62966 .44624 m .62871 .4523 L p .62854 .45083 L 0 0 .108 r
F P
0 g
s
.62871 .4523 m .62881 .45091 L p .62886 .4536 L 0 0 .093 r
F P
0 g
s
.62893 .45679 m .62871 .4523 L p .62886 .4536 L 0 0 .093 r
F P
0 g
s
.62871 .4523 m .62966 .44624 L p .62933 .4473 L .82 .723 .193 r
F P
0 g
s
.62966 .44624 m .63283 .43841 L .63246 .43735 L p .947 .881 .474 r
F P
0 g
s
.633 .42657 m .63246 .43735 L .63283 .43841 L p .948 .886 .484 r
F P
0 g
s
.63283 .43841 m .63359 .42301 L .633 .42657 L p .948 .886 .484 r
F P
0 g
s
.63359 .42301 m .63283 .43841 L .63397 .43455 L p .967 .935 .678 r
F P
0 g
s
.41971 .49462 m .41609 .50098 L .41694 .50106 L p .958 .944 .709 r
F P
0 g
s
.55248 .64294 m .56393 .64454 L .56605 .64539 L p .593 .142 .151 r
F P
0 g
s
.56605 .64539 m .54969 .64311 L .55248 .64294 L p .593 .142 .151 r
F P
0 g
s
.52332 .6283 m .52192 .63001 L .51971 .6288 L p .834 .403 .212 r
F P
0 g
s
.76342 .5729 m .73611 .56824 L .73031 .56701 L p .688 .728 .88 r
F P
0 g
s
.42886 .45471 m .42582 .44219 L .42789 .44296 L p .371 .309 .658 r
F P
0 g
s
.43567 .43701 m .42789 .44296 L .42582 .44219 L p .371 .309 .657 r
F P
0 g
s
.42582 .44219 m .43692 .43368 L .43567 .43701 L p .371 .309 .657 r
F P
0 g
s
.42582 .44219 m .42886 .45471 L .42755 .45425 L p .131 .15 .613 r
F P
0 g
s
.43692 .43368 m .42582 .44219 L .42648 .43843 L p .412 .38 .713 r
F P
0 g
s
.41609 .50098 m .41971 .49462 L .41952 .49491 L p .633 .801 .366 r
F P
0 g
s
.42253 .49011 m .41971 .49462 L .42049 .4932 L p 0 0 0 r
F P
0 g
s
.42149 .49177 m .41952 .49491 L .41971 .49462 L p .601 .799 .381 r
F P
0 g
s
.41971 .49462 m .42253 .49011 L .42149 .49177 L p .601 .799 .381 r
F P
0 g
s
.42193 .48981 m .42049 .4932 L .41971 .49462 L p 0 0 0 r
F P
0 g
s
.65599 .59344 m .64519 .59219 L .64191 .59377 L p .8 .797 .849 r
F P
0 g
s
.7003 .57145 m .72103 .57539 L .72615 .57503 L p .703 .731 .872 r
F P
0 g
s
.72615 .57503 m .69653 .5694 L .7003 .57145 L p .703 .731 .872 r
F P
0 g
s
.72406 .56982 m .7221 .57343 L .72615 .57503 L p .694 .734 .881 r
F P
0 g
s
.72615 .57503 m .72895 .56987 L .72406 .56982 L p .694 .734 .881 r
F P
0 g
s
.69653 .5694 m .72615 .57503 L .7221 .57343 L p .704 .73 .871 r
F P
0 g
s
.23326 .56443 m .22616 .54967 L .21666 .54761 L p .672 .77 .924 r
F P
0 g
s
.60174 .49668 m .6035 .49914 L .6019 .50163 L p .431 .213 .481 r
F P
0 g
s
.42245 .4886 m .42483 .48521 L .42517 .48495 L p 0 0 0 r
F P
0 g
s
.53644 .638 m .53509 .64021 L .5325 .63966 L p .743 .332 .271 r
F P
0 g
s
.41148 .50838 m .4156 .50313 L .41609 .50098 L p .926 .942 .789 r
F P
0 g
s
.60409 .62888 m .60098 .6309 L .59857 .63285 L p .571 .905 .668 r
F P
0 g
s
.50501 .57851 m .50453 .58498 L .50475 .58548 L p 0 0 .173 r
F P
0 g
s
.50475 .58548 m .50544 .57623 L .50501 .57851 L p 0 0 .173 r
F P
0 g
s
.5459 .64513 m .54713 .64262 L .54969 .64311 L p .75 .376 .346 r
F P
0 g
s
.54969 .64311 m .54794 .64669 L .5459 .64513 L p .75 .376 .346 r
F P
0 g
s
.56335 .6456 m .55189 .644 L .54969 .64311 L p .637 .259 .312 r
F P
0 g
s
.54969 .64311 m .56605 .64539 L .56335 .6456 L p .637 .259 .312 r
F P
0 g
s
.54794 .64669 m .54969 .64311 L .55189 .644 L p .636 .248 .291 r
F P
0 g
s
.58713 .63801 m .59705 .63341 L .59857 .63285 L p 0 0 0 r
F P
0 g
s
.59857 .63285 m .5844 .63943 L .58713 .63801 L p 0 0 0 r
F P
0 g
s
.63397 .43455 m .63451 .42376 L .63359 .42301 L p .967 .935 .678 r
F P
0 g
s
.6374 .60504 m .6429 .59596 L .64191 .59377 L p .808 .821 .86 r
F P
0 g
s
.64191 .59377 m .63405 .60675 L .6374 .60504 L p .808 .821 .86 r
F P
0 g
s
.76392 .57185 m .76603 .56783 L .77237 .56793 L p .675 .735 .895 r
F P
0 g
s
.57993 .64294 m .58163 .64034 L .5844 .63943 L p .425 0 .108 r
F P
0 g
s
.5844 .63943 m .58197 .64315 L .57993 .64294 L p .425 0 .108 r
F P
0 g
s
.59605 .6344 m .58613 .639 L .5844 .63943 L p .139 0 0 r
F P
0 g
s
.5844 .63943 m .59857 .63285 L .59605 .6344 L p .139 0 0 r
F P
0 g
s
.58197 .64315 m .5844 .63943 L .58613 .639 L p .146 0 0 r
F P
0 g
s
.54661 .53086 m .54225 .5322 L .54062 .53376 L p .343 0 .172 r
F P
0 g
s
.62414 .60923 m .63109 .6087 L .63405 .60675 L p .829 .919 .896 r
F P
0 g
s
.63405 .60675 m .62412 .6075 L .62414 .60923 L p .829 .919 .896 r
F P
0 g
s
.6391 .59578 m .6336 .60488 L .63405 .60675 L p .84 .871 .866 r
F P
0 g
s
.63405 .60675 m .64191 .59377 L .6391 .59578 L p .84 .871 .866 r
F P
0 g
s
.62412 .6075 m .63405 .60675 L .6336 .60488 L p .866 .883 .847 r
F P
0 g
s
.37837 .80855 m .32545 .86453 L .32836 .85397 L p .746 .759 .863 r
F P
0 g
s
.30167 .84177 m .32836 .85397 L .32545 .86453 L p .746 .759 .863 r
F P
0 g
s
.32545 .86453 m .28729 .84723 L .30167 .84177 L p .746 .759 .863 r
F P
0 g
s
.3772 .81942 m .34014 .85852 L .32545 .86453 L p .736 .741 .855 r
F P
0 g
s
.32545 .86453 m .37837 .80855 L .3772 .81942 L p .736 .741 .855 r
F P
0 g
s
.50794 .56912 m .50781 .56966 L p .50683 .57238 L .743 .835 .382 r
F P
0 g
s
.50544 .57623 m .50668 .57269 L p .50683 .57238 L .743 .835 .382 r
F P
0 g
s
.50668 .57269 m .50794 .56912 L p .50683 .57238 L .743 .835 .382 r
F P
0 g
s
.50964 .56665 m .51055 .56481 L p .50821 .56948 L 0 0 0 r
F P
0 g
s
.50657 .57273 m .5081 .5697 L p .50821 .56948 L 0 0 0 r
F P
0 g
s
.5081 .5697 m .50964 .56665 L p .50821 .56948 L 0 0 0 r
F P
0 g
s
.50496 .58338 m .50544 .5769 L .50544 .57623 L p 0 0 0 r
F P
0 g
s
.50544 .57623 m .50475 .58548 L .50496 .58338 L p 0 0 0 r
F P
0 g
s
.50794 .56912 m .50544 .57623 L .50544 .5769 L p 0 0 0 r
F P
0 g
s
.42861 .46423 m .42816 .45736 L .42886 .45471 L p .009 0 .489 r
F P
0 g
s
.53774 .53517 m .53165 .54063 L .53191 .54156 L p .171 0 0 r
F P
0 g
s
.53191 .54156 m .54062 .53376 L .53774 .53517 L p .171 0 0 r
F P
0 g
s
.42648 .43843 m .43425 .43246 L .43692 .43368 L p .412 .38 .713 r
F P
0 g
s
.65419 .39216 m .64816 .37929 L .64394 .37944 L p .865 .82 .803 r
F P
0 g
s
.55189 .644 m .55067 .64651 L .54794 .64669 L p .636 .248 .291 r
F P
0 g
s
.42049 .4932 m .42246 .49004 L .42253 .49011 L p 0 0 0 r
F P
0 g
s
.7221 .57343 m .70136 .56949 L .69653 .5694 L p .704 .73 .871 r
F P
0 g
s
.69742 .57695 m .7003 .57145 L .69653 .5694 L p .715 .729 .861 r
F P
0 g
s
.69653 .5694 m .69241 .57726 L .69742 .57695 L p .715 .729 .861 r
F P
0 g
s
.41609 .50098 m .41021 .50848 L .41148 .50838 L p .926 .942 .789 r
F P
0 g
s
.41021 .50848 m .41609 .50098 L .4154 .50145 L p .764 .95 .625 r
F P
0 g
s
.41671 .49847 m .4154 .50145 L .41609 .50098 L p .713 .939 .627 r
F P
0 g
s
.41609 .50098 m .41797 .4967 L .41671 .49847 L p .713 .939 .627 r
F P
0 g
s
.41952 .49491 m .41699 .49937 L .41609 .50098 L p .633 .801 .366 r
F P
0 g
s
.41797 .4967 m .41609 .50098 L .41699 .49937 L p .693 .866 .463 r
F P
0 g
s
.26392 .5459 m .26951 .55768 L .2786 .55906 L p .669 .777 .931 r
F P
0 g
s
.2786 .55906 m .2707 .54221 L .26392 .5459 L p .669 .777 .931 r
F P
0 g
s
.31102 .54939 m .28343 .55551 L .2786 .55906 L p .686 .792 .931 r
F P
0 g
s
.2786 .55906 m .31794 .55034 L .31102 .54939 L p .686 .792 .931 r
F P
0 g
s
.2707 .54221 m .2786 .55906 L .28343 .55551 L p .683 .785 .927 r
F P
0 g
s
.6722 .57529 m .68815 .5782 L .69241 .57726 L p .732 .735 .854 r
F P
0 g
s
.69241 .57726 m .66963 .57311 L .6722 .57529 L p .732 .735 .854 r
F P
0 g
s
.69244 .56995 m .68957 .57547 L .69241 .57726 L p .72 .734 .863 r
F P
0 g
s
.69241 .57726 m .69653 .5694 L .69244 .56995 L p .72 .734 .863 r
F P
0 g
s
.66963 .57311 m .69241 .57726 L .68957 .57547 L p .734 .733 .849 r
F P
0 g
s
.53441 .53998 m .5405 .53451 L .54062 .53376 L p .167 0 0 r
F P
0 g
s
.54062 .53376 m .53191 .54156 L .53441 .53998 L p .167 0 0 r
F P
0 g
s
.54685 .53184 m .54062 .53376 L .5405 .53451 L p .233 0 0 r
F P
0 g
s
.54062 .53376 m .54685 .53184 L .54661 .53086 L p .343 0 .172 r
F P
0 g
s
.61464 .48842 m .61293 .48526 L .61467 .48362 L p .323 .164 .505 r
F P
0 g
s
.62182 .47378 m .61467 .48362 L .61293 .48526 L p .313 .15 .493 r
F P
0 g
s
.61293 .48526 m .62315 .47121 L .62182 .47378 L p .313 .15 .493 r
F P
0 g
s
.61241 .4899 m .61121 .48768 L .61293 .48526 L p .423 .203 .473 r
F P
0 g
s
.61293 .48526 m .61464 .48842 L .61241 .4899 L p .423 .203 .473 r
F P
0 g
s
.62315 .47121 m .61293 .48526 L .61429 .48248 L p .226 .044 .413 r
F P
0 g
s
.46167 .82453 m .47337 .79091 L .48234 .78518 L p .738 .705 .82 r
F P
0 g
s
.61429 .48248 m .62145 .47265 L .62315 .47121 L p .226 .044 .413 r
F P
0 g
s
.42789 .44296 m .43002 .45172 L .42886 .45471 L p .371 .309 .658 r
F P
0 g
s
.40308 .51651 m .40937 .51078 L .41021 .50848 L p .878 .921 .851 r
F P
0 g
s
.63246 .43735 m .63024 .44283 L .62966 .44624 L p .947 .881 .474 r
F P
0 g
s
.58613 .639 m .58443 .6416 L .58197 .64315 L p .146 0 0 r
F P
0 g
s
.56879 .6445 m .57993 .64294 L .58197 .64315 L p .422 0 .096 r
F P
0 g
s
.58197 .64315 m .56605 .64539 L .56879 .6445 L p .422 0 .096 r
F P
0 g
s
.62145 .47265 m .62093 .46959 L .62241 .46683 L p .216 .031 .401 r
F P
0 g
s
.64959 .39736 m .64105 .40716 L .64041 .41179 L p .907 .829 .758 r
F P
0 g
s
.58877 .51099 m .59923 .5028 L .6019 .50163 L p .485 .215 .43 r
F P
0 g
s
.42951 .46453 m .42886 .45471 L .43049 .45536 L p .331 .237 .596 r
F P
0 g
s
.43794 .45092 m .43049 .45536 L .42886 .45471 L p .332 .236 .594 r
F P
0 g
s
.42886 .45471 m .43949 .44835 L .43794 .45092 L p .332 .236 .594 r
F P
0 g
s
.42886 .45471 m .42951 .46453 L .42861 .46423 L p .009 0 .489 r
F P
0 g
s
.43949 .44835 m .42886 .45471 L .43002 .45172 L p .369 .308 .657 r
F P
0 g
s
.73492 .5707 m .73556 .56973 L .72987 .56848 L p .698 .723 .869 r
F P
0 g
s
.72987 .56848 m .72895 .56987 L .73492 .5707 L p .698 .723 .869 r
F P
0 g
s
.56227 .64826 m .56335 .6456 L .56605 .64539 L p .647 .281 .337 r
F P
0 g
s
.56605 .64539 m .56451 .6492 L .56227 .64826 L p .647 .281 .337 r
F P
0 g
s
.57936 .64406 m .56821 .64563 L .56605 .64539 L p .507 .143 .284 r
F P
0 g
s
.56605 .64539 m .58197 .64315 L .57936 .64406 L p .507 .143 .284 r
F P
0 g
s
.56451 .6492 m .56605 .64539 L .56821 .64563 L p .505 .138 .276 r
F P
0 g
s
.62315 .47121 m .62241 .46683 L .62342 .46533 L p 0 0 .365 r
F P
0 g
s
.62784 .45515 m .62342 .46533 L .62241 .46683 L p 0 0 .344 r
F P
0 g
s
.62241 .46683 m .62871 .4523 L .62784 .45515 L p 0 0 .344 r
F P
0 g
s
.62241 .46683 m .62315 .47121 L .62145 .47265 L p .216 .031 .401 r
F P
0 g
s
.62871 .4523 m .62241 .46683 L .62345 .46377 L p 0 0 .126 r
F P
0 g
s
.6019 .50163 m .58696 .51333 L .58877 .51099 L p .485 .215 .43 r
F P
0 g
s
.57229 .52077 m .58399 .51404 L .58696 .51333 L p .495 .169 .343 r
F P
0 g
s
.50544 .5769 m .50719 .57192 L .50794 .56912 L p 0 0 0 r
F P
0 g
s
.6336 .60488 m .62665 .60539 L .62412 .6075 L p .866 .883 .847 r
F P
0 g
s
.50488 .58805 m .50553 .59797 L .50567 .59967 L p 0 0 .084 r
F P
0 g
s
.50567 .59967 m .50475 .58548 L .50488 .58805 L p 0 0 .084 r
F P
0 g
s
.41699 .49937 m .4183 .49637 L .41797 .4967 L p .693 .866 .463 r
F P
0 g
s
.6035 .49914 m .61241 .4899 L .61464 .48842 L p .427 .208 .477 r
F P
0 g
s
.61464 .48842 m .6019 .50163 L .6035 .49914 L p .427 .208 .477 r
F P
0 g
s
.54825 .53034 m .55304 .52876 L .5537 .52958 L p .402 .022 .199 r
F P
0 g
s
.5537 .52958 m .54685 .53184 L .54825 .53034 L p .402 .022 .199 r
F P
0 g
s
.66867 .58257 m .6722 .57529 L .66963 .57311 L p .749 .736 .841 r
F P
0 g
s
.66963 .57311 m .66459 .58351 L .66867 .58257 L p .749 .736 .841 r
F P
0 g
s
.32382 .55105 m .34489 .54519 L .34809 .54196 L p .711 .798 .919 r
F P
0 g
s
.34809 .54196 m .31794 .55034 L .32382 .55105 L p .711 .798 .919 r
F P
0 g
s
.62345 .46377 m .62787 .4536 L .62871 .4523 L p 0 0 .126 r
F P
0 g
s
.61467 .48362 m .61586 .48583 L .61464 .48842 L p .323 .164 .505 r
F P
0 g
s
.68957 .57547 m .67362 .57255 L .66963 .57311 L p .734 .733 .849 r
F P
0 g
s
.60379 .50369 m .6019 .50163 L .60405 .49994 L p .47 .267 .522 r
F P
0 g
s
.61296 .49069 m .60405 .49994 L .6019 .50163 L p .464 .258 .515 r
F P
0 g
s
.6019 .50163 m .61464 .48842 L .61296 .49069 L p .464 .258 .515 r
F P
0 g
s
.60133 .50516 m .60001 .50372 L .6019 .50163 L p .523 .271 .474 r
F P
0 g
s
.6019 .50163 m .60379 .50369 L .60133 .50516 L p .523 .271 .474 r
F P
0 g
s
.58696 .51333 m .6019 .50163 L .60001 .50372 L p .52 .266 .471 r
F P
0 g
s
.41021 .50848 m .40121 .51668 L .40308 .51651 L p .878 .921 .851 r
F P
0 g
s
.42829 .4717 m .42869 .46662 L .42951 .46453 L p 0 0 .347 r
F P
0 g
s
.61788 .61794 m .62414 .60923 L .62412 .6075 L p .849 .932 .881 r
F P
0 g
s
.62412 .6075 m .61518 .61994 L .61788 .61794 L p .849 .932 .881 r
F P
0 g
s
.40121 .51668 m .41021 .50848 L .40886 .509 L p .816 1 .818 r
F P
0 g
s
.4093 .50593 m .40886 .509 L .41021 .50848 L p .769 .997 .822 r
F P
0 g
s
.41021 .50848 m .41085 .50408 L .4093 .50593 L p .769 .997 .822 r
F P
0 g
s
.4154 .50145 m .41128 .50671 L .41021 .50848 L p .764 .95 .625 r
F P
0 g
s
.41085 .50408 m .41021 .50848 L .41128 .50671 L p .803 .982 .708 r
F P
0 g
s
.64909 .58342 m .66107 .58501 L .66459 .58351 L p .775 .762 .842 r
F P
0 g
s
.66459 .58351 m .64748 .58123 L .64909 .58342 L p .775 .762 .842 r
F P
0 g
s
.66622 .57429 m .6627 .58158 L .66459 .58351 L p .761 .751 .844 r
F P
0 g
s
.66459 .58351 m .66963 .57311 L .66622 .57429 L p .761 .751 .844 r
F P
0 g
s
.64748 .58123 m .66459 .58351 L .6627 .58158 L p .781 .753 .828 r
F P
0 g
s
.70295 .56604 m .72406 .56982 L .72895 .56987 L p .699 .724 .869 r
F P
0 g
s
.72895 .56987 m .69879 .56447 L .70295 .56604 L p .699 .724 .869 r
F P
0 g
s
.72521 .56789 m .72457 .56886 L .72895 .56987 L p .698 .723 .869 r
F P
0 g
s
.72895 .56987 m .72987 .56848 L .72521 .56789 L p .698 .723 .869 r
F P
0 g
s
.69879 .56447 m .72895 .56987 L .72457 .56886 L p .708 .715 .855 r
F P
0 g
s
.73611 .56824 m .73579 .56927 L .72987 .56848 L p .697 .721 .868 r
F P
0 g
s
.5405 .53451 m .54487 .53318 L .54685 .53184 L p .233 0 0 r
F P
0 g
s
.78392 .56097 m .78085 .56759 L .77237 .56793 L p .673 .733 .895 r
F P
0 g
s
.77237 .56793 m .77672 .55846 L .78392 .56097 L p .673 .733 .895 r
F P
0 g
s
.73931 .56133 m .76704 .56566 L .77237 .56793 L p .679 .729 .887 r
F P
0 g
s
.77237 .56793 m .73278 .56175 L .73931 .56133 L p .679 .729 .887 r
F P
0 g
s
.77672 .55846 m .77237 .56793 L .76704 .56566 L p .671 .73 .894 r
F P
0 g
s
.73278 .56175 m .77237 .56793 L .76603 .56783 L p .679 .729 .887 r
F P
0 g
s
.58971 .51579 m .58696 .51333 L .58955 .51192 L p .518 .263 .468 r
F P
0 g
s
.60001 .50372 m .58955 .51192 L .58696 .51333 L p .52 .266 .471 r
F P
0 g
s
.58687 .51691 m .58495 .51519 L .58696 .51333 L p .555 .256 .414 r
F P
0 g
s
.58696 .51333 m .58971 .51579 L .58687 .51691 L p .555 .256 .414 r
F P
0 g
s
.57022 .52296 m .58696 .51333 L .58495 .51519 L p .526 .216 .385 r
F P
0 g
s
.58696 .51333 m .57022 .52296 L .57229 .52077 L p .495 .169 .343 r
F P
0 g
s
.52192 .63001 m .53087 .63761 L .5325 .63966 L p .847 .445 .279 r
F P
0 g
s
.39105 .52505 m .39997 .51912 L .40121 .51668 L p .827 .889 .887 r
F P
0 g
s
.51914 .55145 m .5129 .559 L .51163 .56141 L p 0 0 .079 r
F P
0 g
s
.53509 .64021 m .5459 .64513 L .54794 .64669 L p .754 .363 .313 r
F P
0 g
s
.54794 .64669 m .5325 .63966 L .53509 .64021 L p .754 .363 .313 r
F P
0 g
s
.76603 .56783 m .73833 .56351 L .73278 .56175 L p .679 .729 .887 r
F P
0 g
s
.60405 .49994 m .60537 .50138 L .60379 .50369 L p .47 .267 .522 r
F P
0 g
s
.43002 .45172 m .43747 .44727 L .43949 .44835 L p .369 .308 .657 r
F P
0 g
s
.60876 .62376 m .61261 .62187 L .61518 .61994 L p .66 .965 .78 r
F P
0 g
s
.61518 .61994 m .60969 .62264 L .60876 .62376 L p .66 .965 .78 r
F P
0 g
s
.62186 .60974 m .61559 .61846 L .61518 .61994 L p .857 .992 .834 r
F P
0 g
s
.61518 .61994 m .62412 .6075 L .62186 .60974 L p .857 .992 .834 r
F P
0 g
s
.60969 .62264 m .61518 .61994 L .61559 .61846 L p .866 .995 .797 r
F P
0 g
s
.56821 .64563 m .56714 .64829 L .56451 .6492 L p .505 .138 .276 r
F P
0 g
s
.5105 .56336 m .50885 .56603 L .50927 .56521 L p .66 .832 .412 r
F P
0 g
s
.50927 .56521 m .51163 .56141 L .5105 .56336 L p .66 .832 .412 r
F P
0 g
s
.58955 .51192 m .59148 .51363 L .58971 .51579 L p .518 .263 .468 r
F P
0 g
s
.5325 .63966 m .51971 .6288 L .52192 .63001 L p .847 .445 .279 r
F P
0 g
s
.50423 .58159 m .50496 .58338 L .50475 .58548 L p .908 .833 .372 r
F P
0 g
s
.50475 .58548 m .5037 .58294 L .50423 .58159 L p .908 .833 .372 r
F P
0 g
s
.50529 .59741 m .50465 .58747 L .50475 .58548 L p .934 .717 .237 r
F P
0 g
s
.50475 .58548 m .50567 .59967 L .50529 .59741 L p .934 .717 .237 r
F P
0 g
s
.5037 .58294 m .50475 .58548 L .50465 .58747 L p .863 .688 .159 r
F P
0 g
s
.51222 .6168 m .51862 .62646 L .51971 .6288 L p .918 .523 .205 r
F P
0 g
s
.39222 .36736 m .37067 .34561 L .3682 .33778 L p .533 .561 .83 r
F P
0 g
s
.3682 .33778 m .39902 .3689 L .39222 .36736 L p .533 .561 .83 r
F P
0 g
s
.55606 .52762 m .56762 .52299 L .57022 .52296 L p .466 .097 .254 r
F P
0 g
s
.72987 .56848 m .73031 .56701 L .73611 .56824 L p .697 .721 .868 r
F P
0 g
s
.57022 .52296 m .5537 .52958 L .55606 .52762 L p .466 .097 .254 r
F P
0 g
s
.54158 .53802 m .54685 .53184 L .54487 .53318 L p .095 0 0 r
F P
0 g
s
.54158 .53802 m .54685 .53184 L .54763 .5323 L p .298 0 0 r
F P
0 g
s
.55242 .53071 m .54763 .5323 L .54685 .53184 L p .282 0 .002 r
F P
0 g
s
.54685 .53184 m .5537 .52958 L .55242 .53071 L p .282 0 .002 r
F P
0 g
s
.70417 .56374 m .72539 .56747 L .72987 .56848 L p .706 .713 .854 r
F P
0 g
s
.72987 .56848 m .69955 .56315 L .70417 .56374 L p .706 .713 .854 r
F P
0 g
s
.73031 .56701 m .72987 .56848 L .72539 .56747 L p .696 .721 .868 r
F P
0 g
s
.70399 .56416 m .72521 .56789 L .72987 .56848 L p .706 .713 .854 r
F P
0 g
s
.72987 .56848 m .69955 .56315 L .70399 .56416 L p .706 .713 .854 r
F P
0 g
s
.52923 .64055 m .53033 .63846 L .5325 .63966 L p .844 .512 .425 r
F P
0 g
s
.5325 .63966 m .53094 .64266 L .52923 .64055 L p .844 .512 .425 r
F P
0 g
s
.51971 .6288 m .5325 .63966 L .53033 .63846 L p .843 .494 .392 r
F P
0 g
s
.54541 .6461 m .5346 .64118 L .5325 .63966 L p .758 .413 .401 r
F P
0 g
s
.5325 .63966 m .54794 .64669 L .54541 .6461 L p .758 .413 .401 r
F P
0 g
s
.53094 .64266 m .5325 .63966 L .5346 .64118 L p .761 .406 .382 r
F P
0 g
s
.41374 .39298 m .40004 .37515 L .39902 .3689 L p .496 .509 .801 r
F P
0 g
s
.72457 .56886 m .70345 .56508 L .69879 .56447 L p .708 .715 .855 r
F P
0 g
s
.63451 .42376 m .63928 .41591 L .64041 .41179 L p .967 .936 .68 r
F P
0 g
s
.50661 .60198 m .51003 .6127 L .51056 .61499 L p .891 .566 .069 r
F P
0 g
s
.62342 .46533 m .62394 .46839 L .62315 .47121 L p 0 0 .365 r
F P
0 g
s
.58495 .51519 m .57323 .52194 L .57022 .52296 L p .526 .216 .385 r
F P
0 g
s
.42951 .46453 m .42893 .47179 L .42829 .4717 L p 0 0 .347 r
F P
0 g
s
.51056 .61499 m .50567 .59967 L .50661 .60198 L p .891 .566 .069 r
F P
0 g
s
.51971 .6288 m .51056 .61499 L .51222 .6168 L p .918 .523 .205 r
F P
0 g
s
.43049 .45536 m .43095 .46224 L .42951 .46453 L p .331 .237 .596 r
F P
0 g
s
.55067 .64651 m .56227 .64826 L .56451 .6492 L p .647 .27 .316 r
F P
0 g
s
.56451 .6492 m .54794 .64669 L .55067 .64651 L p .647 .27 .316 r
F P
0 g
s
.40121 .51668 m .38845 .52516 L .39105 .52505 L p .827 .889 .887 r
F P
0 g
s
.51163 .56141 m .52031 .55091 L p .51914 .55145 L 0 0 .079 r
F P
0 g
s
.51163 .56141 m .51234 .5604 L p .52029 .55093 L .668 .92 .609 r
F P
0 g
s
.52031 .55091 m .52056 .55061 L .5205 .55064 L p 0 0 .079 r
F P
0 g
s
.52056 .55061 m .52031 .55091 L p .52029 .55093 L .668 .92 .609 r
F P
0 g
s
.52031 .55091 m .51163 .56141 L p .52029 .55093 L .668 .92 .609 r
F P
0 g
s
.51234 .5604 m .51859 .55283 L .52019 .55102 L p .668 .92 .609 r
F P
0 g
s
.5205 .55064 m .51914 .55145 L p .52031 .55091 L 0 0 .079 r
F P
0 g
s
.52019 .55102 m .52056 .55061 L p .52029 .55093 L .668 .92 .609 r
F P
0 g
s
.52029 .55093 m .51234 .5604 L .52019 .55102 L .668 .92 .609 r
F
.51049 .56427 m .51414 .55702 L .51447 .55649 L p .814 .975 .676 r
F P
0 g
s
.51859 .55283 m .51433 .55581 L .51449 .55486 L p .802 .992 .75 r
F P
0 g
s
.51447 .55649 m .51576 .55445 L p .51487 .55611 L .814 .975 .676 r
F P
0 g
s
.51487 .55611 m .51049 .56427 L .51447 .55649 L .814 .975 .676 r
F
.51487 .55611 m .51059 .56474 L .51049 .56427 L F
.51576 .55445 m .51498 .55601 L p .51487 .55611 L F P
0 g
s
.51498 .55601 m .51059 .56474 L p .51487 .55611 L .814 .975 .676 r
F P
0 g
s
.51059 .56474 m .51055 .56481 L .51055 .56479 L p .814 .975 .676 r
F P
0 g
s
.51055 .56479 m .51049 .56427 L p .51059 .56474 L .814 .975 .676 r
F P
0 g
s
.51068 .56306 m .51234 .5604 L .51163 .56141 L p 0 0 0 r
F P
0 g
s
.51163 .56141 m .50927 .56521 L .51068 .56306 L p 0 0 0 r
F P
0 g
s
.28343 .55551 m .27796 .5437 L .2707 .54221 L p .683 .785 .927 r
F P
0 g
s
.41128 .50671 m .41173 .50363 L .41085 .50408 L p .803 .982 .708 r
F P
0 g
s
.37462 .53367 m .38671 .52778 L .38845 .52516 L p .78 .854 .906 r
F P
0 g
s
.42893 .47179 m .42951 .46453 L .43087 .46501 L p .294 .169 .534 r
F P
0 g
s
.4379 .46178 m .43087 .46501 L .42951 .46453 L p .296 .167 .529 r
F P
0 g
s
.42951 .46453 m .43955 .4599 L .4379 .46178 L p .296 .167 .529 r
F P
0 g
s
.43955 .4599 m .42951 .46453 L .43095 .46224 L p .326 .232 .593 r
F P
0 g
s
.35264 .54232 m .36876 .53647 L .37115 .53359 L p .74 .823 .916 r
F P
0 g
s
.37115 .53359 m .34809 .54196 L .35264 .54232 L p .74 .823 .916 r
F P
0 g
s
.51676 .62896 m .51804 .62709 L .51971 .6288 L p .921 .601 .419 r
F P
0 g
s
.51971 .6288 m .51787 .63147 L .51676 .62896 L p .921 .601 .419 r
F P
0 g
s
.51056 .61499 m .51971 .6288 L .51804 .62709 L p .923 .58 .371 r
F P
0 g
s
.53033 .63846 m .52137 .63085 L .51971 .6288 L p .843 .494 .392 r
F P
0 g
s
.51787 .63147 m .51971 .6288 L .52137 .63085 L p .85 .488 .365 r
F P
0 g
s
.39902 .3689 m .41862 .39441 L .41374 .39298 L p .496 .509 .801 r
F P
0 g
s
.54451 .6483 m .54541 .6461 L .54794 .64669 L p .761 .428 .422 r
F P
0 g
s
.54794 .64669 m .54665 .64985 L .54451 .6483 L p .761 .428 .422 r
F P
0 g
s
.56185 .6493 m .55025 .64755 L .54794 .64669 L p .662 .327 .396 r
F P
0 g
s
.54794 .64669 m .56451 .6492 L .56185 .6493 L p .662 .327 .396 r
F P
0 g
s
.54665 .64985 m .54794 .64669 L .55025 .64755 L p .662 .319 .381 r
F P
0 g
s
.42743 .4769 m .42812 .47343 L .42893 .47179 L p 0 0 .204 r
F P
0 g
s
.73833 .56351 m .73659 .56719 L .73031 .56701 L p .687 .725 .879 r
F P
0 g
s
.6627 .58158 m .65072 .57998 L .64748 .58123 L p .781 .753 .828 r
F P
0 g
s
.5346 .64118 m .53351 .64327 L .53094 .64266 L p .761 .406 .382 r
F P
0 g
s
.30676 .53999 m .31102 .54939 L .31794 .55034 L p .678 .796 .937 r
F P
0 g
s
.31794 .55034 m .31192 .53689 L .30676 .53999 L p .678 .796 .937 r
F P
0 g
s
.34279 .54142 m .32166 .5473 L .31794 .55034 L p .705 .82 .936 r
F P
0 g
s
.31794 .55034 m .34809 .54196 L .34279 .54142 L p .705 .82 .936 r
F P
0 g
s
.31192 .53689 m .31794 .55034 L .32166 .5473 L p .701 .808 .932 r
F P
0 g
s
.38845 .52516 m .40121 .51668 L .39911 .51709 L p .803 .969 .908 r
F P
0 g
s
.39865 .51354 m .39911 .51709 L .40121 .51668 L p .765 .975 .92 r
F P
0 g
s
.40121 .51668 m .40058 .5116 L .39865 .51354 L p .765 .975 .92 r
F P
0 g
s
.40886 .509 m .40256 .51475 L .40121 .51668 L p .816 1 .818 r
F P
0 g
s
.40058 .5116 m .40121 .51668 L .40256 .51475 L p .824 .994 .859 r
F P
0 g
s
.38845 .52516 m .37115 .53359 L .37462 .53367 L p .78 .854 .906 r
F P
0 g
s
.72539 .56747 m .7257 .56644 L .73031 .56701 L p .696 .721 .868 r
F P
0 g
s
.73031 .56701 m .73278 .56175 L .73833 .56351 L p .687 .725 .879 r
F P
0 g
s
.70476 .56177 m .7261 .56546 L .73031 .56701 L p .695 .72 .868 r
F P
0 g
s
.73031 .56701 m .69985 .56175 L .70476 .56177 L p .695 .72 .868 r
F P
0 g
s
.73278 .56175 m .73031 .56701 L .7261 .56546 L p .686 .724 .879 r
F P
0 g
s
.69985 .56175 m .73031 .56701 L .7257 .56644 L p .704 .711 .853 r
F P
0 g
s
.61592 .49025 m .61464 .48842 L .61623 .48656 L p .368 .222 .548 r
F P
0 g
s
.62296 .47663 m .61623 .48656 L .61464 .48842 L p .356 .206 .536 r
F P
0 g
s
.61464 .48842 m .62424 .47422 L .62296 .47663 L p .356 .206 .536 r
F P
0 g
s
.61386 .49198 m .61296 .49069 L .61464 .48842 L p .454 .247 .507 r
F P
0 g
s
.61464 .48842 m .61592 .49025 L .61386 .49198 L p .454 .247 .507 r
F P
0 g
s
.62424 .47422 m .61464 .48842 L .61586 .48583 L p .307 .147 .494 r
F P
0 g
s
.35848 .33616 m .32512 .30921 L .32044 .29919 L p .566 .606 .852 r
F P
0 g
s
.32044 .29919 m .3682 .33778 L .35848 .33616 L p .566 .606 .852 r
F P
0 g
s
.54487 .53318 m .54118 .5375 L .54158 .53802 L p .095 0 0 r
F P
0 g
s
.59148 .51363 m .60133 .50516 L .60379 .50369 L p .521 .266 .47 r
F P
0 g
s
.82079 .56546 m .78392 .56097 L .77672 .55846 L p .667 .735 .9 r
F P
0 g
s
.77672 .55846 m .82943 .56489 L .82079 .56546 L p .667 .735 .9 r
F P
0 g
s
.76704 .56566 m .77007 .55903 L .77672 .55846 L p .671 .73 .894 r
F P
0 g
s
.60098 .6309 m .60876 .62376 L .60969 .62264 L p .65 .953 .738 r
F P
0 g
s
.60969 .62264 m .59857 .63285 L .60098 .6309 L p .65 .953 .738 r
F P
0 g
s
.52137 .63085 m .52009 .63273 L .51787 .63147 L p .85 .488 .365 r
F P
0 g
s
.50465 .58747 m .50391 .5857 L .5037 .58294 L p .863 .688 .159 r
F P
0 g
s
.57407 .52611 m .57022 .52296 L .57323 .52194 L p .509 .185 .354 r
F P
0 g
s
.57087 .52673 m .56819 .52452 L .57022 .52296 L p .534 .176 .306 r
F P
0 g
s
.57022 .52296 m .57407 .52611 L .57087 .52673 L p .534 .176 .306 r
F P
0 g
s
.5537 .52958 m .57022 .52296 L .56819 .52452 L p .43 .041 .198 r
F P
0 g
s
.63359 .42301 m .64041 .41179 L .63837 .41127 L p .949 .83 .692 r
F P
0 g
s
.63327 .40039 m .63837 .41127 L .64041 .41179 L p .949 .831 .694 r
F P
0 g
s
.64041 .41179 m .63313 .39624 L .63327 .40039 L p .949 .831 .694 r
F P
0 g
s
.64041 .41179 m .63359 .42301 L .63451 .42376 L p .967 .936 .68 r
F P
0 g
s
.63313 .39624 m .64041 .41179 L .64105 .40716 L p .907 .83 .758 r
F P
0 g
s
.60537 .50138 m .61386 .49198 L .61592 .49025 L p .462 .258 .516 r
F P
0 g
s
.61592 .49025 m .60379 .50369 L .60537 .50138 L p .462 .258 .516 r
F P
0 g
s
.61586 .48583 m .62259 .4759 L .62424 .47422 L p .307 .147 .494 r
F P
0 g
s
.64519 .59219 m .64909 .58342 L .64748 .58123 L p .796 .767 .827 r
F P
0 g
s
.64748 .58123 m .64191 .59377 L .64519 .59219 L p .796 .767 .827 r
F P
0 g
s
.42692 .41446 m .41862 .39951 L .41862 .39441 L p .454 .448 .762 r
F P
0 g
s
.60447 .50435 m .60379 .50369 L .60569 .50177 L p .487 .291 .54 r
F P
0 g
s
.61418 .49237 m .60569 .50177 L .60379 .50369 L p .479 .281 .532 r
F P
0 g
s
.60379 .50369 m .61592 .49025 L .61418 .49237 L p .479 .281 .532 r
F P
0 g
s
.60229 .50608 m .60181 .50561 L .60379 .50369 L p .537 .29 .488 r
F P
0 g
s
.60379 .50369 m .60447 .50435 L .60229 .50608 L p .537 .29 .488 r
F P
0 g
s
.58971 .51579 m .60379 .50369 L .60181 .50561 L p .539 .292 .49 r
F P
0 g
s
.60379 .50369 m .58971 .51579 L .59148 .51363 L p .521 .266 .47 r
F P
0 g
s
.73018 .85622 m .69172 .8192 L .69273 .80787 L p .629 .653 .855 r
F P
0 g
s
.69273 .80787 m .74768 .86092 L .73018 .85622 L p .629 .653 .855 r
F P
0 g
s
.50805 .61435 m .50951 .61291 L .51056 .61499 L p .98 .698 .408 r
F P
0 g
s
.51056 .61499 m .50848 .61706 L .50805 .61435 L p .98 .698 .408 r
F P
0 g
s
.50567 .59967 m .51056 .61499 L .50951 .61291 L p .976 .67 .332 r
F P
0 g
s
.51804 .62709 m .51163 .61742 L .51056 .61499 L p .923 .58 .371 r
F P
0 g
s
.50848 .61706 m .51056 .61499 L .51163 .61742 L p .93 .577 .333 r
F P
0 g
s
.70136 .56949 m .70295 .56604 L .69879 .56447 L p .709 .72 .858 r
F P
0 g
s
.69879 .56447 m .69653 .5694 L .70136 .56949 L p .709 .72 .858 r
F P
0 g
s
.50379 .5979 m .50529 .59741 L .50567 .59967 L p .989 .79 .402 r
F P
0 g
s
.50567 .59967 m .50353 .60039 L .50379 .5979 L p .989 .79 .402 r
F P
0 g
s
.50951 .61291 m .50609 .60218 L .50567 .59967 L p .976 .67 .332 r
F P
0 g
s
.50353 .60039 m .50567 .59967 L .50609 .60218 L p .97 .666 .28 r
F P
0 g
s
.59413 .63698 m .59605 .6344 L .59857 .63285 L p .118 0 0 r
F P
0 g
s
.59857 .63285 m .59583 .63655 L .59413 .63698 L p .118 0 0 r
F P
0 g
s
.60757 .62472 m .59978 .63187 L .59857 .63285 L p 0 0 0 r
F P
0 g
s
.59857 .63285 m .60969 .62264 L .60757 .62472 L p 0 0 0 r
F P
0 g
s
.55025 .64755 m .54935 .64976 L .54665 .64985 L p .662 .319 .381 r
F P
0 g
s
.55567 .534 m .5537 .52958 L .55661 .52916 L p .378 0 .081 r
F P
0 g
s
.56819 .52452 m .55661 .52916 L .5537 .52958 L p .43 .041 .198 r
F P
0 g
s
.5538 .53381 m .55242 .53071 L .5537 .52958 L p .379 0 .081 r
F P
0 g
s
.5537 .52958 m .55567 .534 L .5538 .53381 L p .379 0 .081 r
F P
0 g
s
.61559 .61846 m .61175 .62034 L .60969 .62264 L p .866 .995 .797 r
F P
0 g
s
.69172 .8192 m .65532 .83203 L .6407 .82635 L p .629 .653 .855 r
F P
0 g
s
.63007 .43485 m .62961 .44503 L .62966 .44624 L p .826 .732 .207 r
F P
0 g
s
.62966 .44624 m .63032 .4317 L .63007 .43485 L p .826 .732 .207 r
F P
0 g
s
.63032 .4317 m .62966 .44624 L .63024 .44283 L p .954 .886 .491 r
F P
0 g
s
.42893 .47179 m .42794 .47675 L .42743 .4769 L p 0 0 .204 r
F P
0 g
s
.57323 .52194 m .57593 .52414 L .57407 .52611 L p .509 .185 .354 r
F P
0 g
s
.78542 .55734 m .82235 .56184 L .82943 .56489 L p .667 .735 .901 r
F P
0 g
s
.82943 .56489 m .77672 .55846 L .78542 .55734 L p .667 .735 .901 r
F P
0 g
s
.83546 .54993 m .82943 .56489 L .82235 .56184 L p .661 .736 .905 r
F P
0 g
s
.7257 .56644 m .70437 .56276 L .69985 .56175 L p .704 .711 .853 r
F P
0 g
s
.60181 .50561 m .59195 .51408 L .58971 .51579 L p .539 .292 .49 r
F P
0 g
s
.60569 .50177 m .60617 .50223 L .60447 .50435 L p .487 .291 .54 r
F P
0 g
s
.63082 .59586 m .6391 .59578 L .64191 .59377 L p .834 .835 .847 r
F P
0 g
s
.64191 .59377 m .63008 .59388 L .63082 .59586 L p .834 .835 .847 r
F P
0 g
s
.64473 .58306 m .64084 .59185 L .64191 .59377 L p .822 .8 .831 r
F P
0 g
s
.64191 .59377 m .64748 .58123 L .64473 .58306 L p .822 .8 .831 r
F P
0 g
s
.63008 .59388 m .64191 .59377 L .64084 .59185 L p .848 .807 .811 r
F P
0 g
s
.42664 .48002 m .42721 .47801 L .42794 .47675 L p 0 0 .094 r
F P
0 g
s
.43095 .46224 m .43798 .45899 L .43955 .4599 L p .326 .232 .593 r
F P
0 g
s
.67601 .56703 m .69244 .56995 L .69653 .5694 L p .722 .718 .845 r
F P
0 g
s
.69653 .5694 m .67304 .56522 L .67601 .56703 L p .722 .718 .845 r
F P
0 g
s
.6949 .56458 m .69332 .56803 L .69653 .5694 L p .711 .722 .858 r
F P
0 g
s
.69653 .5694 m .69879 .56447 L .6949 .56458 L p .711 .722 .858 r
F P
0 g
s
.67304 .56522 m .69653 .5694 L .69332 .56803 L p .723 .717 .844 r
F P
0 g
s
.70825 .81163 m .74676 .84892 L .74768 .86092 L p .599 .647 .868 r
F P
0 g
s
.74768 .86092 m .69273 .80787 L .70825 .81163 L p .599 .647 .868 r
F P
0 g
s
.80471 .82886 m .74768 .86092 L .74676 .84892 L p .6 .647 .868 r
F P
0 g
s
.54763 .5323 m .54395 .53662 L .54158 .53802 L p .298 0 0 r
F P
0 g
s
.51163 .61742 m .51018 .61887 L .50848 .61706 L p .93 .577 .333 r
F P
0 g
s
.61623 .48656 m .61713 .48785 L .61592 .49025 L p .368 .222 .548 r
F P
0 g
s
.60535 .50515 m .60447 .50435 L .60637 .50244 L p .497 .306 .551 r
F P
0 g
s
.61471 .493 m .60637 .50244 L .60447 .50435 L p .489 .294 .543 r
F P
0 g
s
.60447 .50435 m .61638 .49086 L .61471 .493 L p .489 .294 .543 r
F P
0 g
s
.60319 .50687 m .60258 .50631 L .60447 .50435 L p .545 .302 .498 r
F P
0 g
s
.60447 .50435 m .60535 .50515 L .60319 .50687 L p .545 .302 .498 r
F P
0 g
s
.59076 .51657 m .60447 .50435 L .60258 .50631 L p .548 .306 .5 r
F P
0 g
s
.61638 .49086 m .60447 .50435 L .60617 .50223 L p .479 .281 .533 r
F P
0 g
s
.59269 .51463 m .60229 .50608 L .60447 .50435 L p .539 .292 .49 r
F P
0 g
s
.60447 .50435 m .59076 .51657 L .59269 .51463 L p .539 .292 .49 r
F P
0 g
s
.61663 .78128 m .6407 .82635 L .62932 .82101 L p .658 .636 .817 r
F P
0 g
s
.62706 .78559 m .64389 .81721 L .6407 .82635 L p .623 .62 .827 r
F P
0 g
s
.6407 .82635 m .61663 .78128 L .62706 .78559 L p .623 .62 .827 r
F P
0 g
s
.69273 .80787 m .6407 .82635 L .64389 .81721 L p .622 .62 .827 r
F P
0 g
s
.6407 .82635 m .69273 .80787 L .69172 .8192 L p .629 .653 .855 r
F P
0 g
s
.58443 .6416 m .59413 .63698 L .59583 .63655 L p .126 0 0 r
F P
0 g
s
.59583 .63655 m .58197 .64315 L .58443 .6416 L p .126 0 0 r
F P
0 g
s
.63024 .44283 m .63071 .43265 L .63032 .4317 L p .954 .886 .491 r
F P
0 g
s
.60617 .50223 m .61451 .49279 L .61638 .49086 L p .479 .281 .533 r
F P
0 g
s
.37115 .53359 m .38845 .52516 L .38547 .52533 L p .768 .912 .937 r
F P
0 g
s
.38406 .52087 m .38547 .52533 L .38845 .52516 L p .741 .921 .952 r
F P
0 g
s
.38845 .52516 m .38646 .51877 L .38406 .52087 L p .741 .921 .952 r
F P
0 g
s
.39911 .51709 m .39017 .52303 L .38845 .52516 L p .803 .969 .908 r
F P
0 g
s
.38646 .51877 m .38845 .52516 L .39017 .52303 L p .797 .946 .921 r
F P
0 g
s
.42794 .47675 m .42893 .47179 L .43013 .47209 L p .261 .108 .476 r
F P
0 g
s
.43668 .46972 m .43013 .47209 L .42893 .47179 L p .263 .103 .468 r
F P
0 g
s
.42893 .47179 m .43828 .46841 L .43668 .46972 L p .263 .103 .468 r
F P
0 g
s
.43087 .46501 m .43046 .47011 L .42893 .47179 L p .294 .169 .534 r
F P
0 g
s
.43828 .46841 m .42893 .47179 L .43046 .47011 L p .286 .158 .525 r
F P
0 g
s
.57837 .64677 m .57936 .64406 L .58197 .64315 L p .512 .153 .294 r
F P
0 g
s
.58197 .64315 m .58056 .64702 L .57837 .64677 L p .512 .153 .294 r
F P
0 g
s
.59353 .63812 m .58383 .64274 L .58197 .64315 L p .299 0 .197 r
F P
0 g
s
.58197 .64315 m .59583 .63655 L .59353 .63812 L p .299 0 .197 r
F P
0 g
s
.58056 .64702 m .58197 .64315 L .58383 .64274 L p .303 0 .208 r
F P
0 g
s
.7261 .56546 m .72782 .56178 L .73278 .56175 L p .686 .724 .879 r
F P
0 g
s
.42794 .47675 m .42714 .47962 L .42664 .48002 L p 0 0 .094 r
F P
0 g
s
.40256 .51475 m .40212 .51118 L .40058 .5116 L p .824 .994 .859 r
F P
0 g
s
.50609 .60218 m .50459 .60268 L .50353 .60039 L p .97 .666 .28 r
F P
0 g
s
.41862 .39441 m .39902 .3689 L .40438 .37081 L p .548 .528 .785 r
F P
0 g
s
.41641 .36074 m .40438 .37081 L .39902 .3689 L p .548 .528 .785 r
F P
0 g
s
.39902 .3689 m .41619 .3545 L .41641 .36074 L p .548 .528 .785 r
F P
0 g
s
.37559 .33998 m .39719 .3618 L .39902 .3689 L p .571 .571 .813 r
F P
0 g
s
.39902 .3689 m .3682 .33778 L .37559 .33998 L p .571 .571 .813 r
F P
0 g
s
.41619 .3545 m .39902 .3689 L .39719 .3618 L p .572 .571 .813 r
F P
0 g
s
.4263 .48121 m .4265 .48056 L .42714 .47962 L p 0 0 .042 r
F P
0 g
s
.64105 .40716 m .63596 .39627 L .63313 .39624 L p .907 .83 .758 r
F P
0 g
s
.60637 .50244 m .60698 .503 L .60535 .50515 L p .497 .306 .551 r
F P
0 g
s
.57593 .52414 m .58687 .51691 L .58971 .51579 L p .532 .214 .374 r
F P
0 g
s
.60258 .50631 m .59299 .51487 L .59076 .51657 L p .548 .306 .5 r
F P
0 g
s
.59195 .51408 m .59269 .51463 L .59076 .51657 L p .54 .294 .491 r
F P
0 g
s
.59076 .51657 m .58971 .51579 L .59195 .51408 L p .54 .294 .491 r
F P
0 g
s
.62259 .4759 m .62182 .47378 L .62315 .47121 L p .294 .13 .48 r
F P
0 g
s
.33956 .53401 m .34279 .54142 L .34809 .54196 L p .693 .825 .946 r
F P
0 g
s
.34809 .54196 m .34351 .53135 L .33956 .53401 L p .693 .825 .946 r
F P
0 g
s
.36711 .53344 m .35095 .53931 L .34809 .54196 L p .732 .859 .941 r
F P
0 g
s
.34809 .54196 m .37115 .53359 L .36711 .53344 L p .732 .859 .941 r
F P
0 g
s
.34351 .53135 m .34809 .54196 L .35095 .53931 L p .726 .842 .936 r
F P
0 g
s
.58832 .51801 m .58758 .51746 L .58971 .51579 L p .576 .277 .425 r
F P
0 g
s
.58971 .51579 m .59076 .51657 L .58832 .51801 L p .576 .277 .425 r
F P
0 g
s
.57407 .52611 m .58971 .51579 L .58758 .51746 L p .558 .252 .406 r
F P
0 g
s
.58971 .51579 m .57407 .52611 L .57593 .52414 L p .532 .214 .374 r
F P
0 g
s
.55661 .52916 m .558 .53224 L .55567 .534 L p .378 0 .081 r
F P
0 g
s
.42714 .47962 m .42684 .48056 L .4263 .48121 L p 0 0 .042 r
F P
0 g
s
.41862 .39441 m .43051 .41579 L .42692 .41446 L p .454 .448 .762 r
F P
0 g
s
.53004 .54213 m .52637 .54483 L .52666 .54542 L p .076 0 0 r
F P
0 g
s
.52666 .54542 m .53191 .54156 L .53004 .54213 L p .076 0 0 r
F P
0 g
s
.56714 .64829 m .57837 .64677 L .58056 .64702 L p .511 .148 .286 r
F P
0 g
s
.58056 .64702 m .56451 .6492 L .56714 .64829 L p .511 .148 .286 r
F P
0 g
s
.50964 .56665 m .50781 .56966 L .50794 .56912 L p .754 .888 .481 r
F P
0 g
s
.50794 .56912 m .51055 .56481 L .50964 .56665 L p .754 .888 .481 r
F P
0 g
s
.42595 .48229 m .42621 .48151 L .42684 .48056 L p 0 0 .023 r
F P
0 g
s
.56115 .65159 m .56185 .6493 L .56451 .6492 L p .667 .342 .414 r
F P
0 g
s
.56451 .6492 m .56352 .65247 L .56115 .65159 L p .667 .342 .414 r
F P
0 g
s
.57802 .64784 m .56678 .64936 L .56451 .6492 L p .545 .223 .373 r
F P
0 g
s
.56451 .6492 m .58056 .64702 L .57802 .64784 L p .545 .223 .373 r
F P
0 g
s
.56352 .65247 m .56451 .6492 L .56678 .64936 L p .544 .221 .371 r
F P
0 g
s
.62424 .47422 m .62315 .47121 L .62415 .46951 L p .096 .029 .483 r
F P
0 g
s
.62819 .45941 m .62415 .46951 L .62315 .47121 L p .076 .005 .464 r
F P
0 g
s
.62315 .47121 m .62893 .45679 L .62819 .45941 L p .076 .005 .464 r
F P
0 g
s
.62315 .47121 m .62424 .47422 L .62259 .4759 L p .294 .13 .48 r
F P
0 g
s
.62893 .45679 m .62315 .47121 L .62394 .46839 L p 0 0 .34 r
F P
0 g
s
.62932 .82101 m .61244 .7895 L .61663 .78128 L p .658 .636 .817 r
F P
0 g
s
.61451 .49279 m .61418 .49237 L .61592 .49025 L p .469 .267 .523 r
F P
0 g
s
.42684 .48056 m .42648 .48167 L .42595 .48229 L p 0 0 .023 r
F P
0 g
s
.36472 .52769 m .36711 .53344 L .37115 .53359 L p .714 .867 .954 r
F P
0 g
s
.37115 .53359 m .36777 .52537 L .36472 .52769 L p .714 .867 .954 r
F P
0 g
s
.38547 .52533 m .37334 .53124 L .37115 .53359 L p .768 .912 .937 r
F P
0 g
s
.36777 .52537 m .37115 .53359 L .37334 .53124 L p .759 .889 .936 r
F P
0 g
s
.32836 .85397 m .36542 .8147 L .37837 .80855 L p .746 .759 .863 r
F P
0 g
s
.69332 .56803 m .67688 .56511 L .67304 .56522 L p .723 .717 .844 r
F P
0 g
s
.60818 .50748 m .60535 .50515 L .60745 .50345 L p .516 .333 .571 r
F P
0 g
s
.61559 .49395 m .60745 .50345 L .60535 .50515 L p .507 .319 .56 r
F P
0 g
s
.60535 .50515 m .61698 .49158 L .61559 .49395 L p .507 .319 .56 r
F P
0 g
s
.60589 .509 m .6039 .50737 L .60535 .50515 L p .559 .324 .516 r
F P
0 g
s
.60535 .50515 m .60818 .50748 L .60589 .509 L p .559 .324 .516 r
F P
0 g
s
.5921 .5175 m .60535 .50515 L .6039 .50737 L p .569 .336 .523 r
F P
0 g
s
.61698 .49158 m .60535 .50515 L .60698 .503 L p .488 .294 .543 r
F P
0 g
s
.59392 .51552 m .60319 .50687 L .60535 .50515 L p .548 .306 .501 r
F P
0 g
s
.60535 .50515 m .5921 .5175 L .59392 .51552 L p .548 .306 .501 r
F P
0 g
s
.61638 .49086 m .61592 .49025 L .61735 .48821 L p .388 .248 .566 r
F P
0 g
s
.62379 .47823 m .61735 .48821 L .61592 .49025 L p .373 .229 .554 r
F P
0 g
s
.61592 .49025 m .62511 .47599 L .62379 .47823 L p .373 .229 .554 r
F P
0 g
s
.61592 .49025 m .61638 .49086 L .61451 .49279 L p .469 .267 .523 r
F P
0 g
s
.62511 .47599 m .61592 .49025 L .61713 .48785 L p .352 .205 .537 r
F P
0 g
s
.42483 .48521 m .42574 .48292 L .42648 .48167 L p 0 0 0 r
F P
0 g
s
.43051 .41579 m .41862 .39441 L .42264 .39611 L p .523 .48 .75 r
F P
0 g
s
.43345 .38823 m .42264 .39611 L .41862 .39441 L p .523 .48 .751 r
F P
0 g
s
.41862 .39441 m .43405 .38313 L .43345 .38823 L p .523 .48 .751 r
F P
0 g
s
.40438 .37081 m .41812 .38868 L .41862 .39441 L p .548 .528 .785 r
F P
0 g
s
.43405 .38313 m .41862 .39441 L .41812 .38868 L p .548 .528 .785 r
F P
0 g
s
.60698 .503 m .61512 .49351 L .61698 .49158 L p .488 .294 .543 r
F P
0 g
s
.59978 .63187 m .59787 .63445 L .59583 .63655 L p 0 0 0 r
F P
0 g
s
.32166 .5473 m .31748 .53788 L .31192 .53689 L p .701 .808 .932 r
F P
0 g
s
.53351 .64327 m .54451 .6483 L .54665 .64985 L p .764 .421 .404 r
F P
0 g
s
.54665 .64985 m .53094 .64266 L .53351 .64327 L p .764 .421 .404 r
F P
0 g
s
.51433 .55581 m .51068 .56306 L .50927 .56521 L p .814 .975 .677 r
F P
0 g
s
.50927 .56521 m .51449 .55486 L .51433 .55581 L p .814 .975 .677 r
F P
0 g
s
.67362 .57255 m .67601 .56703 L .67304 .56522 L p .737 .715 .831 r
F P
0 g
s
.67304 .56522 m .66963 .57311 L .67362 .57255 L p .737 .715 .831 r
F P
0 g
s
.62394 .46839 m .62798 .45829 L .62893 .45679 L p 0 0 .34 r
F P
0 g
s
.58758 .51746 m .57663 .52469 L .57407 .52611 L p .558 .252 .406 r
F P
0 g
s
.52009 .63273 m .52923 .64055 L .53094 .64266 L p .852 .506 .398 r
F P
0 g
s
.61713 .48785 m .62357 .47787 L .62511 .47599 L p .352 .205 .537 r
F P
0 g
s
.42714 .47962 m .42794 .47675 L .4291 .47683 L p .235 .062 .431 r
F P
0 g
s
.43522 .47501 m .4291 .47683 L .42794 .47675 L p .235 .053 .418 r
F P
0 g
s
.42794 .47675 m .43669 .47416 L .43522 .47501 L p .235 .053 .418 r
F P
0 g
s
.43013 .47209 m .42944 .47556 L .42794 .47675 L p .261 .108 .476 r
F P
0 g
s
.43669 .47416 m .42794 .47675 L .42944 .47556 L p .25 .091 .461 r
F P
0 g
s
.43425 .43246 m .42976 .41995 L .43051 .41579 L p .412 .38 .714 r
F P
0 g
s
.59299 .51487 m .59392 .51552 L .5921 .5175 L p .55 .309 .503 r
F P
0 g
s
.5921 .5175 m .59076 .51657 L .59299 .51487 L p .55 .309 .503 r
F P
0 g
s
.64084 .59185 m .63256 .59192 L .63008 .59388 L p .848 .807 .811 r
F P
0 g
s
.58974 .51895 m .5888 .5183 L .59076 .51657 L p .585 .288 .432 r
F P
0 g
s
.59076 .51657 m .5921 .5175 L .58974 .51895 L p .585 .288 .432 r
F P
0 g
s
.57582 .52709 m .59076 .51657 L .5888 .5183 L p .576 .276 .423 r
F P
0 g
s
.57786 .52538 m .58832 .51801 L .59076 .51657 L p .559 .252 .403 r
F P
0 g
s
.59076 .51657 m .57582 .52709 L .57786 .52538 L p .559 .252 .403 r
F P
0 g
s
.61512 .49351 m .61471 .493 L .61638 .49086 L p .477 .28 .533 r
F P
0 g
s
.60745 .50345 m .60944 .50508 L .60818 .50748 L p .516 .333 .571 r
F P
0 g
s
.52519 .54587 m .52093 .54949 L .52056 .55061 L p .016 0 0 r
F P
0 g
s
.43046 .47011 m .43701 .46773 L .43828 .46841 L p .286 .158 .525 r
F P
0 g
s
.42648 .48167 m .42517 .48495 L .42483 .48521 L p 0 0 0 r
F P
0 g
s
.65341 .57236 m .66622 .57429 L .66963 .57311 L p .758 .725 .822 r
F P
0 g
s
.66963 .57311 m .65133 .57034 L .65341 .57236 L p .758 .725 .822 r
F P
0 g
s
.66973 .56596 m .66734 .57148 L .66963 .57311 L p .743 .723 .833 r
F P
0 g
s
.66963 .57311 m .67304 .56522 L .66973 .56596 L p .743 .723 .833 r
F P
0 g
s
.65133 .57034 m .66963 .57311 L .66734 .57148 L p .76 .721 .816 r
F P
0 g
s
.50866 .56729 m .51049 .56427 L .51055 .56481 L p .838 .929 .547 r
F P
0 g
s
.51055 .56481 m .50794 .56912 L .50866 .56729 L p .838 .929 .547 r
F P
0 g
s
.58383 .64274 m .58285 .64545 L .58056 .64702 L p .303 0 .208 r
F P
0 g
s
.40423 .82892 m .3772 .81942 L .37837 .80855 L p .736 .741 .855 r
F P
0 g
s
.37837 .80855 m .41702 .82223 L .40423 .82892 L p .736 .741 .855 r
F P
0 g
s
.61698 .49158 m .61638 .49086 L .61781 .48883 L p .401 .265 .579 r
F P
0 g
s
.62414 .47882 m .61781 .48883 L .61638 .49086 L p .383 .243 .563 r
F P
0 g
s
.61638 .49086 m .62543 .47657 L .62414 .47882 L p .383 .243 .563 r
F P
0 g
s
.61638 .49086 m .61698 .49158 L .61512 .49351 L p .477 .28 .533 r
F P
0 g
s
.61735 .48821 m .61768 .48863 L .61638 .49086 L p .388 .248 .566 r
F P
0 g
s
.62543 .47657 m .61638 .49086 L .61768 .48863 L p .372 .229 .554 r
F P
0 g
s
.54935 .64976 m .56115 .65159 L .56352 .65247 L p .668 .333 .398 r
F P
0 g
s
.56352 .65247 m .54665 .64985 L .54935 .64976 L p .668 .333 .398 r
F P
0 g
s
.6039 .50737 m .59463 .51602 L .5921 .5175 L p .569 .336 .523 r
F P
0 g
s
.62961 .44503 m .62894 .44927 L .62871 .4523 L p .82 .723 .193 r
F P
0 g
s
.53094 .64266 m .51787 .63147 L .52009 .63273 L p .852 .506 .398 r
F P
0 g
s
.5281 .64275 m .52881 .64129 L .53094 .64266 L p .842 .538 .475 r
F P
0 g
s
.53094 .64266 m .52993 .64475 L .5281 .64275 L p .842 .538 .475 r
F P
0 g
s
.51787 .63147 m .53094 .64266 L .52881 .64129 L p .844 .528 .454 r
F P
0 g
s
.54416 .64909 m .53316 .64405 L .53094 .64266 L p .763 .449 .455 r
F P
0 g
s
.53094 .64266 m .54665 .64985 L .54416 .64909 L p .763 .449 .455 r
F P
0 g
s
.52993 .64475 m .53094 .64266 L .53316 .64405 L p .766 .442 .439 r
F P
0 g
s
.56678 .64936 m .56609 .65165 L .56352 .65247 L p .544 .221 .371 r
F P
0 g
s
.39017 .52303 m .38878 .51856 L .38646 .51877 L p .797 .946 .921 r
F P
0 g
s
.52056 .55061 m .52666 .54542 L .52519 .54587 L p .016 0 0 r
F P
0 g
s
.54363 .65062 m .54416 .64909 L .54665 .64985 L p .764 .461 .473 r
F P
0 g
s
.54665 .64985 m .54589 .65203 L .54363 .65062 L p .764 .461 .473 r
F P
0 g
s
.56089 .6524 m .54908 .65056 L .54665 .64985 L p .674 .367 .446 r
F P
0 g
s
.54665 .64985 m .56352 .65247 L .56089 .6524 L p .674 .367 .446 r
F P
0 g
s
.54589 .65203 m .54665 .64985 L .54908 .65056 L p .674 .364 .441 r
F P
0 g
s
.38969 .327 m .37559 .33998 L .3682 .33778 L p .571 .571 .814 r
F P
0 g
s
.3682 .33778 m .38831 .31918 L .38969 .327 L p .571 .571 .814 r
F P
0 g
s
.33094 .30172 m .36442 .32879 L .3682 .33778 L p .593 .609 .837 r
F P
0 g
s
.3682 .33778 m .32044 .29919 L .33094 .30172 L p .593 .609 .837 r
F P
0 g
s
.38831 .31918 m .3682 .33778 L .36442 .32879 L p .593 .609 .837 r
F P
0 g
s
.63837 .41127 m .6336 .41913 L .63359 .42301 L p .949 .83 .692 r
F P
0 g
s
.42246 .49004 m .42431 .48643 L .42517 .48495 L p 0 0 0 r
F P
0 g
s
.70345 .56508 m .70399 .56416 L .69955 .56315 L p .716 .704 .837 r
F P
0 g
s
.69955 .56315 m .69879 .56447 L .70345 .56508 L p .716 .704 .837 r
F P
0 g
s
.53316 .64405 m .53246 .64552 L .52993 .64475 L p .766 .442 .439 r
F P
0 g
s
.42684 .48056 m .42714 .47962 L .42832 .47945 L p .222 .039 .409 r
F P
0 g
s
.43416 .47792 m .42832 .47945 L .42714 .47962 L p .218 .024 .39 r
F P
0 g
s
.42714 .47962 m .43547 .47744 L .43416 .47792 L p .218 .024 .39 r
F P
0 g
s
.4291 .47683 m .42853 .47884 L .42714 .47962 L p .235 .062 .431 r
F P
0 g
s
.43547 .47744 m .42714 .47962 L .42853 .47884 L p .224 .043 .412 r
F P
0 g
s
.82235 .56184 m .82653 .55136 L .83546 .54993 L p .661 .736 .905 r
F P
0 g
s
.56535 .79669 m .53312 .79743 L .52571 .79033 L p .689 .656 .813 r
F P
0 g
s
.61768 .48863 m .62401 .47863 L .62543 .47657 L p .372 .229 .554 r
F P
0 g
s
.54118 .5375 m .53441 .53998 L .53191 .54156 L p .069 0 0 r
F P
0 g
s
.52881 .64129 m .51966 .63346 L .51787 .63147 L p .844 .528 .454 r
F P
0 g
s
.62415 .46951 m .62491 .47162 L .62424 .47422 L p .096 .029 .483 r
F P
0 g
s
.42648 .48167 m .42684 .48056 L .42799 .48043 L p .213 .027 .398 r
F P
0 g
s
.43372 .479 m .42799 .48043 L .42684 .48056 L p .209 .009 .374 r
F P
0 g
s
.42684 .48056 m .43503 .47851 L .43372 .479 L p .209 .009 .374 r
F P
0 g
s
.42832 .47945 m .42812 .4801 L .42684 .48056 L p .222 .039 .409 r
F P
0 g
s
.43503 .47851 m .42684 .48056 L .42812 .4801 L p .213 .02 .388 r
F P
0 g
s
.70112 .33024 m .73373 .30536 L .73847 .29481 L p .79 .794 .856 r
F P
0 g
s
.73847 .29481 m .69176 .33046 L .70112 .33024 L p .79 .794 .856 r
F P
0 g
s
.62665 .60539 m .63082 .59586 L .63008 .59388 L p .857 .844 .83 r
F P
0 g
s
.63008 .59388 m .62412 .6075 L .62665 .60539 L p .857 .844 .83 r
F P
0 g
s
.54908 .65056 m .54855 .6521 L .54589 .65203 L p .674 .364 .441 r
F P
0 g
s
.5888 .5183 m .57834 .52567 L .57582 .52709 L p .576 .276 .423 r
F P
0 g
s
.61781 .48883 m .61823 .48934 L .61698 .49158 L p .401 .265 .579 r
F P
0 g
s
.61894 .49371 m .61698 .49158 L .61855 .48975 L p .422 .292 .598 r
F P
0 g
s
.62474 .47973 m .61855 .48975 L .61698 .49158 L p .407 .273 .584 r
F P
0 g
s
.61698 .49158 m .62582 .47727 L .62474 .47973 L p .407 .273 .584 r
F P
0 g
s
.61696 .49544 m .61559 .49395 L .61698 .49158 L p .491 .301 .55 r
F P
0 g
s
.61698 .49158 m .61894 .49371 L .61696 .49544 L p .491 .301 .55 r
F P
0 g
s
.62582 .47727 m .61698 .49158 L .61823 .48934 L p .381 .242 .564 r
F P
0 g
s
.51018 .61887 m .51676 .62896 L .51787 .63147 L p .932 .598 .38 r
F P
0 g
s
.35095 .53931 m .34777 .53188 L .34351 .53135 L p .726 .842 .936 r
F P
0 g
s
.5281 .54363 m .53178 .54092 L .53191 .54156 L p .706 .982 .801 r
F P
0 g
s
.53191 .54156 m .52666 .54542 L .5281 .54363 L p .706 .982 .801 r
F P
0 g
s
.53191 .54156 m .54158 .53802 L .54118 .5375 L p .069 0 0 r
F P
0 g
s
.54158 .53802 m .53191 .54156 L .53178 .54092 L p .454 .87 .947 r
F P
0 g
s
.70437 .56276 m .70417 .56374 L .69955 .56315 L p .714 .701 .837 r
F P
0 g
s
.42517 .48495 m .42648 .48167 L .42743 .48191 L p .189 0 .357 r
F P
0 g
s
.43301 .48058 m .42743 .48191 L .42648 .48167 L p .192 0 .337 r
F P
0 g
s
.42648 .48167 m .43445 .47977 L .43301 .48058 L p .192 0 .337 r
F P
0 g
s
.42799 .48043 m .42774 .48121 L .42648 .48167 L p .213 .027 .398 r
F P
0 g
s
.43445 .47977 m .42648 .48167 L .42774 .48121 L p .202 .002 .37 r
F P
0 g
s
.37334 .53124 m .37099 .52548 L .36777 .52537 L p .759 .889 .936 r
F P
0 g
s
.51764 .79685 m .48733 .79326 L .48234 .78518 L p .715 .68 .814 r
F P
0 g
s
.48234 .78518 m .52571 .79033 L .51764 .79685 L p .715 .68 .814 r
F P
0 g
s
.67816 .56166 m .6949 .56458 L .69879 .56447 L p .715 .708 .842 r
F P
0 g
s
.69879 .56447 m .67487 .56029 L .67816 .56166 L p .715 .708 .842 r
F P
0 g
s
.69585 .56272 m .69531 .56365 L .69879 .56447 L p .716 .704 .837 r
F P
0 g
s
.69879 .56447 m .69955 .56315 L .69585 .56272 L p .716 .704 .837 r
F P
0 g
s
.67487 .56029 m .69879 .56447 L .69531 .56365 L p .726 .694 .819 r
F P
0 g
s
.59651 .52014 m .5921 .5175 L .59463 .51602 L p .575 .345 .531 r
F P
0 g
s
.59403 .52137 m .59094 .51952 L .5921 .5175 L p .604 .318 .456 r
F P
0 g
s
.5921 .5175 m .59651 .52014 L .59403 .52137 L p .604 .318 .456 r
F P
0 g
s
.57818 .52822 m .5921 .5175 L .59094 .51952 L p .611 .326 .461 r
F P
0 g
s
.58 .52646 m .58974 .51895 L .5921 .5175 L p .576 .275 .421 r
F P
0 g
s
.5921 .5175 m .57818 .52822 L .58 .52646 L p .576 .275 .421 r
F P
0 g
s
.74175 .55531 m .73931 .56133 L .73278 .56175 L p .682 .72 .878 r
F P
0 g
s
.73278 .56175 m .73624 .55315 L .74175 .55531 L p .682 .72 .878 r
F P
0 g
s
.707 .55625 m .72864 .55975 L .73278 .56175 L p .69 .714 .867 r
F P
0 g
s
.73278 .56175 m .70188 .55676 L .707 .55625 L p .69 .714 .867 r
F P
0 g
s
.73624 .55315 m .73278 .56175 L .72864 .55975 L p .679 .716 .877 r
F P
0 g
s
.70188 .55676 m .73278 .56175 L .72782 .56178 L p .69 .714 .867 r
F P
0 g
s
.39719 .3618 m .40918 .35168 L .41619 .3545 L p .572 .571 .813 r
F P
0 g
s
.41812 .38868 m .42891 .38076 L .43405 .38313 L p .548 .528 .785 r
F P
0 g
s
.72782 .56178 m .70619 .55828 L .70188 .55676 L p .69 .714 .867 r
F P
0 g
s
.66734 .57148 m .65453 .56954 L .65133 .57034 L p .76 .721 .816 r
F P
0 g
s
.42517 .48495 m .42253 .49011 L .42246 .49004 L p 0 0 0 r
F P
0 g
s
.59463 .51602 m .59772 .51786 L .59651 .52014 L p .575 .345 .531 r
F P
0 g
s
.42944 .47556 m .43556 .47375 L .43669 .47416 L p .25 .091 .461 r
F P
0 g
s
.66853 .35769 m .68914 .33851 L .69176 .33046 L p .825 .808 .834 r
F P
0 g
s
.51787 .63147 m .50848 .61706 L .51018 .61887 L p .932 .598 .38 r
F P
0 g
s
.51537 .63099 m .51625 .6296 L .51787 .63147 L p .915 .625 .479 r
F P
0 g
s
.51787 .63147 m .51661 .63347 L .51537 .63099 L p .915 .625 .479 r
F P
0 g
s
.50848 .61706 m .51787 .63147 L .51625 .6296 L p .919 .617 .456 r
F P
0 g
s
.51661 .63347 m .51787 .63147 L .51966 .63346 L p .849 .523 .435 r
F P
0 g
s
.61704 .61136 m .62186 .60974 L .62412 .6075 L p .874 .972 .848 r
F P
0 g
s
.62412 .6075 m .61725 .6098 L .61704 .61136 L p .874 .972 .848 r
F P
0 g
s
.62802 .59621 m .62385 .60575 L .62412 .6075 L p .899 .903 .819 r
F P
0 g
s
.62412 .6075 m .63008 .59388 L .62802 .59621 L p .899 .903 .819 r
F P
0 g
s
.61725 .6098 m .62412 .6075 L .62385 .60575 L p .924 .913 .789 r
F P
0 g
s
.43692 .43368 m .43051 .41579 L .43362 .41731 L p .501 .432 .711 r
F P
0 g
s
.44383 .41116 m .43362 .41731 L .43051 .41579 L p .5 .433 .712 r
F P
0 g
s
.43051 .41579 m .44509 .40698 L .44383 .41116 L p .5 .433 .712 r
F P
0 g
s
.43051 .41579 m .43692 .43368 L .43425 .43246 L p .412 .38 .714 r
F P
0 g
s
.42264 .39611 m .43097 .41109 L .43051 .41579 L p .523 .48 .75 r
F P
0 g
s
.44509 .40698 m .43051 .41579 L .43097 .41109 L p .523 .481 .751 r
F P
0 g
s
.61823 .48934 m .62442 .47932 L .62582 .47727 L p .381 .242 .564 r
F P
0 g
s
.69176 .33046 m .66226 .35792 L .66853 .35769 L p .825 .808 .834 r
F P
0 g
s
.69955 .56315 m .69985 .56175 L .70437 .56276 L p .714 .701 .837 r
F P
0 g
s
.51966 .63346 m .51878 .63485 L .51661 .63347 L p .849 .523 .435 r
F P
0 g
s
.50719 .57192 m .50423 .58159 L .5037 .58294 L p .79 .805 .317 r
F P
0 g
s
.5037 .58294 m .50794 .56912 L .50719 .57192 L p .79 .805 .317 r
F P
0 g
s
.67918 .55935 m .69599 .56231 L .69955 .56315 L p .724 .691 .818 r
F P
0 g
s
.69955 .56315 m .67554 .55893 L .67918 .55935 L p .724 .691 .818 r
F P
0 g
s
.69985 .56175 m .69955 .56315 L .69599 .56231 L p .714 .701 .837 r
F P
0 g
s
.67904 .55977 m .69585 .56272 L .69955 .56315 L p .724 .691 .818 r
F P
0 g
s
.69955 .56315 m .67554 .55893 L .67904 .55977 L p .724 .691 .818 r
F P
0 g
s
.4183 .49637 m .42149 .49177 L .42253 .49011 L p .66 .861 .473 r
F P
0 g
s
.62357 .47787 m .62296 .47663 L .62424 .47422 L p .337 .185 .522 r
F P
0 g
s
.44488 .77584 m .41702 .82223 L .41608 .81347 L p .755 .729 .828 r
F P
0 g
s
.38902 .80384 m .41608 .81347 L .41702 .82223 L p .756 .729 .828 r
F P
0 g
s
.41702 .82223 m .37837 .80855 L .38902 .80384 L p .756 .729 .828 r
F P
0 g
s
.44717 .78441 m .42764 .81684 L .41702 .82223 L p .738 .705 .82 r
F P
0 g
s
.41702 .82223 m .44488 .77584 L .44717 .78441 L p .738 .705 .82 r
F P
0 g
s
.60944 .50508 m .61696 .49544 L .61894 .49371 L p .503 .319 .564 r
F P
0 g
s
.61894 .49371 m .60818 .50748 L .60944 .50508 L p .503 .319 .564 r
F P
0 g
s
.69531 .56365 m .67857 .56072 L .67487 .56029 L p .726 .694 .819 r
F P
0 g
s
.61855 .48975 m .61992 .49124 L .61894 .49371 L p .422 .292 .598 r
F P
0 g
s
.53246 .64552 m .54363 .65062 L .54589 .65203 L p .767 .454 .456 r
F P
0 g
s
.42253 .49011 m .42517 .48495 L .42581 .48553 L p .137 0 .273 r
F P
0 g
s
.43098 .48447 m .42581 .48553 L .42517 .48495 L p .153 0 .257 r
F P
0 g
s
.42517 .48495 m .43257 .48343 L .43098 .48447 L p .153 0 .257 r
F P
0 g
s
.42743 .48191 m .42652 .4842 L .42517 .48495 L p .189 0 .357 r
F P
0 g
s
.43257 .48343 m .42517 .48495 L .42652 .4842 L p .17 0 .323 r
F P
0 g
s
.52571 .79033 m .57182 .78928 L .56535 .79669 L p .689 .656 .813 r
F P
0 g
s
.59772 .51786 m .60589 .509 L .60818 .50748 L p .567 .337 .526 r
F P
0 g
s
.65072 .57998 m .65341 .57236 L .65133 .57034 L p .777 .726 .805 r
F P
0 g
s
.65133 .57034 m .64748 .58123 L .65072 .57998 L p .777 .726 .805 r
F P
0 g
s
.54589 .65203 m .52993 .64475 L .53246 .64552 L p .767 .454 .456 r
F P
0 g
s
.61351 .51105 m .60818 .50748 L .61047 .50593 L p .548 .382 .607 r
F P
0 g
s
.618 .49629 m .61047 .50593 L .60818 .50748 L p .538 .363 .593 r
F P
0 g
s
.60818 .50748 m .61894 .49371 L .618 .49629 L p .538 .363 .593 r
F P
0 g
s
.61116 .51243 m .60743 .50992 L .60818 .50748 L p .583 .366 .552 r
F P
0 g
s
.60818 .50748 m .61351 .51105 L .61116 .51243 L p .583 .366 .552 r
F P
0 g
s
.59651 .52014 m .60818 .50748 L .60743 .50992 L p .603 .386 .559 r
F P
0 g
s
.60818 .50748 m .59651 .52014 L .59772 .51786 L p .567 .337 .526 r
F P
0 g
s
.51625 .6296 m .50967 .61951 L .50848 .61706 L p .919 .617 .456 r
F P
0 g
s
.42853 .47884 m .43437 .47731 L .43547 .47744 L p .224 .043 .412 r
F P
0 g
s
.51449 .55486 m .52056 .55061 L .51859 .55283 L p .802 .992 .75 r
F P
0 g
s
.56296 .65464 m .54589 .65203 L .54855 .6521 L p .676 .368 .446 r
F P
0 g
s
.54327 .65159 m .54345 .65106 L .54589 .65203 L p .765 .471 .487 r
F P
0 g
s
.54589 .65203 m .54563 .6528 L .54327 .65159 L p .765 .471 .487 r
F P
0 g
s
.52993 .64475 m .54589 .65203 L .54345 .65106 L p .765 .465 .478 r
F P
0 g
s
.56037 .65436 m .54841 .65254 L .54589 .65203 L p .678 .383 .467 r
F P
0 g
s
.54589 .65203 m .56296 .65464 L .56037 .65436 L p .678 .383 .467 r
F P
0 g
s
.54563 .6528 m .54589 .65203 L .54841 .65254 L p .677 .377 .457 r
F P
0 g
s
.54855 .6521 m .5605 .65392 L .56296 .65464 L p .676 .368 .446 r
F P
0 g
s
.51669 .55218 m .52094 .54921 L .52056 .55061 L p .808 .993 .751 r
F P
0 g
s
.52056 .55061 m .51449 .55486 L .51669 .55218 L p .808 .993 .751 r
F P
0 g
s
.52666 .54542 m .52056 .55061 L .52094 .54921 L p .78 .997 .858 r
F P
0 g
s
.70619 .55828 m .70476 .56177 L .69985 .56175 L p .7 .709 .855 r
F P
0 g
s
.5605 .65392 m .56089 .6524 L .56352 .65247 L p .676 .372 .451 r
F P
0 g
s
.51878 .63485 m .5281 .64275 L .52993 .64475 L p .848 .533 .456 r
F P
0 g
s
.57978 .65026 m .56352 .65247 L .56609 .65165 L p .546 .224 .373 r
F P
0 g
s
.56352 .65247 m .56296 .65464 L .5605 .65392 L p .676 .372 .451 r
F P
0 g
s
.57727 .65092 m .56588 .65246 L .56352 .65247 L p .565 .271 .428 r
F P
0 g
s
.56352 .65247 m .57978 .65026 L .57727 .65092 L p .565 .271 .428 r
F P
0 g
s
.56296 .65464 m .56352 .65247 L .56588 .65246 L p .563 .262 .416 r
F P
0 g
s
.62511 .47599 m .62424 .47422 L .62516 .47234 L p .17 .111 .544 r
F P
0 g
s
.62891 .46228 m .62516 .47234 L .62424 .47422 L p .152 .091 .529 r
F P
0 g
s
.62424 .47422 m .6296 .45985 L .62891 .46228 L p .152 .091 .529 r
F P
0 g
s
.62424 .47422 m .62511 .47599 L .62357 .47787 L p .337 .185 .522 r
F P
0 g
s
.6296 .45985 m .62424 .47422 L .62491 .47162 L p .065 0 .463 r
F P
0 g
s
.54345 .65106 m .53228 .64596 L .52993 .64475 L p .765 .465 .478 r
F P
0 g
s
.52993 .64475 m .51661 .63347 L .51878 .63485 L p .848 .533 .456 r
F P
0 g
s
.52764 .64371 m .52787 .64317 L .52993 .64475 L p .839 .551 .5 r
F P
0 g
s
.52993 .64475 m .52959 .64552 L .52764 .64371 L p .839 .551 .5 r
F P
0 g
s
.51661 .63347 m .52993 .64475 L .52787 .64317 L p .843 .543 .481 r
F P
0 g
s
.52959 .64552 m .52993 .64475 L .53228 .64596 L p .766 .461 .469 r
F P
0 g
s
.62798 .45829 m .62784 .45515 L .62871 .4523 L p 0 0 .315 r
F P
0 g
s
.56609 .65165 m .57747 .6501 L .57978 .65026 L p .546 .224 .373 r
F P
0 g
s
.43747 .44727 m .43567 .43701 L .43692 .43368 L p .369 .307 .656 r
F P
0 g
s
.63071 .43265 m .633 .42657 L .63359 .42301 L p .954 .891 .5 r
F P
0 g
s
.53228 .64596 m .53204 .6465 L .52959 .64552 L p .766 .461 .469 r
F P
0 g
s
.42812 .4801 m .43385 .47867 L .43503 .47851 L p .213 .02 .388 r
F P
0 g
s
.69985 .56175 m .70188 .55676 L .70619 .55828 L p .7 .709 .855 r
F P
0 g
s
.67964 .55739 m .69652 .56037 L .69985 .56175 L p .711 .702 .84 r
F P
0 g
s
.69985 .56175 m .67573 .5575 L .67964 .55739 L p .711 .702 .84 r
F P
0 g
s
.70188 .55676 m .69985 .56175 L .69652 .56037 L p .699 .707 .854 r
F P
0 g
s
.69599 .56231 m .6962 .56133 L .69985 .56175 L p .714 .701 .837 r
F P
0 g
s
.67573 .5575 m .69985 .56175 L .6962 .56133 L p .721 .688 .818 r
F P
0 g
s
.63516 .58256 m .64473 .58306 L .64748 .58123 L p .811 .764 .809 r
F P
0 g
s
.64748 .58123 m .6338 .5805 L .63516 .58256 L p .811 .764 .809 r
F P
0 g
s
.6486 .5718 m .6459 .57942 L .64748 .58123 L p .794 .746 .808 r
F P
0 g
s
.64748 .58123 m .65133 .57034 L .6486 .5718 L p .794 .746 .808 r
F P
0 g
s
.6338 .5805 m .64748 .58123 L .6459 .57942 L p .817 .747 .786 r
F P
0 g
s
.59094 .51952 m .5812 .52703 L .57818 .52822 L p .611 .326 .461 r
F P
0 g
s
.57663 .52469 m .57786 .52538 L .57582 .52709 L p .547 .235 .39 r
F P
0 g
s
.57582 .52709 m .57407 .52611 L .57663 .52469 L p .547 .235 .39 r
F P
0 g
s
.54841 .65254 m .54824 .65307 L .54563 .6528 L p .677 .377 .457 r
F P
0 g
s
.558 .53224 m .57087 .52673 L .57407 .52611 L p .465 .048 .164 r
F P
0 g
s
.50459 .60268 m .50805 .61435 L .50848 .61706 L p .983 .698 .354 r
F P
0 g
s
.52094 .54921 m .52522 .54557 L .52666 .54542 L p .78 .997 .858 r
F P
0 g
s
.49115 .52479 m .51797 .52951 L .52556 .533 L p .752 .63 .725 r
F P
0 g
s
.52666 .54542 m .52522 .54557 L p .52566 .5329 L .831 .997 .839 r
F P
0 g
s
.5257 .53287 m .52666 .54542 L p .52566 .5329 L .831 .997 .839 r
F P
0 g
s
.52666 .54542 m .5257 .53287 L p .52743 .53467 L .71 .95 .954 r
F P
0 g
s
.52522 .54557 m .52451 .53663 L .52555 .53304 L p .831 .997 .839 r
F P
0 g
s
.52573 .53285 m .52572 .53284 L .52584 .53279 L .697 .645 .794 r
F
.51449 .55486 m .52527 .5334 L p .52451 .53663 L .842 .999 .796 r
F P
0 g
s
.52571 .53283 m .49658 .50941 L .52577 .53274 L .697 .645 .794 r
F
.49658 .50941 m .52035 .52695 L .5258 .53275 L p F P
0 g
s
.52579 .53275 m .49658 .50941 L .5258 .53275 L .697 .645 .794 r
F
.52541 .53314 m .49115 .52479 L .52556 .533 L .752 .63 .725 r
F
.49244 .50834 m .52569 .53286 L p .51797 .52951 L .745 .636 .739 r
F P
0 g
s
.5257 .53287 m .5257 .53287 L p .52568 .53289 L .831 .997 .839 r
F P
0 g
s
.5257 .53287 m .52568 .53289 L .52566 .5329 L .831 .997 .839 r
F
.52566 .5329 m .52522 .54557 L .52555 .53304 L F
.52451 .53663 m .51669 .55218 L .51449 .55486 L p .842 .999 .796 r
F P
0 g
s
.51576 .55445 m .51506 .55413 L p .52627 .5335 L .841 .999 .796 r
F P
0 g
s
.54158 .53802 m .53855 .53845 L p .52609 .53279 L .599 .901 .986 r
F P
0 g
s
.52654 .53246 m .52653 .53252 L p .52684 .53223 L .398 .436 .783 r
F P
0 g
s
.54158 .53802 m .54278 .5371 L p .52716 .53299 L .548 .883 .988 r
F P
0 g
s
.52618 .53273 m .52718 .53308 L .52716 .53299 L .548 .883 .988 r
F
.52718 .53308 m .54158 .53802 L .52716 .53299 L F
.52617 .53274 m .52719 .53309 L .52618 .53273 L F
.52719 .53309 m .54158 .53802 L .52718 .53308 L F
.52719 .53309 m .52718 .53308 L .52618 .53273 L F
.52694 .53227 m .52698 .53218 L p .52679 .53236 L .398 .436 .783 r
F P
0 g
s
.52614 .53276 m .54158 .53802 L p .52609 .53279 L .599 .901 .986 r
F P
0 g
s
.53855 .53845 m .52743 .53467 L .52592 .53289 L p .599 .901 .986 r
F P
0 g
s
.54395 .53662 m .5538 .53381 L .55567 .534 L p .367 0 .024 r
F P
0 g
s
.55567 .534 m .54158 .53802 L .54395 .53662 L p .367 0 .024 r
F P
0 g
s
.54158 .53802 m .55567 .534 L .55265 .53428 L p .554 .914 .958 r
F P
0 g
s
.55504 .53507 m .55265 .53428 L .55567 .534 L p .368 0 0 r
F P
0 g
s
.55567 .534 m .55909 .53512 L .55504 .53507 L p .368 0 0 r
F P
0 g
s
.55265 .53428 m .54278 .5371 L .54158 .53802 L p .554 .914 .958 r
F P
0 g
s
.55909 .53512 m .52698 .5327 L p .53168 .53331 L .276 .761 .92 r
F P
0 g
s
.52653 .53252 m .52651 .53263 L p .52679 .53236 L .398 .436 .783 r
F P
0 g
s
.52628 .53267 m .52709 .53277 L p .52637 .53265 L .276 .761 .92 r
F P
0 g
s
.52698 .5327 m .52637 .53265 L p .52709 .53277 L .276 .761 .92 r
F P
0 g
s
.52643 .53266 m .52698 .5327 L p .5265 .53267 L .43 0 0 r
F P
0 g
s
.52607 .53278 m .53855 .53845 L .52592 .53289 L .599 .901 .986 r
F
.52767 .53328 m .52765 .53324 L .5261 .53271 L .548 .883 .988 r
F
.5261 .53271 m .5261 .53271 L .52608 .53271 L F
.52767 .53328 m .5261 .53271 L .5261 .53271 L F
.52709 .53277 m .53168 .53331 L p .52698 .5327 L .276 .761 .92 r
F P
0 g
s
.52636 .53258 m .52636 .53261 L p .52654 .53246 L .433 .47 .798 r
F P
0 g
s
.54278 .5371 m .53168 .53331 L .52626 .53267 L p .548 .883 .988 r
F P
0 g
s
.52626 .53267 m .54278 .5371 L .52626 .53267 L .548 .883 .988 r
F
.52618 .53268 m .54278 .5371 L .52624 .53267 L F
.52608 .53271 m .5261 .53271 L .52618 .53268 L F
.5261 .53271 m .54278 .5371 L .52618 .53268 L F
.52538 .49758 m .5239 .50049 L p .52633 .53263 L .575 .587 .828 r
F P
0 g
s
.52641 .53266 m .52694 .53271 L .52658 .53271 L .43 0 0 r
F
.53168 .53331 m .55504 .53507 L .55909 .53512 L p .276 .761 .92 r
F P
0 g
s
.52694 .53271 m .55743 .53534 L .52685 .53273 L .43 0 0 r
F
.52694 .53271 m .52685 .53273 L .52658 .53271 L F
.52663 .53275 m .52694 .53227 L .52679 .53236 L .398 .436 .783 r
F
.52638 .53337 m .52668 .53278 L .52663 .53275 L F
.52668 .53278 m .52694 .53227 L .52663 .53275 L F
.56368 .53928 m .52668 .53278 L p .53407 .53358 L .535 0 0 r
F P
0 g
s
.52626 .53267 m .52624 .53267 L p .52626 .53267 L .548 .883 .988 r
F P
0 g
s
.52622 .53266 m .52638 .53337 L p .52633 .53263 L .575 .587 .828 r
F P
0 g
s
.52633 .53263 m .52633 .53263 L .52632 .53263 L .575 .587 .828 r
F
.52633 .53263 m .52632 .53263 L .52622 .53266 L F
.53407 .53358 m .56063 .53825 L .56368 .53928 L p .535 0 0 r
F P
0 g
s
.56369 .53928 m .52703 .53284 L p .53496 .53473 L .535 0 0 r
F P
0 g
s
.52585 .53281 m .52743 .53467 L p .5257 .53287 L .71 .95 .954 r
F P
0 g
s
.52638 .53337 m .49244 .50834 L .49658 .50941 L p .697 .645 .794 r
F P
0 g
s
.52587 .53423 m .5258 .53435 L .5262 .53362 L .841 .999 .796 r
F
.52592 .53289 m .52584 .53279 L p .52607 .53278 L .599 .901 .986 r
F P
0 g
s
.52598 .53274 m .52607 .53278 L .52584 .53279 L .599 .901 .986 r
F
.52603 .53272 m .52638 .53337 L .52584 .53279 L p .654 .637 .821 r
F P
0 g
s
.52555 .53304 m .52451 .53663 L p .52527 .5334 L .842 .999 .796 r
F P
0 g
s
.52289 .53858 m .52369 .53734 L p .5258 .53435 L .841 .999 .796 r
F P
0 g
s
.51016 .50349 m .52594 .53256 L p .52462 .52557 L .637 .63 .826 r
F P
0 g
s
.52594 .53256 m .52603 .53272 L p .526 .53257 L .637 .63 .826 r
F P
0 g
s
.52594 .53256 m .526 .53257 L .52462 .52557 L .637 .63 .826 r
F
.52646 .53267 m .52643 .53266 L .5265 .53267 L .43 0 0 r
F
.52622 .53265 m .52462 .52557 L p .52602 .53268 L .637 .63 .826 r
F P
0 g
s
.52637 .53265 m .52568 .5326 L .52622 .53266 L p .276 .761 .92 r
F P
0 g
s
.52622 .53266 m .52628 .53267 L p .52635 .53266 L .276 .761 .92 r
F P
0 g
s
.52637 .53265 m .52622 .53266 L .52635 .53266 L .276 .761 .92 r
F
.52624 .53267 m .52622 .53266 L p .52608 .53271 L .548 .883 .988 r
F P
0 g
s
.52603 .53272 m .52617 .53267 L .52602 .53268 L .637 .63 .826 r
F
.52617 .53267 m .52622 .53265 L .52602 .53268 L F
.52594 .53256 m .52603 .53272 L p .52585 .53254 L .654 .637 .821 r
F P
0 g
s
.52622 .53266 m .52568 .5326 L p .52608 .53271 L .548 .883 .988 r
F P
0 g
s
.52608 .53271 m .52608 .53271 L .52622 .53266 L .548 .883 .988 r
F
.52568 .5326 m .5264 .53265 L p .52646 .53267 L .43 0 0 r
F P
0 g
s
.5264 .53265 m .52643 .53266 L p .52646 .53267 L .43 0 0 r
F P
0 g
s
.52668 .53278 m .52568 .5326 L .52658 .53281 L p .535 0 0 r
F P
0 g
s
.52668 .53278 m .52568 .5326 L .5265 .5327 L p .535 0 0 r
F P
0 g
s
.5265 .5327 m .52682 .53273 L p .52668 .53278 L .535 0 0 r
F P
0 g
s
.52682 .53273 m .53407 .53358 L p .52668 .53278 L .535 0 0 r
F P
0 g
s
.52668 .53278 m .52682 .53273 L .52668 .53278 L .535 0 0 r
F
.52614 .53276 m .52767 .53328 L p .52617 .53274 L .548 .883 .988 r
F P
0 g
s
.52569 .53286 m .52638 .53337 L .52556 .533 L p .745 .636 .739 r
F P
0 g
s
.5257 .53287 m .5257 .53287 L p .52585 .53281 L .71 .95 .954 r
F P
0 g
s
.52584 .53279 m .52585 .53281 L p .5257 .53287 L .71 .95 .954 r
F P
0 g
s
.52584 .53279 m .52638 .53337 L p .52573 .53285 L .697 .645 .794 r
F P
0 g
s
.52369 .53734 m .52538 .53469 L p .52612 .53376 L .841 .999 .796 r
F P
0 g
s
.52651 .53263 m .52638 .53337 L p .5267 .53259 L .398 .436 .783 r
F P
0 g
s
.52658 .53281 m .52612 .53376 L .52658 .53281 L .841 .999 .796 r
F
.52665 .53279 m .52664 .5328 L .52658 .53281 L F
.52664 .5328 m .52612 .53376 L .52658 .53281 L F
.52621 .5336 m .5262 .53362 L .52665 .53279 L F
.52636 .53261 m .52638 .53337 L .52653 .53252 L p .433 .47 .798 r
F P
0 g
s
.52587 .53423 m .52665 .53279 L .52665 .53279 L .841 .999 .796 r
F
.52666 .53277 m .52587 .53423 L .52666 .53277 L F
.52664 .53287 m .52668 .53279 L p .52638 .53337 L .398 .436 .783 r
F P
0 g
s
.52668 .53279 m .52694 .53227 L p .52668 .53279 L .398 .436 .783 r
F P
0 g
s
.52668 .53279 m .52668 .53279 L .52638 .53337 L .398 .436 .783 r
F
.56377 .54218 m .53496 .53473 L .52694 .53289 L p .438 0 0 r
F P
0 g
s
.52694 .53289 m .52658 .53281 L p .52701 .53292 L .438 0 0 r
F P
0 g
s
.52701 .53292 m .56377 .54218 L .52694 .53289 L .438 0 0 r
F
.52669 .53276 m .52638 .53337 L p .52669 .53276 L .841 .999 .796 r
F P
0 g
s
.52658 .53281 m .52568 .5326 L p .52654 .53282 L .438 0 0 r
F P
0 g
s
.52603 .53272 m .52614 .53276 L p .52608 .53271 L .548 .883 .988 r
F P
0 g
s
.52614 .53276 m .52617 .53274 L .52608 .53271 L .548 .883 .988 r
F
.52608 .53271 m .52617 .53274 L .52618 .53273 L F
.52598 .53274 m .52614 .53276 L .52609 .53279 L .599 .901 .986 r
F
.52603 .53272 m .52614 .53276 L p .52598 .53274 L F P
0 g
s
.52603 .53272 m .52638 .53337 L .52622 .53265 L p .637 .63 .826 r
F P
0 g
s
.52638 .53337 m .52503 .53314 L p .52518 .53308 L .752 .63 .725 r
F P
0 g
s
.52556 .533 m .52555 .53304 L p .52537 .53321 L .842 .999 .796 r
F P
0 g
s
.52556 .533 m .52638 .53337 L p .52541 .53314 L .752 .63 .725 r
F P
0 g
s
.52653 .53279 m .52659 .53278 L .52658 .53281 L .851 .992 .843 r
F
.52651 .53282 m .52658 .53281 L .52289 .53858 L F
.52653 .53279 m .52658 .53281 L .52651 .53282 L F
.52669 .53276 m .52638 .53337 L .52669 .53276 L .841 .999 .796 r
F
.52638 .53337 m .52636 .53261 L p .52633 .53263 L .575 .587 .828 r
F P
0 g
s
.52694 .53225 m .52648 .53297 L p .52693 .53225 L .851 .992 .843 r
F P
0 g
s
.52693 .53225 m .52648 .53297 L .52648 .53297 L .851 .992 .843 r
F
.52648 .53296 m .52644 .53303 L .52644 .53302 L F
.52693 .53225 m .52648 .53297 L .52648 .53296 L F
.52648 .53297 m .52644 .53303 L .52648 .53296 L F
.52658 .53281 m .52694 .53225 L p .52665 .53279 L .841 .999 .796 r
F P
0 g
s
.52665 .53279 m .52665 .53279 L .52694 .53225 L .841 .999 .796 r
F
.52694 .53226 m .52666 .53277 L .52694 .53225 L F
.52666 .53277 m .52666 .53277 L .52694 .53225 L F
.52653 .53279 m .52693 .53225 L p .52659 .53278 L .851 .992 .843 r
F P
0 g
s
.55743 .53534 m .53407 .53358 L .52689 .53274 L p .43 0 0 r
F P
0 g
s
.52689 .53274 m .52658 .53271 L p .52694 .53274 L .43 0 0 r
F P
0 g
s
.52694 .53274 m .55743 .53534 L .52689 .53274 L .43 0 0 r
F
.52669 .53276 m .52669 .53276 L .52694 .53227 L .841 .999 .796 r
F
.52694 .53227 m .52669 .53276 L .52694 .53226 L F
.52669 .53276 m .52669 .53276 L .52694 .53226 L F
.50482 .56024 m .52095 .53859 L .52643 .53277 L p .815 .866 .886 r
F P
0 g
s
.5267 .53259 m .52679 .53236 L .52651 .53263 L .398 .436 .783 r
F
.52643 .53277 m .52698 .53218 L p .52647 .53283 L .815 .866 .886 r
F P
0 g
s
.52647 .53283 m .50482 .56024 L .52643 .53277 L .815 .866 .886 r
F
.52649 .53278 m .52643 .53277 L p .52649 .5327 L .407 .657 .961 r
F P
0 g
s
.52643 .53277 m .52568 .5326 L p .52636 .53268 L .407 .657 .961 r
F P
0 g
s
.52568 .5326 m .52651 .53282 L p .52653 .53281 L .438 0 0 r
F P
0 g
s
.50391 .56311 m .50482 .56024 L p .52649 .5328 L .815 .866 .886 r
F P
0 g
s
.52698 .53218 m .52651 .53282 L p .52649 .5328 L .815 .866 .886 r
F P
0 g
s
.52651 .53282 m .50391 .56311 L p .52649 .5328 L .815 .866 .886 r
F P
0 g
s
.52652 .53282 m .52651 .53282 L p .52643 .53277 L .217 .639 .954 r
F P
0 g
s
.52651 .53282 m .52568 .5326 L .52643 .53277 L p .217 .639 .954 r
F P
0 g
s
.52643 .53277 m .52651 .53278 L p .52652 .53281 L .217 .639 .954 r
F P
0 g
s
.52652 .53282 m .52643 .53277 L .52652 .53281 L .217 .639 .954 r
F
.49724 .55379 m .52629 .53269 L p .52095 .53859 L .782 .792 .861 r
F P
0 g
s
.52629 .53269 m .52633 .53266 L p .5263 .53269 L .782 .792 .861 r
F P
0 g
s
.52629 .53269 m .5263 .53269 L .52095 .53859 L .782 .792 .861 r
F
.52698 .53218 m .52698 .53217 L .52679 .53236 L .398 .436 .783 r
F
.52633 .53266 m .52698 .53218 L .52643 .53277 L p .782 .792 .861 r
F P
0 g
s
.52643 .53277 m .52095 .53859 L p .52633 .53266 L .782 .792 .861 r
F P
0 g
s
.52636 .53268 m .52639 .53269 L .52643 .53277 L .407 .657 .961 r
F
.52639 .53269 m .52649 .5327 L .52643 .53277 L F
.52644 .53317 m .52638 .53337 L .52627 .5335 L .841 .999 .796 r
F
.52667 .53279 m .52643 .53329 L .52665 .5328 L F
.56685 .54324 m .56377 .54218 L p .52654 .53282 L .438 0 0 r
F P
0 g
s
.52653 .53281 m .52654 .53282 L .52654 .53282 L .438 0 0 r
F
.52654 .53282 m .56685 .54324 L .52654 .53282 L F
.52665 .5328 m .52643 .53329 L .52644 .53317 L .841 .999 .796 r
F
.52694 .53226 m .52667 .53279 L .52665 .5328 L F
.52643 .53329 m .52638 .53337 L .52644 .53317 L F
.52703 .53284 m .52668 .53278 L p .52811 .53316 L .535 0 0 r
F P
0 g
s
.52658 .53281 m .52811 .53316 L p .52668 .53278 L .535 0 0 r
F P
0 g
s
.52811 .53316 m .53496 .53473 L p .52703 .53284 L .535 0 0 r
F P
0 g
s
.55511 .53624 m .53403 .53442 L .52651 .53278 L p .407 .657 .961 r
F P
0 g
s
.52651 .53278 m .52649 .53278 L p .52651 .53278 L .407 .657 .961 r
F P
0 g
s
.52651 .53278 m .55511 .53624 L .52651 .53278 L .407 .657 .961 r
F
.55574 .53519 m .55511 .53624 L p .52649 .5327 L F P
0 g
s
.52621 .53262 m .52622 .53266 L p .52622 .53262 L .575 .587 .828 r
F P
0 g
s
.52658 .53271 m .52568 .5326 L p .52641 .53266 L .43 0 0 r
F P
0 g
s
.52527 .5334 m .52537 .53321 L p .52555 .53304 L .842 .999 .796 r
F P
0 g
s
.52556 .533 m .51797 .52951 L p .52569 .53286 L .745 .636 .739 r
F P
0 g
s
.52537 .53321 m .52568 .5326 L .52556 .533 L p .842 .999 .796 r
F P
0 g
s
.49724 .55379 m .52633 .53266 L p .51864 .53608 L .775 .772 .85 r
F P
0 g
s
.52636 .53261 m .52538 .49758 L p .52633 .53263 L .575 .587 .828 r
F P
0 g
s
.52653 .53252 m .52654 .53246 L p .52636 .53261 L .433 .47 .798 r
F P
0 g
s
.52622 .53262 m .5239 .50049 L .52621 .53262 L .575 .587 .828 r
F
.52633 .53263 m .5239 .50049 L .52622 .53266 L F
.52538 .49758 m .52636 .53258 L p .52755 .52643 L .433 .47 .798 r
F P
0 g
s
.52654 .53246 m .52755 .52643 L p .52636 .53258 L .433 .47 .798 r
F P
0 g
s
.52679 .53236 m .52684 .53223 L .52653 .53252 L .398 .436 .783 r
F
.52698 .5327 m .55909 .53512 L p .52695 .53271 L .43 0 0 r
F P
0 g
s
.55909 .53512 m .55743 .53534 L p .52694 .53271 L .43 0 0 r
F P
0 g
s
.52695 .53271 m .55909 .53512 L .52694 .53271 L .43 0 0 r
F
.52694 .53227 m .52673 .53269 L p .52694 .53227 L .841 .999 .796 r
F P
0 g
s
.55574 .53519 m .55282 .5337 L p .5263 .53263 L .43 .643 .947 r
F P
0 g
s
.52568 .5326 m .52633 .53266 L p .5263 .53263 L .43 .643 .947 r
F P
0 g
s
.52673 .53269 m .52669 .53276 L p .52679 .53257 L .841 .999 .796 r
F P
0 g
s
.52698 .5327 m .52695 .53271 L .5265 .53267 L .43 0 0 r
F
.5265 .53267 m .52695 .53271 L .52694 .53271 L F
.52633 .53266 m .55574 .53519 L p .5263 .53263 L .43 .643 .947 r
F P
0 g
s
.52633 .53266 m .52698 .53218 L .52622 .53254 L p .775 .772 .85 r
F P
0 g
s
.5239 .50049 m .52462 .52557 L .52621 .53262 L p .575 .587 .828 r
F P
0 g
s
.52652 .5325 m .52622 .53254 L p .5265 .53263 L .43 .643 .947 r
F P
0 g
s
.52622 .53254 m .52568 .5326 L p .52633 .53263 L .43 .643 .947 r
F P
0 g
s
.52633 .53263 m .5265 .53263 L .52622 .53254 L .43 .643 .947 r
F
.52603 .53272 m .52603 .53272 L .52035 .52695 L .654 .637 .821 r
F
.52582 .53278 m .52035 .52695 L p .52603 .53272 L F P
0 g
s
.52584 .53279 m .52582 .53278 L p .52603 .53272 L .654 .637 .821 r
F P
0 g
s
.52584 .53279 m .52568 .5326 L p .52598 .53274 L .599 .901 .986 r
F P
0 g
s
.52568 .5326 m .52603 .53272 L p .52598 .53274 L .599 .901 .986 r
F P
0 g
s
.52568 .5326 m .5257 .53287 L p .52566 .5329 L .831 .997 .839 r
F P
0 g
s
.52555 .53304 m .52568 .5326 L p .52566 .5329 L .831 .997 .839 r
F P
0 g
s
.52572 .53284 m .52571 .53283 L .52579 .53275 L .697 .645 .794 r
F
.52571 .53283 m .52577 .53274 L .52579 .53275 L F
.52572 .53284 m .52579 .53275 L .52584 .53279 L F
.5258 .53275 m .52584 .53279 L p .52579 .53275 L F P
0 g
s
.5257 .53287 m .52568 .5326 L .52584 .53279 L p .71 .95 .954 r
F P
0 g
s
.4881 .52664 m .49115 .52479 L p .52518 .53308 L .752 .63 .725 r
F P
0 g
s
.52503 .53314 m .4881 .52664 L p .52518 .53308 L .752 .63 .725 r
F P
0 g
s
.48983 .54436 m .51864 .53608 L .52622 .53254 L p .764 .717 .808 r
F P
0 g
s
.5356 .5104 m .52755 .52643 L .52684 .53066 L p .398 .436 .783 r
F P
0 g
s
.5267 .53148 m .52654 .53246 L p .52682 .53177 L .398 .436 .783 r
F P
0 g
s
.51016 .50349 m .52594 .53256 L p .52035 .52695 L .654 .637 .821 r
F P
0 g
s
.52594 .53256 m .52585 .53254 L .52035 .52695 L .654 .637 .821 r
F
.52699 .53217 m .52842 .52915 L .52694 .53207 L .398 .436 .783 r
F
.52698 .53218 m .52694 .53207 L .52679 .53236 L F
.52699 .53217 m .52694 .53207 L .52698 .53218 L F
.52693 .53202 m .52702 .53191 L .52704 .53173 L F
.52679 .53236 m .52694 .53206 L .52693 .53202 L F
.52694 .53206 m .52702 .53191 L .52693 .53202 L F
.52684 .53223 m .52696 .53194 L .52654 .53246 L F
.52696 .53194 m .5356 .5104 L .52692 .53152 L F
.52696 .53194 m .52692 .53152 L .52654 .53246 L F
.52568 .5326 m .52633 .53266 L p .52636 .53268 L .407 .657 .961 r
F P
0 g
s
.52568 .5326 m .52603 .53272 L p .52608 .53271 L .548 .883 .988 r
F P
0 g
s
.52684 .53066 m .5267 .53148 L p .52692 .53152 L .398 .436 .783 r
F P
0 g
s
.52692 .53152 m .5356 .5104 L .52684 .53066 L .398 .436 .783 r
F
.52699 .53217 m .53788 .51054 L p .52842 .52915 L F P
0 g
s
.53788 .51054 m .5356 .5104 L p .52704 .53173 L .398 .436 .783 r
F P
0 g
s
.52702 .53191 m .53788 .51054 L .52704 .53173 L .398 .436 .783 r
F
.53126 .50203 m .5356 .5104 L .53788 .51054 L p .401 .424 .769 r
F P
0 g
s
.53718 .50975 m .52608 .5318 L p .52978 .52906 L .398 .436 .783 r
F P
0 g
s
.52598 .532 m .52568 .5326 L .52608 .53226 L p .398 .436 .783 r
F P
0 g
s
.49086 .52823 m .51769 .53293 L .52608 .53226 L p .752 .63 .725 r
F P
0 g
s
.52608 .53226 m .52698 .53218 L p .52599 .53207 L .752 .63 .725 r
F P
0 g
s
.52599 .53207 m .49086 .52823 L .52608 .53226 L .752 .63 .725 r
F
.52698 .53218 m .52598 .532 L p .526 .53207 L F P
0 g
s
.54633 .52278 m .52978 .52906 L .52608 .53226 L p .415 .465 .803 r
F P
0 g
s
.52608 .53226 m .52568 .5326 L p .52614 .53238 L .415 .465 .803 r
F P
0 g
s
.52614 .53238 m .54633 .52278 L .52608 .53226 L .415 .465 .803 r
F
.52598 .53199 m .52598 .532 L p .52608 .53226 L .398 .436 .783 r
F P
0 g
s
.48971 .51556 m .49115 .52479 L .4881 .52664 L p .747 .619 .717 r
F P
0 g
s
.48867 .52545 m .49086 .52823 L p .526 .53207 L .752 .63 .725 r
F P
0 g
s
.52598 .532 m .48867 .52545 L p .526 .53207 L .752 .63 .725 r
F P
0 g
s
.54928 .52368 m .54633 .52278 L p .52613 .53238 L .415 .465 .803 r
F P
0 g
s
.52568 .5326 m .52615 .53242 L p .52613 .53238 L .415 .465 .803 r
F P
0 g
s
.52615 .53242 m .52698 .53218 L .52608 .53226 L p .752 .643 .74 r
F P
0 g
s
.52615 .53242 m .54928 .52368 L p .52613 .53238 L .415 .465 .803 r
F P
0 g
s
.52614 .53243 m .52615 .53242 L p .52608 .53226 L .752 .643 .74 r
F P
0 g
s
.48583 .54401 m .52614 .53243 L p .51769 .53293 L .752 .643 .74 r
F P
0 g
s
.52608 .53226 m .51769 .53293 L p .52614 .53243 L .752 .643 .74 r
F P
0 g
s
.52608 .5318 m .52598 .53199 L p .52612 .53222 L .398 .436 .783 r
F P
0 g
s
.52608 .53226 m .52612 .53222 L p .52598 .53199 L .398 .436 .783 r
F P
0 g
s
.52682 .53177 m .52692 .53152 L .5267 .53148 L .398 .436 .783 r
F
.52612 .53222 m .52978 .52906 L p .52608 .5318 L F P
0 g
s
.52698 .53218 m .52615 .53242 L p .52617 .53245 L .764 .717 .808 r
F P
0 g
s
.52622 .53254 m .52698 .53218 L p .52613 .53246 L .764 .717 .808 r
F P
0 g
s
.52698 .53218 m .52699 .53217 L p .52698 .53217 L .398 .436 .783 r
F P
0 g
s
.52693 .53225 m .52698 .53218 L .52694 .53225 L p .851 .992 .843 r
F P
0 g
s
.52694 .53225 m .52698 .53218 L p .52694 .53226 L .841 .999 .796 r
F P
0 g
s
.52698 .53218 m .52694 .53227 L p .52694 .53226 L .841 .999 .796 r
F P
0 g
s
.54928 .52368 m .52615 .53242 L p .53173 .53189 L .446 .581 .895 r
F P
0 g
s
.52615 .53242 m .52568 .5326 L .52622 .53254 L p .446 .581 .895 r
F P
0 g
s
.52622 .53254 m .53173 .53189 L p .52615 .53242 L .446 .581 .895 r
F P
0 g
s
.52617 .53245 m .52614 .53243 L .52614 .53246 L .764 .717 .808 r
F
.52615 .53242 m .52614 .53243 L p .52617 .53245 L F P
0 g
s
.48583 .54401 m .48983 .54436 L p .52614 .53246 L .764 .717 .808 r
F P
0 g
s
.52614 .53243 m .48583 .54401 L p .52614 .53246 L .764 .717 .808 r
F P
0 g
s
.52613 .53246 m .48983 .54436 L .52622 .53254 L .764 .717 .808 r
F
.52622 .53254 m .52621 .53254 L p .52633 .53266 L .775 .772 .85 r
F P
0 g
s
.52621 .53254 m .51864 .53608 L p .52633 .53266 L .775 .772 .85 r
F P
0 g
s
.52636 .53268 m .52649 .53267 L .52649 .5327 L .407 .657 .961 r
F
.52633 .53266 m .52649 .53267 L p .52636 .53268 L F P
0 g
s
.52649 .53267 m .55574 .53519 L p .52649 .5327 L .407 .657 .961 r
F P
0 g
s
.52649 .5327 m .55511 .53624 L .52649 .53278 L .407 .657 .961 r
F
.52648 .53297 m .52644 .53303 L p .52648 .53297 L .851 .992 .843 r
F P
0 g
s
.52644 .53303 m .52289 .53858 L p .52644 .53302 L .851 .992 .843 r
F P
0 g
s
.52679 .53257 m .52679 .53257 L .52694 .53227 L .841 .999 .796 r
F
.55282 .5337 m .53173 .53189 L .52652 .5325 L p .43 .643 .947 r
F P
0 g
s
.52673 .53269 m .52679 .53257 L .52679 .53257 L .841 .999 .796 r
F
.5265 .53263 m .55282 .5337 L .52652 .5325 L .43 .643 .947 r
F
.50391 .56311 m .52653 .53279 L p .52289 .53858 L .851 .992 .843 r
F P
0 g
s
.52651 .53282 m .56685 .54324 L p .52653 .53281 L .438 0 0 r
F P
0 g
s
.52654 .53282 m .56377 .54218 L .52658 .53281 L .438 0 0 r
F
.53496 .53473 m .56157 .5394 L .56369 .53928 L p .535 0 0 r
F P
0 g
s
.56685 .54324 m .52652 .53282 L p .53403 .53442 L .217 .639 .954 r
F P
0 g
s
.52651 .53278 m .53403 .53442 L p .52652 .53282 L .217 .639 .954 r
F P
0 g
s
.52538 .53469 m .52654 .53287 L p .52618 .53365 L .841 .999 .796 r
F P
0 g
s
.52654 .53287 m .52658 .53281 L p .52655 .53288 L .841 .999 .796 r
F P
0 g
s
.52655 .53288 m .52618 .53365 L .52654 .53287 L .841 .999 .796 r
F
.52618 .53365 m .52612 .53376 L .52538 .53469 L F
.52612 .53376 m .5258 .53435 L .52369 .53734 L F
.52587 .53423 m .5262 .53362 L .52621 .5336 L F
.52587 .53423 m .51506 .55413 L .5258 .53435 L F
.51506 .55413 m .52086 .54262 L p .5258 .53435 L F P
0 g
s
.52086 .54262 m .52289 .53858 L p .5258 .53435 L .841 .999 .796 r
F P
0 g
s
.52638 .53337 m .52664 .53287 L p .52638 .53337 L .398 .436 .783 r
F P
0 g
s
.52767 .53328 m .54158 .53802 L p .52765 .53324 L .548 .883 .988 r
F P
0 g
s
.52638 .53337 m .51576 .55445 L p .52627 .5335 L .841 .999 .796 r
F P
0 g
s
.52743 .53467 m .5281 .54363 L .52666 .54542 L p .71 .95 .954 r
F P
0 g
s
.50814 .56344 m .50866 .56729 L .50794 .56912 L p .906 .984 .753 r
F P
0 g
s
.50794 .56912 m .50719 .56362 L .50814 .56344 L p .906 .984 .753 r
F P
0 g
s
.50407 .58047 m .50704 .57079 L .50794 .56912 L p .961 .904 .534 r
F P
0 g
s
.50794 .56912 m .5037 .58294 L .50407 .58047 L p .961 .904 .534 r
F P
0 g
s
.50719 .56362 m .50794 .56912 L .50704 .57079 L p .929 .907 .514 r
F P
0 g
s
.64816 .37929 m .66096 .36426 L .66226 .35792 L p .865 .82 .803 r
F P
0 g
s
.72864 .55975 m .73105 .55372 L .73624 .55315 L p .679 .716 .877 r
F P
0 g
s
.52787 .64317 m .51855 .63527 L .51661 .63347 L p .843 .543 .481 r
F P
0 g
s
.42774 .48121 m .43332 .47988 L .43445 .47977 L p .202 .002 .37 r
F P
0 g
s
.53204 .6465 m .54327 .65159 L .54563 .6528 L p .766 .466 .478 r
F P
0 g
s
.61047 .50593 m .6142 .50844 L .61351 .51105 L p .548 .382 .607 r
F P
0 g
s
.54563 .6528 m .52959 .64552 L .53204 .6465 L p .766 .466 .478 r
F P
0 g
s
.56279 .65541 m .54563 .6528 L .54824 .65307 L p .679 .384 .467 r
F P
0 g
s
.54305 .65226 m .54319 .6518 L .54563 .6528 L p .765 .478 .499 r
F P
0 g
s
.54563 .6528 m .54543 .65345 L .54305 .65226 L p .765 .478 .499 r
F P
0 g
s
.52959 .64552 m .54563 .6528 L .54319 .6518 L p .765 .47 .486 r
F P
0 g
s
.56019 .65511 m .54818 .65329 L .54563 .6528 L p .681 .397 .485 r
F P
0 g
s
.54563 .6528 m .56279 .65541 L .56019 .65511 L p .681 .397 .485 r
F P
0 g
s
.54543 .65345 m .54563 .6528 L .54818 .65329 L p .68 .388 .472 r
F P
0 g
s
.43097 .41109 m .44117 .40491 L .44509 .40698 L p .523 .481 .751 r
F P
0 g
s
.30622 .29744 m .25441 .26253 L .24622 .24912 L p .593 .64 .867 r
F P
0 g
s
.24622 .24912 m .32044 .29919 L .30622 .29744 L p .593 .64 .867 r
F P
0 g
s
.54319 .6518 m .53196 .64671 L .52959 .64552 L p .765 .47 .486 r
F P
0 g
s
.62491 .47162 m .62866 .46156 L .6296 .45985 L p .065 0 .463 r
F P
0 g
s
.57293 .52814 m .57171 .52745 L .57407 .52611 L p .57 .195 .29 r
F P
0 g
s
.57407 .52611 m .57582 .52709 L .57293 .52814 L p .57 .195 .29 r
F P
0 g
s
.55567 .534 m .57407 .52611 L .57171 .52745 L p .47 .056 .171 r
F P
0 g
s
.57407 .52611 m .55567 .534 L .558 .53224 L p .465 .048 .164 r
F P
0 g
s
.60743 .50992 m .59926 .51879 L .59651 .52014 L p .603 .386 .559 r
F P
0 g
s
.57747 .6501 m .57802 .64784 L .58056 .64702 L p .546 .226 .376 r
F P
0 g
s
.77007 .55903 m .74175 .55531 L .73624 .55315 L p .674 .723 .886 r
F P
0 g
s
.73624 .55315 m .77672 .55846 L .77007 .55903 L p .674 .723 .886 r
F P
0 g
s
.62922 .43837 m .62871 .4523 L .62894 .44927 L p .837 .738 .215 r
F P
0 g
s
.62917 .44116 m .62881 .45091 L .62871 .4523 L p 0 0 .08 r
F P
0 g
s
.62871 .4523 m .62922 .43837 L .62917 .44116 L p 0 0 .08 r
F P
0 g
s
.62871 .4523 m .62893 .45679 L .62798 .45829 L p 0 0 .315 r
F P
0 g
s
.6962 .56133 m .67932 .55835 L .67573 .5575 L p .721 .688 .818 r
F P
0 g
s
.54824 .65307 m .56025 .6549 L .56279 .65541 L p .679 .384 .467 r
F P
0 g
s
.42253 .49011 m .41797 .4967 L .4183 .49637 L p .66 .861 .473 r
F P
0 g
s
.51824 .63578 m .52764 .64371 L .52959 .64552 L p .844 .545 .482 r
F P
0 g
s
.52959 .64552 m .51616 .63419 L .51824 .63578 L p .844 .545 .482 r
F P
0 g
s
.52732 .64437 m .52753 .64392 L .52959 .64552 L p .839 .554 .506 r
F P
0 g
s
.52959 .64552 m .5293 .64616 L .52732 .64437 L p .839 .554 .506 r
F P
0 g
s
.51616 .63419 m .52959 .64552 L .52753 .64392 L p .842 .548 .491 r
F P
0 g
s
.5293 .64616 m .52959 .64552 L .53196 .64671 L p .767 .464 .474 r
F P
0 g
s
.67688 .56511 m .67816 .56166 L .67487 .56029 L p .727 .702 .827 r
F P
0 g
s
.67487 .56029 m .67304 .56522 L .67688 .56511 L p .727 .702 .827 r
F P
0 g
s
.53196 .64671 m .53175 .64716 L .5293 .64616 L p .767 .464 .474 r
F P
0 g
s
.56588 .65246 m .5655 .65398 L .56296 .65464 L p .563 .262 .416 r
F P
0 g
s
.59439 .64035 m .58056 .64702 L .58285 .64545 L p .292 0 .194 r
F P
0 g
s
.58056 .64702 m .57978 .65026 L .57747 .6501 L p .546 .226 .376 r
F P
0 g
s
.59221 .64183 m .58252 .64651 L .58056 .64702 L p .368 .065 .313 r
F P
0 g
s
.58056 .64702 m .59439 .64035 L .59221 .64183 L p .368 .065 .313 r
F P
0 g
s
.57978 .65026 m .58056 .64702 L .58252 .64651 L p .369 .068 .317 r
F P
0 g
s
.54818 .65329 m .54804 .65374 L .54543 .65345 L p .68 .388 .472 r
F P
0 g
s
.62268 .49707 m .61894 .49371 L .62066 .49205 L p .458 .342 .633 r
F P
0 g
s
.62644 .48197 m .62066 .49205 L .61894 .49371 L p .445 .322 .618 r
F P
0 g
s
.61894 .49371 m .6272 .47931 L .62644 .48197 L p .445 .322 .618 r
F P
0 g
s
.62062 .49865 m .618 .49629 L .61894 .49371 L p .516 .341 .582 r
F P
0 g
s
.61894 .49371 m .62268 .49707 L .62062 .49865 L p .516 .341 .582 r
F P
0 g
s
.6272 .47931 m .61894 .49371 L .61992 .49124 L p .402 .272 .587 r
F P
0 g
s
.62385 .60575 m .61904 .60736 L .61725 .6098 L p .924 .913 .789 r
F P
0 g
s
.58285 .64545 m .59252 .64077 L .59439 .64035 L p .292 0 .194 r
F P
0 g
s
.61175 .62034 m .61704 .61136 L .61725 .6098 L p .889 .979 .82 r
F P
0 g
s
.61725 .6098 m .60969 .62264 L .61175 .62034 L p .889 .979 .82 r
F P
0 g
s
.53175 .64716 m .54305 .65226 L .54543 .65345 L p .766 .471 .486 r
F P
0 g
s
.41797 .4967 m .42253 .49011 L .4227 .49095 L p .033 0 .114 r
F P
0 g
s
.42717 .49018 m .4227 .49095 L .42253 .49011 L p .078 0 .109 r
F P
0 g
s
.42253 .49011 m .42893 .48902 L .42717 .49018 L p .078 0 .109 r
F P
0 g
s
.42581 .48553 m .42396 .48915 L .42253 .49011 L p .137 0 .273 r
F P
0 g
s
.42893 .48902 m .42253 .49011 L .42396 .48915 L p .102 0 .219 r
F P
0 g
s
.54543 .65345 m .5293 .64616 L .53175 .64716 L p .766 .471 .486 r
F P
0 g
s
.56267 .65608 m .54543 .65345 L .54804 .65374 L p .682 .398 .485 r
F P
0 g
s
.54243 .65407 m .54289 .65266 L .54543 .65345 L p .765 .483 .506 r
F P
0 g
s
.54543 .65345 m .54476 .65547 L .54243 .65407 L p .765 .483 .506 r
F P
0 g
s
.5293 .64616 m .54543 .65345 L .54289 .65266 L p .765 .477 .497 r
F P
0 g
s
.56 .65599 m .54793 .65415 L .54543 .65345 L p .682 .4 .488 r
F P
0 g
s
.54543 .65345 m .56267 .65608 L .56 .65599 L p .682 .4 .488 r
F P
0 g
s
.54476 .65547 m .54543 .65345 L .54793 .65415 L p .682 .393 .478 r
F P
0 g
s
.50848 .61706 m .50353 .60039 L .50459 .60268 L p .983 .698 .354 r
F P
0 g
s
.50637 .6161 m .50746 .61481 L .50848 .61706 L p .974 .723 .493 r
F P
0 g
s
.50848 .61706 m .50691 .6189 L .50637 .6161 L p .974 .723 .493 r
F P
0 g
s
.50353 .60039 m .50848 .61706 L .50746 .61481 L p .977 .718 .472 r
F P
0 g
s
.50691 .6189 m .50848 .61706 L .50967 .61951 L p .926 .616 .437 r
F P
0 g
s
.52912 .75287 m .52571 .79033 L .5204 .78399 L p .725 .658 .783 r
F P
0 g
s
.49002 .78037 m .5204 .78399 L .52571 .79033 L p .725 .658 .783 r
F P
0 g
s
.52571 .79033 m .48234 .78518 L .49002 .78037 L p .725 .658 .783 r
F P
0 g
s
.53482 .75842 m .5324 .78465 L .52571 .79033 L p .693 .629 .78 r
F P
0 g
s
.52571 .79033 m .52912 .75287 L .53482 .75842 L p .693 .629 .78 r
F P
0 g
s
.57182 .78928 m .52571 .79033 L .5324 .78465 L p .693 .629 .78 r
F P
0 g
s
.43362 .41731 m .43811 .42985 L .43692 .43368 L p .501 .432 .711 r
F P
0 g
s
.63032 .4317 m .63359 .42301 L .63219 .42233 L p .983 .815 .597 r
F P
0 g
s
.62772 .41263 m .63219 .42233 L .63359 .42301 L p .983 .816 .598 r
F P
0 g
s
.63359 .42301 m .62721 .40915 L .62772 .41263 L p .983 .816 .598 r
F P
0 g
s
.63359 .42301 m .63032 .4317 L .63071 .43265 L p .954 .891 .5 r
F P
0 g
s
.62721 .40915 m .63359 .42301 L .6336 .41913 L p .948 .829 .694 r
F P
0 g
s
.52753 .64392 m .51813 .63599 L .51616 .63419 L p .842 .548 .491 r
F P
0 g
s
.78864 .5482 m .78542 .55734 L .77672 .55846 L p .669 .729 .895 r
F P
0 g
s
.77672 .55846 m .78127 .54541 L .78864 .5482 L p .669 .729 .895 r
F P
0 g
s
.74293 .55209 m .77129 .55581 L .77672 .55846 L p .673 .724 .887 r
F P
0 g
s
.77672 .55846 m .73624 .55315 L .74293 .55209 L p .673 .724 .887 r
F P
0 g
s
.78127 .54541 m .77672 .55846 L .77129 .55581 L p .665 .725 .894 r
F P
0 g
s
.69652 .56037 m .69794 .55687 L .70188 .55676 L p .699 .707 .854 r
F P
0 g
s
.62401 .47863 m .62379 .47823 L .62511 .47599 L p .353 .206 .538 r
F P
0 g
s
.50967 .61951 m .50858 .6208 L .50691 .6189 L p .926 .616 .437 r
F P
0 g
s
.65637 .56373 m .66973 .56596 L .67304 .56522 L p .743 .701 .812 r
F P
0 g
s
.67304 .56522 m .65395 .56204 L .65637 .56373 L p .743 .701 .812 r
F P
0 g
s
.67171 .56053 m .67043 .56399 L .67304 .56522 L p .73 .706 .827 r
F P
0 g
s
.67304 .56522 m .67487 .56029 L .67171 .56053 L p .73 .706 .827 r
F P
0 g
s
.65395 .56204 m .67304 .56522 L .67043 .56399 L p .744 .699 .809 r
F P
0 g
s
.61992 .49124 m .62571 .48116 L .6272 .47931 L p .402 .272 .587 r
F P
0 g
s
.42652 .4842 m .43169 .48314 L .43257 .48343 L p .17 0 .323 r
F P
0 g
s
.54804 .65374 m .5601 .65558 L .56267 .65608 L p .682 .398 .485 r
F P
0 g
s
.60526 .62722 m .60757 .62472 L .60969 .62264 L p 0 0 0 r
F P
0 g
s
.60639 .6262 m .60705 .62474 L p .6062 .62654 L .659 .782 .317 r
F P
0 g
s
.60639 .6262 m .60465 .62982 L .60335 .63085 L p 0 0 0 r
F P
0 g
s
.60465 .62982 m .60639 .6262 L p .6062 .62654 L .659 .782 .317 r
F P
0 g
s
.60639 .6262 m .60526 .62722 L p .60661 .62582 L 0 0 0 r
F P
0 g
s
.60969 .62264 m .60639 .6262 L p .60661 .62582 L 0 0 0 r
F P
0 g
s
.61554 .61223 m .61025 .62123 L .60969 .62264 L p .832 .974 .668 r
F P
0 g
s
.60969 .62264 m .61725 .6098 L .61554 .61223 L p .832 .974 .668 r
F P
0 g
s
.60639 .6262 m .60969 .62264 L .61025 .62123 L p .812 .946 .594 r
F P
0 g
s
.54289 .65266 m .5316 .64756 L .5293 .64616 L p .765 .477 .497 r
F P
0 g
s
.41173 .50363 m .41671 .49847 L .41797 .4967 L p .759 .976 .712 r
F P
0 g
s
.62516 .47234 m .62577 .47358 L .62511 .47599 L p .17 .111 .544 r
F P
0 g
s
.51786 .63644 m .52732 .64437 L .5293 .64616 L p .843 .549 .492 r
F P
0 g
s
.5293 .64616 m .51578 .63483 L .51786 .63644 L p .843 .549 .492 r
F P
0 g
s
.52648 .64619 m .52712 .64477 L .5293 .64616 L p .838 .561 .519 r
F P
0 g
s
.5293 .64616 m .52839 .64819 L .52648 .64619 L p .838 .561 .519 r
F P
0 g
s
.51578 .63483 m .5293 .64616 L .52712 .64477 L p .839 .555 .507 r
F P
0 g
s
.52839 .64819 m .5293 .64616 L .5316 .64756 L p .767 .473 .489 r
F P
0 g
s
.62894 .44927 m .6293 .43951 L .62922 .43837 L p .837 .738 .215 r
F P
0 g
s
.54793 .65415 m .54747 .65556 L .54476 .65547 L p .682 .393 .478 r
F P
0 g
s
.64389 .81721 m .68032 .8042 L .69273 .80787 L p .622 .62 .827 r
F P
0 g
s
.50391 .5857 m .50379 .5979 L .50353 .60039 L p .945 .778 .317 r
F P
0 g
s
.5316 .64756 m .53097 .64898 L .52839 .64819 L p .767 .473 .489 r
F P
0 g
s
.43949 .44835 m .43692 .43368 L .43942 .43505 L p .483 .387 .67 r
F P
0 g
s
.44941 .4304 m .43942 .43505 L .43692 .43368 L p .482 .387 .671 r
F P
0 g
s
.43692 .43368 m .45119 .42704 L .44941 .4304 L p .482 .387 .671 r
F P
0 g
s
.43692 .43368 m .43949 .44835 L .43747 .44727 L p .369 .307 .656 r
F P
0 g
s
.45119 .42704 m .43692 .43368 L .43811 .42985 L p .502 .434 .712 r
F P
0 g
s
.59252 .64077 m .59353 .63812 L .59583 .63655 L p .288 0 .183 r
F P
0 g
s
.56025 .6549 m .56037 .65436 L .56296 .65464 L p .68 .391 .477 r
F P
0 g
s
.6459 .57942 m .63633 .57891 L .6338 .5805 L p .817 .747 .786 r
F P
0 g
s
.62511 .47599 m .62543 .47657 L .62401 .47863 L p .353 .206 .538 r
F P
0 g
s
.51855 .63527 m .51824 .63578 L .51616 .63419 L p .847 .537 .463 r
F P
0 g
s
.51616 .63419 m .51661 .63347 L .51855 .63527 L p .847 .537 .463 r
F P
0 g
s
.59787 .63445 m .60526 .62722 L .60639 .6262 L p 0 0 0 r
F P
0 g
s
.60639 .6262 m .59583 .63655 L .59787 .63445 L p 0 0 0 r
F P
0 g
s
.59583 .63655 m .59439 .64035 L .59252 .64077 L p .288 0 .183 r
F P
0 g
s
.60457 .62831 m .59717 .63556 L .59583 .63655 L p 0 0 0 r
F P
0 g
s
.59583 .63655 m .60639 .6262 L .60457 .62831 L p 0 0 0 r
F P
0 g
s
.59439 .64035 m .59583 .63655 L .59717 .63556 L p 0 0 .029 r
F P
0 g
s
.61244 .7895 m .58111 .79507 L .57182 .78928 L p .658 .636 .817 r
F P
0 g
s
.50858 .6208 m .51537 .63099 L .51661 .63347 L p .923 .624 .459 r
F P
0 g
s
.50353 .60039 m .5037 .58294 L .50391 .5857 L p .945 .778 .317 r
F P
0 g
s
.51661 .63347 m .50691 .6189 L .50858 .6208 L p .923 .624 .459 r
F P
0 g
s
.51477 .6319 m .51508 .63139 L .51661 .63347 L p .911 .634 .504 r
F P
0 g
s
.51661 .63347 m .51616 .63419 L .51477 .6319 L p .911 .634 .504 r
F P
0 g
s
.50691 .6189 m .51661 .63347 L .51508 .63139 L p .915 .63 .488 r
F P
0 g
s
.57946 .65246 m .56296 .65464 L .5655 .65398 L p .568 .274 .429 r
F P
0 g
s
.56296 .65464 m .56279 .65541 L .56025 .6549 L p .68 .391 .477 r
F P
0 g
s
.57696 .6529 m .56541 .65443 L .56296 .65464 L p .574 .289 .446 r
F P
0 g
s
.56296 .65464 m .57946 .65246 L .57696 .6529 L p .574 .289 .446 r
F P
0 g
s
.56279 .65541 m .56296 .65464 L .56541 .65443 L p .575 .291 .448 r
F P
0 g
s
.53178 .54092 m .53855 .53845 L .54158 .53802 L p .454 .87 .947 r
F P
0 g
s
.62543 .47657 m .62511 .47599 L .62592 .47393 L p .198 .143 .566 r
F P
0 g
s
.62951 .46386 m .62592 .47393 L .62511 .47599 L p .172 .115 .547 r
F P
0 g
s
.62511 .47599 m .63024 .46161 L .62951 .46386 L p .172 .115 .547 r
F P
0 g
s
.63024 .46161 m .62511 .47599 L .62577 .47358 L p .146 .088 .529 r
F P
0 g
s
.62442 .47932 m .62414 .47882 L .62543 .47657 L p .359 .214 .545 r
F P
0 g
s
.36442 .32879 m .37846 .31571 L .38831 .31918 L p .593 .609 .837 r
F P
0 g
s
.57834 .52567 m .58 .52646 L .57818 .52822 L p .57 .267 .415 r
F P
0 g
s
.57818 .52822 m .57582 .52709 L .57834 .52567 L p .57 .267 .415 r
F P
0 g
s
.50746 .61481 m .504 .60314 L .50353 .60039 L p .977 .718 .472 r
F P
0 g
s
.75249 .29478 m .80379 .26178 L .81201 .24746 L p .76 .781 .87 r
F P
0 g
s
.81201 .24746 m .73847 .29481 L .75249 .29478 L p .76 .781 .87 r
F P
0 g
s
.52712 .64477 m .51766 .63683 L .51578 .63483 L p .839 .555 .507 r
F P
0 g
s
.57171 .52745 m .55882 .53297 L .55567 .534 L p .47 .056 .171 r
F P
0 g
s
.62066 .49205 m .62328 .4944 L .62268 .49707 L p .458 .342 .633 r
F P
0 g
s
.5655 .65398 m .57704 .65246 L .57946 .65246 L p .568 .274 .429 r
F P
0 g
s
.60449 .52394 m .59651 .52014 L .59926 .51879 L p .613 .406 .576 r
F P
0 g
s
.60205 .52502 m .59646 .52236 L .59651 .52014 L p .633 .374 .508 r
F P
0 g
s
.59651 .52014 m .60449 .52394 L .60205 .52502 L p .633 .374 .508 r
F P
0 g
s
.58608 .53119 m .59651 .52014 L .59646 .52236 L p .659 .395 .51 r
F P
0 g
s
.58673 .5291 m .59403 .52137 L .59651 .52014 L p .61 .329 .466 r
F P
0 g
s
.59651 .52014 m .58608 .53119 L .58673 .5291 L p .61 .329 .466 r
F P
0 g
s
.50704 .57079 m .50652 .56695 L .50719 .56362 L p .929 .907 .514 r
F P
0 g
s
.58252 .64651 m .58198 .64877 L .57978 .65026 L p .369 .068 .317 r
F P
0 g
s
.6336 .41913 m .62913 .40943 L .62721 .40915 L p .948 .829 .694 r
F P
0 g
s
.5601 .65558 m .56019 .65511 L .56279 .65541 L p .682 .406 .498 r
F P
0 g
s
.67043 .56399 m .65707 .56176 L .65395 .56204 L p .744 .699 .809 r
F P
0 g
s
.66226 .35792 m .64394 .37944 L .64816 .37929 L p .865 .82 .803 r
F P
0 g
s
.62543 .47657 m .62582 .47727 L .62442 .47932 L p .359 .214 .545 r
F P
0 g
s
.51508 .63139 m .50829 .6212 L .50691 .6189 L p .915 .63 .488 r
F P
0 g
s
.59926 .51879 m .60484 .52145 L .60449 .52394 L p .613 .406 .576 r
F P
0 g
s
.56541 .65443 m .56529 .65496 L .56279 .65541 L p .575 .291 .448 r
F P
0 g
s
.57935 .65321 m .56279 .65541 L .56529 .65496 L p .574 .289 .446 r
F P
0 g
s
.56279 .65541 m .56267 .65608 L .5601 .65558 L p .682 .406 .498 r
F P
0 g
s
.57684 .65364 m .56526 .65518 L .56279 .65541 L p .582 .31 .47 r
F P
0 g
s
.56279 .65541 m .57935 .65321 L .57684 .65364 L p .582 .31 .47 r
F P
0 g
s
.56267 .65608 m .56279 .65541 L .56526 .65518 L p .583 .313 .474 r
F P
0 g
s
.57563 .52926 m .57398 .52847 L .57582 .52709 L p .589 .206 .283 r
F P
0 g
s
.57582 .52709 m .57818 .52822 L .57563 .52926 L p .589 .206 .283 r
F P
0 g
s
.55909 .53512 m .57582 .52709 L .57398 .52847 L p .554 .159 .247 r
F P
0 g
s
.56122 .53375 m .57293 .52814 L .57582 .52709 L p .472 .043 .142 r
F P
0 g
s
.57582 .52709 m .55909 .53512 L .56122 .53375 L p .472 .043 .142 r
F P
0 g
s
.53097 .64898 m .54243 .65407 L .54476 .65547 L p .767 .479 .498 r
F P
0 g
s
.62582 .47727 m .62543 .47657 L .62623 .47453 L p .205 .152 .573 r
F P
0 g
s
.62975 .46446 m .62623 .47453 L .62543 .47657 L p .188 .133 .56 r
F P
0 g
s
.62543 .47657 m .63046 .4622 L .62975 .46446 L p .188 .133 .56 r
F P
0 g
s
.62592 .47393 m .62614 .47433 L .62543 .47657 L p .198 .143 .566 r
F P
0 g
s
.63046 .4622 m .62543 .47657 L .62614 .47433 L p .17 .114 .547 r
F P
0 g
s
.51813 .63599 m .51786 .63644 L .51578 .63483 L p .846 .544 .478 r
F P
0 g
s
.51578 .63483 m .51616 .63419 L .51813 .63599 L p .846 .544 .478 r
F P
0 g
s
.42396 .48915 m .42843 .48837 L .42893 .48902 L p .102 0 .219 r
F P
0 g
s
.43798 .45899 m .43794 .45092 L .43949 .44835 L p .328 .231 .591 r
F P
0 g
s
.66226 .35792 m .69176 .33046 L .68382 .33129 L p .803 .756 .81 r
F P
0 g
s
.66528 .31374 m .68382 .33129 L .69176 .33046 L p .803 .756 .809 r
F P
0 g
s
.69176 .33046 m .66533 .30533 L .66528 .31374 L p .803 .756 .809 r
F P
0 g
s
.72699 .29574 m .69422 .32076 L .69176 .33046 L p .776 .756 .834 r
F P
0 g
s
.69176 .33046 m .73847 .29481 L .72699 .29574 L p .776 .756 .834 r
F P
0 g
s
.66533 .30533 m .69176 .33046 L .69422 .32076 L p .776 .756 .834 r
F P
0 g
s
.54476 .65547 m .52839 .64819 L .53097 .64898 L p .767 .479 .498 r
F P
0 g
s
.56228 .65812 m .54476 .65547 L .54747 .65556 L p .684 .402 .489 r
F P
0 g
s
.54136 .65752 m .54211 .65494 L .54476 .65547 L p .764 .501 .535 r
F P
0 g
s
.54476 .65547 m .54369 .65917 L .54136 .65752 L p .764 .501 .535 r
F P
0 g
s
.52839 .64819 m .54476 .65547 L .54211 .65494 L p .764 .495 .527 r
F P
0 g
s
.55953 .65827 m .54726 .65642 L .54476 .65547 L p .686 .423 .518 r
F P
0 g
s
.54476 .65547 m .56228 .65812 L .55953 .65827 L p .686 .423 .518 r
F P
0 g
s
.54369 .65917 m .54476 .65547 L .54726 .65642 L p .687 .42 .513 r
F P
0 g
s
.54747 .65556 m .55973 .65741 L .56228 .65812 L p .684 .402 .489 r
F P
0 g
s
.62577 .47358 m .62935 .46351 L .63024 .46161 L p .146 .088 .529 r
F P
0 g
s
.50789 .6217 m .51477 .6319 L .51616 .63419 L p .916 .632 .489 r
F P
0 g
s
.51616 .63419 m .50633 .61961 L .50789 .6217 L p .916 .632 .489 r
F P
0 g
s
.51436 .63255 m .51462 .63211 L .51616 .63419 L p .908 .637 .516 r
F P
0 g
s
.51616 .63419 m .51578 .63483 L .51436 .63255 L p .908 .637 .516 r
F P
0 g
s
.50633 .61961 m .51616 .63419 L .51462 .63211 L p .912 .634 .503 r
F P
0 g
s
.62881 .45091 m .62896 .45405 L .62893 .45679 L p 0 0 .093 r
F P
0 g
s
.62571 .48116 m .62474 .47973 L .62582 .47727 L p .384 .248 .57 r
F P
0 g
s
.50176 .59894 m .50319 .5979 L .50353 .60039 L p .999 .826 .536 r
F P
0 g
s
.50353 .60039 m .50147 .60188 L .50176 .59894 L p .999 .826 .536 r
F P
0 g
s
.5037 .58294 m .50353 .60039 L .50319 .5979 L p 1 .823 .516 r
F P
0 g
s
.50147 .60188 m .50353 .60039 L .504 .60314 L p .981 .719 .458 r
F P
0 g
s
.64394 .37944 m .66226 .35792 L .65665 .3586 L p .831 .753 .777 r
F P
0 g
s
.64184 .3453 m .65665 .3586 L .66226 .35792 L p .831 .753 .777 r
F P
0 g
s
.66226 .35792 m .64112 .33889 L .64184 .3453 L p .831 .753 .777 r
F P
0 g
s
.68382 .33129 m .66313 .35054 L .66226 .35792 L p .803 .756 .81 r
F P
0 g
s
.64112 .33889 m .66226 .35792 L .66313 .35054 L p .803 .756 .81 r
F P
0 g
s
.41797 .4967 m .41085 .50408 L .41173 .50363 L p .759 .976 .712 r
F P
0 g
s
.55973 .65741 m .56 .65599 L .56267 .65608 L p .684 .408 .499 r
F P
0 g
s
.43811 .42985 m .4481 .42518 L .45119 .42704 L p .502 .434 .712 r
F P
0 g
s
.67857 .56072 m .67904 .55977 L .67554 .55893 L p .733 .679 .799 r
F P
0 g
s
.67554 .55893 m .67487 .56029 L .67857 .56072 L p .733 .679 .799 r
F P
0 g
s
.41085 .50408 m .41797 .4967 L .41752 .49763 L p 0 0 0 r
F P
0 g
s
.42098 .49697 m .41752 .49763 L .41797 .4967 L p 0 0 0 r
F P
0 g
s
.41797 .4967 m .42293 .49575 L .42098 .49697 L p 0 0 0 r
F P
0 g
s
.4227 .49095 m .4195 .49556 L .41797 .4967 L p .033 0 .114 r
F P
0 g
s
.42293 .49575 m .41797 .4967 L .4195 .49556 L p 0 0 .01 r
F P
0 g
s
.56526 .65518 m .56517 .65565 L .56267 .65608 L p .583 .313 .474 r
F P
0 g
s
.57928 .65385 m .56267 .65608 L .56517 .65565 L p .581 .31 .47 r
F P
0 g
s
.56267 .65608 m .56228 .65812 L .55973 .65741 L p .684 .408 .499 r
F P
0 g
s
.57674 .65449 m .56511 .65605 L .56267 .65608 L p .584 .318 .479 r
F P
0 g
s
.56267 .65608 m .57928 .65385 L .57674 .65449 L p .584 .318 .479 r
F P
0 g
s
.56228 .65812 m .56267 .65608 L .56511 .65605 L p .583 .314 .475 r
F P
0 g
s
.56529 .65496 m .57688 .65343 L .57935 .65321 L p .574 .289 .446 r
F P
0 g
s
.5324 .78465 m .56471 .78391 L .57182 .78928 L p .693 .629 .78 r
F P
0 g
s
.56563 .75269 m .57182 .78928 L .56471 .78391 L p .693 .629 .781 r
F P
0 g
s
.57256 .75714 m .57687 .78277 L .57182 .78928 L p .655 .603 .784 r
F P
0 g
s
.57182 .78928 m .56563 .75269 L .57256 .75714 L p .655 .603 .784 r
F P
0 g
s
.61663 .78128 m .57182 .78928 L .57687 .78277 L p .656 .604 .784 r
F P
0 g
s
.57182 .78928 m .61663 .78128 L .61244 .7895 L p .658 .636 .817 r
F P
0 g
s
.54211 .65494 m .53065 .64984 L .52839 .64819 L p .764 .495 .527 r
F P
0 g
s
.50215 .58058 m .50407 .58047 L .5037 .58294 L p .978 .919 .629 r
F P
0 g
s
.5037 .58294 m .50095 .5831 L .50215 .58058 L p .978 .919 .629 r
F P
0 g
s
.50319 .5979 m .50331 .58568 L .5037 .58294 L p 1 .823 .516 r
F P
0 g
s
.50095 .5831 m .5037 .58294 L .50331 .58568 L p 1 .826 .507 r
F P
0 g
s
.65453 .56954 m .65637 .56373 L .65395 .56204 L p .759 .698 .794 r
F P
0 g
s
.65395 .56204 m .65133 .57034 L .65453 .56954 L p .759 .698 .794 r
F P
0 g
s
.51682 .63825 m .52648 .64619 L .52839 .64819 L p .842 .558 .508 r
F P
0 g
s
.52839 .64819 m .51459 .63686 L .51682 .63825 L p .842 .558 .508 r
F P
0 g
s
.52493 .64967 m .52605 .64706 L .52839 .64819 L p .833 .573 .546 r
F P
0 g
s
.52839 .64819 m .5268 .65192 L .52493 .64967 L p .833 .573 .546 r
F P
0 g
s
.51459 .63686 m .52839 .64819 L .52605 .64706 L p .834 .569 .538 r
F P
0 g
s
.5268 .65192 m .52839 .64819 L .53065 .64984 L p .766 .492 .519 r
F P
0 g
s
.6272 .47931 m .62582 .47727 L .62674 .47543 L p .252 .204 .608 r
F P
0 g
s
.63019 .46536 m .62674 .47543 L .62582 .47727 L p .228 .176 .589 r
F P
0 g
s
.62582 .47727 m .63076 .4629 L .63019 .46536 L p .228 .176 .589 r
F P
0 g
s
.62582 .47727 m .6272 .47931 L .62571 .48116 L p .384 .248 .57 r
F P
0 g
s
.62623 .47453 m .62651 .47502 L .62582 .47727 L p .205 .152 .573 r
F P
0 g
s
.63076 .4629 m .62582 .47727 L .62651 .47502 L p .186 .132 .56 r
F P
0 g
s
.504 .60314 m .50256 .60419 L .50147 .60188 L p .981 .719 .458 r
F P
0 g
s
.63256 .59192 m .63516 .58256 L .6338 .5805 L p .834 .768 .789 r
F P
0 g
s
.6338 .5805 m .63008 .59388 L .63256 .59192 L p .834 .768 .789 r
F P
0 g
s
.61025 .62123 m .60794 .62371 L .60639 .6262 L p .812 .946 .594 r
F P
0 g
s
.54726 .65642 m .54651 .659 L .54369 .65917 L p .687 .42 .513 r
F P
0 g
s
.6142 .50844 m .62062 .49865 L .62268 .49707 L p .531 .365 .601 r
F P
0 g
s
.62268 .49707 m .61351 .51105 L .6142 .50844 L p .531 .365 .601 r
F P
0 g
s
.70901 .55051 m .707 .55625 L .70188 .55676 L p .693 .702 .854 r
F P
0 g
s
.70188 .55676 m .70475 .54855 L .70901 .55051 L p .693 .702 .854 r
F P
0 g
s
.68151 .55194 m .69862 .5549 L .70188 .55676 L p .702 .694 .84 r
F P
0 g
s
.70188 .55676 m .67745 .55253 L .68151 .55194 L p .702 .694 .84 r
F P
0 g
s
.70475 .54855 m .70188 .55676 L .69862 .5549 L p .688 .697 .853 r
F P
0 g
s
.67745 .55253 m .70188 .55676 L .69794 .55687 L p .703 .694 .838 r
F P
0 g
s
.51462 .63211 m .50774 .6219 L .50633 .61961 L p .912 .634 .503 r
F P
0 g
s
.67932 .55835 m .67918 .55935 L .67554 .55893 L p .73 .677 .798 r
F P
0 g
s
.77129 .55581 m .77444 .54667 L .78127 .54541 L p .665 .725 .894 r
F P
0 g
s
.69794 .55687 m .68084 .55391 L .67745 .55253 L p .703 .694 .838 r
F P
0 g
s
.59717 .63556 m .59617 .63821 L .59439 .64035 L p 0 0 .029 r
F P
0 g
s
.51766 .63683 m .51682 .63825 L .51459 .63686 L p .843 .553 .497 r
F P
0 g
s
.51459 .63686 m .51578 .63483 L .51766 .63683 L p .843 .553 .497 r
F P
0 g
s
.5204 .78399 m .52277 .75775 L .52912 .75287 L p .725 .658 .783 r
F P
0 g
s
.56517 .65565 m .5768 .65409 L .57928 .65385 L p .581 .31 .47 r
F P
0 g
s
.5074 .62234 m .51436 .63255 L .51578 .63483 L p .912 .636 .504 r
F P
0 g
s
.51578 .63483 m .50584 .62024 L .5074 .62234 L p .912 .636 .504 r
F P
0 g
s
.51325 .63437 m .51409 .63296 L .51578 .63483 L p .903 .642 .533 r
F P
0 g
s
.51578 .63483 m .51459 .63686 L .51325 .63437 L p .903 .642 .533 r
F P
0 g
s
.50584 .62024 m .51578 .63483 L .51409 .63296 L p .906 .639 .523 r
F P
0 g
s
.60484 .52145 m .61116 .51243 L .61351 .51105 L p .597 .391 .573 r
F P
0 g
s
.40212 .51118 m .4093 .50593 L .41085 .50408 L p .786 .996 .867 r
F P
0 g
s
.62614 .47433 m .62966 .46427 L .63046 .4622 L p .17 .114 .547 r
F P
0 g
s
.65809 .55816 m .67171 .56053 L .67487 .56029 L p .733 .687 .806 r
F P
0 g
s
.67487 .56029 m .65541 .55689 L .65809 .55816 L p .733 .687 .806 r
F P
0 g
s
.67252 .55863 m .67205 .55957 L .67487 .56029 L p .734 .68 .799 r
F P
0 g
s
.67487 .56029 m .67554 .55893 L .67252 .55863 L p .734 .68 .799 r
F P
0 g
s
.65541 .55689 m .67487 .56029 L .67205 .55957 L p .744 .665 .773 r
F P
0 g
s
.53065 .64984 m .52954 .65245 L .5268 .65192 L p .766 .492 .519 r
F P
0 g
s
.43942 .43505 m .44123 .44533 L .43949 .44835 L p .483 .387 .67 r
F P
0 g
s
.63801 .57066 m .6486 .5718 L .65133 .57034 L p .784 .712 .784 r
F P
0 g
s
.65133 .57034 m .6362 .56872 L .63801 .57066 L p .784 .712 .784 r
F P
0 g
s
.65123 .56299 m .64939 .5688 L .65133 .57034 L p .768 .708 .796 r
F P
0 g
s
.65133 .57034 m .65395 .56204 L .65123 .56299 L p .768 .708 .796 r
F P
0 g
s
.6362 .56872 m .65133 .57034 L .64939 .5688 L p .787 .705 .773 r
F P
0 g
s
.59646 .52236 m .58916 .53009 L .58608 .53119 L p .659 .395 .51 r
F P
0 g
s
.67554 .55893 m .67573 .5575 L .67932 .55835 L p .73 .677 .798 r
F P
0 g
s
.62168 .51545 m .61351 .51105 L .61595 .50961 L p .586 .441 .651 r
F P
0 g
s
.62237 .49982 m .61595 .50961 L .61351 .51105 L p .574 .418 .632 r
F P
0 g
s
.61351 .51105 m .62268 .49707 L .62237 .49982 L p .574 .418 .632 r
F P
0 g
s
.61931 .51672 m .61359 .51363 L .61351 .51105 L p .611 .422 .602 r
F P
0 g
s
.61351 .51105 m .62168 .51545 L .61931 .51672 L p .611 .422 .602 r
F P
0 g
s
.60449 .52394 m .61351 .51105 L .61359 .51363 L p .638 .443 .603 r
F P
0 g
s
.61351 .51105 m .60449 .52394 L .60484 .52145 L p .597 .391 .573 r
F P
0 g
s
.63219 .42233 m .6299 .42842 L .63032 .4317 L p .983 .815 .597 r
F P
0 g
s
.56511 .65605 m .56484 .65748 L .56228 .65812 L p .583 .314 .475 r
F P
0 g
s
.63596 .39627 m .64352 .38452 L .64394 .37944 L p .907 .829 .758 r
F P
0 g
s
.57704 .65246 m .57727 .65092 L .57978 .65026 L p .571 .283 .44 r
F P
0 g
s
.34839 .28412 m .33094 .30172 L .32044 .29919 L p .593 .609 .837 r
F P
0 g
s
.32044 .29919 m .3453 .27395 L .34839 .28412 L p .593 .609 .837 r
F P
0 g
s
.26159 .25214 m .31364 .28729 L .32044 .29919 L p .613 .641 .855 r
F P
0 g
s
.32044 .29919 m .24622 .24912 L .26159 .25214 L p .613 .641 .855 r
F P
0 g
s
.3453 .27395 m .32044 .29919 L .31364 .28729 L p .612 .641 .855 r
F P
0 g
s
.62193 .59732 m .62802 .59621 L .63008 .59388 L p .887 .863 .81 r
F P
0 g
s
.63008 .59388 m .62138 .59545 L .62193 .59732 L p .887 .863 .81 r
F P
0 g
s
.63178 .58266 m .62918 .59203 L .63008 .59388 L p .87 .808 .786 r
F P
0 g
s
.63008 .59388 m .6338 .5805 L .63178 .58266 L p .87 .808 .786 r
F P
0 g
s
.62138 .59545 m .63008 .59388 L .62918 .59203 L p .898 .814 .757 r
F P
0 g
s
.65897 .5558 m .67263 .5582 L .67554 .55893 L p .74 .661 .772 r
F P
0 g
s
.67554 .55893 m .65603 .55551 L .65897 .5558 L p .74 .661 .772 r
F P
0 g
s
.67573 .5575 m .67554 .55893 L .67263 .5582 L p .73 .676 .798 r
F P
0 g
s
.65886 .55623 m .67252 .55863 L .67554 .55893 L p .74 .661 .772 r
F P
0 g
s
.67554 .55893 m .65603 .55551 L .65886 .55623 L p .74 .661 .772 r
F P
0 g
s
.50331 .58568 m .50139 .5858 L .50095 .5831 L p 1 .826 .507 r
F P
0 g
s
.62866 .46156 m .62819 .45941 L .62893 .45679 L p .041 0 .44 r
F P
0 g
s
.52605 .64706 m .51638 .63912 L .51459 .63686 L p .834 .569 .538 r
F P
0 g
s
.59373 .64354 m .57978 .65026 L .58198 .64877 L p .366 .064 .313 r
F P
0 g
s
.57978 .65026 m .57946 .65246 L .57704 .65246 L p .571 .283 .44 r
F P
0 g
s
.59159 .64487 m .58182 .64958 L .57978 .65026 L p .411 .138 .386 r
F P
0 g
s
.57978 .65026 m .59373 .64354 L .59159 .64487 L p .411 .138 .386 r
F P
0 g
s
.57946 .65246 m .57978 .65026 L .58182 .64958 L p .418 .152 .401 r
F P
0 g
s
.5812 .52703 m .58673 .5291 L .58608 .53119 L p .615 .334 .468 r
F P
0 g
s
.58608 .53119 m .57818 .52822 L .5812 .52703 L p .615 .334 .468 r
F P
0 g
s
.43955 .4599 m .43949 .44835 L .44158 .44958 L p .471 .346 .628 r
F P
0 g
s
.45146 .44646 m .44158 .44958 L .43949 .44835 L p .47 .346 .629 r
F P
0 g
s
.43949 .44835 m .4536 .4439 L .45146 .44646 L p .47 .346 .629 r
F P
0 g
s
.43949 .44835 m .43955 .4599 L .43798 .45899 L p .328 .231 .591 r
F P
0 g
s
.4536 .4439 m .43949 .44835 L .44123 .44533 L p .485 .389 .671 r
F P
0 g
s
.67205 .55957 m .65843 .5572 L .65541 .55689 L p .744 .665 .773 r
F P
0 g
s
.57398 .52847 m .56227 .53409 L .55909 .53512 L p .554 .159 .247 r
F P
0 g
s
.62651 .47502 m .62996 .46495 L .63076 .4629 L p .186 .132 .56 r
F P
0 g
s
.68084 .55391 m .67964 .55739 L .67573 .5575 L p .714 .688 .823 r
F P
0 g
s
.50829 .6212 m .50789 .6217 L .50633 .61961 L p .919 .628 .475 r
F P
0 g
s
.50633 .61961 m .50691 .6189 L .50829 .6212 L p .919 .628 .475 r
F P
0 g
s
.51409 .63296 m .50712 .62275 L .50584 .62024 L p .906 .639 .523 r
F P
0 g
s
.41608 .81347 m .43557 .78094 L .44488 .77584 L p .755 .729 .828 r
F P
0 g
s
.57911 .65587 m .56228 .65812 L .56484 .65748 L p .585 .319 .479 r
F P
0 g
s
.5591 .66083 m .55953 .65827 L .56228 .65812 L p .688 .427 .523 r
F P
0 g
s
.56228 .65812 m .56168 .66177 L .5591 .66083 L p .688 .427 .523 r
F P
0 g
s
.57652 .65675 m .56474 .65832 L .56228 .65812 L p .593 .34 .503 r
F P
0 g
s
.56228 .65812 m .57911 .65587 L .57652 .65675 L p .593 .34 .503 r
F P
0 g
s
.56168 .66177 m .56228 .65812 L .56474 .65832 L p .593 .34 .503 r
F P
0 g
s
.56471 .78391 m .56035 .7583 L .56563 .75269 L p .693 .629 .781 r
F P
0 g
s
.58358 .53197 m .57805 .52989 L .57818 .52822 L p .624 .263 .338 r
F P
0 g
s
.57818 .52822 m .58608 .53119 L .58358 .53197 L p .624 .263 .338 r
F P
0 g
s
.56549 .53636 m .57818 .52822 L .57805 .52989 L p .65 .286 .34 r
F P
0 g
s
.56675 .53495 m .57563 .52926 L .57818 .52822 L p .553 .149 .23 r
F P
0 g
s
.57818 .52822 m .56549 .53636 L .56675 .53495 L p .553 .149 .23 r
F P
0 g
s
.4195 .49556 m .42298 .49489 L .42293 .49575 L p 0 0 .01 r
F P
0 g
s
.50256 .60419 m .50637 .6161 L .50691 .6189 L p .979 .724 .476 r
F P
0 g
s
.67573 .5575 m .67745 .55253 L .68084 .55391 L p .714 .688 .823 r
F P
0 g
s
.65924 .55378 m .67302 .55622 L .67573 .5575 L p .725 .678 .804 r
F P
0 g
s
.67573 .5575 m .65604 .55401 L .65924 .55378 L p .725 .678 .804 r
F P
0 g
s
.67745 .55253 m .67573 .5575 L .67302 .55622 L p .712 .685 .822 r
F P
0 g
s
.67263 .5582 m .67277 .55719 L .67573 .5575 L p .73 .676 .798 r
F P
0 g
s
.65604 .55401 m .67573 .5575 L .67277 .55719 L p .736 .657 .771 r
F P
0 g
s
.74676 .84892 m .78659 .82632 L .80471 .82886 L p .6 .647 .868 r
F P
0 g
s
.61595 .50961 m .62167 .51269 L .62168 .51545 L p .586 .441 .651 r
F P
0 g
s
.58198 .64877 m .59174 .64406 L .59373 .64354 L p .366 .064 .313 r
F P
0 g
s
.69862 .5549 m .70062 .54915 L .70475 .54855 L p .688 .697 .853 r
F P
0 g
s
.50691 .6189 m .50147 .60188 L .50256 .60419 L p .979 .724 .476 r
F P
0 g
s
.50559 .61696 m .50599 .61646 L .50691 .6189 L p .967 .728 .524 r
F P
0 g
s
.50691 .6189 m .50633 .61961 L .50559 .61696 L p .967 .728 .524 r
F P
0 g
s
.50147 .60188 m .50691 .6189 L .50599 .61646 L p .968 .727 .52 r
F P
0 g
s
.62879 .50138 m .62268 .49707 L .62458 .49554 L p .504 .405 .676 r
F P
0 g
s
.62968 .48538 m .62458 .49554 L .62268 .49707 L p .49 .383 .659 r
F P
0 g
s
.62268 .49707 m .62996 .48256 L .62968 .48538 L p .49 .383 .659 r
F P
0 g
s
.62665 .50284 m .62237 .49982 L .62268 .49707 L p .548 .395 .626 r
F P
0 g
s
.62268 .49707 m .62879 .50138 L .62665 .50284 L p .548 .395 .626 r
F P
0 g
s
.62996 .48256 m .62268 .49707 L .62328 .4944 L p .437 .321 .624 r
F P
0 g
s
.62674 .47543 m .6277 .47685 L .6272 .47931 L p .252 .204 .608 r
F P
0 g
s
.61359 .51363 m .60727 .52266 L .60449 .52394 L p .638 .443 .603 r
F P
0 g
s
.62328 .4944 m .62838 .48425 L .62996 .48256 L p .437 .321 .624 r
F P
0 g
s
.64939 .5688 m .6388 .56766 L .6362 .56872 L p .787 .705 .773 r
F P
0 g
s
.43701 .46773 m .4379 .46178 L .43955 .4599 L p .288 .156 .521 r
F P
0 g
s
.56484 .65748 m .57662 .6559 L .57911 .65587 L p .585 .319 .479 r
F P
0 g
s
.6296 .45985 m .62893 .45679 L .62907 .45521 L p 0 0 .312 r
F P
0 g
s
.62935 .44563 m .62907 .45521 L .62893 .45679 L p 0 0 .288 r
F P
0 g
s
.62893 .45679 m .62932 .4431 L .62935 .44563 L p 0 0 .288 r
F P
0 g
s
.62893 .45679 m .6296 .45985 L .62866 .46156 L p .041 0 .44 r
F P
0 g
s
.62932 .4431 m .62893 .45679 L .62896 .45405 L p 0 0 .075 r
F P
0 g
s
.52954 .65245 m .54136 .65752 L .54369 .65917 L p .767 .498 .528 r
F P
0 g
s
.67277 .55719 m .65899 .55476 L .65604 .55401 L p .736 .657 .771 r
F P
0 g
s
.54651 .659 m .5591 .66083 L .56168 .66177 L p .688 .425 .518 r
F P
0 g
s
.56168 .66177 m .54369 .65917 L .54651 .659 L p .688 .425 .518 r
F P
0 g
s
.41752 .49763 m .41253 .5028 L .41085 .50408 L p 0 0 0 r
F P
0 g
s
.73105 .55372 m .70901 .55051 L .70475 .54855 L p .682 .705 .865 r
F P
0 g
s
.70475 .54855 m .73624 .55315 L .73105 .55372 L p .682 .705 .865 r
F P
0 g
s
.41085 .50408 m .40058 .5116 L .40212 .51118 L p .786 .996 .867 r
F P
0 g
s
.40058 .5116 m .41085 .50408 L .40968 .50491 L p .441 .825 .592 r
F P
0 g
s
.41194 .50394 m .40968 .50491 L .41085 .50408 L p 0 0 0 r
F P
0 g
s
.41085 .50408 m .4141 .50269 L .41194 .50394 L p 0 0 0 r
F P
0 g
s
.4141 .50269 m .41085 .50408 L .41253 .5028 L p 0 0 0 r
F P
0 g
s
.54369 .65917 m .5268 .65192 L .52954 .65245 L p .767 .498 .528 r
F P
0 g
s
.53982 .66303 m .54087 .65896 L .54369 .65917 L p .763 .522 .57 r
F P
0 g
s
.54369 .65917 m .54219 .66498 L .53982 .66303 L p .763 .522 .57 r
F P
0 g
s
.5268 .65192 m .54369 .65917 L .54087 .65896 L p .762 .517 .563 r
F P
0 g
s
.55882 .66224 m .54622 .66041 L .54369 .65917 L p .691 .45 .553 r
F P
0 g
s
.54369 .65917 m .56168 .66177 L .55882 .66224 L p .691 .45 .553 r
F P
0 g
s
.54219 .66498 m .54369 .65917 L .54622 .66041 L p .691 .449 .551 r
F P
0 g
s
.47337 .79091 m .44717 .78441 L .44488 .77584 L p .738 .705 .82 r
F P
0 g
s
.44488 .77584 m .48234 .78518 L .47337 .79091 L p .738 .705 .82 r
F P
0 g
s
.67302 .55622 m .67422 .55274 L .67745 .55253 L p .712 .685 .822 r
F P
0 g
s
.62838 .48425 m .62644 .48197 L .6272 .47931 L p .419 .297 .606 r
F P
0 g
s
.50599 .61646 m .50219 .60454 L .50147 .60188 L p .968 .727 .52 r
F P
0 g
s
.58182 .64958 m .5816 .65112 L .57946 .65246 L p .418 .152 .401 r
F P
0 g
s
.44123 .44533 m .4511 .4422 L .4536 .4439 L p .485 .389 .671 r
F P
0 g
s
.56474 .65832 m .56432 .66088 L .56168 .66177 L p .593 .34 .503 r
F P
0 g
s
.62996 .48256 m .6272 .47931 L .62825 .47765 L p .311 .272 .652 r
F P
0 g
s
.63144 .46759 m .62825 .47765 L .6272 .47931 L p .294 .25 .637 r
F P
0 g
s
.6272 .47931 m .63175 .46495 L .63144 .46759 L p .294 .25 .637 r
F P
0 g
s
.6272 .47931 m .62996 .48256 L .62838 .48425 L p .419 .297 .606 r
F P
0 g
s
.63175 .46495 m .6272 .47931 L .6277 .47685 L p .219 .173 .59 r
F P
0 g
s
.57688 .65343 m .57696 .6529 L .57946 .65246 L p .573 .287 .443 r
F P
0 g
s
.50774 .6219 m .5074 .62234 L .50584 .62024 L p .915 .633 .493 r
F P
0 g
s
.50584 .62024 m .50633 .61961 L .50774 .6219 L p .915 .633 .493 r
F P
0 g
s
.7455 .54381 m .74293 .55209 L .73624 .55315 L p .675 .714 .878 r
F P
0 g
s
.73624 .55315 m .73989 .54132 L .7455 .54381 L p .675 .714 .878 r
F P
0 g
s
.70998 .54752 m .73204 .55074 L .73624 .55315 L p .68 .707 .867 r
F P
0 g
s
.73624 .55315 m .70475 .54855 L .70998 .54752 L p .68 .707 .867 r
F P
0 g
s
.73989 .54132 m .73624 .55315 L .73204 .55074 L p .669 .708 .877 r
F P
0 g
s
.62918 .59203 m .62309 .59313 L .62138 .59545 L p .898 .814 .757 r
F P
0 g
s
.6293 .43951 m .63007 .43485 L .63032 .4317 L p .842 .747 .229 r
F P
0 g
s
.63313 .39624 m .64394 .37944 L .63992 .3799 L p .859 .745 .736 r
F P
0 g
s
.6277 .36938 m .63992 .3799 L .64394 .37944 L p .859 .745 .736 r
F P
0 g
s
.64394 .37944 m .62651 .36438 L .6277 .36938 L p .859 .745 .736 r
F P
0 g
s
.64394 .37944 m .63313 .39624 L .63596 .39627 L p .907 .829 .758 r
F P
0 g
s
.65665 .3586 m .64381 .37368 L .64394 .37944 L p .831 .753 .777 r
F P
0 g
s
.62651 .36438 m .64394 .37944 L .64381 .37368 L p .831 .753 .777 r
F P
0 g
s
.65707 .56176 m .65809 .55816 L .65541 .55689 L p .746 .68 .787 r
F P
0 g
s
.65541 .55689 m .65395 .56204 L .65707 .56176 L p .746 .68 .787 r
F P
0 g
s
.22616 .54967 m .26392 .5459 L .2707 .54221 L p .668 .772 .928 r
F P
0 g
s
.2707 .54221 m .21666 .54761 L .22616 .54967 L p .668 .772 .928 r
F P
0 g
s
.38878 .51856 m .39865 .51354 L .40058 .5116 L p .766 .954 .935 r
F P
0 g
s
.50602 .62423 m .51325 .63437 L .51459 .63686 L p .907 .642 .524 r
F P
0 g
s
.51459 .63686 m .50426 .62236 L .50602 .62423 L p .907 .642 .524 r
F P
0 g
s
.51117 .63797 m .51267 .63529 L .51459 .63686 L p .893 .649 .562 r
F P
0 g
s
.51459 .63686 m .51245 .6407 L .51117 .63797 L p .893 .649 .562 r
F P
0 g
s
.50426 .62236 m .51459 .63686 L .51267 .63529 L p .894 .648 .558 r
F P
0 g
s
.51245 .6407 m .51459 .63686 L .51638 .63912 L p .837 .568 .532 r
F P
0 g
s
.62896 .45405 m .62923 .44447 L .62932 .4431 L p 0 0 .075 r
F P
0 g
s
.50162 .60505 m .50559 .61696 L .50633 .61961 L p .968 .728 .52 r
F P
0 g
s
.50633 .61961 m .50066 .60259 L .50162 .60505 L p .968 .728 .52 r
F P
0 g
s
.50505 .6176 m .50539 .61716 L .50633 .61961 L p .962 .728 .538 r
F P
0 g
s
.50633 .61961 m .50584 .62024 L .50505 .6176 L p .962 .728 .538 r
F P
0 g
s
.50066 .60259 m .50633 .61961 L .50539 .61716 L p .963 .728 .536 r
F P
0 g
s
.54087 .65896 m .52905 .65388 L .5268 .65192 L p .762 .517 .563 r
F P
0 g
s
.51638 .63912 m .51488 .64181 L .51245 .6407 L p .837 .568 .532 r
F P
0 g
s
.54622 .66041 m .54517 .66449 L .54219 .66498 L p .691 .449 .551 r
F P
0 g
s
.57946 .65246 m .57935 .65321 L .57688 .65343 L p .573 .287 .443 r
F P
0 g
s
.62458 .49554 m .62886 .49855 L .62879 .50138 L p .504 .405 .676 r
F P
0 g
s
.59348 .64563 m .57946 .65246 L .5816 .65112 L p .406 .134 .385 r
F P
0 g
s
.59136 .64677 m .58154 .65155 L .57946 .65246 L p .42 .157 .407 r
F P
0 g
s
.57946 .65246 m .59348 .64563 L .59136 .64677 L p .42 .157 .407 r
F P
0 g
s
.57935 .65321 m .57946 .65246 L .58154 .65155 L p .418 .154 .404 r
F P
0 g
s
.66313 .35054 m .64836 .33718 L .64112 .33889 L p .803 .756 .81 r
F P
0 g
s
.57687 .78277 m .60825 .77715 L .61663 .78128 L p .656 .604 .784 r
F P
0 g
s
.43955 .4599 m .43828 .46841 L .43701 .46773 L p .288 .156 .521 r
F P
0 g
s
.44158 .44958 m .44162 .45766 L .43955 .4599 L p .471 .346 .628 r
F P
0 g
s
.5768 .65409 m .57684 .65364 L .57935 .65321 L p .58 .307 .466 r
F P
0 g
s
.63999 .56136 m .65123 .56299 L .65395 .56204 L p .762 .679 .77 r
F P
0 g
s
.65395 .56204 m .6379 .55971 L .63999 .56136 L p .762 .679 .77 r
F P
0 g
s
.65276 .55728 m .65174 .56089 L .65395 .56204 L p .749 .683 .788 r
F P
0 g
s
.65395 .56204 m .65541 .55689 L .65276 .55728 L p .749 .683 .788 r
F P
0 g
s
.6379 .55971 m .65395 .56204 L .65174 .56089 L p .763 .676 .766 r
F P
0 g
s
.51488 .64181 m .52493 .64967 L .5268 .65192 L p .836 .572 .539 r
F P
0 g
s
.5268 .65192 m .51245 .6407 L .51488 .64181 L p .836 .572 .539 r
F P
0 g
s
.52256 .65531 m .52423 .65115 L .5268 .65192 L p .825 .588 .581 r
F P
0 g
s
.5268 .65192 m .52442 .65786 L .52256 .65531 L p .825 .588 .581 r
F P
0 g
s
.51245 .6407 m .5268 .65192 L .52423 .65115 L p .825 .585 .576 r
F P
0 g
s
.52442 .65786 m .5268 .65192 L .52905 .65388 L p .764 .516 .558 r
F P
0 g
s
.6277 .47685 m .63089 .4668 L .63175 .46495 L p .219 .173 .59 r
F P
0 g
s
.55882 .53297 m .56122 .53375 L .55909 .53512 L p .41 0 .079 r
F P
0 g
s
.55909 .53512 m .55567 .534 L .55882 .53297 L p .41 0 .079 r
F P
0 g
s
.59174 .64406 m .59221 .64183 L .59439 .64035 L p .365 .061 .31 r
F P
0 g
s
.61545 .52821 m .60449 .52394 L .60727 .52266 L p .651 .471 .627 r
F P
0 g
s
.61307 .52918 m .60539 .52618 L .60449 .52394 L p .664 .446 .579 r
F P
0 g
s
.60449 .52394 m .61545 .52821 L .61307 .52918 L p .664 .446 .579 r
F P
0 g
s
.5983 .53494 m .60449 .52394 L .60539 .52618 L p .692 .459 .566 r
F P
0 g
s
.59771 .53272 m .60205 .52502 L .60449 .52394 L p .653 .413 .543 r
F P
0 g
s
.60449 .52394 m .5983 .53494 L .59771 .53272 L p .653 .413 .543 r
F P
0 g
s
.43828 .46841 m .43955 .4599 L .44136 .46096 L p .464 .311 .588 r
F P
0 g
s
.451 .45935 m .44136 .46096 L .43955 .4599 L p .464 .311 .589 r
F P
0 g
s
.43955 .4599 m .45331 .45759 L .451 .45935 L p .464 .311 .589 r
F P
0 g
s
.45331 .45759 m .43955 .4599 L .44162 .45766 L p .473 .349 .63 r
F P
0 g
s
.57935 .65321 m .57928 .65385 L .5768 .65409 L p .58 .307 .466 r
F P
0 g
s
.49466 .74785 m .48234 .78518 L .47917 .77827 L p .752 .688 .789 r
F P
0 g
s
.45293 .7717 m .47917 .77827 L .48234 .78518 L p .753 .688 .789 r
F P
0 g
s
.48234 .78518 m .44488 .77584 L .45293 .7717 L p .753 .688 .789 r
F P
0 g
s
.49867 .75425 m .49002 .78037 L .48234 .78518 L p .725 .658 .783 r
F P
0 g
s
.48234 .78518 m .49466 .74785 L .49867 .75425 L p .725 .658 .783 r
F P
0 g
s
.52905 .65388 m .52738 .65805 L .52442 .65786 L p .764 .516 .558 r
F P
0 g
s
.43556 .47375 m .43668 .46972 L .43828 .46841 L p .253 .088 .454 r
F P
0 g
s
.57805 .52989 m .56917 .53559 L .56549 .53636 L p .65 .286 .34 r
F P
0 g
s
.50539 .61716 m .50142 .60525 L .50066 .60259 L p .963 .728 .536 r
F P
0 g
s
.60727 .52266 m .61495 .52564 L .61545 .52821 L p .651 .471 .627 r
F P
0 g
s
.62922 .43837 m .63032 .4317 L .62931 .43085 L p .997 .773 .459 r
F P
0 g
s
.62521 .42197 m .62931 .43085 L .63032 .4317 L p .997 .773 .459 r
F P
0 g
s
.63032 .4317 m .62447 .41902 L .62521 .42197 L p .997 .773 .459 r
F P
0 g
s
.63032 .4317 m .62922 .43837 L .6293 .43951 L p .842 .747 .229 r
F P
0 g
s
.62447 .41902 m .63032 .4317 L .6299 .42842 L p .983 .815 .599 r
F P
0 g
s
.41253 .5028 m .41481 .50183 L .4141 .50269 L p 0 0 0 r
F P
0 g
s
.5816 .65112 m .59141 .64634 L .59348 .64563 L p .406 .134 .385 r
F P
0 g
s
.58154 .65155 m .58147 .65208 L .57935 .65321 L p .418 .154 .404 r
F P
0 g
s
.59343 .64637 m .57935 .65321 L .58147 .65208 L p .42 .158 .407 r
F P
0 g
s
.5913 .64749 m .58145 .65229 L .57935 .65321 L p .439 .191 .439 r
F P
0 g
s
.57935 .65321 m .59343 .64637 L .5913 .64749 L p .439 .191 .439 r
F P
0 g
s
.57928 .65385 m .57935 .65321 L .58145 .65229 L p .436 .186 .434 r
F P
0 g
s
.63633 .57891 m .63801 .57066 L .6362 .56872 L p .805 .713 .763 r
F P
0 g
s
.6362 .56872 m .6338 .5805 L .63633 .57891 L p .805 .713 .763 r
F P
0 g
s
.50712 .62275 m .50602 .62423 L .50426 .62236 L p .909 .639 .516 r
F P
0 g
s
.50426 .62236 m .50584 .62024 L .50712 .62275 L p .909 .639 .516 r
F P
0 g
s
.60465 .62982 m .59439 .64035 L .59617 .63821 L p 0 0 0 r
F P
0 g
s
.59439 .64035 m .59373 .64354 L .59174 .64406 L p .365 .061 .31 r
F P
0 g
s
.603 .63187 m .59582 .63924 L .59439 .64035 L p .045 0 .169 r
F P
0 g
s
.59439 .64035 m .60465 .62982 L .603 .63187 L p .045 0 .169 r
F P
0 g
s
.59373 .64354 m .59439 .64035 L .59582 .63924 L p .071 0 .207 r
F P
0 g
s
.61904 .60736 m .62193 .59732 L .62138 .59545 L p .911 .871 .786 r
F P
0 g
s
.62138 .59545 m .61725 .6098 L .61904 .60736 L p .911 .871 .786 r
F P
0 g
s
.62907 .45521 m .62955 .45735 L .6296 .45985 L p 0 0 .312 r
F P
0 g
s
.57662 .6559 m .57674 .65449 L .57928 .65385 L p .586 .322 .483 r
F P
0 g
s
.57893 .65943 m .56168 .66177 L .56432 .66088 L p .593 .34 .503 r
F P
0 g
s
.55832 .66617 m .55882 .66224 L .56168 .66177 L p .691 .452 .556 r
F P
0 g
s
.56168 .66177 m .56098 .6674 L .55832 .66617 L p .691 .452 .556 r
F P
0 g
s
.57629 .66062 m .56422 .66226 L .56168 .66177 L p .605 .376 .544 r
F P
0 g
s
.56168 .66177 m .57893 .65943 L .57629 .66062 L p .605 .376 .544 r
F P
0 g
s
.56098 .6674 m .56168 .66177 L .56422 .66226 L p .605 .374 .54 r
F P
0 g
s
.50092 .60571 m .50505 .6176 L .50584 .62024 L p .963 .728 .536 r
F P
0 g
s
.50584 .62024 m .49995 .60325 L .50092 .60571 L p .963 .728 .536 r
F P
0 g
s
.50356 .61952 m .50467 .61804 L .50584 .62024 L p .955 .728 .556 r
F P
0 g
s
.50584 .62024 m .50426 .62236 L .50356 .61952 L p .955 .728 .556 r
F P
0 g
s
.49995 .60325 m .50584 .62024 L .50467 .61804 L p .953 .728 .561 r
F P
0 g
s
.70295 .2718 m .72699 .29574 L .73847 .29481 L p .776 .756 .834 r
F P
0 g
s
.73847 .29481 m .70423 .26048 L .70295 .2718 L p .776 .756 .834 r
F P
0 g
s
.79511 .24842 m .7435 .2817 L .73847 .29481 L p .752 .753 .853 r
F P
0 g
s
.73847 .29481 m .81201 .24746 L .79511 .24842 L p .752 .753 .853 r
F P
0 g
s
.70423 .26048 m .73847 .29481 L .7435 .2817 L p .752 .753 .853 r
F P
0 g
s
.68318 .54623 m .68151 .55194 L .67745 .55253 L p .703 .678 .822 r
F P
0 g
s
.67745 .55253 m .67983 .54437 L .68318 .54623 L p .703 .678 .822 r
F P
0 g
s
.66084 .54817 m .67481 .55074 L .67745 .55253 L p .713 .668 .804 r
F P
0 g
s
.67745 .55253 m .65751 .54886 L .66084 .54817 L p .713 .668 .804 r
F P
0 g
s
.67983 .54437 m .67745 .55253 L .67481 .55074 L p .697 .67 .821 r
F P
0 g
s
.65751 .54886 m .67745 .55253 L .67422 .55274 L p .714 .667 .802 r
F P
0 g
s
.62935 .46351 m .62891 .46228 L .6296 .45985 L p .125 .064 .511 r
F P
0 g
s
.67422 .55274 m .66027 .55017 L .65751 .54886 L p .714 .667 .802 r
F P
0 g
s
.65174 .56089 m .6405 .55925 L .6379 .55971 L p .763 .676 .766 r
F P
0 g
s
.59617 .63821 m .60335 .63085 L .60465 .62982 L p 0 0 0 r
F P
0 g
s
.51267 .63529 m .50544 .62514 L .50426 .62236 L p .894 .648 .558 r
F P
0 g
s
.65843 .5572 m .65886 .55623 L .65603 .55551 L p .75 .645 .745 r
F P
0 g
s
.65603 .55551 m .65541 .55689 L .65843 .5572 L p .75 .645 .745 r
F P
0 g
s
.62825 .47765 m .63019 .47992 L .62996 .48256 L p .311 .272 .652 r
F P
0 g
s
.56432 .66088 m .57639 .65924 L .57893 .65943 L p .593 .34 .503 r
F P
0 g
s
.40058 .5116 m .38646 .51877 L .38878 .51856 L p .766 .954 .935 r
F P
0 g
s
.58145 .65229 m .5814 .65273 L .57928 .65385 L p .436 .186 .434 r
F P
0 g
s
.59342 .64701 m .57928 .65385 L .5814 .65273 L p .44 .191 .439 r
F P
0 g
s
.57928 .65385 m .57911 .65587 L .57662 .6559 L p .586 .322 .483 r
F P
0 g
s
.59128 .64833 m .58138 .65313 L .57928 .65385 L p .446 .203 .45 r
F P
0 g
s
.57928 .65385 m .59342 .64701 L .59128 .64833 L p .446 .203 .45 r
F P
0 g
s
.57911 .65587 m .57928 .65385 L .58138 .65313 L p .449 .208 .455 r
F P
0 g
s
.65899 .55476 m .65897 .5558 L .65603 .55551 L p .746 .641 .744 r
F P
0 g
s
.61249 .61444 m .61554 .61223 L .61725 .6098 L p .882 .988 .729 r
F P
0 g
s
.61725 .6098 m .61289 .61296 L .61249 .61444 L p .882 .988 .729 r
F P
0 g
s
.61999 .59803 m .6171 .60808 L .61725 .6098 L p .952 .925 .74 r
F P
0 g
s
.61725 .6098 m .62138 .59545 L .61999 .59803 L p .952 .925 .74 r
F P
0 g
s
.61289 .61296 m .61725 .6098 L .6171 .60808 L p .969 .925 .692 r
F P
0 g
s
.73204 .55074 m .73457 .54245 L .73989 .54132 L p .669 .708 .877 r
F P
0 g
s
.52423 .65115 m .51418 .64329 L .51245 .6407 L p .825 .585 .576 r
F P
0 g
s
.40968 .50491 m .40248 .51018 L .40058 .5116 L p .441 .825 .592 r
F P
0 g
s
.50139 .5858 m .50176 .59894 L .50147 .60188 L p 1 .829 .522 r
F P
0 g
s
.62418 .583 m .63178 .58266 L .6338 .5805 L p .852 .767 .768 r
F P
0 g
s
.6338 .5805 m .62295 .58098 L .62418 .583 L p .852 .767 .768 r
F P
0 g
s
.63407 .57047 m .63239 .57872 L .6338 .5805 L p .83 .738 .762 r
F P
0 g
s
.6338 .5805 m .6362 .56872 L .63407 .57047 L p .83 .738 .762 r
F P
0 g
s
.62295 .58098 m .6338 .5805 L .63239 .57872 L p .855 .738 .733 r
F P
0 g
s
.65603 .55551 m .65604 .55401 L .65899 .55476 L p .746 .641 .744 r
F P
0 g
s
.38646 .51877 m .40058 .5116 L .39861 .51216 L p .633 .963 .884 r
F P
0 g
s
.39974 .51037 m .39861 .51216 L .40058 .5116 L p .511 .913 .846 r
F P
0 g
s
.40058 .5116 m .4022 .50904 L .39974 .51037 L p .511 .913 .846 r
F P
0 g
s
.4022 .50904 m .40058 .5116 L .40248 .51018 L p .556 .922 .756 r
F P
0 g
s
.43828 .46841 m .43669 .47416 L .43556 .47375 L p .253 .088 .454 r
F P
0 g
s
.69422 .32076 m .67577 .30311 L .66533 .30533 L p .776 .756 .834 r
F P
0 g
s
.58147 .65208 m .59132 .64729 L .59343 .64637 L p .42 .158 .407 r
F P
0 g
s
.60539 .52618 m .60107 .53389 L .5983 .53494 L p .692 .459 .566 r
F P
0 g
s
.62167 .51269 m .62665 .50284 L .62879 .50138 L p .564 .423 .648 r
F P
0 g
s
.62879 .50138 m .62168 .51545 L .62167 .51269 L p .564 .423 .648 r
F P
0 g
s
.50219 .60454 m .50162 .60505 L .50066 .60259 L p .969 .727 .516 r
F P
0 g
s
.50066 .60259 m .50147 .60188 L .50219 .60454 L p .969 .727 .516 r
F P
0 g
s
.37099 .52548 m .38406 .52087 L .38646 .51877 L p .736 .897 .951 r
F P
0 g
s
.64128 .55535 m .65276 .55728 L .65541 .55689 L p .748 .66 .763 r
F P
0 g
s
.65541 .55689 m .63901 .55413 L .64128 .55535 L p .748 .66 .763 r
F P
0 g
s
.65346 .55529 m .65304 .55626 L .65541 .55689 L p .75 .645 .745 r
F P
0 g
s
.65541 .55689 m .65603 .55551 L .65346 .55529 L p .75 .645 .745 r
F P
0 g
s
.63901 .55413 m .65541 .55689 L .65304 .55626 L p .759 .628 .716 r
F P
0 g
s
.51414 .55702 m .50814 .56344 L .50719 .56362 L p .866 .996 .78 r
F P
0 g
s
.50719 .56362 m .51576 .55445 L .51414 .55702 L p .866 .996 .78 r
F P
0 g
s
.6299 .42842 m .62581 .41953 L .62447 .41902 L p .983 .815 .599 r
F P
0 g
s
.44162 .45766 m .45125 .45604 L .45331 .45759 L p .473 .349 .63 r
F P
0 g
s
.66027 .55017 m .65924 .55378 L .65604 .55401 L p .727 .66 .783 r
F P
0 g
s
.64194 .5528 m .65354 .55484 L .65603 .55551 L p .754 .623 .714 r
F P
0 g
s
.65603 .55551 m .63945 .55259 L .64194 .5528 L p .754 .623 .714 r
F P
0 g
s
.65604 .55401 m .65603 .55551 L .65354 .55484 L p .745 .64 .744 r
F P
0 g
s
.64186 .55325 m .65346 .55529 L .65603 .55551 L p .754 .623 .714 r
F P
0 g
s
.65603 .55551 m .63945 .55259 L .64186 .55325 L p .754 .623 .714 r
F P
0 g
s
.67481 .55074 m .67647 .54502 L .67983 .54437 L p .697 .67 .821 r
F P
0 g
s
.61495 .52564 m .61931 .51672 L .62168 .51545 L p .628 .456 .63 r
F P
0 g
s
.43437 .47731 m .43522 .47501 L .43669 .47416 L p .225 .035 .4 r
F P
0 g
s
.63024 .46161 m .6296 .45985 L .62972 .4581 L p 0 0 .445 r
F P
0 g
s
.62987 .44862 m .62972 .4581 L .6296 .45985 L p 0 0 .41 r
F P
0 g
s
.6296 .45985 m .62982 .44631 L .62987 .44862 L p 0 0 .41 r
F P
0 g
s
.6296 .45985 m .63024 .46161 L .62935 .46351 L p .125 .064 .511 r
F P
0 g
s
.62982 .44631 m .6296 .45985 L .62955 .45735 L p 0 0 .282 r
F P
0 g
s
.64381 .37368 m .63162 .36312 L .62651 .36438 L p .831 .753 .777 r
F P
0 g
s
.42891 .38076 m .41641 .36074 L .41619 .3545 L p .548 .528 .785 r
F P
0 g
s
.41619 .3545 m .43405 .38313 L .42891 .38076 L p .548 .528 .785 r
F P
0 g
s
.50147 .60188 m .50095 .5831 L .50139 .5858 L p 1 .829 .522 r
F P
0 g
s
.50066 .59967 m .50123 .59917 L .50147 .60188 L p .992 .825 .577 r
F P
0 g
s
.50147 .60188 m .50066 .60259 L .50066 .59967 L p .992 .825 .577 r
F P
0 g
s
.50095 .5831 m .50147 .60188 L .50123 .59917 L p .988 .824 .592 r
F P
0 g
s
.56422 .66226 m .56373 .6662 L .56098 .6674 L p .605 .374 .54 r
F P
0 g
s
.50467 .61804 m .50054 .60615 L .49995 .60325 L p .953 .728 .561 r
F P
0 g
s
.65604 .55401 m .65751 .54886 L .66027 .55017 L p .727 .66 .783 r
F P
0 g
s
.64214 .55063 m .65376 .55275 L .65604 .55401 L p .738 .65 .762 r
F P
0 g
s
.65604 .55401 m .63945 .55097 L .64214 .55063 L p .738 .65 .762 r
F P
0 g
s
.65751 .54886 m .65604 .55401 L .65376 .55275 L p .723 .656 .783 r
F P
0 g
s
.65354 .55484 m .65356 .55379 L .65604 .55401 L p .745 .64 .744 r
F P
0 g
s
.63945 .55097 m .65604 .55401 L .65356 .55379 L p .749 .619 .715 r
F P
0 g
s
.60335 .63085 m .60457 .62831 L .60639 .6262 L p 0 0 0 r
F P
0 g
s
.44117 .40491 m .43345 .38823 L .43405 .38313 L p .523 .481 .751 r
F P
0 g
s
.5814 .65273 m .5913 .64794 L .59342 .64701 L p .44 .191 .439 r
F P
0 g
s
.63259 .52015 m .62168 .51545 L .62423 .51406 L p .619 .499 .695 r
F P
0 g
s
.62921 .50421 m .62423 .51406 L .62168 .51545 L p .607 .473 .673 r
F P
0 g
s
.62168 .51545 m .62879 .50138 L .62921 .50421 L p .607 .473 .673 r
F P
0 g
s
.63016 .52132 m .62252 .51803 L .62168 .51545 L p .636 .482 .657 r
F P
0 g
s
.62168 .51545 m .63259 .52015 L .63016 .52132 L p .636 .482 .657 r
F P
0 g
s
.61545 .52821 m .62168 .51545 L .62252 .51803 L p .664 .497 .649 r
F P
0 g
s
.62168 .51545 m .61545 .52821 L .61495 .52564 L p .628 .456 .63 r
F P
0 g
s
.60794 .62371 m .61249 .61444 L .61289 .61296 L p .878 .977 .675 r
F P
0 g
s
.61289 .61296 m .60639 .6262 L .60794 .62371 L p .878 .977 .675 r
F P
0 g
s
.52738 .65805 m .53982 .66303 L .54219 .66498 L p .765 .521 .564 r
F P
0 g
s
.65304 .55626 m .64155 .55433 L .63901 .55413 L p .759 .628 .716 r
F P
0 g
s
.54517 .66449 m .55832 .66617 L .56098 .6674 L p .692 .451 .553 r
F P
0 g
s
.56098 .6674 m .54219 .66498 L .54517 .66449 L p .692 .451 .553 r
F P
0 g
s
.61161 .61547 m .60705 .62474 L .60639 .6262 L p .71 .842 .407 r
F P
0 g
s
.60639 .6262 m .61289 .61296 L .61161 .61547 L p .71 .842 .407 r
F P
0 g
s
.43669 .47416 m .43828 .46841 L .43994 .46929 L p .459 .283 .554 r
F P
0 g
s
.4491 .46897 m .43994 .46929 L .43828 .46841 L p .46 .282 .552 r
F P
0 g
s
.43828 .46841 m .45137 .46794 L .4491 .46897 L p .46 .282 .552 r
F P
0 g
s
.44136 .46096 m .44048 .46693 L .43828 .46841 L p .464 .311 .588 r
F P
0 g
s
.45137 .46794 m .43828 .46841 L .44048 .46693 L p .464 .312 .589 r
F P
0 g
s
.62913 .40943 m .63327 .40039 L .63313 .39624 L p .948 .83 .695 r
F P
0 g
s
.59582 .63924 m .59536 .64147 L .59373 .64354 L p .071 0 .207 r
F P
0 g
s
.70062 .54915 m .68318 .54623 L .67983 .54437 L p .69 .681 .836 r
F P
0 g
s
.67983 .54437 m .70475 .54855 L .70062 .54915 L p .69 .681 .836 r
F P
0 g
s
.43669 .47416 m .43547 .47744 L .43437 .47731 L p .225 .035 .4 r
F P
0 g
s
.58916 .53009 m .59771 .53272 L .5983 .53494 L p .673 .425 .538 r
F P
0 g
s
.5983 .53494 m .58608 .53119 L .58916 .53009 L p .673 .425 .538 r
F P
0 g
s
.27796 .5437 m .30676 .53999 L .31192 .53689 L p .676 .787 .933 r
F P
0 g
s
.31192 .53689 m .2707 .54221 L .27796 .5437 L p .676 .787 .933 r
F P
0 g
s
.58138 .65313 m .58126 .65454 L .57911 .65587 L p .449 .208 .455 r
F P
0 g
s
.65356 .55379 m .64194 .55166 L .63945 .55097 L p .749 .619 .715 r
F P
0 g
s
.63992 .3799 m .63234 .39167 L .63313 .39624 L p .859 .745 .736 r
F P
0 g
s
.57639 .65924 m .57652 .65675 L .57911 .65587 L p .593 .341 .504 r
F P
0 g
s
.54219 .66498 m .52442 .65786 L .52738 .65805 L p .765 .521 .564 r
F P
0 g
s
.53778 .67118 m .53914 .66522 L .54219 .66498 L p .759 .544 .605 r
F P
0 g
s
.54219 .66498 m .54025 .67351 L .53778 .67118 L p .759 .544 .605 r
F P
0 g
s
.52442 .65786 m .54219 .66498 L .53914 .66522 L p .759 .541 .602 r
F P
0 g
s
.55797 .6683 m .54482 .66661 L .54219 .66498 L p .693 .479 .593 r
F P
0 g
s
.54219 .66498 m .56098 .6674 L .55797 .6683 L p .693 .479 .593 r
F P
0 g
s
.54025 .67351 m .54219 .66498 L .54482 .66661 L p .694 .478 .59 r
F P
0 g
s
.82653 .55136 m .78864 .5482 L .78127 .54541 L p .663 .73 .9 r
F P
0 g
s
.78127 .54541 m .83546 .54993 L .82653 .55136 L p .663 .73 .9 r
F P
0 g
s
.43385 .47867 m .43416 .47792 L .43547 .47744 L p .21 .006 .371 r
F P
0 g
s
.62966 .46427 m .62951 .46386 L .63024 .46161 L p .139 .081 .524 r
F P
0 g
s
.65376 .55275 m .65478 .54915 L .65751 .54886 L p .723 .656 .783 r
F P
0 g
s
.50123 .59917 m .50086 .58602 L .50095 .5831 L p .988 .824 .592 r
F P
0 g
s
.43547 .47744 m .43503 .47851 L .43385 .47867 L p .21 .006 .371 r
F P
0 g
s
.43405 .38313 m .44509 .40698 L .44117 .40491 L p .523 .481 .751 r
F P
0 g
s
.63239 .57872 m .62479 .57905 L .62295 .58098 L p .855 .738 .733 r
F P
0 g
s
.71215 .53965 m .70998 .54752 L .70475 .54855 L p .681 .693 .855 r
F P
0 g
s
.70475 .54855 m .70784 .53731 L .71215 .53965 L p .681 .693 .855 r
F P
0 g
s
.68401 .54333 m .70147 .54626 L .70475 .54855 L p .688 .684 .84 r
F P
0 g
s
.70475 .54855 m .67983 .54437 L .68401 .54333 L p .688 .684 .84 r
F P
0 g
s
.70784 .53731 m .70475 .54855 L .70147 .54626 L p .672 .684 .853 r
F P
0 g
s
.59339 .64895 m .57911 .65587 L .58126 .65454 L p .445 .201 .45 r
F P
0 g
s
.57911 .65587 m .57893 .65943 L .57639 .65924 L p .593 .341 .504 r
F P
0 g
s
.59124 .65052 m .58124 .65536 L .57911 .65587 L p .463 .234 .481 r
F P
0 g
s
.57911 .65587 m .59339 .64895 L .59124 .65052 L p .463 .234 .481 r
F P
0 g
s
.57893 .65943 m .57911 .65587 L .58124 .65536 L p .463 .235 .482 r
F P
0 g
s
.43332 .47988 m .43372 .479 L .43503 .47851 L p .199 0 .349 r
F P
0 g
s
.62252 .51803 m .61816 .52697 L .61545 .52821 L p .664 .497 .649 r
F P
0 g
s
.38646 .51877 m .36777 .52537 L .37099 .52548 L p .736 .897 .951 r
F P
0 g
s
.59596 .53557 m .5874 .53294 L .58608 .53119 L p .677 .375 .456 r
F P
0 g
s
.58608 .53119 m .5983 .53494 L .59596 .53557 L p .677 .375 .456 r
F P
0 g
s
.58116 .53947 m .58608 .53119 L .5874 .53294 L p .703 .377 .422 r
F P
0 g
s
.58013 .53776 m .58358 .53197 L .58608 .53119 L p .655 .32 .393 r
F P
0 g
s
.58608 .53119 m .58116 .53947 L .58013 .53776 L p .655 .32 .393 r
F P
0 g
s
.26192 .54042 m .22403 .54421 L .21666 .54761 L p .665 .776 .932 r
F P
0 g
s
.21666 .54761 m .2707 .54221 L .26192 .54042 L p .665 .776 .932 r
F P
0 g
s
.21114 .52808 m .21666 .54761 L .22403 .54421 L p .664 .771 .929 r
F P
0 g
s
.62955 .45735 m .6297 .44788 L .62982 .44631 L p 0 0 .282 r
F P
0 g
s
.6388 .56766 m .63999 .56136 L .6379 .55971 L p .78 .675 .748 r
F P
0 g
s
.6379 .55971 m .6362 .56872 L .6388 .56766 L p .78 .675 .748 r
F P
0 g
s
.62423 .51406 m .63187 .51734 L .63259 .52015 L p .619 .499 .695 r
F P
0 g
s
.63024 .46161 m .63046 .4622 L .62966 .46427 L p .139 .081 .524 r
F P
0 g
s
.50906 .56056 m .51506 .55413 L .51576 .55445 L p .861 .996 .777 r
F P
0 g
s
.51576 .55445 m .50719 .56362 L .50906 .56056 L p .861 .996 .777 r
F P
0 g
s
.40248 .51018 m .40363 .50838 L .4022 .50904 L p .556 .922 .756 r
F P
0 g
s
.43503 .47851 m .43445 .47977 L .43332 .47988 L p .199 0 .349 r
F P
0 g
s
.6347 .48676 m .62996 .48256 L .6312 .48104 L p .38 .352 .702 r
F P
0 g
s
.63399 .47096 m .6312 .48104 L .62996 .48256 L p .364 .329 .686 r
F P
0 g
s
.62996 .48256 m .63394 .46817 L .63399 .47096 L p .364 .329 .686 r
F P
0 g
s
.63299 .48832 m .62968 .48538 L .62996 .48256 L p .461 .357 .65 r
F P
0 g
s
.62996 .48256 m .6347 .48676 L .63299 .48832 L p .461 .357 .65 r
F P
0 g
s
.63394 .46817 m .62996 .48256 L .63019 .47992 L p .283 .247 .64 r
F P
0 g
s
.34777 .53188 m .36472 .52769 L .36777 .52537 L p .71 .848 .948 r
F P
0 g
s
.62931 .43085 m .62854 .43552 L .62922 .43837 L p .997 .773 .459 r
F P
0 g
s
.6171 .60808 m .61405 .61028 L .61289 .61296 L p .969 .925 .692 r
F P
0 g
s
.62996 .46495 m .62975 .46446 L .63046 .4622 L p .166 .111 .545 r
F P
0 g
s
.43169 .48314 m .43301 .48058 L .43445 .47977 L p .175 0 .306 r
F P
0 g
s
.50142 .60525 m .50092 .60571 L .49995 .60325 L p .964 .728 .534 r
F P
0 g
s
.49995 .60325 m .50066 .60259 L .50142 .60525 L p .964 .728 .534 r
F P
0 g
s
.62886 .49855 m .63299 .48832 L .6347 .48676 L p .478 .384 .67 r
F P
0 g
s
.6347 .48676 m .62879 .50138 L .62886 .49855 L p .478 .384 .67 r
F P
0 g
s
.54482 .66661 m .54346 .67258 L .54025 .67351 L p .694 .478 .59 r
F P
0 g
s
.63773 .50621 m .62879 .50138 L .63089 .49992 L p .547 .469 .719 r
F P
0 g
s
.63503 .48968 m .63089 .49992 L .62879 .50138 L p .534 .445 .7 r
F P
0 g
s
.62879 .50138 m .6347 .48676 L .63503 .48968 L p .534 .445 .7 r
F P
0 g
s
.63546 .50759 m .62921 .50421 L .62879 .50138 L p .578 .453 .674 r
F P
0 g
s
.62879 .50138 m .63773 .50621 L .63546 .50759 L p .578 .453 .674 r
F P
0 g
s
.4481 .42518 m .44383 .41116 L .44509 .40698 L p .502 .434 .713 r
F P
0 g
s
.53914 .66522 m .5267 .66023 L .52442 .65786 L p .759 .541 .602 r
F P
0 g
s
.40918 .35168 m .38969 .327 L .38831 .31918 L p .572 .571 .814 r
F P
0 g
s
.38831 .31918 m .41619 .3545 L .40918 .35168 L p .572 .571 .814 r
F P
0 g
s
.50342 .62807 m .51117 .63797 L .51245 .6407 L p .895 .649 .559 r
F P
0 g
s
.51245 .6407 m .50138 .62654 L .50342 .62807 L p .895 .649 .559 r
F P
0 g
s
.50791 .64395 m .51022 .63958 L .51245 .6407 L p .878 .656 .597 r
F P
0 g
s
.51245 .6407 m .50915 .64695 L .50791 .64395 L p .878 .656 .597 r
F P
0 g
s
.50138 .62654 m .51245 .6407 L .51022 .63958 L p .878 .656 .598 r
F P
0 g
s
.50915 .64695 m .51245 .6407 L .51418 .64329 L p .828 .585 .573 r
F P
0 g
s
.58126 .65454 m .59125 .6497 L .59339 .64895 L p .445 .201 .45 r
F P
0 g
s
.62512 .56997 m .63407 .57047 L .6362 .56872 L p .813 .698 .739 r
F P
0 g
s
.6362 .56872 m .62341 .56801 L .62512 .56997 L p .813 .698 .739 r
F P
0 g
s
.63563 .56088 m .63445 .56718 L .6362 .56872 L p .793 .689 .749 r
F P
0 g
s
.6362 .56872 m .6379 .55971 L .63563 .56088 L p .793 .689 .749 r
F P
0 g
s
.62341 .56801 m .6362 .56872 L .63445 .56718 L p .815 .684 .719 r
F P
0 g
s
.6624 .54226 m .66084 .54817 L .65751 .54886 L p .711 .647 .784 r
F P
0 g
s
.65751 .54886 m .65972 .54043 L .6624 .54226 L p .711 .647 .784 r
F P
0 g
s
.64355 .54463 m .65532 .54704 L .65751 .54886 L p .722 .637 .763 r
F P
0 g
s
.65751 .54886 m .64069 .54542 L .64355 .54463 L p .722 .637 .763 r
F P
0 g
s
.65972 .54043 m .65751 .54886 L .65532 .54704 L p .703 .638 .782 r
F P
0 g
s
.64069 .54542 m .65751 .54886 L .65478 .54915 L p .723 .634 .759 r
F P
0 g
s
.62972 .4581 m .63016 .45933 L .63024 .46161 L p 0 0 .445 r
F P
0 g
s
.36777 .52537 m .38646 .51877 L .38362 .51895 L p .687 .934 .966 r
F P
0 g
s
.38379 .51592 m .38362 .51895 L .38646 .51877 L p .619 .927 .97 r
F P
0 g
s
.38646 .51877 m .38672 .51444 L .38379 .51592 L p .619 .927 .97 r
F P
0 g
s
.39861 .51216 m .38872 .51718 L .38646 .51877 L p .633 .963 .884 r
F P
0 g
s
.38672 .51444 m .38646 .51877 L .38872 .51718 L p .675 .962 .939 r
F P
0 g
s
.49988 .58648 m .50066 .59967 L .50066 .60259 L p .988 .822 .59 r
F P
0 g
s
.50066 .60259 m .49954 .58375 L .49988 .58648 L p .988 .822 .59 r
F P
0 g
s
.49984 .60034 m .50034 .59988 L .50066 .60259 L p .988 .82 .588 r
F P
0 g
s
.50066 .60259 m .49995 .60325 L .49984 .60034 L p .988 .82 .588 r
F P
0 g
s
.49954 .58375 m .50066 .60259 L .50034 .59988 L p .979 .817 .612 r
F P
0 g
s
.43547 .47744 m .43669 .47416 L .4383 .47482 L p .454 .262 .529 r
F P
0 g
s
.4469 .47536 m .4383 .47482 L .43669 .47416 L p .456 .259 .523 r
F P
0 g
s
.43669 .47416 m .44898 .47493 L .4469 .47536 L p .456 .259 .523 r
F P
0 g
s
.43994 .46929 m .43882 .47332 L .43669 .47416 L p .459 .283 .554 r
F P
0 g
s
.44898 .47493 m .43669 .47416 L .43882 .47332 L p .457 .279 .551 r
F P
0 g
s
.63019 .47992 m .63297 .46985 L .63394 .46817 L p .283 .247 .64 r
F P
0 g
s
.63046 .4622 m .63076 .4629 L .62996 .46495 L p .166 .111 .545 r
F P
0 g
s
.63046 .4622 m .63024 .46161 L .63027 .4597 L p 0 0 .462 r
F P
0 g
s
.63031 .45029 m .63027 .4597 L .63024 .46161 L p 0 0 .417 r
F P
0 g
s
.63024 .46161 m .63029 .44817 L .63031 .45029 L p 0 0 .417 r
F P
0 g
s
.63029 .44817 m .63024 .46161 L .63016 .45933 L p 0 0 .406 r
F P
0 g
s
.50652 .56695 m .50215 .58058 L .50095 .5831 L p .954 .931 .592 r
F P
0 g
s
.51418 .64329 m .51187 .64767 L .50915 .64695 L p .828 .585 .573 r
F P
0 g
s
.31748 .53788 m .33956 .53401 L .34351 .53135 L p .69 .812 .941 r
F P
0 g
s
.47917 .77827 m .48777 .75211 L .49466 .74785 L p .752 .688 .789 r
F P
0 g
s
.44048 .46693 m .44964 .46659 L .45137 .46794 L p .464 .312 .589 r
F P
0 g
s
.65478 .54915 m .64302 .54674 L .64069 .54542 L p .723 .634 .759 r
F P
0 g
s
.34351 .53135 m .31192 .53689 L .31748 .53788 L p .69 .812 .941 r
F P
0 g
s
.59141 .64634 m .59159 .64487 L .59373 .64354 L p .399 .12 .369 r
F P
0 g
s
.36777 .52537 m .34351 .53135 L .34777 .53188 L p .71 .848 .948 r
F P
0 g
s
.62721 .40915 m .63313 .39624 L .63015 .39646 L p .885 .732 .687 r
F P
0 g
s
.61972 .38778 m .63015 .39646 L .63313 .39624 L p .885 .731 .686 r
F P
0 g
s
.63313 .39624 m .61824 .38383 L .61972 .38778 L p .885 .731 .686 r
F P
0 g
s
.63313 .39624 m .62721 .40915 L .62913 .40943 L p .948 .83 .695 r
F P
0 g
s
.61824 .38383 m .63313 .39624 L .63234 .39167 L p .859 .745 .736 r
F P
0 g
s
.44509 .40698 m .43405 .38313 L .43796 .38556 L p .567 .503 .743 r
F P
0 g
s
.44882 .3797 m .43796 .38556 L .43405 .38313 L p .567 .503 .743 r
F P
0 g
s
.43405 .38313 m .44956 .37473 L .44882 .3797 L p .567 .503 .743 r
F P
0 g
s
.42132 .35738 m .43383 .37744 L .43405 .38313 L p .583 .542 .775 r
F P
0 g
s
.43405 .38313 m .41619 .3545 L .42132 .35738 L p .583 .542 .775 r
F P
0 g
s
.44956 .37473 m .43405 .38313 L .43383 .37744 L p .584 .543 .775 r
F P
0 g
s
.49892 .60785 m .50356 .61952 L .50426 .62236 L p .952 .727 .56 r
F P
0 g
s
.50426 .62236 m .49763 .60569 L .49892 .60785 L p .952 .727 .56 r
F P
0 g
s
.50073 .6235 m .50275 .62057 L .50426 .62236 L p .938 .724 .587 r
F P
0 g
s
.50426 .62236 m .50138 .62654 L .50073 .6235 L p .938 .724 .587 r
F P
0 g
s
.49763 .60569 m .50426 .62236 L .50275 .62057 L p .935 .727 .596 r
F P
0 g
s
.50138 .62654 m .50426 .62236 L .50544 .62514 L p .896 .648 .556 r
F P
0 g
s
.43445 .47977 m .43257 .48343 L .43169 .48314 L p .175 0 .306 r
F P
0 g
s
.50544 .62514 m .50342 .62807 L .50138 .62654 L p .896 .648 .556 r
F P
0 g
s
.62834 .53244 m .61545 .52821 L .61816 .52697 L p .677 .528 .676 r
F P
0 g
s
.62594 .53331 m .61691 .53035 L .61545 .52821 L p .685 .512 .648 r
F P
0 g
s
.61545 .52821 m .62834 .53244 L .62594 .53331 L p .685 .512 .648 r
F P
0 g
s
.61182 .53863 m .61545 .52821 L .61691 .53035 L p .709 .518 .628 r
F P
0 g
s
.61052 .53647 m .61307 .52918 L .61545 .52821 L p .683 .49 .619 r
F P
0 g
s
.61545 .52821 m .61182 .53863 L .61052 .53647 L p .683 .49 .619 r
F P
0 g
s
.57902 .66498 m .56098 .6674 L .56373 .6662 L p .607 .378 .544 r
F P
0 g
s
.55756 .67415 m .55797 .6683 L .56098 .6674 L p .694 .482 .595 r
F P
0 g
s
.56098 .6674 m .56039 .67576 L .55756 .67415 L p .694 .482 .595 r
F P
0 g
s
.57631 .66657 m .56368 .66826 L .56098 .6674 L p .618 .416 .586 r
F P
0 g
s
.56098 .6674 m .57902 .66498 L .57631 .66657 L p .618 .416 .586 r
F P
0 g
s
.56039 .67576 m .56098 .6674 L .56368 .66826 L p .618 .416 .586 r
F P
0 g
s
.61816 .52697 m .62719 .52993 L .62834 .53244 L p .677 .528 .676 r
F P
0 g
s
.51187 .64767 m .52256 .65531 L .52442 .65786 L p .827 .588 .577 r
F P
0 g
s
.63089 .4668 m .63019 .46536 L .63076 .4629 L p .19 .14 .567 r
F P
0 g
s
.60705 .62474 m .60584 .62727 L .60465 .62982 L p .659 .782 .317 r
F P
0 g
s
.52442 .65786 m .50915 .64695 L .51187 .64767 L p .827 .588 .577 r
F P
0 g
s
.51923 .66378 m .52154 .6576 L .52442 .65786 L p .815 .604 .617 r
F P
0 g
s
.52442 .65786 m .52112 .6667 L .51923 .66378 L p .815 .604 .617 r
F P
0 g
s
.50915 .64695 m .52442 .65786 L .52154 .6576 L p .815 .602 .615 r
F P
0 g
s
.52112 .6667 m .52442 .65786 L .5267 .66023 L p .76 .541 .599 r
F P
0 g
s
.79002 .54346 m .828 .54663 L .83546 .54993 L p .661 .732 .902 r
F P
0 g
s
.83546 .54993 m .78127 .54541 L .79002 .54346 L p .661 .732 .902 r
F P
0 g
s
.84038 .53102 m .83546 .54993 L .828 .54663 L p .656 .732 .906 r
F P
0 g
s
.70147 .54626 m .70362 .53839 L .70784 .53731 L p .672 .684 .853 r
F P
0 g
s
.65532 .54704 m .65687 .54114 L .65972 .54043 L p .703 .638 .782 r
F P
0 g
s
.58124 .65536 m .58112 .65785 L .57893 .65943 L p .463 .235 .482 r
F P
0 g
s
.56373 .6662 m .57635 .66451 L .57902 .66498 L p .607 .378 .544 r
F P
0 g
s
.6405 .55925 m .64128 .55535 L .63901 .55413 L p .761 .652 .742 r
F P
0 g
s
.63901 .55413 m .6379 .55971 L .6405 .55925 L p .761 .652 .742 r
F P
0 g
s
.63076 .4629 m .63046 .4622 L .63049 .4603 L p 0 0 .502 r
F P
0 g
s
.63048 .45091 m .63049 .4603 L .63046 .4622 L p 0 0 .475 r
F P
0 g
s
.63046 .4622 m .63044 .44879 L .63048 .45091 L p 0 0 .475 r
F P
0 g
s
.63027 .4597 m .63043 .4601 L .63046 .4622 L p 0 0 .462 r
F P
0 g
s
.63044 .44879 m .63046 .4622 L .63043 .4601 L p 0 0 .415 r
F P
0 g
s
.42843 .48837 m .43098 .48447 L .43257 .48343 L p .121 0 .206 r
F P
0 g
s
.60387 .63285 m .59373 .64354 L .59536 .64147 L p .024 0 .161 r
F P
0 g
s
.59373 .64354 m .59348 .64563 L .59141 .64634 L p .399 .12 .369 r
F P
0 g
s
.60231 .63477 m .59521 .64225 L .59373 .64354 L p .129 0 .28 r
F P
0 g
s
.59373 .64354 m .60387 .63285 L .60231 .63477 L p .129 0 .28 r
F P
0 g
s
.59348 .64563 m .59373 .64354 L .59521 .64225 L p .139 0 .292 r
F P
0 g
s
.31364 .28729 m .33097 .26952 L .3453 .27395 L p .612 .641 .855 r
F P
0 g
s
.43503 .47851 m .43547 .47744 L .43713 .47783 L p .451 .25 .515 r
F P
0 g
s
.44531 .47883 m .43713 .47783 L .43547 .47744 L p .452 .245 .506 r
F P
0 g
s
.43547 .47744 m .44715 .47887 L .44531 .47883 L p .452 .245 .506 r
F P
0 g
s
.4383 .47482 m .43744 .47712 L .43547 .47744 L p .454 .262 .529 r
F P
0 g
s
.44715 .47887 m .43547 .47744 L .43744 .47712 L p .452 .255 .521 r
F P
0 g
s
.62923 .44447 m .62917 .44116 L .62922 .43837 L p 0 0 .062 r
F P
0 g
s
.5874 .53294 m .58396 .53874 L .58116 .53947 L p .703 .377 .422 r
F P
0 g
s
.5267 .66023 m .52439 .66642 L .52112 .6667 L p .76 .541 .599 r
F P
0 g
s
.50034 .59988 m .49956 .58669 L .49954 .58375 L p .979 .817 .612 r
F P
0 g
s
.61691 .53035 m .61438 .53764 L .61182 .53863 L p .709 .518 .628 r
F P
0 g
s
.64194 .55166 m .64194 .5528 L .63945 .55259 L p .756 .602 .686 r
F P
0 g
s
.63945 .55259 m .63945 .55097 L .64194 .55166 L p .756 .602 .686 r
F P
0 g
s
.63445 .56718 m .62549 .56668 L .62341 .56801 L p .815 .684 .719 r
F P
0 g
s
.64155 .55433 m .64186 .55325 L .63945 .55259 L p .76 .606 .687 r
F P
0 g
s
.67647 .54502 m .6624 .54226 L .65972 .54043 L p .696 .65 .8 r
F P
0 g
s
.65972 .54043 m .67983 .54437 L .67647 .54502 L p .696 .65 .8 r
F P
0 g
s
.43445 .47977 m .43503 .47851 L .43663 .47896 L p .449 .242 .505 r
F P
0 g
s
.44465 .4801 m .43663 .47896 L .43503 .47851 L p .451 .236 .496 r
F P
0 g
s
.43503 .47851 m .44648 .48013 L .44465 .4801 L p .451 .236 .496 r
F P
0 g
s
.43713 .47783 m .43682 .47858 L .43503 .47851 L p .451 .25 .515 r
F P
0 g
s
.44648 .48013 m .43503 .47851 L .43682 .47858 L p .45 .243 .505 r
F P
0 g
s
.56227 .53409 m .56675 .53495 L .56549 .53636 L p .535 .129 .217 r
F P
0 g
s
.56549 .53636 m .55909 .53512 L .56227 .53409 L p .535 .129 .217 r
F P
0 g
s
.50095 .5831 m .50719 .56362 L .50652 .56695 L p .954 .931 .592 r
F P
0 g
s
.63089 .49992 m .63715 .50329 L .63773 .50621 L p .547 .469 .719 r
F P
0 g
s
.64302 .54674 m .64214 .55063 L .63945 .55097 L p .736 .628 .738 r
F P
0 g
s
.6258 .55966 m .63563 .56088 L .6379 .55971 L p .781 .653 .721 r
F P
0 g
s
.6379 .55971 m .62385 .55797 L .6258 .55966 L p .781 .653 .721 r
F P
0 g
s
.6367 .55466 m .63592 .55856 L .6379 .55971 L p .767 .658 .742 r
F P
0 g
s
.6379 .55971 m .63901 .55413 L .6367 .55466 L p .767 .658 .742 r
F P
0 g
s
.62385 .55797 m .6379 .55971 L .63592 .55856 L p .782 .648 .714 r
F P
0 g
s
.63945 .55259 m .63901 .55413 L .64155 .55433 L p .76 .606 .687 r
F P
0 g
s
.44509 .40698 m .45119 .42704 L .4481 .42518 L p .502 .434 .713 r
F P
0 g
s
.45119 .42704 m .44509 .40698 L .4482 .40908 L p .553 .466 .71 r
F P
0 g
s
.45848 .4043 m .4482 .40908 L .44509 .40698 L p .552 .466 .711 r
F P
0 g
s
.44509 .40698 m .45978 .40015 L .45848 .4043 L p .552 .466 .711 r
F P
0 g
s
.43796 .38556 m .4457 .40227 L .44509 .40698 L p .567 .503 .743 r
F P
0 g
s
.45978 .40015 m .44509 .40698 L .4457 .40227 L p .568 .504 .743 r
F P
0 g
s
.50086 .58602 m .49988 .58648 L .49954 .58375 L p .985 .821 .599 r
F P
0 g
s
.49954 .58375 m .50095 .5831 L .50086 .58602 L p .985 .821 .599 r
F P
0 g
s
.6312 .48104 m .63451 .48398 L .6347 .48676 L p .38 .352 .702 r
F P
0 g
s
.63016 .45933 m .6302 .44993 L .63029 .44817 L p 0 0 .406 r
F P
0 g
s
.59536 .64147 m .60245 .63399 L .60387 .63285 L p .024 0 .161 r
F P
0 g
s
.50054 .60615 m .49892 .60785 L .49763 .60569 L p .951 .728 .564 r
F P
0 g
s
.49763 .60569 m .49995 .60325 L .50054 .60615 L p .951 .728 .564 r
F P
0 g
s
.63175 .46495 m .63076 .4629 L .63089 .46121 L p 0 0 .541 r
F P
0 g
s
.63084 .45183 m .63089 .46121 L .63076 .4629 L p 0 0 .53 r
F P
0 g
s
.63076 .4629 m .63068 .44951 L .63084 .45183 L p 0 0 .53 r
F P
0 g
s
.63076 .4629 m .63175 .46495 L .63089 .4668 L p .19 .14 .567 r
F P
0 g
s
.63049 .4603 m .6307 .46079 L .63076 .4629 L p 0 0 .502 r
F P
0 g
s
.63068 .44951 m .63076 .4629 L .6307 .46079 L p 0 0 .474 r
F P
0 g
s
.50055 .58065 m .50153 .5802 L .50095 .5831 L p .973 .914 .683 r
F P
0 g
s
.50095 .5831 m .49954 .58375 L .50055 .58065 L p .973 .914 .683 r
F P
0 g
s
.50719 .56362 m .50095 .5831 L .50153 .5802 L p .962 .9 .714 r
F P
0 g
s
.63945 .55097 m .64069 .54542 L .64302 .54674 L p .736 .628 .738 r
F P
0 g
s
.62703 .54773 m .63741 .54968 L .63945 .55097 L p .747 .614 .711 r
F P
0 g
s
.63945 .55097 m .62463 .54818 L .62703 .54773 L p .747 .614 .711 r
F P
0 g
s
.64069 .54542 m .63945 .55097 L .63741 .54968 L p .731 .622 .737 r
F P
0 g
s
.63724 .55195 m .63724 .55081 L .63945 .55097 L p .755 .601 .686 r
F P
0 g
s
.63945 .55097 m .63945 .55259 L .63724 .55195 L p .755 .601 .686 r
F P
0 g
s
.62463 .54818 m .63945 .55097 L .63724 .55081 L p .755 .575 .653 r
F P
0 g
s
.68601 .53561 m .68401 .54333 L .67983 .54437 L p .687 .665 .823 r
F P
0 g
s
.67983 .54437 m .68267 .53334 L .68601 .53561 L p .687 .665 .823 r
F P
0 g
s
.66316 .53935 m .67724 .54211 L .67983 .54437 L p .693 .654 .806 r
F P
0 g
s
.67983 .54437 m .65972 .54043 L .66316 .53935 L p .693 .654 .806 r
F P
0 g
s
.68267 .53334 m .67983 .54437 L .67724 .54211 L p .674 .653 .821 r
F P
0 g
s
.43257 .48343 m .43445 .47977 L .43577 .48064 L p .443 .224 .485 r
F P
0 g
s
.44359 .48193 m .43577 .48064 L .43445 .47977 L p .449 .221 .475 r
F P
0 g
s
.43445 .47977 m .44563 .48162 L .44359 .48193 L p .449 .221 .475 r
F P
0 g
s
.43663 .47896 m .43623 .47984 L .43445 .47977 L p .449 .242 .505 r
F P
0 g
s
.44563 .48162 m .43445 .47977 L .43623 .47984 L p .448 .233 .494 r
F P
0 g
s
.49864 .58725 m .49984 .60034 L .49995 .60325 L p .979 .814 .61 r
F P
0 g
s
.49995 .60325 m .49823 .58455 L .49864 .58725 L p .979 .814 .61 r
F P
0 g
s
.49758 .60261 m .4992 .60091 L .49995 .60325 L p .977 .806 .604 r
F P
0 g
s
.49995 .60325 m .49763 .60569 L .49758 .60261 L p .977 .806 .604 r
F P
0 g
s
.49823 .58455 m .49995 .60325 L .4992 .60091 L p .965 .808 .637 r
F P
0 g
s
.51022 .63958 m .50247 .62967 L .50138 .62654 L p .878 .656 .598 r
F P
0 g
s
.62694 .55014 m .63724 .55195 L .63945 .55259 L p .762 .58 .652 r
F P
0 g
s
.63945 .55259 m .62474 .55001 L .62694 .55014 L p .762 .58 .652 r
F P
0 g
s
.62689 .55064 m .63719 .55245 L .63945 .55259 L p .762 .58 .652 r
F P
0 g
s
.63945 .55259 m .62474 .55001 L .62689 .55064 L p .762 .58 .652 r
F P
0 g
s
.63901 .55413 m .63945 .55259 L .63719 .55245 L p .761 .607 .687 r
F P
0 g
s
.43882 .47332 m .44743 .47385 L .44898 .47493 L p .457 .279 .551 r
F P
0 g
s
.57635 .66451 m .57629 .66062 L .57893 .65943 L p .607 .381 .548 r
F P
0 g
s
.56035 .7583 m .53482 .75842 L .52912 .75287 L p .693 .629 .78 r
F P
0 g
s
.56368 .66826 m .56327 .67412 L .56039 .67576 L p .618 .416 .586 r
F P
0 g
s
.43346 .35008 m .42132 .35738 L .41619 .3545 L p .582 .542 .775 r
F P
0 g
s
.41619 .3545 m .43352 .34404 L .43346 .35008 L p .582 .542 .775 r
F P
0 g
s
.39533 .32268 m .41486 .34744 L .41619 .3545 L p .6 .581 .803 r
F P
0 g
s
.41619 .3545 m .38831 .31918 L .39533 .32268 L p .6 .581 .803 r
F P
0 g
s
.43352 .34404 m .41619 .3545 L .41486 .34744 L p .599 .58 .803 r
F P
0 g
s
.38872 .51718 m .38891 .51415 L .38672 .51444 L p .675 .962 .939 r
F P
0 g
s
.25911 .52964 m .26192 .54042 L .2707 .54221 L p .658 .779 .938 r
F P
0 g
s
.2707 .54221 m .26677 .5268 L .25911 .52964 L p .658 .779 .938 r
F P
0 g
s
.30526 .53565 m .27636 .53937 L .2707 .54221 L p .671 .796 .942 r
F P
0 g
s
.2707 .54221 m .31192 .53689 L .30526 .53565 L p .671 .796 .942 r
F P
0 g
s
.26677 .5268 m .2707 .54221 L .27636 .53937 L p .67 .786 .936 r
F P
0 g
s
.34351 .53135 m .36777 .52537 L .36394 .5251 L p .689 .875 .968 r
F P
0 g
s
.36332 .52052 m .36394 .5251 L .36777 .52537 L p .652 .878 .982 r
F P
0 g
s
.36777 .52537 m .3669 .51883 L .36332 .52052 L p .652 .878 .982 r
F P
0 g
s
.38362 .51895 m .37052 .52357 L .36777 .52537 L p .687 .934 .966 r
F P
0 g
s
.3669 .51883 m .36777 .52537 L .37052 .52357 L p .695 .907 .97 r
F P
0 g
s
.59354 .6524 m .57893 .65943 L .58112 .65785 L p .463 .234 .481 r
F P
0 g
s
.57893 .65943 m .57902 .66498 L .57635 .66451 L p .607 .381 .548 r
F P
0 g
s
.5914 .65427 m .58116 .65919 L .57893 .65943 L p .491 .288 .531 r
F P
0 g
s
.57893 .65943 m .59354 .6524 L .5914 .65427 L p .491 .288 .531 r
F P
0 g
s
.57902 .66498 m .57893 .65943 L .58116 .65919 L p .492 .292 .536 r
F P
0 g
s
.62648 .553 m .6367 .55466 L .63901 .55413 L p .761 .628 .713 r
F P
0 g
s
.63901 .55413 m .62441 .55176 L .62648 .553 L p .761 .628 .713 r
F P
0 g
s
.63719 .55245 m .63688 .55353 L .63901 .55413 L p .761 .607 .687 r
F P
0 g
s
.62441 .55176 m .63901 .55413 L .63688 .55353 L p .768 .587 .653 r
F P
0 g
s
.43257 .48343 m .42893 .48902 L .42843 .48837 L p .121 0 .206 r
F P
0 g
s
.63741 .54968 m .63828 .54579 L .64069 .54542 L p .731 .622 .737 r
F P
0 g
s
.62309 .59313 m .62418 .583 L .62295 .58098 L p .875 .771 .743 r
F P
0 g
s
.62295 .58098 m .62138 .59545 L .62309 .59313 L p .875 .771 .743 r
F P
0 g
s
.63592 .55856 m .62608 .55735 L .62385 .55797 L p .782 .648 .714 r
F P
0 g
s
.63724 .55081 m .62686 .54886 L .62463 .54818 L p .755 .575 .653 r
F P
0 g
s
.63234 .39167 m .62192 .38298 L .61824 .38383 L p .859 .745 .736 r
F P
0 g
s
.52154 .6576 m .51085 .64996 L .50915 .64695 L p .815 .602 .615 r
F P
0 g
s
.62932 .4431 m .62923 .44447 L p .62923 .44104 L 0 0 .062 r
F P
0 g
s
.62922 .43837 m .62932 .4431 L p .62923 .44104 L 0 0 .062 r
F P
0 g
s
.62932 .4431 m .62859 .44186 L p .62939 .44475 L .914 .595 .117 r
F P
0 g
s
.62982 .44631 m .6297 .44788 L p .62941 .44433 L 0 0 .256 r
F P
0 g
s
.62932 .4431 m .62982 .44631 L p .62941 .44433 L 0 0 .256 r
F P
0 g
s
.6297 .44788 m .62935 .44563 L .62932 .4431 L p 0 0 .256 r
F P
0 g
s
.62982 .44631 m .62909 .4449 L p .63008 .44762 L .851 .51 0 r
F P
0 g
s
.63029 .44817 m .6302 .44993 L p .62982 .44633 L 0 0 .366 r
F P
0 g
s
.62982 .44631 m .63029 .44817 L p .62982 .44633 L 0 0 .366 r
F P
0 g
s
.6302 .44993 m .62987 .44862 L .62982 .44631 L p 0 0 .366 r
F P
0 g
s
.63029 .44817 m .62952 .44658 L p .63044 .44878 L .849 .508 0 r
F P
0 g
s
.63029 .44817 m .63044 .44879 L .63042 .45072 L p 0 0 .364 r
F P
0 g
s
.63044 .44879 m .63029 .44817 L p .63044 .44878 L .849 .508 0 r
F P
0 g
s
.63029 .44817 m .62982 .44631 L p .63008 .44762 L .851 .51 0 r
F P
0 g
s
.62982 .44631 m .62932 .4431 L p .62939 .44475 L .914 .595 .117 r
F P
0 g
s
.62932 .4431 m .62922 .43837 L .62842 .43731 L p .971 .691 .28 r
F P
0 g
s
.62458 .42885 m .62842 .43731 L .62922 .43837 L p .974 .699 .293 r
F P
0 g
s
.62922 .43837 m .62373 .42628 L .62458 .42885 L p .974 .699 .293 r
F P
0 g
s
.62373 .42628 m .62922 .43837 L .62854 .43552 L p .997 .773 .459 r
F P
0 g
s
.50275 .62057 m .4981 .6089 L .49763 .60569 L p .935 .727 .596 r
F P
0 g
s
.62719 .52993 m .63016 .52132 L .63259 .52015 L p .651 .517 .686 r
F P
0 g
s
.63259 .52015 m .62834 .53244 L .62719 .52993 L p .651 .517 .686 r
F P
0 g
s
.4511 .4422 m .44941 .4304 L .45119 .42704 L p .484 .39 .672 r
F P
0 g
s
.64512 .53838 m .64355 .54463 L .64069 .54542 L p .717 .612 .739 r
F P
0 g
s
.64069 .54542 m .64294 .53648 L .64512 .53838 L p .717 .612 .739 r
F P
0 g
s
.62838 .54119 m .63882 .54353 L .64069 .54542 L p .726 .599 .714 r
F P
0 g
s
.64069 .54542 m .62578 .54208 L .62838 .54119 L p .726 .599 .714 r
F P
0 g
s
.64294 .53648 m .64069 .54542 L .63882 .54353 L p .704 .598 .736 r
F P
0 g
s
.62578 .54208 m .64069 .54542 L .63828 .54579 L p .727 .595 .708 r
F P
0 g
s
.60107 .53389 m .61052 .53647 L .61182 .53863 L p .708 .497 .601 r
F P
0 g
s
.61182 .53863 m .5983 .53494 L .60107 .53389 L p .708 .497 .601 r
F P
0 g
s
.63187 .51734 m .63546 .50759 L .63773 .50621 L p .593 .483 .698 r
F P
0 g
s
.63773 .50621 m .63259 .52015 L .63187 .51734 L p .593 .483 .698 r
F P
0 g
s
.63043 .4601 m .63042 .45072 L .63044 .44879 L p 0 0 .415 r
F P
0 g
s
.56192 .5362 m .55743 .53534 L .55909 .53512 L p .318 0 0 r
F P
0 g
s
.55909 .53512 m .56549 .53636 L .56192 .5362 L p .318 0 0 r
F P
0 g
s
.43383 .37744 m .44468 .37154 L .44956 .37473 L p .584 .543 .775 r
F P
0 g
s
.59132 .64729 m .59136 .64677 L .59348 .64563 L p .422 .161 .411 r
F P
0 g
s
.52277 .75775 m .49867 .75425 L .49466 .74785 L p .725 .658 .783 r
F P
0 g
s
.49466 .74785 m .52912 .75287 L .52277 .75775 L p .725 .658 .783 r
F P
0 g
s
.63828 .54579 m .62784 .54345 L .62578 .54208 L p .727 .595 .708 r
F P
0 g
s
.63882 .54353 m .64039 .53727 L .64294 .53648 L p .704 .598 .736 r
F P
0 g
s
.63688 .55353 m .62666 .55187 L .62441 .55176 L p .768 .587 .653 r
F P
0 g
s
.59521 .64225 m .59503 .64371 L .59348 .64563 L p .139 0 .292 r
F P
0 g
s
.54346 .67258 m .55756 .67415 L .56039 .67576 L p .695 .481 .593 r
F P
0 g
s
.56039 .67576 m .54025 .67351 L .54346 .67258 L p .695 .481 .593 r
F P
0 g
s
.50153 .5802 m .5059 .56655 L .50719 .56362 L p .962 .9 .714 r
F P
0 g
s
.42298 .49489 m .42717 .49018 L .42893 .48902 L p .014 0 .014 r
F P
0 g
s
.64294 .53648 m .62834 .53244 L .63109 .53125 L p .69 .577 .723 r
F P
0 g
s
.63406 .52264 m .63109 .53125 L .62834 .53244 L p .679 .547 .697 r
F P
0 g
s
.62834 .53244 m .63259 .52015 L .63406 .52264 L p .679 .547 .697 r
F P
0 g
s
.64039 .53727 m .63017 .53444 L .62834 .53244 L p .695 .567 .707 r
F P
0 g
s
.62834 .53244 m .64294 .53648 L .64039 .53727 L p .695 .567 .707 r
F P
0 g
s
.62578 .54208 m .62834 .53244 L .63017 .53444 L p .716 .569 .687 r
F P
0 g
s
.62415 .54006 m .62594 .53331 L .62834 .53244 L p .698 .55 .682 r
F P
0 g
s
.62834 .53244 m .62578 .54208 L .62415 .54006 L p .698 .55 .682 r
F P
0 g
s
.67724 .54211 m .67922 .53439 L .68267 .53334 L p .674 .653 .821 r
F P
0 g
s
.64613 .52476 m .63259 .52015 L .63527 .51878 L p .643 .552 .737 r
F P
0 g
s
.63887 .50901 m .63527 .51878 L .63259 .52015 L p .632 .525 .715 r
F P
0 g
s
.63259 .52015 m .63773 .50621 L .63887 .50901 L p .632 .525 .715 r
F P
0 g
s
.64354 .52587 m .63406 .52264 L .63259 .52015 L p .654 .538 .71 r
F P
0 g
s
.63259 .52015 m .64613 .52476 L .64354 .52587 L p .654 .538 .71 r
F P
0 g
s
.52439 .66642 m .53778 .67118 L .54025 .67351 L p .761 .543 .602 r
F P
0 g
s
.42893 .48902 m .43257 .48343 L .43343 .48466 L p .425 .181 .438 r
F P
0 g
s
.44062 .48634 m .43343 .48466 L .43257 .48343 L p .442 .185 .428 r
F P
0 g
s
.43257 .48343 m .44284 .48582 L .44062 .48634 L p .442 .185 .428 r
F P
0 g
s
.43577 .48064 m .43445 .4832 L .43257 .48343 L p .443 .224 .485 r
F P
0 g
s
.44284 .48582 m .43257 .48343 L .43445 .4832 L p .438 .209 .468 r
F P
0 g
s
.58112 .65785 m .59134 .65293 L .59354 .6524 L p .463 .234 .481 r
F P
0 g
s
.77444 .54667 m .7455 .54381 L .73989 .54132 L p .666 .716 .886 r
F P
0 g
s
.73989 .54132 m .78127 .54541 L .77444 .54667 L p .666 .716 .886 r
F P
0 g
s
.43744 .47712 m .44562 .47811 L .44715 .47887 L p .452 .255 .521 r
F P
0 g
s
.63017 .53444 m .62838 .54119 L .62578 .54208 L p .716 .569 .687 r
F P
0 g
s
.65687 .54114 m .64512 .53838 L .64294 .53648 L p .698 .613 .757 r
F P
0 g
s
.64294 .53648 m .65972 .54043 L .65687 .54114 L p .698 .613 .757 r
F P
0 g
s
.4457 .40227 m .45597 .39748 L .45978 .40015 L p .568 .504 .743 r
F P
0 g
s
.60956 .53916 m .60009 .53658 L .5983 .53494 L p .711 .475 .565 r
F P
0 g
s
.5983 .53494 m .61182 .53863 L .60956 .53916 L p .711 .475 .565 r
F P
0 g
s
.5964 .54261 m .5983 .53494 L .60009 .53658 L p .731 .468 .53 r
F P
0 g
s
.59462 .54094 m .59596 .53557 L .5983 .53494 L p .707 .444 .524 r
F P
0 g
s
.5983 .53494 m .5964 .54261 L .59462 .54094 L p .707 .444 .524 r
F P
0 g
s
.61583 .59981 m .61999 .59803 L .62138 .59545 L p .942 .891 .751 r
F P
0 g
s
.62138 .59545 m .61543 .59798 L .61583 .59981 L p .942 .891 .751 r
F P
0 g
s
.62166 .58346 m .62056 .59359 L .62138 .59545 L p .921 .813 .723 r
F P
0 g
s
.62138 .59545 m .62295 .58098 L .62166 .58346 L p .921 .813 .723 r
F P
0 g
s
.61543 .59798 m .62138 .59545 L .62056 .59359 L p .945 .814 .683 r
F P
0 g
s
.59348 .64563 m .59343 .64637 L .59132 .64729 L p .422 .161 .411 r
F P
0 g
s
.63109 .53125 m .64131 .53408 L .64294 .53648 L p .69 .577 .723 r
F P
0 g
s
.54025 .67351 m .52112 .6667 L .52439 .66642 L p .761 .543 .602 r
F P
0 g
s
.53523 .68278 m .53688 .67433 L .54025 .67351 L p .754 .566 .642 r
F P
0 g
s
.54025 .67351 m .5379 .68559 L .53523 .68278 L p .754 .566 .642 r
F P
0 g
s
.52112 .6667 m .54025 .67351 L .53688 .67433 L p .754 .565 .641 r
F P
0 g
s
.55717 .6772 m .54307 .67562 L .54025 .67351 L p .695 .51 .633 r
F P
0 g
s
.54025 .67351 m .56039 .67576 L .55717 .6772 L p .695 .51 .633 r
F P
0 g
s
.5379 .68559 m .54025 .67351 L .54307 .67562 L p .697 .51 .631 r
F P
0 g
s
.52912 .75287 m .56563 .75269 L .56035 .7583 L p .693 .629 .78 r
F P
0 g
s
.66511 .53148 m .66316 .53935 L .65972 .54043 L p .689 .631 .786 r
F P
0 g
s
.65972 .54043 m .6625 .52919 L .66511 .53148 L p .689 .631 .786 r
F P
0 g
s
.6459 .53536 m .65765 .53812 L .65972 .54043 L p .695 .618 .767 r
F P
0 g
s
.65972 .54043 m .64294 .53648 L .6459 .53536 L p .695 .618 .767 r
F P
0 g
s
.6625 .52919 m .65972 .54043 L .65765 .53812 L p .673 .615 .782 r
F P
0 g
s
.6307 .46079 m .63065 .45142 L .63068 .44951 L p 0 0 .474 r
F P
0 g
s
.5913 .64794 m .5913 .64749 L .59343 .64637 L p .442 .196 .443 r
F P
0 g
s
.31192 .53689 m .34351 .53135 L .33845 .53061 L p .679 .827 .954 r
F P
0 g
s
.33713 .52424 m .33845 .53061 L .34351 .53135 L p .659 .832 .966 r
F P
0 g
s
.34351 .53135 m .34168 .52225 L .33713 .52424 L p .659 .832 .966 r
F P
0 g
s
.36394 .5251 m .34694 .52929 L .34351 .53135 L p .689 .875 .968 r
F P
0 g
s
.34168 .52225 m .34351 .53135 L .34694 .52929 L p .688 .851 .961 r
F P
0 g
s
.43682 .47858 m .44484 .47971 L .44648 .48013 L p .45 .243 .505 r
F P
0 g
s
.30325 .52724 m .30526 .53565 L .31192 .53689 L p .659 .799 .95 r
F P
0 g
s
.31192 .53689 m .30911 .52487 L .30325 .52724 L p .659 .799 .95 r
F P
0 g
s
.33845 .53061 m .3163 .53449 L .31192 .53689 L p .679 .827 .954 r
F P
0 g
s
.30911 .52487 m .31192 .53689 L .3163 .53449 L p .678 .812 .947 r
F P
0 g
s
.4482 .40908 m .45247 .42312 L .45119 .42704 L p .553 .466 .71 r
F P
0 g
s
.63297 .46985 m .63144 .46759 L .63175 .46495 L p .263 .222 .623 r
F P
0 g
s
.50677 .5602 m .50906 .56056 L .50719 .56362 L p .868 .961 .861 r
F P
0 g
s
.50719 .56362 m .50391 .56311 L .50677 .5602 L p .868 .961 .861 r
F P
0 g
s
.50391 .56311 m .50719 .56362 L .5059 .56655 L p .958 .889 .72 r
F P
0 g
s
.63015 .39646 m .626 .4055 L .62721 .40915 L p .885 .732 .687 r
F P
0 g
s
.4992 .60091 m .49799 .58781 L .49823 .58455 L p .965 .808 .637 r
F P
0 g
s
.62854 .43552 m .6247 .42706 L .62373 .42628 L p .997 .773 .459 r
F P
0 g
s
.60366 .6349 m .59348 .64563 L .59503 .64371 L p .125 0 .279 r
F P
0 g
s
.60212 .63662 m .59499 .64413 L .59348 .64563 L p .17 0 .329 r
F P
0 g
s
.59348 .64563 m .60366 .6349 L .60212 .63662 L p .17 0 .329 r
F P
0 g
s
.59343 .64637 m .59348 .64563 L .59499 .64413 L p .189 0 .351 r
F P
0 g
s
.61438 .53764 m .62415 .54006 L .62578 .54208 L p .723 .553 .66 r
F P
0 g
s
.22403 .54421 m .22023 .53054 L .21114 .52808 L p .664 .771 .929 r
F P
0 g
s
.62784 .54345 m .62703 .54773 L .62463 .54818 L p .742 .587 .683 r
F P
0 g
s
.62463 .54818 m .62578 .54208 L .62784 .54345 L p .742 .587 .683 r
F P
0 g
s
.64814 .52715 m .6459 .53536 L .64294 .53648 L p .687 .592 .744 r
F P
0 g
s
.64294 .53648 m .64613 .52476 L .64814 .52715 L p .687 .592 .744 r
F P
0 g
s
.64613 .52476 m .64294 .53648 L .64131 .53408 L p .665 .569 .737 r
F P
0 g
s
.43623 .47984 m .44405 .48113 L .44563 .48162 L p .448 .233 .494 r
F P
0 g
s
.53227 .724 m .52912 .75287 L .5249 .74778 L p .733 .635 .75 r
F P
0 g
s
.50077 .74426 m .5249 .74778 L .52912 .75287 L p .733 .635 .75 r
F P
0 g
s
.52912 .75287 m .49466 .74785 L .50077 .74426 L p .733 .635 .75 r
F P
0 g
s
.53678 .72837 m .53457 .74858 L .52912 .75287 L p .696 .601 .746 r
F P
0 g
s
.52912 .75287 m .53227 .724 L .53678 .72837 L p .696 .601 .746 r
F P
0 g
s
.56563 .75269 m .52912 .75287 L .53457 .74858 L p .696 .601 .746 r
F P
0 g
s
.64131 .53408 m .64354 .52587 L .64613 .52476 L p .665 .569 .737 r
F P
0 g
s
.59343 .64637 m .59342 .64701 L .5913 .64794 L p .442 .196 .443 r
F P
0 g
s
.63089 .46121 m .63159 .46264 L .63175 .46495 L p 0 0 .541 r
F P
0 g
s
.65765 .53812 m .6596 .53025 L .6625 .52919 L p .673 .615 .782 r
F P
0 g
s
.63527 .51878 m .64475 .522 L .64613 .52476 L p .643 .552 .737 r
F P
0 g
s
.62578 .54208 m .61182 .53863 L .61438 .53764 L p .723 .553 .66 r
F P
0 g
s
.6227 .54681 m .62351 .54253 L .62578 .54208 L p .734 .579 .682 r
F P
0 g
s
.62578 .54208 m .62463 .54818 L .6227 .54681 L p .734 .579 .682 r
F P
0 g
s
.61182 .53863 m .62578 .54208 L .62351 .54253 L p .725 .544 .646 r
F P
0 g
s
.35023 .79485 m .28729 .84723 L .29337 .83753 L p .752 .774 .871 r
F P
0 g
s
.27574 .82723 m .29337 .83753 L .28729 .84723 L p .752 .775 .871 r
F P
0 g
s
.28729 .84723 m .26204 .83262 L .27574 .82723 L p .752 .775 .871 r
F P
0 g
s
.34569 .80518 m .30167 .84177 L .28729 .84723 L p .746 .759 .863 r
F P
0 g
s
.28729 .84723 m .35023 .79485 L .34569 .80518 L p .746 .759 .863 r
F P
0 g
s
.60009 .53658 m .59877 .54195 L .5964 .54261 L p .731 .468 .53 r
F P
0 g
s
.58116 .65919 m .58123 .66308 L .57902 .66498 L p .492 .292 .536 r
F P
0 g
s
.4536 .4439 m .45119 .42704 L .45378 .4289 L p .544 .432 .677 r
F P
0 g
s
.46405 .42521 m .45378 .4289 L .45119 .42704 L p .542 .433 .679 r
F P
0 g
s
.45119 .42704 m .46585 .42175 L .46405 .42521 L p .542 .433 .679 r
F P
0 g
s
.45119 .42704 m .4536 .4439 L .4511 .4422 L p .484 .39 .672 r
F P
0 g
s
.46585 .42175 m .45119 .42704 L .45247 .42312 L p .555 .467 .711 r
F P
0 g
s
.5059 .56655 m .5036 .5662 L .50391 .56311 L p .958 .889 .72 r
F P
0 g
s
.54307 .67562 m .54143 .68408 L .5379 .68559 L p .697 .51 .631 r
F P
0 g
s
.59125 .6497 m .59128 .64833 L .59342 .64701 L p .442 .196 .444 r
F P
0 g
s
.63394 .46817 m .63175 .46495 L .63203 .46344 L p .02 .13 .639 r
F P
0 g
s
.63191 .4541 m .63203 .46344 L .63175 .46495 L p 0 .1 .618 r
F P
0 g
s
.63175 .46495 m .63158 .4516 L .63191 .4541 L p 0 .1 .618 r
F P
0 g
s
.63175 .46495 m .63394 .46817 L .63297 .46985 L p .263 .222 .623 r
F P
0 g
s
.63158 .4516 m .63175 .46495 L .63159 .46264 L p 0 0 .529 r
F P
0 g
s
.62351 .54253 m .61373 .54012 L .61182 .53863 L p .725 .544 .646 r
F P
0 g
s
.53688 .67433 m .52349 .66956 L .52112 .6667 L p .754 .565 .641 r
F P
0 g
s
.6106 .54546 m .61182 .53863 L .61373 .54012 L p .742 .537 .616 r
F P
0 g
s
.6087 .54394 m .60956 .53916 L .61182 .53863 L p .728 .523 .614 r
F P
0 g
s
.61182 .53863 m .6106 .54546 L .6087 .54394 L p .728 .523 .614 r
F P
0 g
s
.62581 .41953 m .62772 .41263 L .62721 .40915 L p .983 .816 .6 r
F P
0 g
s
.37052 .52357 m .36993 .51899 L .3669 .51883 L p .695 .907 .97 r
F P
0 g
s
.62686 .54886 m .62694 .55014 L .62474 .55001 L p .76 .557 .621 r
F P
0 g
s
.62474 .55001 m .62463 .54818 L .62686 .54886 L p .76 .557 .621 r
F P
0 g
s
.59499 .64413 m .59496 .64465 L .59343 .64637 L p .189 0 .351 r
F P
0 g
s
.60361 .63561 m .59343 .64637 L .59496 .64465 L p .167 0 .328 r
F P
0 g
s
.60208 .63732 m .59495 .64485 L .59343 .64637 L p .204 .002 .369 r
F P
0 g
s
.59343 .64637 m .60361 .63561 L .60208 .63732 L p .204 .002 .369 r
F P
0 g
s
.59342 .64701 m .59343 .64637 L .59495 .64485 L p .229 .035 .398 r
F P
0 g
s
.828 .54663 m .83139 .53339 L .84038 .53102 L p .656 .732 .906 r
F P
0 g
s
.42893 .48902 m .42293 .49575 L .42298 .49489 L p .014 0 .014 r
F P
0 g
s
.61373 .54012 m .61288 .5449 L .6106 .54546 L p .742 .537 .616 r
F P
0 g
s
.59503 .64371 m .60216 .6362 L .60366 .6349 L p .125 0 .279 r
F P
0 g
s
.60245 .63399 m .603 .63187 L .60465 .62982 L p 0 0 .123 r
F P
0 g
s
.79264 .532 m .79002 .54346 L .78127 .54541 L p .662 .725 .896 r
F P
0 g
s
.78127 .54541 m .78495 .52904 L .79264 .532 L p .662 .725 .896 r
F P
0 g
s
.74657 .53961 m .77557 .54248 L .78127 .54541 L p .664 .718 .889 r
F P
0 g
s
.78127 .54541 m .73989 .54132 L .74657 .53961 L p .664 .718 .889 r
F P
0 g
s
.78495 .52904 m .78127 .54541 L .77557 .54248 L p .656 .719 .895 r
F P
0 g
s
.49956 .58669 m .49864 .58725 L .49823 .58455 L p .973 .813 .624 r
F P
0 g
s
.49823 .58455 m .49954 .58375 L .49956 .58669 L p .973 .813 .624 r
F P
0 g
s
.42293 .49575 m .42893 .48902 L .42916 .49044 L p .383 .092 .342 r
F P
0 g
s
.43521 .49245 m .42916 .49044 L .42893 .48902 L p .423 .117 .341 r
F P
0 g
s
.42893 .48902 m .43757 .49189 L .43521 .49245 L p .423 .117 .341 r
F P
0 g
s
.43343 .48466 m .43088 .48857 L .42893 .48902 L p .425 .181 .438 r
F P
0 g
s
.43757 .49189 m .42893 .48902 L .43088 .48857 L p .413 .151 .404 r
F P
0 g
s
.43445 .4832 m .44164 .48487 L .44284 .48582 L p .438 .209 .468 r
F P
0 g
s
.57963 .67298 m .56039 .67576 L .56327 .67412 L p .618 .416 .586 r
F P
0 g
s
.55699 .68535 m .55717 .6772 L .56039 .67576 L p .697 .513 .635 r
F P
0 g
s
.56039 .67576 m .56013 .6874 L .55699 .68535 L p .697 .513 .635 r
F P
0 g
s
.57685 .67511 m .56338 .67706 L .56039 .67576 L p .628 .457 .631 r
F P
0 g
s
.56039 .67576 m .57963 .67298 L .57685 .67511 L p .628 .457 .631 r
F P
0 g
s
.56013 .6874 m .56039 .67576 L .56338 .67706 L p .629 .456 .63 r
F P
0 g
s
.61288 .5449 m .6227 .54681 L .62463 .54818 L p .752 .57 .65 r
F P
0 g
s
.62463 .54818 m .6106 .54546 L .61288 .5449 L p .752 .57 .65 r
F P
0 g
s
.62263 .54935 m .62255 .54807 L .62463 .54818 L p .759 .555 .622 r
F P
0 g
s
.62463 .54818 m .62474 .55001 L .62263 .54935 L p .759 .555 .622 r
F P
0 g
s
.6106 .54546 m .62463 .54818 L .62255 .54807 L p .755 .524 .582 r
F P
0 g
s
.53457 .74858 m .56014 .74846 L .56563 .75269 L p .696 .601 .746 r
F P
0 g
s
.56327 .67412 m .57673 .67217 L .57963 .67298 L p .618 .416 .586 r
F P
0 g
s
.62666 .55187 m .62689 .55064 L .62474 .55001 L p .766 .562 .621 r
F P
0 g
s
.60825 .77715 m .59722 .75287 L .60089 .74656 L p .655 .604 .784 r
F P
0 g
s
.60089 .74656 m .61663 .78128 L .60825 .77715 L p .655 .604 .784 r
F P
0 g
s
.5036 .5662 m .50055 .58065 L .49954 .58375 L p .965 .894 .706 r
F P
0 g
s
.49954 .58375 m .50391 .56311 L .5036 .5662 L p .965 .894 .706 r
F P
0 g
s
.49886 .5814 m .49978 .58085 L .49954 .58375 L p .973 .891 .684 r
F P
0 g
s
.49954 .58375 m .49823 .58455 L .49886 .5814 L p .973 .891 .684 r
F P
0 g
s
.50391 .56311 m .49954 .58375 L .49978 .58085 L p .938 .863 .74 r
F P
0 g
s
.64204 .49157 m .6347 .48676 L .63617 .48533 L p .446 .431 .749 r
F P
0 g
s
.63832 .47523 m .63617 .48533 L .6347 .48676 L p .431 .409 .733 r
F P
0 g
s
.6347 .48676 m .63777 .47235 L .63832 .47523 L p .431 .409 .733 r
F P
0 g
s
.64016 .49305 m .63503 .48968 L .6347 .48676 L p .504 .422 .697 r
F P
0 g
s
.6347 .48676 m .64204 .49157 L .64016 .49305 L p .504 .422 .697 r
F P
0 g
s
.63777 .47235 m .6347 .48676 L .63451 .48398 L p .348 .326 .693 r
F P
0 g
s
.62056 .59359 m .6164 .59536 L .61543 .59798 L p .945 .814 .683 r
F P
0 g
s
.62842 .43731 m .62849 .44062 L .62932 .4431 L p .971 .691 .28 r
F P
0 g
s
.59495 .64485 m .59494 .6453 L .59342 .64701 L p .229 .035 .398 r
F P
0 g
s
.6036 .63621 m .59342 .64701 L .59494 .6453 L p .201 0 .368 r
F P
0 g
s
.59342 .64701 m .59339 .64895 L .59125 .6497 L p .442 .196 .444 r
F P
0 g
s
.60207 .63812 m .59494 .64568 L .59342 .64701 L p .207 .008 .375 r
F P
0 g
s
.59342 .64701 m .6036 .63621 L .60207 .63812 L p .207 .008 .375 r
F P
0 g
s
.59339 .64895 m .59342 .64701 L .59494 .64568 L p .225 .033 .397 r
F P
0 g
s
.60844 .74978 m .61946 .77412 L .61663 .78128 L p .613 .582 .795 r
F P
0 g
s
.61663 .78128 m .60089 .74656 L .60844 .74978 L p .613 .582 .795 r
F P
0 g
s
.65584 .76662 m .61663 .78128 L .61946 .77412 L p .613 .582 .795 r
F P
0 g
s
.65451 .77539 m .62706 .78559 L .61663 .78128 L p .623 .62 .827 r
F P
0 g
s
.61663 .78128 m .65584 .76662 L .65451 .77539 L p .623 .62 .827 r
F P
0 g
s
.61049 .61629 m .60465 .62982 L .60584 .62727 L p .762 .863 .429 r
F P
0 g
s
.60465 .62982 m .60387 .63285 L .60245 .63399 L p 0 0 .123 r
F P
0 g
s
.60947 .61877 m .60538 .62824 L .60465 .62982 L p 0 0 0 r
F P
0 g
s
.60465 .62982 m .61049 .61629 L .60947 .61877 L p 0 0 0 r
F P
0 g
s
.60387 .63285 m .60465 .62982 L .60538 .62824 L p 0 0 0 r
F P
0 g
s
.45247 .42312 m .46273 .41942 L .46585 .42175 L p .555 .467 .711 r
F P
0 g
s
.59722 .75287 m .57256 .75714 L .56563 .75269 L p .655 .603 .784 r
F P
0 g
s
.41481 .50183 m .42098 .49697 L .42293 .49575 L p 0 0 0 r
F P
0 g
s
.62255 .54807 m .61273 .54616 L .6106 .54546 L p .755 .524 .582 r
F P
0 g
s
.41486 .34744 m .42698 .34009 L .43352 .34404 L p .599 .58 .803 r
F P
0 g
s
.45125 .45604 m .45146 .44646 L .4536 .4439 L p .472 .349 .631 r
F P
0 g
s
.60584 .62727 m .60992 .6178 L .61049 .61629 L p .762 .863 .429 r
F P
0 g
s
.63715 .50329 m .64016 .49305 L .64204 .49157 L p .52 .45 .718 r
F P
0 g
s
.64204 .49157 m .63773 .50621 L .63715 .50329 L p .52 .45 .718 r
F P
0 g
s
.5249 .74778 m .5271 .72757 L .53227 .724 L p .733 .635 .75 r
F P
0 g
s
.6497 .51114 m .63773 .50621 L .64006 .50476 L p .583 .527 .758 r
F P
0 g
s
.64307 .49451 m .64006 .50476 L .63773 .50621 L p .571 .503 .74 r
F P
0 g
s
.63773 .50621 m .64204 .49157 L .64307 .49451 L p .571 .503 .74 r
F P
0 g
s
.64725 .51247 m .63887 .50901 L .63773 .50621 L p .604 .511 .722 r
F P
0 g
s
.63773 .50621 m .6497 .51114 L .64725 .51247 L p .604 .511 .722 r
F P
0 g
s
.62479 .57905 m .62512 .56997 L .62341 .56801 L p .835 .697 .712 r
F P
0 g
s
.62341 .56801 m .62295 .58098 L .62479 .57905 L p .835 .697 .712 r
F P
0 g
s
.61289 .54763 m .62263 .54935 L .62474 .55001 L p .764 .53 .58 r
F P
0 g
s
.62474 .55001 m .61082 .54756 L .61289 .54763 L p .764 .53 .58 r
F P
0 g
s
.62474 .55001 m .62441 .55176 L .62666 .55187 L p .766 .562 .621 r
F P
0 g
s
.61288 .54821 m .62262 .54992 L .62474 .55001 L p .764 .53 .58 r
F P
0 g
s
.62474 .55001 m .61082 .54756 L .61288 .54821 L p .764 .53 .58 r
F P
0 g
s
.62441 .55176 m .62474 .55001 L .62262 .54992 L p .768 .563 .622 r
F P
0 g
s
.63451 .48398 m .63666 .47389 L .63777 .47235 L p .348 .326 .693 r
F P
0 g
s
.56218 .72465 m .56563 .75269 L .56014 .74846 L p .696 .601 .746 r
F P
0 g
s
.56748 .72804 m .56989 .74768 L .56563 .75269 L p .652 .569 .749 r
F P
0 g
s
.56563 .75269 m .56218 .72465 L .56748 .72804 L p .652 .569 .749 r
F P
0 g
s
.60089 .74656 m .56563 .75269 L .56989 .74768 L p .652 .569 .749 r
F P
0 g
s
.56563 .75269 m .60089 .74656 L .59722 .75287 L p .655 .603 .784 r
F P
0 g
s
.63159 .46264 m .63146 .4533 L .63158 .4516 L p 0 0 .529 r
F P
0 g
s
.62608 .55735 m .62648 .553 L .62441 .55176 L p .775 .618 .686 r
F P
0 g
s
.73457 .54245 m .71215 .53965 L .70784 .53731 L p .669 .695 .865 r
F P
0 g
s
.70784 .53731 m .73989 .54132 L .73457 .54245 L p .669 .695 .865 r
F P
0 g
s
.59496 .64465 m .60209 .63712 L .60361 .63561 L p .167 0 .328 r
F P
0 g
s
.27636 .53937 m .27366 .52859 L .26677 .5268 L p .67 .786 .936 r
F P
0 g
s
.4994 .63462 m .50791 .64395 L .50915 .64695 L p .878 .656 .597 r
F P
0 g
s
.50915 .64695 m .49699 .63361 L .4994 .63462 L p .878 .656 .597 r
F P
0 g
s
.50327 .65304 m .50654 .64645 L .50915 .64695 L p .861 .663 .633 r
F P
0 g
s
.50915 .64695 m .5045 .65637 L .50327 .65304 L p .861 .663 .633 r
F P
0 g
s
.49699 .63361 m .50915 .64695 L .50654 .64645 L p .861 .664 .635 r
F P
0 g
s
.5045 .65637 m .50915 .64695 L .51085 .64996 L p .816 .603 .614 r
F P
0 g
s
.61405 .61028 m .61583 .59981 L .61543 .59798 L p .961 .894 .716 r
F P
0 g
s
.61543 .59798 m .61289 .61296 L .61405 .61028 L p .961 .894 .716 r
F P
0 g
s
.57673 .67217 m .57631 .66657 L .57902 .66498 L p .618 .416 .586 r
F P
0 g
s
.6596 .53025 m .64814 .52715 L .64613 .52476 L p .665 .588 .758 r
F P
0 g
s
.62447 .41902 m .62721 .40915 L .62492 .40914 L p .908 .711 .623 r
F P
0 g
s
.61571 .40177 m .62492 .40914 L .62721 .40915 L p .908 .71 .622 r
F P
0 g
s
.62721 .40915 m .61404 .39862 L .61571 .40177 L p .908 .71 .622 r
F P
0 g
s
.62721 .40915 m .62447 .41902 L .62581 .41953 L p .983 .816 .6 r
F P
0 g
s
.61404 .39862 m .62721 .40915 L .626 .4055 L p .886 .732 .686 r
F P
0 g
s
.34694 .52929 m .34568 .52291 L .34168 .52225 L p .688 .851 .961 r
F P
0 g
s
.51085 .64996 m .5076 .65655 L .5045 .65637 L p .816 .603 .614 r
F P
0 g
s
.5076 .65655 m .51923 .66378 L .52112 .6667 L p .816 .604 .616 r
F P
0 g
s
.52112 .6667 m .5045 .65637 L .5076 .65655 L p .816 .604 .616 r
F P
0 g
s
.51478 .67582 m .51784 .66708 L .52112 .6667 L p .803 .62 .654 r
F P
0 g
s
.52112 .6667 m .51675 .67918 L .51478 .67582 L p .803 .62 .654 r
F P
0 g
s
.5045 .65637 m .52112 .6667 L .51784 .66708 L p .803 .619 .654 r
F P
0 g
s
.51675 .67918 m .52112 .6667 L .52349 .66956 L p .755 .565 .64 r
F P
0 g
s
.56917 .53559 m .58013 .53776 L .58116 .53947 L p .669 .324 .38 r
F P
0 g
s
.58116 .53947 m .56549 .53636 L .56917 .53559 L p .669 .324 .38 r
F P
0 g
s
.45378 .4289 m .45547 .44071 L .4536 .4439 L p .544 .432 .677 r
F P
0 g
s
.59418 .65767 m .57902 .66498 L .58123 .66308 L p .488 .286 .531 r
F P
0 g
s
.57902 .66498 m .57963 .67298 L .57673 .67217 L p .618 .416 .586 r
F P
0 g
s
.59207 .65995 m .58145 .66507 L .57902 .66498 L p .516 .34 .581 r
F P
0 g
s
.57902 .66498 m .59418 .65767 L .59207 .65995 L p .516 .34 .581 r
F P
0 g
s
.57963 .67298 m .57902 .66498 L .58145 .66507 L p .516 .34 .581 r
F P
0 g
s
.62549 .56668 m .6258 .55966 L .62385 .55797 L p .8 .648 .693 r
F P
0 g
s
.62441 .55176 m .62385 .55797 L .62608 .55735 L p .775 .618 .686 r
F P
0 g
s
.62262 .54992 m .62239 .55115 L .62441 .55176 L p .768 .563 .622 r
F P
0 g
s
.6625 .52919 m .64613 .52476 L .64905 .5234 L p .658 .598 .776 r
F P
0 g
s
.65155 .51387 m .64905 .5234 L .64613 .52476 L p .649 .572 .756 r
F P
0 g
s
.64613 .52476 m .6497 .51114 L .65155 .51387 L p .649 .572 .756 r
F P
0 g
s
.64613 .52476 m .6625 .52919 L .6596 .53025 L p .665 .588 .758 r
F P
0 g
s
.6497 .51114 m .64613 .52476 L .64475 .522 L p .617 .54 .745 r
F P
0 g
s
.56014 .74846 m .55771 .72883 L .56218 .72465 L p .696 .601 .746 r
F P
0 g
s
.49519 .61258 m .50073 .6235 L .50138 .62654 L p .933 .721 .594 r
F P
0 g
s
.50138 .62654 m .49347 .61094 L .49519 .61258 L p .933 .721 .594 r
F P
0 g
s
.49635 .63035 m .49943 .62541 L .50138 .62654 L p .916 .718 .62 r
F P
0 g
s
.50138 .62654 m .49699 .63361 L .49635 .63035 L p .916 .718 .62 r
F P
0 g
s
.49347 .61094 m .50138 .62654 L .49943 .62541 L p .914 .722 .63 r
F P
0 g
s
.49699 .63361 m .50138 .62654 L .50247 .62967 L p .878 .656 .598 r
F P
0 g
s
.7435 .2817 m .71961 .25753 L .70423 .26048 L p .752 .753 .853 r
F P
0 g
s
.64475 .522 m .64725 .51247 L .6497 .51114 L p .617 .54 .745 r
F P
0 g
s
.60992 .6178 m .61161 .61547 L .61289 .61296 L p .796 .905 .504 r
F P
0 g
s
.50247 .62967 m .4994 .63462 L .49699 .63361 L p .878 .656 .598 r
F P
0 g
s
.52349 .66956 m .52044 .6783 L .51675 .67918 L p .755 .565 .64 r
F P
0 g
s
.61273 .55093 m .62234 .55243 L .62441 .55176 L p .771 .588 .65 r
F P
0 g
s
.62441 .55176 m .61068 .54961 L .61273 .55093 L p .771 .588 .65 r
F P
0 g
s
.62385 .55797 m .62441 .55176 L .62234 .55243 L p .783 .626 .686 r
F P
0 g
s
.61068 .54961 m .62441 .55176 L .62239 .55115 L p .772 .538 .581 r
F P
0 g
s
.56338 .67706 m .5632 .68521 L .56013 .6874 L p .629 .456 .63 r
F P
0 g
s
.61289 .61296 m .61049 .61629 L .60992 .6178 L p .796 .905 .504 r
F P
0 g
s
.61461 .6007 m .61283 .61119 L .61289 .61296 L p .979 .916 .613 r
F P
0 g
s
.61289 .61296 m .61543 .59798 L .61461 .6007 L p .979 .916 .613 r
F P
0 g
s
.61049 .61629 m .61289 .61296 L .61283 .61119 L p .976 .899 .548 r
F P
0 g
s
.3163 .53449 m .31437 .52607 L .30911 .52487 L p .678 .812 .947 r
F P
0 g
s
.59494 .6453 m .60207 .63774 L .6036 .63621 L p .201 0 .368 r
F P
0 g
s
.59134 .65293 m .59124 .65052 L .59339 .64895 L p .462 .233 .48 r
F P
0 g
s
.62385 .55797 m .62341 .56801 L .62549 .56668 L p .8 .648 .693 r
F P
0 g
s
.49978 .58085 m .50284 .5664 L .50391 .56311 L p .938 .863 .74 r
F P
0 g
s
.43088 .48857 m .43694 .49058 L .43757 .49189 L p .413 .151 .404 r
F P
0 g
s
.61596 .58455 m .62166 .58346 L .62295 .58098 L p .898 .775 .717 r
F P
0 g
s
.62295 .58098 m .61481 .58253 L .61596 .58455 L p .898 .775 .717 r
F P
0 g
s
.62192 .57008 m .6216 .57917 L .62295 .58098 L p .868 .726 .703 r
F P
0 g
s
.62295 .58098 m .62341 .56801 L .62192 .57008 L p .868 .726 .703 r
F P
0 g
s
.61481 .58253 m .62295 .58098 L .6216 .57917 L p .893 .723 .663 r
F P
0 g
s
.63203 .46344 m .63356 .4657 L .63394 .46817 L p .02 .13 .639 r
F P
0 g
s
.62239 .55115 m .61278 .54964 L .61068 .54961 L p .772 .538 .581 r
F P
0 g
s
.58123 .66308 m .59184 .65796 L .59418 .65767 L p .488 .286 .531 r
F P
0 g
s
.495 .59037 m .49758 .60261 L .49763 .60569 L p .962 .795 .629 r
F P
0 g
s
.49763 .60569 m .49394 .5882 L .495 .59037 L p .962 .795 .629 r
F P
0 g
s
.49337 .60775 m .49628 .60408 L .49763 .60569 L p .956 .781 .626 r
F P
0 g
s
.49763 .60569 m .49347 .61094 L .49337 .60775 L p .956 .781 .626 r
F P
0 g
s
.49394 .5882 m .49763 .60569 L .49628 .60408 L p .947 .79 .654 r
F P
0 g
s
.49347 .61094 m .49763 .60569 L .4981 .6089 L p .931 .724 .601 r
F P
0 g
s
.4981 .6089 m .49519 .61258 L .49347 .61094 L p .931 .724 .601 r
F P
0 g
s
.59494 .64568 m .59492 .64704 L .59339 .64895 L p .225 .033 .397 r
F P
0 g
s
.6248 .43373 m .62859 .44186 L .62932 .4431 L p .915 .597 .119 r
F P
0 g
s
.62932 .4431 m .6239 .43148 L .6248 .43373 L p .915 .597 .119 r
F P
0 g
s
.6239 .43148 m .62932 .4431 L .62849 .44062 L p .976 .699 .299 r
F P
0 g
s
.37846 .31571 m .34839 .28412 L .3453 .27395 L p .593 .609 .837 r
F P
0 g
s
.3453 .27395 m .38831 .31918 L .37846 .31571 L p .593 .609 .837 r
F P
0 g
s
.61306 .55854 m .62202 .5594 L .62385 .55797 L p .799 .624 .663 r
F P
0 g
s
.62385 .55797 m .61104 .55674 L .61306 .55854 L p .799 .624 .663 r
F P
0 g
s
.62341 .56801 m .62385 .55797 L .62202 .5594 L p .82 .665 .691 r
F P
0 g
s
.62234 .55243 m .62195 .55679 L .62385 .55797 L p .783 .626 .686 r
F P
0 g
s
.61104 .55674 m .62385 .55797 L .62195 .55679 L p .8 .612 .647 r
F P
0 g
s
.54143 .68408 m .55699 .68535 L .56013 .6874 L p .698 .512 .633 r
F P
0 g
s
.56013 .6874 m .5379 .68559 L .54143 .68408 L p .698 .512 .633 r
F P
0 g
s
.45331 .45759 m .4536 .4439 L .45586 .4456 L p .543 .407 .646 r
F P
0 g
s
.46647 .44315 m .45586 .4456 L .4536 .4439 L p .539 .407 .649 r
F P
0 g
s
.4536 .4439 m .46876 .44039 L .46647 .44315 L p .539 .407 .649 r
F P
0 g
s
.4536 .4439 m .45331 .45759 L .45125 .45604 L p .472 .349 .631 r
F P
0 g
s
.46876 .44039 m .4536 .4439 L .45547 .44071 L p .547 .436 .679 r
F P
0 g
s
.59877 .54195 m .6087 .54394 L .6106 .54546 L p .749 .513 .573 r
F P
0 g
s
.74858 .52931 m .74657 .53961 L .73989 .54132 L p .664 .708 .88 r
F P
0 g
s
.73989 .54132 m .74272 .5266 L .74858 .52931 L p .664 .708 .88 r
F P
0 g
s
.71303 .53579 m .73548 .5386 L .73989 .54132 L p .667 .698 .87 r
F P
0 g
s
.73989 .54132 m .70784 .53731 L .71303 .53579 L p .667 .698 .87 r
F P
0 g
s
.74272 .5266 m .73989 .54132 L .73548 .5386 L p .654 .699 .879 r
F P
0 g
s
.6036 .63805 m .59339 .64895 L .59492 .64704 L p .2 .003 .373 r
F P
0 g
s
.59339 .64895 m .59354 .6524 L .59134 .65293 L p .462 .233 .48 r
F P
0 g
s
.6021 .6402 m .59495 .64783 L .59339 .64895 L p .258 .078 .436 r
F P
0 g
s
.59339 .64895 m .6036 .63805 L .6021 .6402 L p .258 .078 .436 r
F P
0 g
s
.59354 .6524 m .59339 .64895 L .59495 .64783 L p .265 .09 .447 r
F P
0 g
s
.61273 .54616 m .61289 .54763 L .61082 .54756 L p .759 .502 .545 r
F P
0 g
s
.61082 .54756 m .6106 .54546 L .61273 .54616 L p .759 .502 .545 r
F P
0 g
s
.64006 .50476 m .64844 .50821 L .6497 .51114 L p .583 .527 .758 r
F P
0 g
s
.42916 .49044 m .42496 .49516 L .42293 .49575 L p .383 .092 .342 r
F P
0 g
s
.4141 .50269 m .42293 .49575 L .42242 .49711 L p .282 0 .147 r
F P
0 g
s
.42697 .499 m .42242 .49711 L .42293 .49575 L p .367 0 .181 r
F P
0 g
s
.42293 .49575 m .42943 .49845 L .42697 .499 L p .367 0 .181 r
F P
0 g
s
.42293 .49575 m .4141 .50269 L .41481 .50183 L p 0 0 0 r
F P
0 g
s
.42943 .49845 m .42293 .49575 L .42496 .49516 L p .349 .026 .269 r
F P
0 g
s
.52044 .6783 m .53523 .68278 L .5379 .68559 L p .755 .566 .641 r
F P
0 g
s
.60538 .62824 m .60484 .63036 L .60387 .63285 L p 0 0 0 r
F P
0 g
s
.64905 .5234 m .66052 .5265 L .6625 .52919 L p .658 .598 .776 r
F P
0 g
s
.67922 .53439 m .66511 .53148 L .6625 .52919 L p .67 .63 .801 r
F P
0 g
s
.63617 .48533 m .64131 .48869 L .64204 .49157 L p .446 .431 .749 r
F P
0 g
s
.70362 .53839 m .68601 .53561 L .68267 .53334 L p .671 .666 .837 r
F P
0 g
s
.68267 .53334 m .70784 .53731 L .70362 .53839 L p .671 .666 .837 r
F P
0 g
s
.5379 .68559 m .51675 .67918 L .52044 .6783 L p .755 .566 .641 r
F P
0 g
s
.53224 .69868 m .53411 .68714 L .5379 .68559 L p .748 .589 .679 r
F P
0 g
s
.5379 .68559 m .53523 .70206 L .53224 .69868 L p .748 .589 .679 r
F P
0 g
s
.51675 .67918 m .5379 .68559 L .53411 .68714 L p .747 .588 .679 r
F P
0 g
s
.55663 .68956 m .54106 .68829 L .5379 .68559 L p .697 .542 .673 r
F P
0 g
s
.5379 .68559 m .56013 .6874 L .55663 .68956 L p .697 .542 .673 r
F P
0 g
s
.53523 .70206 m .5379 .68559 L .54106 .68829 L p .698 .542 .672 r
F P
0 g
s
.626 .4055 m .61679 .39813 L .61404 .39862 L p .886 .732 .686 r
F P
0 g
s
.6106 .54546 m .5964 .54261 L .59877 .54195 L p .749 .513 .573 r
F P
0 g
s
.60867 .54685 m .60852 .54537 L .6106 .54546 L p .756 .5 .546 r
F P
0 g
s
.6106 .54546 m .61082 .54756 L .60867 .54685 L p .756 .5 .546 r
F P
0 g
s
.5964 .54261 m .6106 .54546 L .60852 .54537 L p .746 .456 .491 r
F P
0 g
s
.57871 .53944 m .56774 .53726 L .56549 .53636 L p .591 .103 .064 r
F P
0 g
s
.56549 .53636 m .58116 .53947 L .57871 .53944 L p .591 .103 .064 r
F P
0 g
s
.56368 .53928 m .56549 .53636 L .56774 .53726 L p .564 .03 0 r
F P
0 g
s
.56063 .53825 m .56192 .5362 L .56549 .53636 L p .568 .035 0 r
F P
0 g
s
.56549 .53636 m .56368 .53928 L .56063 .53825 L p .568 .035 0 r
F P
0 g
s
.61441 .57021 m .62192 .57008 L .62341 .56801 L p .844 .686 .687 r
F P
0 g
s
.62341 .56801 m .61267 .56818 L .61441 .57021 L p .844 .686 .687 r
F P
0 g
s
.62202 .5594 m .62171 .56642 L .62341 .56801 L p .82 .665 .691 r
F P
0 g
s
.61267 .56818 m .62341 .56801 L .62171 .56642 L p .842 .657 .651 r
F P
0 g
s
.77557 .54248 m .7781 .53102 L .78495 .52904 L p .656 .719 .895 r
F P
0 g
s
.62195 .55679 m .61298 .55592 L .61104 .55674 L p .8 .612 .647 r
F P
0 g
s
.4999 .56756 m .49886 .5814 L .49823 .58455 L p .938 .85 .729 r
F P
0 g
s
.49823 .58455 m .49971 .56476 L .4999 .56756 L p .938 .85 .729 r
F P
0 g
s
.49442 .5851 m .49742 .58255 L .49823 .58455 L p .964 .847 .678 r
F P
0 g
s
.49823 .58455 m .49394 .5882 L .49442 .5851 L p .964 .847 .678 r
F P
0 g
s
.49971 .56476 m .49823 .58455 L .49742 .58255 L p .936 .848 .731 r
F P
0 g
s
.49394 .5882 m .49823 .58455 L .49799 .58781 L p .954 .797 .649 r
F P
0 g
s
.49799 .58781 m .495 .59037 L .49394 .5882 L p .954 .797 .649 r
F P
0 g
s
.51784 .66708 m .5062 .65985 L .5045 .65637 L p .803 .619 .654 r
F P
0 g
s
.56989 .74768 m .59457 .74338 L .60089 .74656 L p .652 .569 .749 r
F P
0 g
s
.6625 .52919 m .68267 .53334 L .67922 .53439 L p .67 .63 .801 r
F P
0 g
s
.63666 .47389 m .63399 .47096 L .63394 .46817 L p .327 .299 .674 r
F P
0 g
s
.36542 .8147 m .34569 .80518 L .35023 .79485 L p .746 .76 .864 r
F P
0 g
s
.35023 .79485 m .37837 .80855 L .36542 .8147 L p .746 .76 .864 r
F P
0 g
s
.54106 .68829 m .5392 .69982 L .53523 .70206 L p .698 .542 .672 r
F P
0 g
s
.50654 .64645 m .49802 .63711 L .49699 .63361 L p .861 .664 .635 r
F P
0 g
s
.6216 .57917 m .61591 .58025 L .61481 .58253 L p .893 .723 .663 r
F P
0 g
s
.60852 .54537 m .59857 .54338 L .5964 .54261 L p .746 .456 .491 r
F P
0 g
s
.68267 .53334 m .6625 .52919 L .6659 .52781 L p .665 .638 .813 r
F P
0 g
s
.66781 .51844 m .6659 .52781 L .6625 .52919 L p .659 .615 .794 r
F P
0 g
s
.6625 .52919 m .66522 .51581 L .66781 .51844 L p .659 .615 .794 r
F P
0 g
s
.66522 .51581 m .6625 .52919 L .66052 .5265 L p .634 .591 .788 r
F P
0 g
s
.44964 .46659 m .451 .45935 L .45331 .45759 L p .464 .312 .589 r
F P
0 g
s
.58145 .66507 m .58188 .67067 L .57963 .67298 L p .516 .34 .581 r
F P
0 g
s
.45547 .44071 m .46607 .43825 L .46876 .44039 L p .547 .436 .679 r
F P
0 g
s
.62849 .44062 m .6247 .43249 L .6239 .43148 L p .976 .699 .299 r
F P
0 g
s
.40363 .50838 m .41194 .50394 L .4141 .50269 L p .422 .848 .703 r
F P
0 g
s
.59492 .64704 m .60207 .63941 L .6036 .63805 L p .2 .003 .373 r
F P
0 g
s
.58396 .53874 m .59462 .54094 L .5964 .54261 L p .73 .435 .479 r
F P
0 g
s
.63777 .47235 m .63394 .46817 L .6344 .46682 L p .145 .251 .716 r
F P
0 g
s
.63402 .45753 m .6344 .46682 L .63394 .46817 L p .124 .226 .7 r
F P
0 g
s
.63394 .46817 m .63341 .45491 L .63402 .45753 L p .124 .226 .7 r
F P
0 g
s
.63394 .46817 m .63777 .47235 L .63666 .47389 L p .327 .299 .674 r
F P
0 g
s
.63341 .45491 m .63394 .46817 L .63356 .4657 L p 0 .092 .616 r
F P
0 g
s
.53411 .68714 m .51931 .68266 L .51675 .67918 L p .747 .588 .679 r
F P
0 g
s
.61283 .61119 m .61115 .61352 L .61049 .61629 L p .976 .899 .548 r
F P
0 g
s
.62171 .56642 m .61419 .56654 L .61267 .56818 L p .842 .657 .651 r
F P
0 g
s
.61278 .54964 m .61288 .54821 L .61082 .54756 L p .766 .508 .544 r
F P
0 g
s
.71472 .5262 m .71303 .53579 L .70784 .53731 L p .666 .684 .858 r
F P
0 g
s
.70784 .53731 m .71023 .52361 L .71472 .5262 L p .666 .684 .858 r
F P
0 g
s
.6868 .53191 m .70443 .5347 L .70784 .53731 L p .668 .671 .844 r
F P
0 g
s
.70784 .53731 m .68267 .53334 L .6868 .53191 L p .668 .671 .844 r
F P
0 g
s
.71023 .52361 m .70784 .53731 L .70443 .5347 L p .651 .67 .855 r
F P
0 g
s
.49943 .62541 m .49389 .61448 L .49347 .61094 L p .914 .722 .63 r
F P
0 g
s
.66052 .5265 m .66242 .51714 L .66522 .51581 L p .634 .591 .788 r
F P
0 g
s
.58134 .68422 m .56013 .6874 L .5632 .68521 L p .629 .457 .631 r
F P
0 g
s
.55694 .70074 m .55663 .68956 L .56013 .6874 L p .698 .543 .673 r
F P
0 g
s
.56013 .6874 m .56058 .70337 L .55694 .70074 L p .698 .543 .673 r
F P
0 g
s
.57845 .68704 m .56359 .68926 L .56013 .6874 L p .638 .496 .673 r
F P
0 g
s
.56013 .6874 m .58134 .68422 L .57845 .68704 L p .638 .496 .673 r
F P
0 g
s
.56058 .70337 m .56013 .6874 L .56359 .68926 L p .638 .496 .672 r
F P
0 g
s
.40981 .31322 m .39533 .32268 L .38831 .31918 L p .601 .58 .803 r
F P
0 g
s
.38831 .31918 m .40898 .30561 L .40981 .31322 L p .601 .58 .803 r
F P
0 g
s
.35525 .27839 m .38538 .31009 L .38831 .31918 L p .616 .614 .827 r
F P
0 g
s
.38831 .31918 m .3453 .27395 L .35525 .27839 L p .616 .614 .827 r
F P
0 g
s
.40898 .30561 m .38831 .31918 L .38538 .31009 L p .616 .615 .827 r
F P
0 g
s
.62492 .40914 m .623 .41605 L .62447 .41902 L p .908 .711 .623 r
F P
0 g
s
.68847 .52257 m .6868 .53191 L .68267 .53334 L p .664 .653 .829 r
F P
0 g
s
.68267 .53334 m .68504 .51999 L .68847 .52257 L p .664 .653 .829 r
F P
0 g
s
.6659 .52781 m .68003 .53072 L .68267 .53334 L p .665 .638 .813 r
F P
0 g
s
.68504 .51999 m .68267 .53334 L .68003 .53072 L p .645 .634 .825 r
F P
0 g
s
.59884 .54512 m .60867 .54685 L .61082 .54756 L p .758 .464 .488 r
F P
0 g
s
.61082 .54756 m .59677 .54509 L .59884 .54512 L p .758 .464 .488 r
F P
0 g
s
.61082 .54756 m .61068 .54961 L .61278 .54964 L p .766 .508 .544 r
F P
0 g
s
.59889 .5458 m .60872 .54753 L .61082 .54756 L p .758 .464 .488 r
F P
0 g
s
.61082 .54756 m .59677 .54509 L .59889 .5458 L p .758 .464 .488 r
F P
0 g
s
.61068 .54961 m .61082 .54756 L .60872 .54753 L p .769 .511 .544 r
F P
0 g
s
.55771 .72883 m .53678 .72837 L .53227 .724 L p .695 .601 .746 r
F P
0 g
s
.42496 .49516 m .42952 .49704 L .42943 .49845 L p .349 .026 .269 r
F P
0 g
s
.5632 .68521 m .57804 .68298 L .58134 .68422 L p .629 .457 .631 r
F P
0 g
s
.41478 .7729 m .38902 .80384 L .37837 .80855 L p .755 .729 .828 r
F P
0 g
s
.5964 .54261 m .58116 .53947 L .58396 .53874 L p .73 .435 .479 r
F P
0 g
s
.45586 .4456 m .45566 .45519 L .45331 .45759 L p .543 .407 .646 r
F P
0 g
s
.60216 .6362 m .60231 .63477 L .60387 .63285 L p .116 0 .267 r
F P
0 g
s
.59495 .64783 m .59506 .65025 L .59354 .6524 L p .265 .09 .447 r
F P
0 g
s
.41518 .76428 m .37837 .80855 L .38015 .80011 L p .769 .753 .838 r
F P
0 g
s
.36046 .79047 m .38015 .80011 L .37837 .80855 L p .769 .752 .838 r
F P
0 g
s
.37837 .80855 m .35023 .79485 L .36046 .79047 L p .769 .752 .838 r
F P
0 g
s
.37837 .80855 m .41518 .76428 L .41478 .7729 L p .755 .729 .828 r
F P
0 g
s
.49628 .60408 m .4937 .59184 L .49394 .5882 L p .947 .79 .654 r
F P
0 g
s
.56774 .53726 m .56648 .53931 L .56368 .53928 L p .564 .03 0 r
F P
0 g
s
.62859 .44186 m .62894 .44411 L .62982 .44631 L p .914 .595 .117 r
F P
0 g
s
.73548 .5386 m .73745 .5283 L .74272 .5266 L p .654 .699 .879 r
F P
0 g
s
.63356 .4657 m .63319 .45641 L .63341 .45491 L p 0 .092 .616 r
F P
0 g
s
.48777 .75211 m .46692 .74603 L .46486 .73913 L p .752 .688 .789 r
F P
0 g
s
.46486 .73913 m .49466 .74785 L .48777 .75211 L p .752 .688 .789 r
F P
0 g
s
.50729 .72389 m .50077 .74426 L .49466 .74785 L p .733 .635 .75 r
F P
0 g
s
.5271 .72757 m .50729 .72389 L .50397 .71874 L p .733 .635 .75 r
F P
0 g
s
.50397 .71874 m .53227 .724 L .5271 .72757 L p .733 .635 .75 r
F P
0 g
s
.59857 .54338 m .59884 .54512 L .59677 .54509 L p .746 .426 .441 r
F P
0 g
s
.59677 .54509 m .5964 .54261 L .59857 .54338 L p .746 .426 .441 r
F P
0 g
s
.59443 .54428 m .59418 .54255 L .5964 .54261 L p .739 .421 .443 r
F P
0 g
s
.5964 .54261 m .59677 .54509 L .59443 .54428 L p .739 .421 .443 r
F P
0 g
s
.58116 .53947 m .5964 .54261 L .59418 .54255 L p .712 .345 .35 r
F P
0 g
s
.50397 .71874 m .49466 .74785 L .49199 .7422 L p .765 .67 .758 r
F P
0 g
s
.47113 .73608 m .49199 .7422 L .49466 .74785 L p .765 .67 .758 r
F P
0 g
s
.49466 .74785 m .46486 .73913 L .47113 .73608 L p .765 .67 .758 r
F P
0 g
s
.49466 .74785 m .50397 .71874 L .50729 .72389 L p .733 .635 .75 r
F P
0 g
s
.53523 .70206 m .53227 .724 L .52879 .71988 L p .741 .612 .715 r
F P
0 g
s
.50899 .7162 m .52879 .71988 L .53227 .724 L p .741 .612 .715 r
F P
0 g
s
.53227 .724 m .50397 .71874 L .50899 .7162 L p .741 .612 .715 r
F P
0 g
s
.53893 .7055 m .53686 .72086 L .53227 .724 L p .697 .572 .71 r
F P
0 g
s
.53227 .724 m .53523 .70206 L .53893 .7055 L p .697 .572 .71 r
F P
0 g
s
.56218 .72465 m .53227 .724 L .53686 .72086 L p .697 .572 .71 r
F P
0 g
s
.53227 .724 m .56218 .72465 L .55771 .72883 L p .695 .601 .746 r
F P
0 g
s
.60872 .54753 m .60863 .54896 L .61068 .54961 L p .769 .511 .544 r
F P
0 g
s
.43557 .78094 m .41478 .7729 L .41518 .76428 L p .755 .729 .828 r
F P
0 g
s
.41518 .76428 m .44488 .77584 L .43557 .78094 L p .755 .729 .828 r
F P
0 g
s
.45331 .45759 m .45137 .46794 L .44964 .46659 L p .464 .312 .589 r
F P
0 g
s
.42242 .49711 m .41623 .50197 L .4141 .50269 L p .282 0 .147 r
F P
0 g
s
.5392 .69982 m .55694 .70074 L .56058 .70337 L p .698 .543 .673 r
F P
0 g
s
.56058 .70337 m .53523 .70206 L .5392 .69982 L p .698 .543 .673 r
F P
0 g
s
.45137 .46794 m .45331 .45759 L .45536 .45917 L p .548 .39 .618 r
F P
0 g
s
.46634 .45838 m .45536 .45917 L .45331 .45759 L p .544 .39 .623 r
F P
0 g
s
.45331 .45759 m .469 .45646 L .46634 .45838 L p .544 .39 .623 r
F P
0 g
s
.469 .45646 m .45331 .45759 L .45566 .45519 L p .548 .414 .651 r
F P
0 g
s
.53686 .72086 m .55779 .72131 L .56218 .72465 L p .697 .572 .71 r
F P
0 g
s
.61946 .77412 m .64691 .76382 L .65584 .76662 L p .613 .582 .795 r
F P
0 g
s
.59184 .65796 m .5914 .65427 L .59354 .6524 L p .487 .282 .526 r
F P
0 g
s
.46692 .74603 m .45293 .7717 L .44488 .77584 L p .752 .688 .789 r
F P
0 g
s
.68003 .53072 m .68168 .52137 L .68504 .51999 L p .645 .634 .825 r
F P
0 g
s
.6247 .42706 m .62521 .42197 L .62447 .41902 L p .997 .773 .459 r
F P
0 g
s
.61298 .55592 m .61273 .55093 L .61068 .54961 L p .785 .575 .615 r
F P
0 g
s
.51538 .6946 m .53224 .69868 L .53523 .70206 L p .748 .589 .679 r
F P
0 g
s
.53523 .70206 m .51114 .69625 L .51538 .6946 L p .748 .589 .679 r
F P
0 g
s
.52879 .71988 m .53087 .70452 L .53523 .70206 L p .741 .612 .715 r
F P
0 g
s
.51114 .69625 m .53523 .70206 L .53087 .70452 L p .741 .612 .715 r
F P
0 g
s
.55667 .70642 m .53893 .7055 L .53523 .70206 L p .697 .572 .71 r
F P
0 g
s
.53523 .70206 m .56058 .70337 L .55667 .70642 L p .697 .572 .71 r
F P
0 g
s
.56359 .68926 m .56391 .70044 L .56058 .70337 L p .638 .496 .672 r
F P
0 g
s
.60939 .61918 m .60387 .63285 L .60484 .63036 L p 0 0 0 r
F P
0 g
s
.60387 .63285 m .60366 .6349 L .60216 .6362 L p .116 0 .267 r
F P
0 g
s
.60851 .62154 m .60465 .63111 L .60387 .63285 L p 0 0 .042 r
F P
0 g
s
.60387 .63285 m .60939 .61918 L .60851 .62154 L p 0 0 .042 r
F P
0 g
s
.60366 .6349 m .60387 .63285 L .60465 .63111 L p 0 0 .111 r
F P
0 g
s
.62537 .43691 m .62909 .4449 L .62982 .44631 L p .86 .523 .008 r
F P
0 g
s
.62982 .44631 m .62449 .43491 L .62537 .43691 L p .86 .523 .008 r
F P
0 g
s
.62449 .43491 m .62982 .44631 L .62894 .44411 L p .915 .597 .12 r
F P
0 g
s
.46486 .73913 m .44488 .77584 L .44388 .76874 L p .774 .717 .799 r
F P
0 g
s
.42309 .76062 m .44388 .76874 L .44488 .77584 L p .774 .716 .799 r
F P
0 g
s
.44488 .77584 m .41518 .76428 L .42309 .76062 L p .774 .716 .799 r
F P
0 g
s
.44488 .77584 m .46486 .73913 L .46692 .74603 L p .752 .688 .789 r
F P
0 g
s
.70443 .5347 m .70609 .5251 L .71023 .52361 L p .651 .67 .855 r
F P
0 g
s
.49742 .58255 m .49845 .56869 L .49971 .56476 L p .936 .848 .731 r
F P
0 g
s
.4141 .50269 m .4022 .50904 L .40363 .50838 L p .422 .848 .703 r
F P
0 g
s
.4022 .50904 m .4141 .50269 L .41284 .50374 L p .043 0 0 r
F P
0 g
s
.4159 .50485 m .41284 .50374 L .4141 .50269 L p .216 0 0 r
F P
0 g
s
.4141 .50269 m .41848 .50427 L .4159 .50485 L p .216 0 0 r
F P
0 g
s
.41848 .50427 m .4141 .50269 L .41623 .50197 L p .194 0 0 r
F P
0 g
s
.59418 .54255 m .58351 .54035 L .58116 .53947 L p .712 .345 .35 r
F P
0 g
s
.44743 .47385 m .4491 .46897 L .45137 .46794 L p .458 .279 .549 r
F P
0 g
s
.57804 .68298 m .57685 .67511 L .57963 .67298 L p .629 .458 .632 r
F P
0 g
s
.61068 .54961 m .61104 .55674 L .61298 .55592 L p .785 .575 .615 r
F P
0 g
s
.59926 .54904 m .60884 .55047 L .61068 .54961 L p .778 .537 .571 r
F P
0 g
s
.61068 .54961 m .59701 .54756 L .59926 .54904 L p .778 .537 .571 r
F P
0 g
s
.61104 .55674 m .61068 .54961 L .60884 .55047 L p .8 .586 .612 r
F P
0 g
s
.59701 .54756 m .61068 .54961 L .60863 .54896 L p .77 .475 .486 r
F P
0 g
s
.66242 .51714 m .65155 .51387 L .6497 .51114 L p .624 .564 .767 r
F P
0 g
s
.63042 .45072 m .63031 .45029 L .63029 .44817 L p 0 0 .364 r
F P
0 g
s
.45597 .39748 m .44882 .3797 L .44956 .37473 L p .567 .504 .744 r
F P
0 g
s
.60391 .64138 m .59354 .6524 L .59506 .65025 L p .252 .074 .435 r
F P
0 g
s
.59354 .6524 m .59418 .65767 L .59184 .65796 L p .487 .282 .526 r
F P
0 g
s
.60247 .64382 m .59521 .65153 L .59354 .6524 L p .316 .16 .505 r
F P
0 g
s
.59354 .6524 m .60391 .64138 L .60247 .64382 L p .316 .16 .505 r
F P
0 g
s
.59418 .65767 m .59354 .6524 L .59521 .65153 L p .318 .165 .509 r
F P
0 g
s
.58161 .54243 m .58116 .53947 L .58351 .54035 L p .705 .297 .271 r
F P
0 g
s
.57902 .54151 m .57871 .53944 L .58116 .53947 L p .686 .282 .276 r
F P
0 g
s
.58116 .53947 m .58161 .54243 L .57902 .54151 L p .686 .282 .276 r
F P
0 g
s
.28402 .22735 m .26159 .25214 L .24622 .24912 L p .613 .641 .855 r
F P
0 g
s
.24622 .24912 m .27813 .21351 L .28402 .22735 L p .613 .641 .855 r
F P
0 g
s
.66522 .51581 m .6497 .51114 L .65237 .50965 L p .61 .579 .794 r
F P
0 g
s
.65439 .49942 m .65237 .50965 L .6497 .51114 L p .6 .556 .777 r
F P
0 g
s
.6497 .51114 m .65257 .49653 L .65439 .49942 L p .6 .556 .777 r
F P
0 g
s
.6497 .51114 m .66522 .51581 L .66242 .51714 L p .624 .564 .767 r
F P
0 g
s
.65257 .49653 m .6497 .51114 L .64844 .50821 L p .555 .512 .763 r
F P
0 g
s
.59584 .66543 m .57963 .67298 L .58188 .67067 L p .516 .34 .581 r
F P
0 g
s
.57963 .67298 m .58134 .68422 L .57804 .68298 L p .629 .458 .632 r
F P
0 g
s
.59379 .66821 m .58243 .67349 L .57963 .67298 L p .544 .398 .633 r
F P
0 g
s
.57963 .67298 m .59584 .66543 L .59379 .66821 L p .544 .398 .633 r
F P
0 g
s
.58134 .68422 m .57963 .67298 L .58243 .67349 L p .544 .398 .634 r
F P
0 g
s
.44956 .37473 m .45978 .40015 L .45597 .39748 L p .567 .504 .744 r
F P
0 g
s
.60484 .63036 m .6087 .6208 L .60939 .61918 L p 0 0 0 r
F P
0 g
s
.50284 .5664 m .4999 .56756 L .49971 .56476 L p .921 .84 .748 r
F P
0 g
s
.49971 .56476 m .50391 .56311 L .50284 .5664 L p .921 .84 .748 r
F P
0 g
s
.53087 .70452 m .514 .70046 L .51114 .69625 L p .741 .612 .715 r
F P
0 g
s
.60863 .54896 m .59906 .54753 L .59701 .54756 L p .77 .475 .486 r
F P
0 g
s
.64844 .50821 m .65045 .49799 L .65257 .49653 L p .555 .512 .763 r
F P
0 g
s
.55779 .72131 m .55667 .70642 L .56058 .70337 L p .697 .572 .71 r
F P
0 g
s
.56058 .70337 m .56218 .72465 L .55779 .72131 L p .697 .572 .71 r
F P
0 g
s
.44468 .37154 m .43346 .35008 L .43352 .34404 L p .583 .543 .775 r
F P
0 g
s
.43352 .34404 m .44956 .37473 L .44468 .37154 L p .583 .543 .775 r
F P
0 g
s
.51931 .68266 m .51538 .6946 L .51114 .69625 L p .748 .588 .678 r
F P
0 g
s
.51114 .69625 m .51675 .67918 L .51931 .68266 L p .748 .588 .678 r
F P
0 g
s
.6344 .46682 m .63707 .46974 L .63777 .47235 L p .145 .251 .716 r
F P
0 g
s
.50185 .66913 m .51478 .67582 L .51675 .67918 L p .803 .62 .654 r
F P
0 g
s
.51675 .67918 m .49827 .66962 L .50185 .66913 L p .803 .62 .654 r
F P
0 g
s
.50902 .6923 m .51296 .68035 L .51675 .67918 L p .791 .636 .689 r
F P
0 g
s
.51675 .67918 m .51114 .69625 L .50902 .6923 L p .791 .636 .689 r
F P
0 g
s
.49827 .66962 m .51675 .67918 L .51296 .68035 L p .791 .636 .69 r
F P
0 g
s
.52289 .53858 m .50677 .5602 L .50391 .56311 L p .851 .992 .843 r
F P
0 g
s
.50188 .56139 m .50482 .56024 L .50391 .56311 L p .889 .947 .841 r
F P
0 g
s
.50391 .56311 m .49971 .56476 L .50188 .56139 L p .889 .947 .841 r
F P
0 g
s
.56478 .7059 m .56589 .7208 L .56218 .72465 L p .646 .533 .712 r
F P
0 g
s
.56218 .72465 m .56058 .70337 L .56478 .7059 L p .646 .533 .712 r
F P
0 g
s
.59086 .7198 m .56218 .72465 L .56589 .7208 L p .646 .533 .712 r
F P
0 g
s
.58755 .72465 m .56748 .72804 L .56218 .72465 L p .652 .569 .749 r
F P
0 g
s
.56218 .72465 m .59086 .7198 L .58755 .72465 L p .652 .569 .749 r
F P
0 g
s
.58351 .54035 m .58382 .54242 L .58161 .54243 L p .705 .297 .271 r
F P
0 g
s
.45566 .45519 m .46664 .45439 L .469 .45646 L p .548 .414 .651 r
F P
0 g
s
.46273 .41942 m .45848 .4043 L .45978 .40015 L p .554 .467 .711 r
F P
0 g
s
.63065 .45142 m .63048 .45091 L .63044 .44879 L p 0 0 .442 r
F P
0 g
s
.68032 .8042 m .65451 .77539 L .65584 .76662 L p .623 .619 .827 r
F P
0 g
s
.65584 .76662 m .69273 .80787 L .68032 .8042 L p .623 .619 .827 r
F P
0 g
s
.58479 .69942 m .56058 .70337 L .56391 .70044 L p .639 .497 .673 r
F P
0 g
s
.58172 .70314 m .56478 .7059 L .56058 .70337 L p .646 .533 .712 r
F P
0 g
s
.56058 .70337 m .58479 .69942 L .58172 .70314 L p .646 .533 .712 r
F P
0 g
s
.29337 .83753 m .33745 .8008 L .35023 .79485 L p .752 .774 .871 r
F P
0 g
s
.58188 .67067 m .59323 .66538 L .59584 .66543 L p .516 .34 .581 r
F P
0 g
s
.65045 .49799 m .64307 .49451 L .64204 .49157 L p .542 .486 .743 r
F P
0 g
s
.65257 .49653 m .64204 .49157 L .64381 .49014 L p .503 .503 .789 r
F P
0 g
s
.64515 .48002 m .64381 .49014 L .64204 .49157 L p .492 .482 .775 r
F P
0 g
s
.64204 .49157 m .64394 .47711 L .64515 .48002 L p .492 .482 .775 r
F P
0 g
s
.64204 .49157 m .65257 .49653 L .65045 .49799 L p .542 .486 .743 r
F P
0 g
s
.64394 .47711 m .64204 .49157 L .64131 .48869 L p .413 .409 .746 r
F P
0 g
s
.62373 .42628 m .62447 .41902 L .62262 .41876 L p .926 .677 .543 r
F P
0 g
s
.61423 .41218 m .62262 .41876 L .62447 .41902 L p .926 .677 .543 r
F P
0 g
s
.62447 .41902 m .61249 .40961 L .61423 .41218 L p .926 .677 .543 r
F P
0 g
s
.62447 .41902 m .62373 .42628 L .6247 .42706 L p .997 .773 .459 r
F P
0 g
s
.61249 .40961 m .62447 .41902 L .623 .41605 L p .909 .711 .622 r
F P
0 g
s
.45137 .46794 m .44898 .47493 L .44743 .47385 L p .458 .279 .549 r
F P
0 g
s
.38891 .51415 m .39974 .51037 L .4022 .50904 L p .585 .938 .93 r
F P
0 g
s
.59506 .65025 m .60231 .64253 L .60391 .64138 L p .252 .074 .435 r
F P
0 g
s
.7632 .21441 m .79511 .24842 L .81201 .24746 L p .752 .753 .853 r
F P
0 g
s
.81201 .24746 m .7666 .19859 L .7632 .21441 L p .752 .753 .853 r
F P
0 g
s
.63068 .44951 m .63065 .45142 L p .63046 .44897 L 0 0 .442 r
F P
0 g
s
.63068 .44951 m .63002 .44815 L p .6313 .45098 L .689 .326 0 r
F P
0 g
s
.63068 .44951 m .63158 .4516 L .63146 .4533 L p 0 0 .516 r
F P
0 g
s
.63158 .4516 m .63068 .44951 L p .6313 .45098 L .689 .326 0 r
F P
0 g
s
.63044 .44879 m .63068 .44951 L p .63046 .44897 L 0 0 .442 r
F P
0 g
s
.63162 .36312 m .64184 .3453 L .64112 .33889 L p .831 .753 .777 r
F P
0 g
s
.64112 .33889 m .62651 .36438 L .63162 .36312 L p .831 .753 .777 r
F P
0 g
s
.62894 .44411 m .62521 .43613 L .62449 .43491 L p .915 .597 .12 r
F P
0 g
s
.6164 .59536 m .61596 .58455 L .61481 .58253 L p .919 .775 .686 r
F P
0 g
s
.61481 .58253 m .61543 .59798 L .6164 .59536 L p .919 .775 .686 r
F P
0 g
s
.60209 .63712 m .60212 .63662 L .60366 .6349 L p .148 0 .305 r
F P
0 g
s
.60884 .55047 m .60909 .55546 L .61104 .55674 L p .8 .586 .612 r
F P
0 g
s
.64131 .48869 m .64264 .47857 L .64394 .47711 L p .413 .409 .746 r
F P
0 g
s
.45536 .45917 m .454 .46642 L .45137 .46794 L p .548 .39 .618 r
F P
0 g
s
.56391 .70044 m .58085 .69767 L .58479 .69942 L p .639 .497 .673 r
F P
0 g
s
.44562 .47811 m .4469 .47536 L .44898 .47493 L p .454 .253 .516 r
F P
0 g
s
.41623 .50197 m .41931 .50307 L .41848 .50427 L p .194 0 0 r
F P
0 g
s
.60465 .63111 m .6045 .63254 L .60366 .6349 L p 0 0 .111 r
F P
0 g
s
.49199 .7422 m .4985 .72182 L .50397 .71874 L p .765 .67 .758 r
F P
0 g
s
.59906 .54753 m .59889 .5458 L .59677 .54509 L p .757 .434 .438 r
F P
0 g
s
.62579 .43867 m .62952 .44658 L .63029 .44817 L p .84 .497 0 r
F P
0 g
s
.63029 .44817 m .62496 .43688 L .62579 .43867 L p .84 .497 0 r
F P
0 g
s
.62909 .4449 m .62942 .4462 L .63029 .44817 L p .851 .51 0 r
F P
0 g
s
.62496 .43688 m .63029 .44817 L .62942 .4462 L p .863 .525 .012 r
F P
0 g
s
.63146 .4533 m .63084 .45183 L .63068 .44951 L p 0 0 .516 r
F P
0 g
s
.44898 .47493 m .45137 .46794 L .45329 .46939 L p .557 .38 .596 r
F P
0 g
s
.46425 .4705 m .45329 .46939 L .45137 .46794 L p .554 .38 .601 r
F P
0 g
s
.45137 .46794 m .46702 .46952 L .46425 .4705 L p .554 .38 .601 r
F P
0 g
s
.46702 .46952 m .45137 .46794 L .454 .46642 L p .553 .399 .626 r
F P
0 g
s
.56589 .7208 m .58597 .7174 L .59086 .7198 L p .646 .533 .712 r
F P
0 g
s
.5062 .65985 m .50185 .66913 L .49827 .66962 L p .803 .62 .653 r
F P
0 g
s
.49827 .66962 m .5045 .65637 L .5062 .65985 L p .803 .62 .653 r
F P
0 g
s
.45978 .40015 m .44956 .37473 L .45296 .37776 L p .595 .519 .739 r
F P
0 g
s
.46196 .37378 m .45296 .37776 L .44956 .37473 L p .594 .519 .739 r
F P
0 g
s
.44956 .37473 m .46241 .36904 L .46196 .37378 L p .594 .519 .739 r
F P
0 g
s
.43798 .3477 m .44921 .3692 L .44956 .37473 L p .608 .554 .769 r
F P
0 g
s
.44956 .37473 m .43352 .34404 L .43798 .3477 L p .608 .554 .769 r
F P
0 g
s
.46241 .36904 m .44956 .37473 L .44921 .3692 L p .607 .554 .769 r
F P
0 g
s
.58382 .54242 m .59443 .54428 L .59677 .54509 L p .733 .36 .344 r
F P
0 g
s
.59677 .54509 m .58161 .54243 L .58382 .54242 L p .733 .36 .344 r
F P
0 g
s
.59677 .54509 m .59701 .54756 L .59906 .54753 L p .757 .434 .438 r
F P
0 g
s
.584 .54325 m .59461 .54511 L .59677 .54509 L p .733 .36 .344 r
F P
0 g
s
.59677 .54509 m .58161 .54243 L .584 .54325 L p .733 .36 .344 r
F P
0 g
s
.59701 .54756 m .59677 .54509 L .59461 .54511 L p .764 .439 .436 r
F P
0 g
s
.49381 .64452 m .50327 .65304 L .5045 .65637 L p .859 .662 .635 r
F P
0 g
s
.5045 .65637 m .49097 .64419 L .49381 .64452 L p .859 .662 .635 r
F P
0 g
s
.49706 .6659 m .50143 .65662 L .5045 .65637 L p .842 .67 .669 r
F P
0 g
s
.5045 .65637 m .49827 .66962 L .49706 .6659 L p .842 .67 .669 r
F P
0 g
s
.49097 .64419 m .5045 .65637 L .50143 .65662 L p .842 .671 .67 r
F P
0 g
s
.60366 .6349 m .60361 .63561 L .60209 .63712 L p .148 0 .305 r
F P
0 g
s
.46585 .42175 m .45978 .40015 L .46252 .40271 L p .584 .486 .709 r
F P
0 g
s
.47106 .39935 m .46252 .40271 L .45978 .40015 L p .584 .486 .709 r
F P
0 g
s
.45978 .40015 m .47197 .39534 L .47106 .39935 L p .584 .486 .709 r
F P
0 g
s
.45978 .40015 m .46585 .42175 L .46273 .41942 L p .554 .467 .711 r
F P
0 g
s
.45296 .37776 m .46012 .39556 L .45978 .40015 L p .595 .519 .739 r
F P
0 g
s
.47197 .39534 m .45978 .40015 L .46012 .39556 L p .596 .519 .739 r
F P
0 g
s
.62192 .38298 m .6277 .36938 L .62651 .36438 L p .859 .745 .736 r
F P
0 g
s
.61419 .56654 m .61306 .55854 L .61104 .55674 L p .819 .615 .628 r
F P
0 g
s
.65237 .50965 m .66324 .51292 L .66522 .51581 L p .61 .579 .794 r
F P
0 g
s
.61212 .60276 m .61461 .6007 L .61543 .59798 L p .982 .904 .651 r
F P
0 g
s
.61543 .59798 m .61188 .60092 L .61212 .60276 L p .982 .904 .651 r
F P
0 g
s
.61423 .58524 m .61467 .59606 L .61543 .59798 L p .965 .808 .636 r
F P
0 g
s
.61543 .59798 m .61481 .58253 L .61423 .58524 L p .965 .808 .636 r
F P
0 g
s
.61188 .60092 m .61543 .59798 L .61467 .59606 L p .981 .802 .588 r
F P
0 g
s
.60207 .63774 m .60208 .63732 L .60361 .63561 L p .175 0 .338 r
F P
0 g
s
.44898 .47493 m .44715 .47887 L .44562 .47811 L p .454 .253 .516 r
F P
0 g
s
.64836 .33718 m .66528 .31374 L .66533 .30533 L p .803 .756 .809 r
F P
0 g
s
.66533 .30533 m .64112 .33889 L .64836 .33718 L p .803 .756 .809 r
F P
0 g
s
.51296 .68035 m .50001 .67367 L .49827 .66962 L p .791 .636 .69 r
F P
0 g
s
.623 .41605 m .61462 .40946 L .61249 .40961 L p .909 .711 .622 r
F P
0 g
s
.63068 .44951 m .63044 .44879 L .62969 .44721 L p .78 .426 0 r
F P
0 g
s
.62598 .43932 m .62969 .44721 L .63044 .44879 L p .773 .418 0 r
F P
0 g
s
.63044 .44879 m .62515 .43751 L .62598 .43932 L p .773 .418 0 r
F P
0 g
s
.62952 .44658 m .62963 .44701 L .63044 .44879 L p .849 .508 0 r
F P
0 g
s
.62515 .43751 m .63044 .44879 L .62963 .44701 L p .84 .497 0 r
F P
0 g
s
.44484 .47971 m .44531 .47883 L .44715 .47887 L p .451 .239 .498 r
F P
0 g
s
.58243 .67349 m .58364 .68136 L .58134 .68422 L p .544 .398 .634 r
F P
0 g
s
.59521 .65153 m .59566 .65522 L .59418 .65767 L p .318 .165 .509 r
F P
0 g
s
.41284 .50374 m .40451 .50819 L .4022 .50904 L p .043 0 0 r
F P
0 g
s
.66664 .76949 m .6925 .79844 L .69273 .80787 L p .584 .609 .843 r
F P
0 g
s
.69273 .80787 m .65584 .76662 L .66664 .76949 L p .584 .609 .843 r
F P
0 g
s
.73356 .78301 m .69273 .80787 L .6925 .79844 L p .584 .609 .843 r
F P
0 g
s
.7369 .79435 m .70825 .81163 L .69273 .80787 L p .599 .647 .869 r
F P
0 g
s
.69273 .80787 m .73356 .78301 L .7369 .79435 L p .599 .647 .869 r
F P
0 g
s
.609 .62112 m .60366 .6349 L .6045 .63254 L p 0 0 .032 r
F P
0 g
s
.60819 .6233 m .60445 .63294 L .60366 .6349 L p 0 0 .125 r
F P
0 g
s
.60366 .6349 m .609 .62112 L .60819 .6233 L p 0 0 .125 r
F P
0 g
s
.60361 .63561 m .60366 .6349 L .60445 .63294 L p 0 0 .164 r
F P
0 g
s
.44715 .47887 m .44648 .48013 L .44484 .47971 L p .451 .239 .498 r
F P
0 g
s
.61104 .55674 m .61267 .56818 L .61419 .56654 L p .819 .615 .628 r
F P
0 g
s
.60157 .55799 m .60979 .55848 L .61104 .55674 L p .821 .595 .596 r
F P
0 g
s
.61104 .55674 m .59931 .55603 L .60157 .55799 L p .821 .595 .596 r
F P
0 g
s
.61267 .56818 m .61104 .55674 L .60979 .55848 L p .848 .635 .615 r
F P
0 g
s
.59931 .55603 m .61104 .55674 L .60909 .55546 L p .816 .563 .555 r
F P
0 g
s
.44405 .48113 m .44465 .4801 L .44648 .48013 L p .449 .229 .486 r
F P
0 g
s
.60361 .63561 m .6036 .63621 L .60207 .63774 L p .175 0 .338 r
F P
0 g
s
.6087 .6208 m .60947 .61877 L .61049 .61629 L p 0 0 0 r
F P
0 g
s
.44648 .48013 m .44563 .48162 L .44405 .48113 L p .449 .229 .486 r
F P
0 g
s
.49802 .63711 m .49381 .64452 L .49097 .64419 L p .859 .663 .636 r
F P
0 g
s
.49097 .64419 m .49699 .63361 L .49802 .63711 L p .859 .663 .636 r
F P
0 g
s
.46012 .39556 m .46865 .39218 L .47197 .39534 L p .596 .519 .739 r
F P
0 g
s
.59461 .54511 m .59478 .54684 L .59701 .54756 L p .764 .439 .436 r
F P
0 g
s
.46607 .43825 m .46405 .42521 L .46585 .42175 L p .545 .437 .681 r
F P
0 g
s
.38672 .51444 m .4022 .50904 L .40019 .50964 L p .337 .813 .76 r
F P
0 g
s
.4022 .50904 m .38672 .51444 L .38891 .51415 L p .585 .938 .93 r
F P
0 g
s
.402 .50946 m .40019 .50964 L .4022 .50904 L p 0 0 0 r
F P
0 g
s
.4022 .50904 m .4048 .50878 L .402 .50946 L p 0 0 0 r
F P
0 g
s
.4048 .50878 m .4022 .50904 L .40451 .50819 L p 0 0 0 r
F P
0 g
s
.454 .46642 m .46496 .46752 L .46702 .46952 L p .553 .399 .626 r
F P
0 g
s
.4898 .62072 m .49635 .63035 L .49699 .63361 L p .909 .714 .627 r
F P
0 g
s
.49699 .63361 m .48761 .61985 L .4898 .62072 L p .909 .714 .627 r
F P
0 g
s
.49038 .64069 m .4946 .63328 L .49699 .63361 L p .892 .713 .652 r
F P
0 g
s
.49699 .63361 m .49097 .64419 L .49038 .64069 L p .892 .713 .652 r
F P
0 g
s
.48761 .61985 m .49699 .63361 L .4946 .63328 L p .892 .717 .658 r
F P
0 g
s
.64264 .47857 m .63832 .47523 L .63777 .47235 L p .396 .383 .728 r
F P
0 g
s
.62633 .44028 m .63002 .44815 L .63068 .44951 L p .721 .362 0 r
F P
0 g
s
.63068 .44951 m .62541 .43827 L .62633 .44028 L p .721 .362 0 r
F P
0 g
s
.62969 .44721 m .62986 .44772 L .63068 .44951 L p .78 .426 0 r
F P
0 g
s
.62541 .43827 m .63068 .44951 L .62986 .44772 L p .772 .418 0 r
F P
0 g
s
.60207 .63941 m .60207 .63812 L .6036 .63621 L p .182 0 .35 r
F P
0 g
s
.60909 .55546 m .60087 .55497 L .59931 .55603 L p .816 .563 .555 r
F P
0 g
s
.44164 .48487 m .44359 .48193 L .44563 .48162 L p .444 .208 .46 r
F P
0 g
s
.61115 .61352 m .61212 .60276 L .61188 .60092 L p .988 .896 .605 r
F P
0 g
s
.61188 .60092 m .61049 .61629 L .61115 .61352 L p .988 .896 .605 r
F P
0 g
s
.514 .70046 m .50899 .7162 L .50397 .71874 L p .741 .612 .715 r
F P
0 g
s
.50397 .71874 m .51114 .69625 L .514 .70046 L p .741 .612 .715 r
F P
0 g
s
.64381 .49014 m .65119 .49361 L .65257 .49653 L p .503 .503 .789 r
F P
0 g
s
.46252 .40271 m .46678 .41784 L .46585 .42175 L p .584 .486 .709 r
F P
0 g
s
.62942 .4462 m .62569 .43829 L .62496 .43688 L p .863 .525 .012 r
F P
0 g
s
.60939 .61918 m .6087 .6208 L p .60977 .61811 L 0 0 0 r
F P
0 g
s
.60939 .61918 m .60941 .61714 L p .60913 .61992 L .856 .74 .222 r
F P
0 g
s
.609 .62112 m .60824 .62289 L p .60917 .61989 L 0 0 0 r
F P
0 g
s
.60939 .61918 m .609 .62112 L p .60917 .61989 L 0 0 0 r
F P
0 g
s
.60824 .62289 m .60851 .62154 L .60939 .61918 L p 0 0 0 r
F P
0 g
s
.609 .62112 m .60904 .61888 L p .60894 .62157 L .791 .669 .119 r
F P
0 g
s
.609 .62112 m .60893 .62181 L .60814 .62379 L p 0 0 .086 r
F P
0 g
s
.60893 .62181 m .609 .62112 L p .60894 .62157 L .791 .669 .119 r
F P
0 g
s
.609 .62112 m .60939 .61918 L p .60913 .61992 L .856 .74 .222 r
F P
0 g
s
.61049 .61629 m .60939 .61918 L p .60977 .61811 L 0 0 0 r
F P
0 g
s
.61146 .60365 m .61048 .61441 L .61049 .61629 L p .955 .862 .448 r
F P
0 g
s
.61049 .61629 m .61188 .60092 L .61146 .60365 L p .955 .862 .448 r
F P
0 g
s
.60939 .61918 m .61049 .61629 L .61048 .61441 L p .93 .828 .375 r
F P
0 g
s
.44715 .47887 m .44898 .47493 L .45087 .47619 L p .564 .373 .58 r
F P
0 g
s
.46129 .47888 m .45087 .47619 L .44898 .47493 L p .563 .373 .582 r
F P
0 g
s
.44898 .47493 m .46387 .47877 L .46129 .47888 L p .563 .373 .582 r
F P
0 g
s
.45329 .46939 m .45162 .47429 L .44898 .47493 L p .557 .38 .596 r
F P
0 g
s
.46387 .47877 m .44898 .47493 L .45162 .47429 L p .559 .386 .603 r
F P
0 g
s
.62651 .36438 m .61824 .38383 L .62192 .38298 L p .859 .745 .736 r
F P
0 g
s
.60445 .63294 m .60442 .63344 L .60361 .63561 L p 0 0 .164 r
F P
0 g
s
.60893 .62181 m .60361 .63561 L .60442 .63344 L p 0 0 .123 r
F P
0 g
s
.60813 .62398 m .60441 .63363 L .60361 .63561 L p 0 0 .158 r
F P
0 g
s
.60361 .63561 m .60893 .62181 L .60813 .62398 L p 0 0 .158 r
F P
0 g
s
.6036 .63621 m .60361 .63561 L .60441 .63363 L p 0 0 .212 r
F P
0 g
s
.64394 .47711 m .63777 .47235 L .63849 .47108 L p .275 .373 .783 r
F P
0 g
s
.63776 .46181 m .63849 .47108 L .63777 .47235 L p .262 .356 .772 r
F P
0 g
s
.63777 .47235 m .63672 .45912 L .63776 .46181 L p .262 .356 .772 r
F P
0 g
s
.63777 .47235 m .64394 .47711 L .64264 .47857 L p .396 .383 .728 r
F P
0 g
s
.63672 .45912 m .63777 .47235 L .63707 .46974 L p .102 .219 .701 r
F P
0 g
s
.38538 .31009 m .39984 .30055 L .40898 .30561 L p .616 .615 .827 r
F P
0 g
s
.6045 .63254 m .60824 .62289 L .609 .62112 L p 0 0 .032 r
F P
0 g
s
.44921 .3692 m .4582 .36521 L .46241 .36904 L p .607 .554 .769 r
F P
0 g
s
.62262 .41876 m .6221 .42385 L .62373 .42628 L p .926 .677 .543 r
F P
0 g
s
.68168 .52137 m .66781 .51844 L .66522 .51581 L p .639 .612 .807 r
F P
0 g
s
.44388 .76874 m .45786 .74301 L .46486 .73913 L p .774 .717 .799 r
F P
0 g
s
.49389 .61448 m .4898 .62072 L .48761 .61985 L p .908 .718 .634 r
F P
0 g
s
.48761 .61985 m .49347 .61094 L .49389 .61448 L p .908 .718 .634 r
F P
0 g
s
.48911 .59761 m .49337 .60775 L .49347 .61094 L p .938 .768 .645 r
F P
0 g
s
.49347 .61094 m .48739 .59644 L .48911 .59761 L p .938 .768 .645 r
F P
0 g
s
.48748 .61658 m .49159 .61034 L .49347 .61094 L p .93 .758 .648 r
F P
0 g
s
.49347 .61094 m .48761 .61985 L .48748 .61658 L p .93 .758 .648 r
F P
0 g
s
.48739 .59644 m .49347 .61094 L .49159 .61034 L p .928 .767 .662 r
F P
0 g
s
.61467 .59606 m .61218 .59811 L .61188 .60092 L p .981 .802 .588 r
F P
0 g
s
.49429 .68605 m .50902 .6923 L .51114 .69625 L p .791 .636 .69 r
F P
0 g
s
.51114 .69625 m .49009 .68733 L .49429 .68605 L p .791 .636 .69 r
F P
0 g
s
.50163 .71407 m .50665 .69831 L .51114 .69625 L p .778 .653 .724 r
F P
0 g
s
.51114 .69625 m .50397 .71874 L .50163 .71407 L p .778 .653 .724 r
F P
0 g
s
.49009 .68733 m .51114 .69625 L .50665 .69831 L p .778 .653 .724 r
F P
0 g
s
.59323 .66538 m .59207 .65995 L .59418 .65767 L p .516 .34 .581 r
F P
0 g
s
.44563 .48162 m .44284 .48582 L .44164 .48487 L p .444 .208 .46 r
F P
0 g
s
.61591 .58025 m .61441 .57021 L .61267 .56818 L p .865 .682 .654 r
F P
0 g
s
.58085 .69767 m .57845 .68704 L .58134 .68422 L p .639 .497 .674 r
F P
0 g
s
.61267 .56818 m .61481 .58253 L .61591 .58025 L p .865 .682 .654 r
F P
0 g
s
.46876 .44039 m .46585 .42175 L .46819 .42399 L p .577 .459 .682 r
F P
0 g
s
.4768 .4211 m .46819 .42399 L .46585 .42175 L p .575 .459 .683 r
F P
0 g
s
.46585 .42175 m .47815 .41761 L .4768 .4211 L p .575 .459 .683 r
F P
0 g
s
.46585 .42175 m .46876 .44039 L .46607 .43825 L p .545 .437 .681 r
F P
0 g
s
.47815 .41761 m .46585 .42175 L .46678 .41784 L p .585 .487 .709 r
F P
0 g
s
.36993 .51899 m .38379 .51592 L .38672 .51444 L p .643 .905 .983 r
F P
0 g
s
.62963 .44701 m .62592 .43912 L .62515 .43751 L p .84 .497 0 r
F P
0 g
s
.48437 .70806 m .50163 .71407 L .50397 .71874 L p .778 .653 .724 r
F P
0 g
s
.50397 .71874 m .47932 .71018 L .48437 .70806 L p .778 .653 .724 r
F P
0 g
s
.47932 .71018 m .50397 .71874 L .4985 .72182 L p .765 .67 .758 r
F P
0 g
s
.60441 .63363 m .60439 .63405 L .6036 .63621 L p 0 0 .212 r
F P
0 g
s
.60889 .62239 m .6036 .63621 L .60439 .63405 L p 0 0 .157 r
F P
0 g
s
.6036 .63621 m .6036 .63805 L .60207 .63941 L p .182 0 .35 r
F P
0 g
s
.60809 .62474 m .60439 .63442 L .6036 .63621 L p 0 0 .201 r
F P
0 g
s
.6036 .63621 m .60889 .62239 L .60809 .62474 L p 0 0 .201 r
F P
0 g
s
.6036 .63805 m .6036 .63621 L .60439 .63442 L p 0 0 .237 r
F P
0 g
s
.50143 .65662 m .49195 .6481 L .49097 .64419 L p .842 .671 .67 r
F P
0 g
s
.60979 .55848 m .61092 .56649 L .61267 .56818 L p .848 .635 .615 r
F P
0 g
s
.63319 .45641 m .63191 .4541 L .63158 .4516 L p 0 .057 .591 r
F P
0 g
s
.63707 .46974 m .63634 .46048 L .63672 .45912 L p .102 .219 .701 r
F P
0 g
s
.44648 .48013 m .44715 .47887 L .44912 .47985 L p .567 .369 .572 r
F P
0 g
s
.45893 .48342 m .44912 .47985 L .44715 .47887 L p .567 .368 .571 r
F P
0 g
s
.44715 .47887 m .46116 .48398 L .45893 .48342 L p .567 .368 .571 r
F P
0 g
s
.45087 .47619 m .44958 .47895 L .44715 .47887 L p .564 .373 .58 r
F P
0 g
s
.46116 .48398 m .44715 .47887 L .44958 .47895 L p .564 .375 .583 r
F P
0 g
s
.61824 .38383 m .62651 .36438 L .62192 .36595 L p .81 .683 .723 r
F P
0 g
s
.60499 .35885 m .62192 .36595 L .62651 .36438 L p .81 .682 .723 r
F P
0 g
s
.62651 .36438 m .60233 .35422 L .60499 .35885 L p .81 .682 .723 r
F P
0 g
s
.63496 .34093 m .62472 .3588 L .62651 .36438 L p .794 .7 .761 r
F P
0 g
s
.62651 .36438 m .64112 .33889 L .63496 .34093 L p .794 .7 .761 r
F P
0 g
s
.60233 .35422 m .62651 .36438 L .62472 .3588 L p .794 .7 .761 r
F P
0 g
s
.6247 .43249 m .62458 .42885 L .62373 .42628 L p .979 .707 .313 r
F P
0 g
s
.68504 .51999 m .66522 .51581 L .6684 .51423 L p .629 .624 .827 r
F P
0 g
s
.66967 .50397 m .6684 .51423 L .66522 .51581 L p .622 .603 .811 r
F P
0 g
s
.66522 .51581 m .66702 .50116 L .66967 .50397 L p .622 .603 .811 r
F P
0 g
s
.66522 .51581 m .68504 .51999 L .68168 .52137 L p .639 .612 .807 r
F P
0 g
s
.66702 .50116 m .66522 .51581 L .66324 .51292 L p .585 .57 .803 r
F P
0 g
s
.43694 .49058 m .44062 .48634 L .44284 .48582 L p .43 .158 .398 r
F P
0 g
s
.38015 .80011 m .40592 .76907 L .41518 .76428 L p .769 .753 .838 r
F P
0 g
s
.49176 .57509 m .49442 .5851 L .49394 .5882 L p .925 .806 .71 r
F P
0 g
s
.49394 .5882 m .49014 .5739 L .49176 .57509 L p .925 .806 .71 r
F P
0 g
s
.48769 .59344 m .49228 .58767 L .49394 .5882 L p .941 .797 .672 r
F P
0 g
s
.49394 .5882 m .48739 .59644 L .48769 .59344 L p .941 .797 .672 r
F P
0 g
s
.49014 .5739 m .49394 .5882 L .49228 .58767 L p .937 .81 .694 r
F P
0 g
s
.48739 .59644 m .49394 .5882 L .4937 .59184 L p .933 .776 .664 r
F P
0 g
s
.60087 .55497 m .59926 .54904 L .59701 .54756 L p .792 .517 .521 r
F P
0 g
s
.60494 .64651 m .59418 .65767 L .59566 .65522 L p .313 .158 .505 r
F P
0 g
s
.59418 .65767 m .59584 .66543 L .59323 .66538 L p .516 .34 .581 r
F P
0 g
s
.60363 .64932 m .59609 .65714 L .59418 .65767 L p .377 .247 .575 r
F P
0 g
s
.59418 .65767 m .60494 .64651 L .60363 .64932 L p .377 .247 .575 r
F P
0 g
s
.59584 .66543 m .59418 .65767 L .59609 .65714 L p .378 .251 .579 r
F P
0 g
s
.4937 .59184 m .48911 .59761 L .48739 .59644 L p .933 .776 .664 r
F P
0 g
s
.59923 .67609 m .58134 .68422 L .58364 .68136 L p .543 .397 .633 r
F P
0 g
s
.58134 .68422 m .58479 .69942 L .58085 .69767 L p .639 .497 .674 r
F P
0 g
s
.59725 .67954 m .58473 .68523 L .58134 .68422 L p .566 .449 .679 r
F P
0 g
s
.58134 .68422 m .59923 .67609 L .59725 .67954 L p .566 .449 .679 r
F P
0 g
s
.58479 .69942 m .58134 .68422 L .58473 .68523 L p .566 .45 .68 r
F P
0 g
s
.42698 .34009 m .40981 .31322 L .40898 .30561 L p .6 .58 .803 r
F P
0 g
s
.40898 .30561 m .43352 .34404 L .42698 .34009 L p .6 .58 .803 r
F P
0 g
s
.59701 .54756 m .59931 .55603 L .60087 .55497 L p .792 .517 .521 r
F P
0 g
s
.58571 .54727 m .59559 .54868 L .59701 .54756 L p .782 .475 .468 r
F P
0 g
s
.59701 .54756 m .5829 .54555 L .58571 .54727 L p .782 .475 .468 r
F P
0 g
s
.59931 .55603 m .59701 .54756 L .59559 .54868 L p .815 .53 .507 r
F P
0 g
s
.5829 .54555 m .59701 .54756 L .59478 .54684 L p .753 .372 .333 r
F P
0 g
s
.59457 .74338 m .58755 .72465 L .59086 .7198 L p .652 .569 .749 r
F P
0 g
s
.59086 .7198 m .60089 .74656 L .59457 .74338 L p .652 .569 .749 r
F P
0 g
s
.44563 .48162 m .44648 .48013 L .44836 .4812 L p .568 .365 .565 r
F P
0 g
s
.45791 .48503 m .44836 .4812 L .44648 .48013 L p .569 .365 .564 r
F P
0 g
s
.44648 .48013 m .46013 .4856 L .45791 .48503 L p .569 .365 .564 r
F P
0 g
s
.44912 .47985 m .44865 .48074 L .44648 .48013 L p .567 .369 .572 r
F P
0 g
s
.46013 .4856 m .44648 .48013 L .44865 .48074 L p .567 .368 .57 r
F P
0 g
s
.40451 .50819 m .40634 .508 L .4048 .50878 L p 0 0 0 r
F P
0 g
s
.61679 .39813 m .61972 .38778 L .61824 .38383 L p .886 .731 .685 r
F P
0 g
s
.60442 .63344 m .60814 .62379 L .60893 .62181 L p 0 0 .123 r
F P
0 g
s
.45162 .47429 m .46205 .47697 L .46387 .47877 L p .559 .386 .603 r
F P
0 g
s
.56648 .53931 m .57902 .54151 L .58161 .54243 L p .647 .158 .077 r
F P
0 g
s
.46678 .41784 m .47538 .41494 L .47815 .41761 L p .585 .487 .709 r
F P
0 g
s
.62986 .44772 m .62617 .43985 L .62541 .43827 L p .772 .418 0 r
F P
0 g
s
.59478 .54684 m .58491 .54543 L .5829 .54555 L p .753 .372 .333 r
F P
0 g
s
.66324 .51292 m .6645 .50267 L .66702 .50116 L p .585 .57 .803 r
F P
0 g
s
.4985 .72182 m .48124 .71584 L .47932 .71018 L p .765 .67 .758 r
F P
0 g
s
.44284 .48582 m .44563 .48162 L .44706 .48319 L p .569 .356 .552 r
F P
0 g
s
.45628 .48731 m .44706 .48319 L .44563 .48162 L p .574 .356 .547 r
F P
0 g
s
.44563 .48162 m .4588 .4875 L .45628 .48731 L p .574 .356 .547 r
F P
0 g
s
.44836 .4812 m .44776 .48225 L .44563 .48162 L p .568 .365 .565 r
F P
0 g
s
.4588 .4875 m .44563 .48162 L .44776 .48225 L p .569 .364 .563 r
F P
0 g
s
.61048 .61441 m .60971 .61643 L .60939 .61918 L p .93 .828 .375 r
F P
0 g
s
.60614 .5713 m .61196 .57058 L .61267 .56818 L p .882 .679 .623 r
F P
0 g
s
.61267 .56818 m .60434 .56921 L .60614 .5713 L p .882 .679 .623 r
F P
0 g
s
.61481 .58253 m .61267 .56818 L .61196 .57058 L p .906 .709 .625 r
F P
0 g
s
.60434 .56921 m .61267 .56818 L .61092 .56649 L p .869 .621 .561 r
F P
0 g
s
.63002 .44815 m .63065 .44962 L .63158 .4516 L p .689 .326 0 r
F P
0 g
s
.50665 .69831 m .49191 .69207 L .49009 .68733 L p .778 .653 .724 r
F P
0 g
s
.61456 .33143 m .63496 .34093 L .64112 .33889 L p .794 .7 .761 r
F P
0 g
s
.64112 .33889 m .61199 .32528 L .61456 .33143 L p .794 .7 .761 r
F P
0 g
s
.6568 .30797 m .63985 .33149 L .64112 .33889 L p .776 .713 .793 r
F P
0 g
s
.64112 .33889 m .66533 .30533 L .6568 .30797 L p .776 .713 .793 r
F P
0 g
s
.61199 .32528 m .64112 .33889 L .63985 .33149 L p .776 .713 .793 r
F P
0 g
s
.58364 .68136 m .59615 .67567 L .59923 .67609 L p .543 .397 .633 r
F P
0 g
s
.44815 .34289 m .43798 .3477 L .43352 .34404 L p .608 .554 .769 r
F P
0 g
s
.43352 .34404 m .44805 .33715 L .44815 .34289 L p .608 .554 .769 r
F P
0 g
s
.41506 .31022 m .43224 .33714 L .43352 .34404 L p .62 .588 .796 r
F P
0 g
s
.43352 .34404 m .40898 .30561 L .41506 .31022 L p .62 .588 .796 r
F P
0 g
s
.44805 .33715 m .43352 .34404 L .43224 .33714 L p .62 .588 .796 r
F P
0 g
s
.61043 .58683 m .61423 .58524 L .61481 .58253 L p .945 .782 .649 r
F P
0 g
s
.61481 .58253 m .60938 .5848 L .61043 .58683 L p .945 .782 .649 r
F P
0 g
s
.61196 .57058 m .61346 .58063 L .61481 .58253 L p .906 .709 .625 r
F P
0 g
s
.60938 .5848 m .61481 .58253 L .61346 .58063 L p .926 .701 .578 r
F P
0 g
s
.63341 .45491 m .63158 .4516 L .63105 .45044 L p 0 0 .388 r
F P
0 g
s
.62622 .44048 m .63158 .4516 L .63065 .44962 L p .731 .368 0 r
F P
0 g
s
.6273 .44266 m .63105 .45044 L .63158 .4516 L p 0 0 .382 r
F P
0 g
s
.63065 .44962 m .6269 .44183 L .62622 .44048 L p .731 .368 0 r
F P
0 g
s
.63158 .4516 m .62622 .44048 L .6273 .44266 L p 0 0 .382 r
F P
0 g
s
.63158 .4516 m .63341 .45491 L .63319 .45641 L p 0 .057 .591 r
F P
0 g
s
.59566 .65522 m .6032 .64741 L .60494 .64651 L p .313 .158 .505 r
F P
0 g
s
.59646 .72215 m .60348 .74091 L .60089 .74656 L p .6 .541 .76 r
F P
0 g
s
.60089 .74656 m .59086 .7198 L .59646 .72215 L p .6 .541 .76 r
F P
0 g
s
.63134 .73451 m .60089 .74656 L .60348 .74091 L p .6 .541 .76 r
F P
0 g
s
.62976 .74137 m .60844 .74978 L .60089 .74656 L p .613 .582 .795 r
F P
0 g
s
.60089 .74656 m .63134 .73451 L .62976 .74137 L p .613 .582 .795 r
F P
0 g
s
.58161 .54243 m .56368 .53928 L .56648 .53931 L p .647 .158 .077 r
F P
0 g
s
.58491 .54543 m .584 .54325 L .58161 .54243 L p .721 .307 .262 r
F P
0 g
s
.58161 .54243 m .5829 .54555 L .58491 .54543 L p .721 .307 .262 r
F P
0 g
s
.56697 .54031 m .57952 .54252 L .58161 .54243 L p .647 .158 .077 r
F P
0 g
s
.58161 .54243 m .56369 .53928 L .56697 .54031 L p .647 .158 .077 r
F P
0 g
s
.5829 .54555 m .58161 .54243 L .57952 .54252 L p .737 .316 .247 r
F P
0 g
s
.60439 .63405 m .6081 .62438 L .60889 .62239 L p 0 0 .157 r
F P
0 g
s
.60231 .64253 m .6021 .6402 L .6036 .63805 L p .244 .062 .424 r
F P
0 g
s
.46819 .42399 m .47023 .43704 L .46876 .44039 L p .577 .459 .682 r
F P
0 g
s
.40019 .50964 m .38935 .51342 L .38672 .51444 L p .337 .813 .76 r
F P
0 g
s
.4946 .63328 m .48803 .62366 L .48761 .61985 L p .892 .717 .658 r
F P
0 g
s
.49845 .56869 m .49176 .57509 L .49014 .5739 L p .912 .816 .739 r
F P
0 g
s
.49014 .5739 m .49971 .56476 L .49845 .56869 L p .912 .816 .739 r
F P
0 g
s
.44284 .48582 m .43757 .49189 L .43694 .49058 L p .43 .158 .398 r
F P
0 g
s
.6239 .43148 m .62373 .42628 L .62211 .4258 L p .933 .642 .467 r
F P
0 g
s
.61421 .41978 m .62211 .4258 L .62373 .42628 L p .932 .637 .46 r
F P
0 g
s
.62373 .42628 m .61244 .41768 L .61421 .41978 L p .932 .637 .46 r
F P
0 g
s
.62373 .42628 m .6239 .43148 L .6247 .43249 L p .979 .707 .313 r
F P
0 g
s
.61244 .41768 m .62373 .42628 L .6221 .42385 L p .926 .677 .543 r
F P
0 g
s
.44958 .47895 m .45939 .48252 L .46116 .48398 L p .564 .375 .583 r
F P
0 g
s
.50016 .5537 m .50188 .56139 L .49971 .56476 L p .792 .769 .832 r
F P
0 g
s
.49971 .56476 m .49724 .55379 L .50016 .5537 L p .792 .769 .832 r
F P
0 g
s
.49116 .57136 m .49786 .56497 L .49971 .56476 L p .913 .817 .739 r
F P
0 g
s
.49971 .56476 m .49014 .5739 L .49116 .57136 L p .913 .817 .739 r
F P
0 g
s
.49724 .55379 m .49971 .56476 L .49786 .56497 L p .91 .83 .754 r
F P
0 g
s
.60439 .63442 m .60439 .63571 L .6036 .63805 L p 0 0 .237 r
F P
0 g
s
.46664 .45439 m .46647 .44315 L .46876 .44039 L p .544 .414 .654 r
F P
0 g
s
.63849 .47108 m .64282 .47441 L .64394 .47711 L p .275 .373 .783 r
F P
0 g
s
.61092 .56649 m .6051 .5672 L .60434 .56921 L p .869 .621 .561 r
F P
0 g
s
.43757 .49189 m .44284 .48582 L .44358 .48776 L p .565 .329 .517 r
F P
0 g
s
.45168 .49249 m .44358 .48776 L .44284 .48582 L p .583 .338 .511 r
F P
0 g
s
.44284 .48582 m .45441 .49258 L .45168 .49249 L p .583 .338 .511 r
F P
0 g
s
.44706 .48319 m .44511 .48614 L .44284 .48582 L p .569 .356 .552 r
F P
0 g
s
.45441 .49258 m .44284 .48582 L .44511 .48614 L p .569 .35 .543 r
F P
0 g
s
.3669 .51883 m .38672 .51444 L .38392 .51454 L p .562 .908 .972 r
F P
0 g
s
.38492 .51278 m .38392 .51454 L .38672 .51444 L p .433 .86 .94 r
F P
0 g
s
.38672 .51444 m .38817 .51192 L .38492 .51278 L p .433 .86 .94 r
F P
0 g
s
.38672 .51444 m .3669 .51883 L .36993 .51899 L p .643 .905 .983 r
F P
0 g
s
.38817 .51192 m .38672 .51444 L .38935 .51342 L p .477 .893 .911 r
F P
0 g
s
.44865 .48074 m .4582 .48456 L .46013 .4856 L p .567 .368 .57 r
F P
0 g
s
.6684 .51423 m .68229 .51715 L .68504 .51999 L p .629 .624 .827 r
F P
0 g
s
.61404 .39862 m .61824 .38383 L .61469 .385 L p .824 .66 .68 r
F P
0 g
s
.60015 .37956 m .61469 .385 L .61824 .38383 L p .823 .66 .68 r
F P
0 g
s
.61824 .38383 m .59747 .37604 L .60015 .37956 L p .823 .66 .68 r
F P
0 g
s
.61824 .38383 m .61404 .39862 L .61679 .39813 L p .886 .731 .685 r
F P
0 g
s
.62192 .36595 m .61612 .37958 L .61824 .38383 L p .81 .683 .723 r
F P
0 g
s
.59747 .37604 m .61824 .38383 L .61612 .37958 L p .811 .683 .723 r
F P
0 g
s
.70609 .5251 m .68847 .52257 L .68504 .51999 L p .648 .653 .841 r
F P
0 g
s
.42952 .49704 m .43521 .49245 L .43757 .49189 L p .395 .06 .276 r
F P
0 g
s
.60884 .62419 m .6036 .63805 L .60439 .63571 L p 0 0 .197 r
F P
0 g
s
.6036 .63805 m .60391 .64138 L .60231 .64253 L p .244 .062 .424 r
F P
0 g
s
.60809 .62677 m .60443 .63647 L .6036 .63805 L p 0 0 .317 r
F P
0 g
s
.6036 .63805 m .60884 .62419 L .60809 .62677 L p 0 0 .317 r
F P
0 g
s
.60391 .64138 m .6036 .63805 L .60443 .63647 L p 0 0 .346 r
F P
0 g
s
.59559 .54868 m .5972 .55461 L .59931 .55603 L p .815 .53 .507 r
F P
0 g
s
.49159 .61034 m .48733 .60019 L .48739 .59644 L p .928 .767 .662 r
F P
0 g
s
.44776 .48225 m .45698 .48636 L .4588 .4875 L p .569 .364 .563 r
F P
0 g
s
.61346 .58063 m .60966 .58221 L .60938 .5848 L p .926 .701 .578 r
F P
0 g
s
.58473 .68523 m .58714 .69587 L .58479 .69942 L p .566 .45 .68 r
F P
0 g
s
.58597 .7174 m .58172 .70314 L .58479 .69942 L p .646 .533 .712 r
F P
0 g
s
.62472 .3588 m .6078 .35166 L .60233 .35422 L p .794 .7 .761 r
F P
0 g
s
.34568 .52291 m .36332 .52052 L .3669 .51883 L p .658 .854 .975 r
F P
0 g
s
.6645 .50267 m .65439 .49942 L .65257 .49653 L p .575 .546 .785 r
F P
0 g
s
.59609 .65714 m .59726 .66257 L .59584 .66543 L p .378 .251 .579 r
F P
0 g
s
.6221 .42385 m .6142 .41782 L .61244 .41768 L p .926 .677 .543 r
F P
0 g
s
.469 .45646 m .46876 .44039 L .47088 .44243 L p .577 .441 .658 r
F P
0 g
s
.48009 .44015 m .47088 .44243 L .46876 .44039 L p .574 .441 .662 r
F P
0 g
s
.46876 .44039 m .48192 .43714 L .48009 .44015 L p .574 .441 .662 r
F P
0 g
s
.46876 .44039 m .469 .45646 L .46664 .45439 L p .544 .414 .654 r
F P
0 g
s
.48192 .43714 m .46876 .44039 L .47023 .43704 L p .58 .462 .683 r
F P
0 g
s
.49228 .58767 m .48962 .57766 L .49014 .5739 L p .937 .81 .694 r
F P
0 g
s
.66702 .50116 m .65257 .49653 L .65477 .49502 L p .55 .565 .822 r
F P
0 g
s
.65532 .48479 m .65477 .49502 L .65257 .49653 L p .54 .545 .809 r
F P
0 g
s
.65257 .49653 m .65336 .48192 L .65532 .48479 L p .54 .545 .809 r
F P
0 g
s
.65257 .49653 m .66702 .50116 L .6645 .50267 L p .575 .546 .785 r
F P
0 g
s
.65336 .48192 m .65257 .49653 L .65119 .49361 L p .475 .488 .791 r
F P
0 g
s
.57952 .54252 m .58042 .54471 L .5829 .54555 L p .737 .316 .247 r
F P
0 g
s
.50001 .67367 m .49429 .68605 L .49009 .68733 L p .791 .636 .69 r
F P
0 g
s
.49009 .68733 m .49827 .66962 L .50001 .67367 L p .791 .636 .69 r
F P
0 g
s
.58479 .69942 m .59086 .7198 L .58597 .7174 L p .646 .533 .712 r
F P
0 g
s
.71023 .52361 m .68504 .51999 L .68895 .51825 L p .641 .662 .854 r
F P
0 g
s
.68975 .50782 m .68895 .51825 L .68504 .51999 L p .637 .644 .841 r
F P
0 g
s
.68504 .51999 m .68616 .50508 L .68975 .50782 L p .637 .644 .841 r
F P
0 g
s
.68504 .51999 m .71023 .52361 L .70609 .5251 L p .648 .653 .841 r
F P
0 g
s
.68616 .50508 m .68504 .51999 L .68229 .51715 L p .608 .619 .837 r
F P
0 g
s
.60439 .63571 m .60805 .626 L .60884 .62419 L p 0 0 .197 r
F P
0 g
s
.44511 .48614 m .45321 .49086 L .45441 .49258 L p .569 .35 .543 r
F P
0 g
s
.65119 .49361 m .65174 .48338 L .65336 .48192 L p .475 .488 .791 r
F P
0 g
s
.47023 .43704 m .47943 .43476 L .48192 .43714 L p .58 .462 .683 r
F P
0 g
s
.60531 .69057 m .58479 .69942 L .58714 .69587 L p .565 .449 .68 r
F P
0 g
s
.60343 .69486 m .58906 .70105 L .58479 .69942 L p .584 .496 .721 r
F P
0 g
s
.58479 .69942 m .60531 .69057 L .60343 .69486 L p .584 .496 .721 r
F P
0 g
s
.59086 .7198 m .58479 .69942 L .58906 .70105 L p .584 .496 .721 r
F P
0 g
s
.63105 .45044 m .63233 .45276 L .63341 .45491 L p 0 0 .388 r
F P
0 g
s
.38935 .51342 m .39037 .51166 L .38817 .51192 L p .477 .893 .911 r
F P
0 g
s
.46865 .39218 m .46196 .37378 L .46241 .36904 L p .595 .519 .739 r
F P
0 g
s
.46241 .36904 m .47197 .39534 L .46865 .39218 L p .595 .519 .739 r
F P
0 g
s
.48648 .6582 m .49706 .6659 L .49827 .66962 L p .841 .669 .67 r
F P
0 g
s
.49827 .66962 m .48314 .65862 L .48648 .6582 L p .841 .669 .67 r
F P
0 g
s
.48891 .68309 m .49464 .67069 L .49827 .66962 L p .825 .679 .703 r
F P
0 g
s
.49827 .66962 m .49009 .68733 L .48891 .68309 L p .825 .679 .703 r
F P
0 g
s
.48314 .65862 m .49827 .66962 L .49464 .67069 L p .825 .68 .703 r
F P
0 g
s
.61612 .37958 m .60159 .37411 L .59747 .37604 L p .811 .683 .723 r
F P
0 g
s
.42943 .49845 m .43757 .49189 L .43746 .49383 L p .548 .268 .442 r
F P
0 g
s
.44365 .49874 m .43746 .49383 L .43757 .49189 L p .587 .3 .448 r
F P
0 g
s
.43757 .49189 m .44642 .4989 L .44365 .49874 L p .587 .3 .448 r
F P
0 g
s
.43757 .49189 m .42943 .49845 L .42952 .49704 L p .395 .06 .276 r
F P
0 g
s
.44358 .48776 m .43989 .49201 L .43757 .49189 L p .565 .329 .517 r
F P
0 g
s
.44642 .4989 m .43757 .49189 L .43989 .49201 L p .562 .309 .49 r
F P
0 g
s
.62521 .43613 m .6248 .43373 L .6239 .43148 L p .917 .599 .123 r
F P
0 g
s
.47538 .41494 m .47106 .39935 L .47197 .39534 L p .584 .487 .71 r
F P
0 g
s
.62211 .4258 m .62223 .42944 L .6239 .43148 L p .933 .642 .467 r
F P
0 g
s
.49786 .56497 m .49613 .55729 L .49724 .55379 L p .91 .83 .754 r
F P
0 g
s
.43224 .33714 m .44241 .3323 L .44805 .33715 L p .62 .588 .796 r
F P
0 g
s
.73745 .5283 m .71472 .5262 L .71023 .52361 L p .653 .685 .868 r
F P
0 g
s
.63634 .46048 m .63402 .45753 L .63341 .45491 L p .077 .192 .682 r
F P
0 g
s
.60348 .74091 m .62479 .73245 L .63134 .73451 L p .6 .541 .76 r
F P
0 g
s
.61462 .40946 m .61571 .40177 L .61404 .39862 L p .909 .71 .621 r
F P
0 g
s
.67577 .30311 m .70295 .2718 L .70423 .26048 L p .776 .756 .834 r
F P
0 g
s
.70423 .26048 m .66533 .30533 L .67577 .30311 L p .776 .756 .834 r
F P
0 g
s
.60443 .63647 m .60464 .6388 L .60391 .64138 L p 0 0 .346 r
F P
0 g
s
.61011 .60362 m .60939 .61918 L .60971 .61643 L p .967 .856 .452 r
F P
0 g
s
.60992 .60624 m .60941 .61714 L .60939 .61918 L p .898 .786 .298 r
F P
0 g
s
.60939 .61918 m .61011 .60362 L .60992 .60624 L p .898 .786 .298 r
F P
0 g
s
.68229 .51715 m .68306 .50672 L .68616 .50508 L p .608 .619 .837 r
F P
0 g
s
.61469 .385 m .61175 .39536 L .61404 .39862 L p .824 .66 .68 r
F P
0 g
s
.47088 .44243 m .47105 .45368 L .469 .45646 L p .577 .441 .658 r
F P
0 g
s
.3669 .51883 m .34168 .52225 L .34568 .52291 L p .658 .854 .975 r
F P
0 g
s
.58906 .70105 m .59331 .71533 L .59086 .7198 L p .584 .496 .721 r
F P
0 g
s
.61538 .70964 m .59086 .7198 L .59331 .71533 L p .584 .496 .721 r
F P
0 g
s
.61363 .71506 m .59646 .72215 L .59086 .7198 L p .6 .541 .76 r
F P
0 g
s
.59086 .7198 m .61538 .70964 L .61363 .71506 L p .6 .541 .76 r
F P
0 g
s
.4582 .36521 m .44815 .34289 L .44805 .33715 L p .608 .554 .769 r
F P
0 g
s
.44805 .33715 m .46241 .36904 L .4582 .36521 L p .608 .554 .769 r
F P
0 g
s
.38392 .51454 m .37003 .51761 L .3669 .51883 L p .562 .908 .972 r
F P
0 g
s
.47815 .41761 m .47197 .39534 L .47409 .39825 L p .602 .498 .708 r
F P
0 g
s
.47962 .39619 m .47409 .39825 L .47197 .39534 L p .602 .498 .708 r
F P
0 g
s
.47197 .39534 m .47987 .39239 L .47962 .39619 L p .602 .498 .708 r
F P
0 g
s
.47197 .39534 m .47815 .41761 L .47538 .41494 L p .584 .487 .71 r
F P
0 g
s
.46506 .37252 m .47176 .39093 L .47197 .39534 L p .612 .529 .736 r
F P
0 g
s
.47197 .39534 m .46241 .36904 L .46506 .37252 L p .612 .529 .736 r
F P
0 g
s
.47987 .39239 m .47197 .39534 L .47176 .39093 L p .613 .53 .736 r
F P
0 g
s
.60971 .61643 m .61022 .60554 L .61011 .60362 L p .967 .856 .452 r
F P
0 g
s
.46496 .46752 m .46634 .45838 L .469 .45646 L p .549 .399 .63 r
F P
0 g
s
.59615 .67567 m .59379 .66821 L .59584 .66543 L p .543 .397 .632 r
F P
0 g
s
.58714 .69587 m .6015 .68967 L .60531 .69057 L p .565 .449 .68 r
F P
0 g
s
.41931 .50307 m .42697 .499 L .42943 .49845 L p .301 0 .045 r
F P
0 g
s
.34168 .52225 m .3669 .51883 L .36319 .51842 L p .63 .868 .987 r
F P
0 g
s
.36366 .51497 m .36319 .51842 L .3669 .51883 L p .571 .863 .996 r
F P
0 g
s
.3669 .51883 m .3676 .51391 L .36366 .51497 L p .571 .863 .996 r
F P
0 g
s
.3676 .51391 m .3669 .51883 L .37003 .51761 L p .605 .891 .989 r
F P
0 g
s
.63672 .45912 m .63341 .45491 L .63309 .45389 L p 0 .023 .592 r
F P
0 g
s
.62933 .44616 m .63309 .45389 L .63341 .45491 L p 0 .009 .58 r
F P
0 g
s
.63341 .45491 m .62804 .44386 L .62933 .44616 L p 0 .009 .58 r
F P
0 g
s
.63341 .45491 m .63672 .45912 L .63634 .46048 L p .077 .192 .682 r
F P
0 g
s
.62804 .44386 m .63341 .45491 L .63233 .45276 L p 0 0 .379 r
F P
0 g
s
.31437 .52607 m .33713 .52424 L .34168 .52225 L p .66 .815 .958 r
F P
0 g
s
.63985 .33149 m .61946 .32193 L .61199 .32528 L p .776 .713 .793 r
F P
0 g
s
.47093 .37026 m .46506 .37252 L .46241 .36904 L p .612 .529 .737 r
F P
0 g
s
.46241 .36904 m .47079 .3658 L .47093 .37026 L p .612 .529 .737 r
F P
0 g
s
.45154 .3414 m .4616 .36374 L .46241 .36904 L p .622 .562 .765 r
F P
0 g
s
.46241 .36904 m .44805 .33715 L .45154 .3414 L p .622 .562 .765 r
F P
0 g
s
.47079 .3658 m .46241 .36904 L .4616 .36374 L p .622 .562 .765 r
F P
0 g
s
.6051 .5672 m .60157 .55799 L .59931 .55603 L p .838 .581 .552 r
F P
0 g
s
.6032 .64741 m .60247 .64382 L .60391 .64138 L p .311 .154 .501 r
F P
0 g
s
.61218 .59811 m .61043 .58683 L .60938 .5848 L p .96 .778 .613 r
F P
0 g
s
.60938 .5848 m .61188 .60092 L .61218 .59811 L p .96 .778 .613 r
F P
0 g
s
.7781 .53102 m .74858 .52931 L .74272 .5266 L p .656 .71 .888 r
F P
0 g
s
.43989 .49201 m .44608 .49691 L .44642 .4989 L p .562 .309 .49 r
F P
0 g
s
.65174 .48338 m .64515 .48002 L .64394 .47711 L p .462 .465 .776 r
F P
0 g
s
.48124 .71584 m .47113 .73608 L .46486 .73913 L p .765 .67 .758 r
F P
0 g
s
.71023 .52361 m .74272 .5266 L .73745 .5283 L p .653 .685 .868 r
F P
0 g
s
.47176 .39093 m .47728 .38886 L .47987 .39239 L p .613 .53 .736 r
F P
0 g
s
.60733 .65386 m .59584 .66543 L .59726 .66257 L p .372 .245 .575 r
F P
0 g
s
.59584 .66543 m .59923 .67609 L .59615 .67567 L p .543 .397 .632 r
F P
0 g
s
.6062 .65717 m .59816 .66526 L .59584 .66543 L p .43 .328 .638 r
F P
0 g
s
.59584 .66543 m .60733 .65386 L .6062 .65717 L p .43 .328 .638 r
F P
0 g
s
.59923 .67609 m .59584 .66543 L .59816 .66526 L p .43 .331 .641 r
F P
0 g
s
.62449 .43491 m .6239 .43148 L .6224 .43078 L p .931 .591 .37 r
F P
0 g
s
.61489 .425 m .6224 .43078 L .6239 .43148 L p .93 .591 .368 r
F P
0 g
s
.6239 .43148 m .61316 .42323 L .61489 .425 L p .93 .591 .368 r
F P
0 g
s
.6239 .43148 m .62449 .43491 L .62521 .43613 L p .917 .599 .123 r
F P
0 g
s
.61316 .42323 m .6239 .43148 L .62223 .42944 L p .934 .638 .458 r
F P
0 g
s
.65477 .49502 m .66489 .49826 L .66702 .50116 L p .55 .565 .822 r
F P
0 g
s
.5716 .54342 m .56697 .54031 L .56369 .53928 L p .586 .041 0 r
F P
0 g
s
.56369 .53928 m .5703 .54371 L .5716 .54342 L p .586 .041 0 r
F P
0 g
s
.5703 .54371 m .56369 .53928 L .56157 .5394 L p .586 .044 0 r
F P
0 g
s
.47409 .39825 m .47841 .41385 L .47815 .41761 L p .602 .498 .708 r
F P
0 g
s
.65336 .48192 m .64394 .47711 L .64504 .47582 L p .388 .479 .832 r
F P
0 g
s
.64391 .46647 m .64504 .47582 L .64394 .47711 L p .376 .462 .821 r
F P
0 g
s
.64394 .47711 m .64232 .46376 L .64391 .46647 L p .376 .462 .821 r
F P
0 g
s
.64394 .47711 m .65336 .48192 L .65174 .48338 L p .462 .465 .776 r
F P
0 g
s
.64232 .46376 m .64394 .47711 L .64282 .47441 L p .244 .354 .777 r
F P
0 g
s
.6925 .79844 m .72102 .78096 L .73356 .78301 L p .584 .609 .843 r
F P
0 g
s
.68895 .51825 m .7066 .52079 L .71023 .52361 L p .641 .662 .854 r
F P
0 g
s
.59931 .55603 m .60434 .56921 L .6051 .5672 L p .838 .581 .552 r
F P
0 g
s
.59235 .55816 m .59896 .55813 L .59931 .55603 L p .854 .573 .511 r
F P
0 g
s
.59931 .55603 m .58985 .55606 L .59235 .55816 L p .854 .573 .511 r
F P
0 g
s
.60434 .56921 m .59931 .55603 L .59896 .55813 L p .875 .596 .51 r
F P
0 g
s
.58985 .55606 m .59931 .55603 L .5972 .55461 L p .827 .488 .414 r
F P
0 g
s
.61022 .60554 m .61146 .60365 L .61188 .60092 L p .978 .877 .507 r
F P
0 g
s
.83139 .53339 m .79264 .532 L .78495 .52904 L p .656 .727 .901 r
F P
0 g
s
.74272 .5266 m .71023 .52361 L .71521 .52164 L p .648 .692 .877 r
F P
0 g
s
.71579 .51073 m .71521 .52164 L .71023 .52361 L p .646 .678 .866 r
F P
0 g
s
.71023 .52361 m .71103 .50803 L .71579 .51073 L p .646 .678 .866 r
F P
0 g
s
.71103 .50803 m .71023 .52361 L .7066 .52079 L p .625 .66 .864 r
F P
0 g
s
.61249 .40961 m .61404 .39862 L .61119 .39944 L p .834 .634 .632 r
F P
0 g
s
.59832 .39514 m .61119 .39944 L .61404 .39862 L p .833 .631 .629 r
F P
0 g
s
.61404 .39862 m .59566 .39248 L .59832 .39514 L p .833 .631 .629 r
F P
0 g
s
.61404 .39862 m .61249 .40961 L .61462 .40946 L p .909 .71 .621 r
F P
0 g
s
.59566 .39248 m .61404 .39862 L .61175 .39536 L p .824 .661 .68 r
F P
0 g
s
.61188 .60092 m .61011 .60362 L .61022 .60554 L p .978 .877 .507 r
F P
0 g
s
.6094 .5876 m .61115 .59889 L .61188 .60092 L p .992 .788 .529 r
F P
0 g
s
.61188 .60092 m .60938 .5848 L .6094 .5876 L p .992 .788 .529 r
F P
0 g
s
.61011 .60362 m .61188 .60092 L .61115 .59889 L p .996 .776 .48 r
F P
0 g
s
.49464 .67069 m .48405 .66299 L .48314 .65862 L p .825 .68 .703 r
F P
0 g
s
.43746 .49383 m .43176 .49843 L .42943 .49845 L p .548 .268 .442 r
F P
0 g
s
.46702 .46952 m .469 .45646 L .47103 .45838 L p .588 .434 .641 r
F P
0 g
s
.48134 .4572 m .47103 .45838 L .469 .45646 L p .58 .434 .647 r
F P
0 g
s
.469 .45646 m .48372 .45477 L .48134 .4572 L p .58 .434 .647 r
F P
0 g
s
.469 .45646 m .46702 .46952 L .46496 .46752 L p .549 .399 .63 r
F P
0 g
s
.48372 .45477 m .469 .45646 L .47105 .45368 L p .583 .447 .662 r
F P
0 g
s
.60911 .62741 m .60391 .64138 L .60464 .6388 L p 0 0 .312 r
F P
0 g
s
.60391 .64138 m .60494 .64651 L .6032 .64741 L p .311 .154 .501 r
F P
0 g
s
.60849 .63027 m .60484 .64005 L .60391 .64138 L p .02 0 .442 r
F P
0 g
s
.60391 .64138 m .60911 .62741 L .60849 .63027 L p .02 0 .442 r
F P
0 g
s
.60494 .64651 m .60391 .64138 L .60484 .64005 L p .035 0 .46 r
F P
0 g
s
.5972 .55461 m .59058 .55463 L .58985 .55606 L p .827 .488 .414 r
F P
0 g
s
.60941 .61714 m .60914 .61849 L .609 .62112 L p .856 .74 .222 r
F P
0 g
s
.74272 .5266 m .78495 .52904 L .7781 .53102 L p .656 .71 .888 r
F P
0 g
s
.49195 .6481 m .48648 .6582 L .48314 .65862 L p .841 .671 .671 r
F P
0 g
s
.48314 .65862 m .49097 .64419 L .49195 .6481 L p .841 .671 .671 r
F P
0 g
s
.47943 .43476 m .4768 .4211 L .47815 .41761 L p .578 .462 .684 r
F P
0 g
s
.63233 .45276 m .62857 .44502 L .62804 .44386 L p 0 0 .379 r
F P
0 g
s
.78495 .52904 m .84038 .53102 L .83139 .53339 L p .656 .727 .901 r
F P
0 g
s
.64282 .47441 m .64168 .46507 L .64232 .46376 L p .244 .354 .777 r
F P
0 g
s
.47932 .71018 m .46486 .73913 L .46377 .7333 L p .791 .704 .768 r
F P
0 g
s
.44712 .72613 m .46377 .7333 L .46486 .73913 L p .792 .704 .768 r
F P
0 g
s
.46486 .73913 m .44107 .72892 L .44712 .72613 L p .792 .704 .768 r
F P
0 g
s
.46486 .73913 m .47932 .71018 L .48124 .71584 L p .765 .67 .758 r
F P
0 g
s
.44107 .72892 m .46486 .73913 L .45786 .74301 L p .774 .718 .799 r
F P
0 g
s
.59726 .66257 m .60529 .65447 L .60733 .65386 L p .372 .245 .575 r
F P
0 g
s
.60814 .62379 m .60819 .6233 L .609 .62112 L p 0 0 .086 r
F P
0 g
s
.59331 .71533 m .61047 .7082 L .61538 .70964 L p .584 .496 .721 r
F P
0 g
s
.59058 .55463 m .58571 .54727 L .5829 .54555 L p .79 .441 .395 r
F P
0 g
s
.5829 .54555 m .58985 .55606 L .59058 .55463 L p .79 .441 .395 r
F P
0 g
s
.57381 .54576 m .58263 .54705 L .5829 .54555 L p .803 .418 .325 r
F P
0 g
s
.5829 .54555 m .5703 .54371 L .57381 .54576 L p .803 .418 .325 r
F P
0 g
s
.58985 .55606 m .5829 .54555 L .58263 .54705 L p .821 .438 .327 r
F P
0 g
s
.5703 .54371 m .5829 .54555 L .58042 .54471 L p .66 .14 0 r
F P
0 g
s
.41848 .50427 m .42943 .49845 L .42852 .50003 L p .492 .135 .287 r
F P
0 g
s
.43266 .50411 m .42852 .50003 L .42943 .49845 L p .566 .213 .329 r
F P
0 g
s
.42943 .49845 m .43536 .50428 L .43266 .50411 L p .566 .213 .329 r
F P
0 g
s
.42943 .49845 m .41848 .50427 L .41931 .50307 L p .301 0 .045 r
F P
0 g
s
.43536 .50428 m .42943 .49845 L .43176 .49843 L p .533 .217 .378 r
F P
0 g
s
.4616 .36374 m .46747 .36146 L .47079 .3658 L p .622 .562 .765 r
F P
0 g
s
.48297 .63246 m .49038 .64069 L .49097 .64419 L p .887 .71 .656 r
F P
0 g
s
.49097 .64419 m .48037 .63243 L .48297 .63246 L p .887 .71 .656 r
F P
0 g
s
.48266 .65481 m .48814 .6447 L .49097 .64419 L p .87 .713 .684 r
F P
0 g
s
.49097 .64419 m .48314 .65862 L .48266 .65481 L p .87 .713 .684 r
F P
0 g
s
.48037 .63243 m .49097 .64419 L .48814 .6447 L p .871 .715 .687 r
F P
0 g
s
.34168 .52225 m .30911 .52487 L .31437 .52607 L p .66 .815 .958 r
F P
0 g
s
.47105 .45368 m .48135 .45249 L .48372 .45477 L p .583 .447 .662 r
F P
0 g
s
.58042 .54471 m .5716 .54342 L .5703 .54371 L p .66 .14 0 r
F P
0 g
s
.62569 .43829 m .62537 .43691 L .62449 .43491 L p .872 .537 .03 r
F P
0 g
s
.62223 .42944 m .61471 .42366 L .61316 .42323 L p .934 .638 .458 r
F P
0 g
s
.37003 .51761 m .37053 .51417 L .3676 .51391 L p .605 .891 .989 r
F P
0 g
s
.48192 .43714 m .47815 .41761 L .47995 .42014 L p .594 .473 .684 r
F P
0 g
s
.48554 .41825 m .47995 .42014 L .47815 .41761 L p .594 .472 .684 r
F P
0 g
s
.47815 .41761 m .48613 .41491 L .48554 .41825 L p .594 .472 .684 r
F P
0 g
s
.47815 .41761 m .48192 .43714 L .47943 .43476 L p .578 .462 .684 r
F P
0 g
s
.48613 .41491 m .47815 .41761 L .47841 .41385 L p .602 .498 .708 r
F P
0 g
s
.27366 .52859 m .30325 .52724 L .30911 .52487 L p .66 .789 .943 r
F P
0 g
s
.49191 .69207 m .48437 .70806 L .47932 .71018 L p .778 .653 .724 r
F P
0 g
s
.47932 .71018 m .49009 .68733 L .49191 .69207 L p .778 .653 .724 r
F P
0 g
s
.61175 .39536 m .59889 .39106 L .59566 .39248 L p .824 .661 .68 r
F P
0 g
s
.60464 .6388 m .60828 .62903 L .60911 .62741 L p 0 0 .312 r
F P
0 g
s
.47841 .41385 m .48399 .41195 L .48613 .41491 L p .602 .498 .708 r
F P
0 g
s
.46205 .47697 m .46425 .4705 L .46702 .46952 L p .556 .386 .606 r
F P
0 g
s
.45786 .74301 m .4412 .7359 L .44107 .72892 L p .774 .718 .799 r
F P
0 g
s
.7066 .52079 m .70714 .50989 L .71103 .50803 L p .625 .66 .864 r
F P
0 g
s
.6081 .62438 m .60813 .62398 L .60893 .62181 L p 0 0 .104 r
F P
0 g
s
.63122 .29501 m .6568 .30797 L .66533 .30533 L p .776 .713 .793 r
F P
0 g
s
.66533 .30533 m .62879 .28676 L .63122 .29501 L p .776 .713 .793 r
F P
0 g
s
.69212 .26391 m .66487 .29538 L .66533 .30533 L p .757 .722 .819 r
F P
0 g
s
.66533 .30533 m .70423 .26048 L .69212 .26391 L p .757 .722 .819 r
F P
0 g
s
.62879 .28676 m .66533 .30533 L .66487 .29538 L p .757 .722 .819 r
F P
0 g
s
.61115 .59889 m .60991 .60077 L .61011 .60362 L p .996 .776 .48 r
F P
0 g
s
.47103 .45838 m .46965 .46753 L .46702 .46952 L p .588 .434 .641 r
F P
0 g
s
.63309 .45389 m .63541 .45684 L .63672 .45912 L p 0 .023 .592 r
F P
0 g
s
.78495 .52904 m .74272 .5266 L .74919 .5243 L p .652 .714 .893 r
F P
0 g
s
.7498 .51248 m .74919 .5243 L .74272 .5266 L p .651 .705 .886 r
F P
0 g
s
.74272 .5266 m .74355 .50973 L .7498 .51248 L p .651 .705 .886 r
F P
0 g
s
.71521 .52164 m .73798 .52373 L .74272 .5266 L p .648 .692 .877 r
F P
0 g
s
.74355 .50973 m .74272 .5266 L .73798 .52373 L p .637 .692 .885 r
F P
0 g
s
.60938 .60547 m .609 .62112 L .60914 .61849 L p .908 .786 .303 r
F P
0 g
s
.60931 .60793 m .60904 .61888 L .609 .62112 L p .85 .728 .205 r
F P
0 g
s
.609 .62112 m .60938 .60547 L .60931 .60793 L p .85 .728 .205 r
F P
0 g
s
.30911 .52487 m .34168 .52225 L .3368 .52132 L p .649 .824 .967 r
F P
0 g
s
.33687 .51612 m .3368 .52132 L .34168 .52225 L p .62 .826 .98 r
F P
0 g
s
.34168 .52225 m .34181 .51481 L .33687 .51612 L p .62 .826 .98 r
F P
0 g
s
.36319 .51842 m .34552 .52081 L .34168 .52225 L p .63 .868 .987 r
F P
0 g
s
.34181 .51481 m .34168 .52225 L .34552 .52081 L p .642 .844 .978 r
F P
0 g
s
.59896 .55813 m .60249 .56736 L .60434 .56921 L p .875 .596 .51 r
F P
0 g
s
.33097 .26952 m .28402 .22735 L .27813 .21351 L p .613 .641 .855 r
F P
0 g
s
.27813 .21351 m .3453 .27395 L .33097 .26952 L p .613 .641 .855 r
F P
0 g
s
.6224 .43078 m .62282 .43318 L .62449 .43491 L p .931 .591 .37 r
F P
0 g
s
.43176 .49843 m .43591 .5025 L .43536 .50428 L p .533 .217 .378 r
F P
0 g
s
.47995 .42014 m .48259 .43381 L .48192 .43714 L p .594 .473 .684 r
F P
0 g
s
.62449 .43491 m .62496 .43688 L .62569 .43829 L p .872 .537 .03 r
F P
0 g
s
.40634 .508 m .4159 .50485 L .41848 .50427 L p .068 0 0 r
F P
0 g
s
.48803 .62366 m .48297 .63246 L .48037 .63243 L p .887 .714 .661 r
F P
0 g
s
.48037 .63243 m .48761 .61985 L .48803 .62366 L p .887 .714 .661 r
F P
0 g
s
.47728 .38886 m .47093 .37026 L .47079 .3658 L p .612 .529 .737 r
F P
0 g
s
.47079 .3658 m .47987 .39239 L .47728 .38886 L p .612 .529 .737 r
F P
0 g
s
.60889 .62239 m .6081 .62438 L p .6089 .62191 L 0 0 .104 r
F P
0 g
s
.60889 .62239 m .6089 .62031 L p .60885 .62376 L .731 .604 .033 r
F P
0 g
s
.60889 .62239 m .60884 .62419 L .60805 .626 L p 0 0 .163 r
F P
0 g
s
.60884 .62419 m .60889 .62239 L p .60885 .62376 L .731 .604 .033 r
F P
0 g
s
.60893 .62181 m .60889 .62239 L p .6089 .62191 L 0 0 .104 r
F P
0 g
s
.61119 .39944 m .6101 .40713 L .61249 .40961 L p .834 .634 .632 r
F P
0 g
s
.22023 .53054 m .25911 .52964 L .26677 .5268 L p .658 .772 .933 r
F P
0 g
s
.30911 .52487 m .26677 .5268 L .27366 .52859 L p .66 .789 .943 r
F P
0 g
s
.47696 .67595 m .48891 .68309 L .49009 .68733 L p .824 .679 .703 r
F P
0 g
s
.49009 .68733 m .47301 .67714 L .47696 .67595 L p .824 .679 .703 r
F P
0 g
s
.47817 .70526 m .48572 .68925 L .49009 .68733 L p .808 .691 .736 r
F P
0 g
s
.49009 .68733 m .47932 .71018 L .47817 .70526 L p .808 .691 .736 r
F P
0 g
s
.47301 .67714 m .49009 .68733 L .48572 .68925 L p .808 .691 .736 r
F P
0 g
s
.59816 .66526 m .60053 .67273 L .59923 .67609 L p .43 .331 .641 r
F P
0 g
s
.4823 .60867 m .48748 .61658 L .48761 .61985 L p .918 .749 .657 r
F P
0 g
s
.48761 .61985 m .48021 .60855 L .4823 .60867 L p .918 .749 .657 r
F P
0 g
s
.48032 .62901 m .48539 .62021 L .48761 .61985 L p .907 .746 .67 r
F P
0 g
s
.48761 .61985 m .48037 .63243 L .48032 .62901 L p .907 .746 .67 r
F P
0 g
s
.48021 .60855 m .48761 .61985 L .48539 .62021 L p .908 .751 .676 r
F P
0 g
s
.48399 .41195 m .47962 .39619 L .47987 .39239 L p .602 .498 .708 r
F P
0 g
s
.46702 .46952 m .46387 .47877 L .46205 .47697 L p .556 .386 .606 r
F P
0 g
s
.62592 .43912 m .62579 .43867 L .62496 .43688 L p .83 .485 0 r
F P
0 g
s
.62496 .43688 m .62449 .43491 L .62301 .43401 L p .925 .564 .32 r
F P
0 g
s
.61567 .42841 m .62301 .43401 L .62449 .43491 L p .923 .558 .311 r
F P
0 g
s
.62449 .43491 m .61401 .4269 L .61567 .42841 L p .923 .558 .311 r
F P
0 g
s
.61401 .4269 m .62449 .43491 L .62282 .43318 L p .931 .591 .368 r
F P
0 g
s
.60914 .61849 m .60941 .60754 L .60938 .60547 L p .908 .786 .303 r
F P
0 g
s
.56157 .5394 m .5662 .54251 L .5703 .54371 L p .586 .044 0 r
F P
0 g
s
.64504 .47582 m .65164 .47918 L .65336 .48192 L p .388 .479 .832 r
F P
0 g
s
.68306 .50672 m .66967 .50397 L .66702 .50116 L p .601 .599 .821 r
F P
0 g
s
.46387 .47877 m .46702 .46952 L .46905 .4714 L p .606 .438 .628 r
F P
0 g
s
.48056 .47229 m .46905 .4714 L .46702 .46952 L p .596 .439 .639 r
F P
0 g
s
.46702 .46952 m .48347 .47079 L .48056 .47229 L p .596 .439 .639 r
F P
0 g
s
.48347 .47079 m .46702 .46952 L .46965 .46753 L p .595 .447 .65 r
F P
0 g
s
.48613 .41491 m .47987 .39239 L .48122 .39562 L p .606 .5 .707 r
F P
0 g
s
.48311 .39496 m .48122 .39562 L .47987 .39239 L p .602 .498 .708 r
F P
0 g
s
.47987 .39239 m .48257 .39144 L .48311 .39496 L p .602 .498 .708 r
F P
0 g
s
.47987 .39239 m .48613 .41491 L .48399 .41195 L p .602 .498 .708 r
F P
0 g
s
.47258 .36964 m .47893 .38825 L .47987 .39239 L p .617 .532 .736 r
F P
0 g
s
.47987 .39239 m .47079 .3658 L .47258 .36964 L p .617 .532 .736 r
F P
0 g
s
.48257 .39144 m .47987 .39239 L .47893 .38825 L p .612 .528 .736 r
F P
0 g
s
.60484 .64005 m .60557 .64364 L .60494 .64651 L p .035 0 .46 r
F P
0 g
s
.60805 .626 m .60809 .62474 L .60889 .62239 L p 0 0 .163 r
F P
0 g
s
.60966 .58221 m .60614 .5713 L .60434 .56921 L p .897 .671 .587 r
F P
0 g
s
.60434 .56921 m .60938 .5848 L .60966 .58221 L p .897 .671 .587 r
F P
0 g
s
.42852 .50003 m .42085 .5041 L .41848 .50427 L p .492 .135 .287 r
F P
0 g
s
.45939 .48252 m .46129 .47888 L .46387 .47877 L p .563 .375 .584 r
F P
0 g
s
.62496 .43688 m .62515 .43751 L .62592 .43912 L p .83 .485 0 r
F P
0 g
s
.6142 .41782 m .61423 .41218 L .61249 .40961 L p .926 .677 .543 r
F P
0 g
s
.60904 .61888 m .60899 .61937 L .60893 .62181 L p .791 .669 .119 r
F P
0 g
s
.6092 .60613 m .60893 .62181 L .60899 .61937 L p .855 .73 .208 r
F P
0 g
s
.60915 .60858 m .60896 .61955 L .60893 .62181 L p .826 .701 .165 r
F P
0 g
s
.60893 .62181 m .6092 .60613 L .60915 .60858 L p .826 .701 .165 r
F P
0 g
s
.60889 .62239 m .60893 .62181 L .60896 .61955 L p .775 .651 .094 r
F P
0 g
s
.47893 .38825 m .48082 .38759 L .48257 .39144 L p .612 .528 .736 r
F P
0 g
s
.37345 .26567 m .35525 .27839 L .3453 .27395 L p .616 .614 .827 r
F P
0 g
s
.3453 .27395 m .37127 .25571 L .37345 .26567 L p .616 .614 .827 r
F P
0 g
s
.29277 .21936 m .33982 .26177 L .3453 .27395 L p .629 .644 .846 r
F P
0 g
s
.3453 .27395 m .27813 .21351 L .29277 .21936 L p .629 .644 .846 r
F P
0 g
s
.37127 .25571 m .3453 .27395 L .33982 .26177 L p .629 .644 .846 r
F P
0 g
s
.46377 .7333 m .47389 .71302 L .47932 .71018 L p .791 .704 .768 r
F P
0 g
s
.84038 .53102 m .78495 .52904 L .79347 .52627 L p .654 .729 .904 r
F P
0 g
s
.7944 .51297 m .79347 .52627 L .78495 .52904 L p .654 .723 .899 r
F P
0 g
s
.78495 .52904 m .7862 .51004 L .7944 .51297 L p .654 .723 .899 r
F P
0 g
s
.74919 .5243 m .77878 .526 L .78495 .52904 L p .652 .714 .893 r
F P
0 g
s
.7862 .51004 m .78495 .52904 L .77878 .526 L p .645 .715 .899 r
F P
0 g
s
.62617 .43985 m .62598 .43932 L .62515 .43751 L p .765 .41 0 r
F P
0 g
s
.48122 .39562 m .4856 .41138 L .48613 .41491 L p .606 .5 .707 r
F P
0 g
s
.58263 .54705 m .5875 .55441 L .58985 .55606 L p .821 .438 .327 r
F P
0 g
s
.68616 .50508 m .66702 .50116 L .66976 .49949 L p .584 .616 .85 r
F P
0 g
s
.66956 .48906 m .66976 .49949 L .66702 .50116 L p .577 .599 .838 r
F P
0 g
s
.66702 .50116 m .66672 .48627 L .66956 .48906 L p .577 .599 .838 r
F P
0 g
s
.66702 .50116 m .68616 .50508 L .68306 .50672 L p .601 .599 .821 r
F P
0 g
s
.66672 .48627 m .66702 .50116 L .66489 .49826 L p .525 .555 .829 r
F P
0 g
s
.48733 .60019 m .4823 .60867 L .48021 .60855 L p .918 .759 .669 r
F P
0 g
s
.48021 .60855 m .48739 .59644 L .48733 .60019 L p .918 .759 .669 r
F P
0 g
s
.48814 .6447 m .48072 .63647 L .48037 .63243 L p .871 .715 .687 r
F P
0 g
s
.48395 .58694 m .48769 .59344 L .48739 .59644 L p .921 .778 .685 r
F P
0 g
s
.48739 .59644 m .48204 .58716 L .48395 .58694 L p .921 .778 .685 r
F P
0 g
s
.48049 .60553 m .48552 .59706 L .48739 .59644 L p .924 .77 .672 r
F P
0 g
s
.48739 .59644 m .48021 .60855 L .48049 .60553 L p .924 .77 .672 r
F P
0 g
s
.48204 .58716 m .48739 .59644 L .48552 .59706 L p .925 .778 .679 r
F P
0 g
s
.47463 .36891 m .47258 .36964 L .47079 .3658 L p .622 .534 .734 r
F P
0 g
s
.47079 .3658 m .47372 .36476 L .47463 .36891 L p .622 .534 .734 r
F P
0 g
s
.45998 .33797 m .46928 .36076 L .47079 .3658 L p .632 .566 .763 r
F P
0 g
s
.47079 .3658 m .45752 .33324 L .45998 .33797 L p .632 .566 .763 r
F P
0 g
s
.47372 .36476 m .47079 .3658 L .46928 .36076 L p .632 .566 .763 r
F P
0 g
s
.45752 .33324 m .47079 .3658 L .46747 .36146 L p .622 .562 .765 r
F P
0 g
s
.26677 .5268 m .21114 .52808 L .22023 .53054 L p .658 .772 .933 r
F P
0 g
s
.46965 .46753 m .48116 .46841 L .48347 .47079 L p .595 .447 .65 r
F P
0 g
s
.46747 .36146 m .45817 .33868 L .45752 .33324 L p .622 .562 .765 r
F P
0 g
s
.46387 .47877 m .46116 .48398 L .45939 .48252 L p .563 .375 .584 r
F P
0 g
s
.62515 .43751 m .62541 .43827 L .62617 .43985 L p .765 .41 0 r
F P
0 g
s
.52095 .53859 m .50016 .5537 L .49724 .55379 L p .782 .792 .861 r
F P
0 g
s
.64168 .46507 m .63776 .46181 L .63672 .45912 L p .229 .335 .765 r
F P
0 g
s
.48135 .45249 m .48009 .44015 L .48192 .43714 L p .579 .447 .665 r
F P
0 g
s
.4582 .48456 m .45893 .48342 L .46116 .48398 L p .568 .368 .57 r
F P
0 g
s
.4048 .50878 m .41848 .50427 L .4169 .5053 L p .328 0 0 r
F P
0 g
s
.41953 .50782 m .4169 .5053 L .41848 .50427 L p .472 .013 .081 r
F P
0 g
s
.41848 .50427 m .42224 .50787 L .41953 .50782 L p .472 .013 .081 r
F P
0 g
s
.41848 .50427 m .4048 .50878 L .40634 .508 L p .068 0 0 r
F P
0 g
s
.42224 .50787 m .41848 .50427 L .42085 .5041 L p .438 .016 .139 r
F P
0 g
s
.79347 .52627 m .83234 .52766 L .84038 .53102 L p .654 .729 .904 r
F P
0 g
s
.8425 .50881 m .84038 .53102 L .83234 .52766 L p .65 .73 .908 r
F P
0 g
s
.60896 .61955 m .60893 .61996 L .60889 .62239 L p .775 .651 .094 r
F P
0 g
s
.60908 .6067 m .60889 .62239 L .60893 .61996 L p .829 .702 .167 r
F P
0 g
s
.60903 .60933 m .6089 .62031 L .60889 .62239 L p .774 .649 .091 r
F P
0 g
s
.60889 .62239 m .60908 .6067 L .60903 .60933 L p .774 .649 .091 r
F P
0 g
s
.34552 .52081 m .34563 .51561 L .34181 .51481 L p .642 .844 .978 r
F P
0 g
s
.46432 .69835 m .47817 .70526 L .47932 .71018 L p .808 .691 .736 r
F P
0 g
s
.47932 .71018 m .45951 .70033 L .46432 .69835 L p .808 .691 .736 r
F P
0 g
s
.45951 .70033 m .47932 .71018 L .47389 .71302 L p .791 .704 .768 r
F P
0 g
s
.62282 .43318 m .61548 .42757 L .61401 .4269 L p .931 .591 .368 r
F P
0 g
s
.48082 .38759 m .47463 .36891 L .47372 .36476 L p .617 .531 .735 r
F P
0 g
s
.47372 .36476 m .48257 .39144 L .48082 .38759 L p .617 .531 .735 r
F P
0 g
s
.45817 .33868 m .45154 .3414 L .44805 .33715 L p .622 .562 .765 r
F P
0 g
s
.73798 .52373 m .73853 .51192 L .74355 .50973 L p .637 .692 .885 r
F P
0 g
s
.66489 .49826 m .66467 .48784 L .66672 .48627 L p .525 .555 .829 r
F P
0 g
s
.44805 .33715 m .45752 .33324 L .45817 .33868 L p .622 .562 .765 r
F P
0 g
s
.43122 .3023 m .44638 .33049 L .44805 .33715 L p .633 .594 .792 r
F P
0 g
s
.44805 .33715 m .4264 .2969 L .43122 .3023 L p .633 .594 .792 r
F P
0 g
s
.45752 .33324 m .44805 .33715 L .44638 .33049 L p .633 .594 .792 r
F P
0 g
s
.4264 .2969 m .44805 .33715 L .44241 .3323 L p .62 .588 .796 r
F P
0 g
s
.60899 .61937 m .60918 .60839 L .6092 .60613 L p .855 .73 .208 r
F P
0 g
s
.46116 .48398 m .46013 .4856 L .4582 .48456 L p .568 .368 .57 r
F P
0 g
s
.48835 .41042 m .48394 .39467 L .48257 .39144 L p .618 .508 .707 r
F P
0 g
s
.48257 .39144 m .48888 .41394 L .48835 .41042 L p .618 .508 .707 r
F P
0 g
s
.48537 .39046 m .48257 .39144 L .48394 .39467 L p .622 .511 .706 r
F P
0 g
s
.48363 .3866 m .48168 .38729 L .48257 .39144 L p .632 .54 .733 r
F P
0 g
s
.48257 .39144 m .48537 .39046 L .48363 .3866 L p .632 .54 .733 r
F P
0 g
s
.47372 .36476 m .48257 .39144 L .48168 .38729 L p .627 .537 .733 r
F P
0 g
s
.48752 .41071 m .48311 .39496 L .48257 .39144 L p .607 .501 .708 r
F P
0 g
s
.48257 .39144 m .48888 .41394 L .48752 .41071 L p .607 .501 .708 r
F P
0 g
s
.6269 .44183 m .62633 .44028 L .62541 .43827 L p .761 .403 0 r
F P
0 g
s
.6015 .68967 m .59725 .67954 L .59923 .67609 L p .565 .448 .679 r
F P
0 g
s
.60731 .58926 m .6094 .5876 L .60938 .5848 L p .982 .779 .556 r
F P
0 g
s
.60938 .5848 m .60639 .58717 L .60731 .58926 L p .982 .779 .556 r
F P
0 g
s
.60449 .57185 m .60801 .58276 L .60938 .5848 L p .938 .684 .527 r
F P
0 g
s
.60938 .5848 m .60434 .56921 L .60449 .57185 L p .938 .684 .527 r
F P
0 g
s
.60639 .58717 m .60938 .5848 L .60801 .58276 L p .948 .673 .484 r
F P
0 g
s
.45698 .48636 m .45791 .48503 L .46013 .4856 L p .569 .363 .562 r
F P
0 g
s
.60084 .57302 m .60449 .57185 L .60434 .56921 L p .923 .671 .54 r
F P
0 g
s
.60434 .56921 m .59913 .57087 L .60084 .57302 L p .923 .671 .54 r
F P
0 g
s
.59913 .57087 m .60434 .56921 L .60249 .56736 L p .888 .576 .452 r
F P
0 g
s
.26677 .5268 m .30911 .52487 L .30271 .5234 L p .654 .794 .949 r
F P
0 g
s
.30245 .51622 m .30271 .5234 L .30911 .52487 L p .639 .797 .958 r
F P
0 g
s
.30911 .52487 m .30881 .51462 L .30245 .51622 L p .639 .797 .958 r
F P
0 g
s
.3368 .52132 m .31398 .52316 L .30911 .52487 L p .649 .824 .967 r
F P
0 g
s
.30881 .51462 m .30911 .52487 L .31398 .52316 L p .653 .807 .957 r
F P
0 g
s
.46905 .4714 m .46684 .47788 L .46387 .47877 L p .606 .438 .628 r
F P
0 g
s
.61244 .41768 m .61249 .40961 L .61007 .41013 L p .841 .602 .578 r
F P
0 g
s
.59838 .40666 m .61007 .41013 L .61249 .40961 L p .84 .599 .575 r
F P
0 g
s
.61249 .40961 m .59579 .40465 L .59838 .40666 L p .84 .599 .575 r
F P
0 g
s
.61249 .40961 m .61244 .41768 L .6142 .41782 L p .926 .677 .543 r
F P
0 g
s
.59579 .40465 m .61249 .40961 L .6101 .40713 L p .836 .633 .629 r
F P
0 g
s
.44241 .3323 m .42726 .30415 L .4264 .2969 L p .62 .588 .796 r
F P
0 g
s
.48962 .57766 m .48395 .58694 L .48204 .58716 L p .921 .794 .703 r
F P
0 g
s
.48204 .58716 m .49014 .5739 L .48962 .57766 L p .921 .794 .703 r
F P
0 g
s
.62515 .43751 m .62496 .43688 L .62345 .43579 L p .919 .54 .28 r
F P
0 g
s
.61622 .43026 m .62345 .43579 L .62496 .43688 L p .92 .546 .288 r
F P
0 g
s
.62496 .43688 m .61464 .42897 L .61622 .43026 L p .92 .546 .288 r
F P
0 g
s
.62301 .43401 m .62334 .43539 L .62496 .43688 L p .925 .564 .32 r
F P
0 g
s
.61464 .42897 m .62496 .43688 L .62334 .43539 L p .924 .558 .309 r
F P
0 g
s
.48168 .38729 m .47548 .36861 L .47372 .36476 L p .627 .537 .733 r
F P
0 g
s
.489 .56818 m .49116 .57136 L .49014 .5739 L p .891 .787 .74 r
F P
0 g
s
.48572 .68925 m .47376 .68213 L .47301 .67714 L p .808 .691 .736 r
F P
0 g
s
.48372 .45477 m .48192 .43714 L .48359 .43941 L p .592 .457 .666 r
F P
0 g
s
.48963 .43761 m .48359 .43941 L .48192 .43714 L p .59 .456 .667 r
F P
0 g
s
.48192 .43714 m .49055 .43456 L .48963 .43761 L p .59 .456 .667 r
F P
0 g
s
.48192 .43714 m .48372 .45477 L .48135 .45249 L p .579 .447 .665 r
F P
0 g
s
.49055 .43456 m .48192 .43714 L .48259 .43381 L p .595 .474 .684 r
F P
0 g
s
.46013 .4856 m .4588 .4875 L .45698 .48636 L p .569 .363 .562 r
F P
0 g
s
.46116 .48398 m .46387 .47877 L .46592 .48058 L p .625 .447 .621 r
F P
0 g
s
.47779 .48436 m .46592 .48058 L .46387 .47877 L p .616 .448 .631 r
F P
0 g
s
.46387 .47877 m .48083 .48416 L .47779 .48436 L p .616 .448 .631 r
F P
0 g
s
.48083 .48416 m .46387 .47877 L .46684 .47788 L p .613 .455 .645 r
F P
0 g
s
.64232 .46376 m .63672 .45912 L .63671 .45816 L p 0 .269 .775 r
F P
0 g
s
.63285 .45045 m .63671 .45816 L .63672 .45912 L p 0 .258 .768 r
F P
0 g
s
.63672 .45912 m .6312 .44811 L .63285 .45045 L p 0 .258 .768 r
F P
0 g
s
.63672 .45912 m .64232 .46376 L .64168 .46507 L p .229 .335 .765 r
F P
0 g
s
.6312 .44811 m .63672 .45912 L .63541 .45684 L p 0 .002 .573 r
F P
0 g
s
.48259 .43381 m .48864 .432 L .49055 .43456 L p .595 .474 .684 r
F P
0 g
s
.46928 .36076 m .47133 .36003 L .47372 .36476 L p .632 .566 .763 r
F P
0 g
s
.48394 .39467 m .4859 .39399 L .48537 .39046 L p .622 .511 .706 r
F P
0 g
s
.49014 .5739 m .48704 .56935 L .489 .56818 L p .891 .787 .74 r
F P
0 g
s
.48285 .58462 m .48852 .57534 L .49014 .5739 L p .914 .781 .7 r
F P
0 g
s
.49014 .5739 m .48204 .58716 L .48285 .58462 L p .914 .781 .7 r
F P
0 g
s
.48704 .56935 m .49014 .5739 L .48852 .57534 L p .915 .785 .703 r
F P
0 g
s
.60529 .65447 m .60363 .64932 L .60494 .64651 L p .371 .241 .571 r
F P
0 g
s
.45321 .49086 m .45628 .48731 L .4588 .4875 L p .574 .351 .54 r
F P
0 g
s
.4856 .41138 m .48752 .41071 L .48888 .41394 L p .611 .504 .707 r
F P
0 g
s
.48888 .41394 m .48613 .41491 L .4856 .41138 L p .611 .504 .707 r
F P
0 g
s
.47665 .36372 m .47372 .36476 L .47548 .36861 L p .622 .534 .734 r
F P
0 g
s
.47432 .35897 m .47226 .3597 L .47372 .36476 L p .632 .566 .763 r
F P
0 g
s
.47372 .36476 m .47665 .36372 L .47432 .35897 L p .632 .566 .763 r
F P
0 g
s
.46085 .33204 m .47372 .36476 L .47226 .3597 L p .632 .566 .763 r
F P
0 g
s
.46085 .33204 m .47372 .36476 L .47133 .36003 L p .632 .566 .763 r
F P
0 g
s
.48864 .432 m .48554 .41825 L .48613 .41491 L p .595 .473 .684 r
F P
0 g
s
.47548 .36861 m .47753 .36789 L .47665 .36372 L p .622 .534 .734 r
F P
0 g
s
.49613 .55729 m .489 .56818 L .48704 .56935 L p .896 .813 .758 r
F P
0 g
s
.48704 .56935 m .49724 .55379 L .49613 .55729 L p .896 .813 .758 r
F P
0 g
s
.60249 .56736 m .59884 .56852 L .59913 .57087 L p .888 .576 .452 r
F P
0 g
s
.49055 .43456 m .48613 .41491 L .48722 .4177 L p .602 .478 .684 r
F P
0 g
s
.48915 .41703 m .48722 .4177 L .48613 .41491 L p .602 .478 .684 r
F P
0 g
s
.48613 .41491 m .48888 .41394 L .48915 .41703 L p .602 .478 .684 r
F P
0 g
s
.48613 .41491 m .49055 .43456 L .48864 .432 L p .595 .473 .684 r
F P
0 g
s
.62541 .43827 m .62515 .43751 L .62365 .43645 L p .907 .506 .224 r
F P
0 g
s
.61644 .43095 m .62365 .43645 L .62515 .43751 L p .908 .51 .23 r
F P
0 g
s
.62515 .43751 m .61485 .42965 L .61644 .43095 L p .908 .51 .23 r
F P
0 g
s
.62345 .43579 m .62358 .43624 L .62515 .43751 L p .919 .54 .28 r
F P
0 g
s
.61485 .42965 m .62515 .43751 L .62358 .43624 L p .92 .546 .289 r
F P
0 g
s
.42726 .30415 m .41506 .31022 L .40898 .30561 L p .619 .588 .796 r
F P
0 g
s
.40898 .30561 m .4264 .2969 L .42726 .30415 L p .619 .588 .796 r
F P
0 g
s
.37991 .2617 m .40632 .29667 L .40898 .30561 L p .631 .62 .821 r
F P
0 g
s
.40898 .30561 m .37127 .25571 L .37991 .2617 L p .631 .62 .821 r
F P
0 g
s
.4264 .2969 m .40898 .30561 L .40632 .29667 L p .63 .62 .821 r
F P
0 g
s
.37127 .25571 m .40898 .30561 L .39984 .30055 L p .616 .615 .827 r
F P
0 g
s
.60893 .61996 m .60907 .60897 L .60908 .6067 L p .829 .702 .167 r
F P
0 g
s
.39984 .30055 m .37345 .26567 L .37127 .25571 L p .616 .615 .827 r
F P
0 g
s
.61197 .66405 m .59923 .67609 L .60053 .67273 L p .425 .325 .638 r
F P
0 g
s
.59923 .67609 m .60531 .69057 L .6015 .68967 L p .565 .448 .679 r
F P
0 g
s
.61112 .66797 m .60219 .67639 L .59923 .67609 L p .473 .399 .693 r
F P
0 g
s
.59923 .67609 m .61197 .66405 L .61112 .66797 L p .473 .399 .693 r
F P
0 g
s
.60531 .69057 m .59923 .67609 L .60219 .67639 L p .473 .4 .694 r
F P
0 g
s
.42085 .5041 m .42349 .50662 L .42224 .50787 L p .438 .016 .139 r
F P
0 g
s
.47753 .36789 m .48363 .3866 L .48537 .39046 L p .627 .538 .734 r
F P
0 g
s
.49165 .413 m .48537 .39046 L .4859 .39399 L p .618 .507 .706 r
F P
0 g
s
.49195 .4092 m .48755 .39342 L .48537 .39046 L p .622 .51 .705 r
F P
0 g
s
.48537 .39046 m .49165 .413 L .49195 .4092 L p .622 .51 .705 r
F P
0 g
s
.49366 .38776 m .48537 .39046 L .48755 .39342 L p .622 .51 .705 r
F P
0 g
s
.48537 .39046 m .47665 .36372 L .47753 .36789 L p .627 .538 .734 r
F P
0 g
s
.49115 .38414 m .48535 .38604 L .48537 .39046 L p .631 .54 .733 r
F P
0 g
s
.48537 .39046 m .49366 .38776 L .49115 .38414 L p .631 .54 .733 r
F P
0 g
s
.47665 .36372 m .48537 .39046 L .48535 .38604 L p .632 .54 .733 r
F P
0 g
s
.48539 .62021 m .4802 .61229 L .48021 .60855 L p .908 .751 .676 r
F P
0 g
s
.6101 .40713 m .59841 .40366 L .59579 .40465 L p .836 .633 .629 r
F P
0 g
s
.51864 .53608 m .49781 .55121 L .49724 .55379 L p .775 .772 .85 r
F P
0 g
s
.48642 .55077 m .49724 .55379 L .49781 .55121 L p .804 .8 .848 r
F P
0 g
s
.48701 .55355 m .49459 .55566 L .49724 .55379 L p .856 .736 .73 r
F P
0 g
s
.49724 .55379 m .48642 .55077 L .48701 .55355 L p .856 .736 .73 r
F P
0 g
s
.48704 .56935 m .49724 .55379 L .49459 .55566 L p .862 .752 .741 r
F P
0 g
s
.4859 .39399 m .49029 .40976 L .49165 .413 L p .618 .507 .706 r
F P
0 g
s
.60801 .58276 m .60592 .58442 L .60639 .58717 L p .948 .673 .484 r
F P
0 g
s
.47133 .36003 m .46231 .33713 L .46085 .33204 L p .632 .566 .763 r
F P
0 g
s
.64691 .76382 m .62976 .74137 L .63134 .73451 L p .613 .582 .795 r
F P
0 g
s
.63134 .73451 m .65584 .76662 L .64691 .76382 L p .613 .582 .795 r
F P
0 g
s
.61024 .6324 m .60494 .64651 L .60557 .64364 L p .003 0 .439 r
F P
0 g
s
.60494 .64651 m .60733 .65386 L .60529 .65447 L p .371 .241 .571 r
F P
0 g
s
.60983 .63561 m .60612 .64549 L .60494 .64651 L p .147 .108 .553 r
F P
0 g
s
.60494 .64651 m .61024 .6324 L .60983 .63561 L p .147 .108 .553 r
F P
0 g
s
.60733 .65386 m .60494 .64651 L .60612 .64549 L p .152 .116 .56 r
F P
0 g
s
.47389 .71302 m .46002 .70614 L .45951 .70033 L p .791 .704 .768 r
F P
0 g
s
.46013 .4856 m .46116 .48398 L .46333 .48555 L p .636 .452 .617 r
F P
0 g
s
.47444 .49144 m .46333 .48555 L .46116 .48398 L p .631 .454 .625 r
F P
0 g
s
.46116 .48398 m .47704 .4924 L .47444 .49144 L p .631 .454 .625 r
F P
0 g
s
.46592 .48058 m .46402 .48423 L .46116 .48398 L p .625 .447 .621 r
F P
0 g
s
.47704 .4924 m .46116 .48398 L .46402 .48423 L p .625 .458 .636 r
F P
0 g
s
.46684 .47788 m .47871 .48165 L .48083 .48416 L p .613 .455 .645 r
F P
0 g
s
.63541 .45684 m .63154 .44913 L .6312 .44811 L p 0 .002 .573 r
F P
0 g
s
.4588 .4875 m .45441 .49258 L .45321 .49086 L p .574 .351 .54 r
F P
0 g
s
.6089 .62031 m .60886 .62157 L .60884 .62419 L p .731 .604 .033 r
F P
0 g
s
.62541 .43827 m .62622 .44048 L .6269 .44183 L p .761 .403 0 r
F P
0 g
s
.48359 .43941 m .48485 .45176 L .48372 .45477 L p .592 .457 .666 r
F P
0 g
s
.39037 .51166 m .402 .50946 L .4048 .50878 L p .291 .79 .83 r
F P
0 g
s
.48722 .4177 m .49032 .43146 L .49055 .43456 L p .602 .478 .684 r
F P
0 g
s
.62622 .44048 m .62541 .43827 L .62402 .43743 L p .905 .502 .214 r
F P
0 g
s
.61683 .43196 m .62402 .43743 L .62541 .43827 L p .897 .483 .188 r
F P
0 g
s
.62541 .43827 m .61514 .43044 L .61683 .43196 L p .897 .483 .188 r
F P
0 g
s
.62365 .43645 m .62384 .43698 L .62541 .43827 L p .907 .506 .224 r
F P
0 g
s
.61514 .43044 m .62541 .43827 L .62384 .43698 L p .908 .51 .231 r
F P
0 g
s
.60828 .62903 m .60809 .62677 L .60884 .62419 L p 0 0 .284 r
F P
0 g
s
.60941 .60754 m .60992 .60624 L .61011 .60362 L p .935 .818 .364 r
F P
0 g
s
.4412 .7359 m .42309 .76062 L .41518 .76428 L p .774 .717 .799 r
F P
0 g
s
.4588 .4875 m .46013 .4856 L .46212 .48735 L p .64 .453 .614 r
F P
0 g
s
.47274 .49388 m .46212 .48735 L .46013 .4856 L p .637 .453 .618 r
F P
0 g
s
.46013 .4856 m .4753 .49493 L .47274 .49388 L p .637 .453 .618 r
F P
0 g
s
.46333 .48555 m .4626 .48669 L .46013 .4856 L p .636 .452 .617 r
F P
0 g
s
.4753 .49493 m .46013 .4856 L .4626 .48669 L p .633 .456 .626 r
F P
0 g
s
.48535 .38604 m .47925 .36731 L .47665 .36372 L p .632 .54 .733 r
F P
0 g
s
.47226 .3597 m .46325 .33679 L .46085 .33204 L p .632 .566 .763 r
F P
0 g
s
.62334 .43539 m .61611 .42986 L .61464 .42897 L p .924 .558 .309 r
F P
0 g
s
.77878 .526 m .77961 .51271 L .7862 .51004 L p .645 .715 .899 r
F P
0 g
s
.48755 .39342 m .49336 .39153 L .49366 .38776 L p .622 .51 .705 r
F P
0 g
s
.49029 .40976 m .48835 .41042 L .48888 .41394 L p .613 .505 .707 r
F P
0 g
s
.44608 .49691 m .45168 .49249 L .45441 .49258 L p .579 .321 .489 r
F P
0 g
s
.48552 .59706 m .48178 .59057 L .48204 .58716 L p .925 .778 .679 r
F P
0 g
s
.66976 .49949 m .68317 .50223 L .68616 .50508 L p .584 .616 .85 r
F P
0 g
s
.60991 .60077 m .60731 .58926 L .60639 .58717 L p .988 .771 .52 r
F P
0 g
s
.60639 .58717 m .61011 .60362 L .60991 .60077 L p .988 .771 .52 r
F P
0 g
s
.48553 .36084 m .47665 .36372 L .47925 .36731 L p .632 .541 .733 r
F P
0 g
s
.46558 .33594 m .47432 .35897 L .47665 .36372 L p .632 .566 .763 r
F P
0 g
s
.47665 .36372 m .46418 .33083 L .46558 .33594 L p .632 .566 .763 r
F P
0 g
s
.48242 .35632 m .47621 .35835 L .47665 .36372 L p .641 .571 .761 r
F P
0 g
s
.47665 .36372 m .48553 .36084 L .48242 .35632 L p .641 .571 .761 r
F P
0 g
s
.46418 .33083 m .47665 .36372 L .47621 .35835 L p .641 .571 .761 r
F P
0 g
s
.4169 .5053 m .40732 .50846 L .4048 .50878 L p .328 0 0 r
F P
0 g
s
.49326 .43048 m .49001 .41673 L .48888 .41394 L p .605 .48 .683 r
F P
0 g
s
.48888 .41394 m .49352 .43357 L .49326 .43048 L p .605 .48 .683 r
F P
0 g
s
.49165 .413 m .48888 .41394 L .49001 .41673 L p .605 .48 .683 r
F P
0 g
s
.48888 .41394 m .49165 .413 L .49029 .40976 L p .613 .505 .707 r
F P
0 g
s
.4924 .43077 m .48915 .41703 L .48888 .41394 L p .602 .478 .684 r
F P
0 g
s
.48888 .41394 m .49352 .43357 L .4924 .43077 L p .602 .478 .684 r
F P
0 g
s
.21114 .52808 m .26677 .5268 L .25828 .52473 L p .656 .775 .937 r
F P
0 g
s
.25766 .51535 m .25828 .52473 L .26677 .5268 L p .647 .777 .943 r
F P
0 g
s
.26677 .5268 m .26596 .51341 L .25766 .51535 L p .647 .777 .943 r
F P
0 g
s
.30271 .5234 m .27303 .52475 L .26677 .5268 L p .654 .794 .949 r
F P
0 g
s
.26596 .51341 m .26677 .5268 L .27303 .52475 L p .656 .783 .942 r
F P
0 g
s
.45441 .49258 m .4588 .4875 L .46 .48987 L p .645 .449 .603 r
F P
0 g
s
.46989 .49703 m .46 .48987 L .4588 .4875 L p .65 .45 .6 r
F P
0 g
s
.4588 .4875 m .47294 .49772 L .46989 .49703 L p .65 .45 .6 r
F P
0 g
s
.46212 .48735 m .46119 .48868 L .4588 .4875 L p .64 .453 .614 r
F P
0 g
s
.47294 .49772 m .4588 .4875 L .46119 .48868 L p .638 .455 .619 r
F P
0 g
s
.60053 .67273 m .60944 .6643 L .61197 .66405 L p .425 .325 .638 r
F P
0 g
s
.61011 .60362 m .60938 .60547 L .60941 .60754 L p .935 .818 .364 r
F P
0 g
s
.6068 .58991 m .6094 .60143 L .61011 .60362 L p .995 .758 .429 r
F P
0 g
s
.61011 .60362 m .60639 .58717 L .6068 .58991 L p .995 .758 .429 r
F P
0 g
s
.60938 .60547 m .61011 .60362 L .6094 .60143 L p .992 .743 .385 r
F P
0 g
s
.60557 .64364 m .60928 .63376 L .61024 .6324 L p .003 0 .439 r
F P
0 g
s
.48852 .57534 m .48635 .57215 L .48704 .56935 L p .915 .785 .703 r
F P
0 g
s
.47925 .36731 m .48546 .3653 L .48553 .36084 L p .632 .541 .733 r
F P
0 g
s
.61007 .41013 m .61004 .41577 L .61244 .41768 L p .841 .602 .578 r
F P
0 g
s
.31398 .52316 m .31379 .51598 L .30881 .51462 L p .653 .807 .957 r
F P
0 g
s
.62857 .44502 m .6273 .44266 L .62622 .44048 L p 0 0 .373 r
F P
0 g
s
.44638 .33049 m .45301 .32774 L .45752 .33324 L p .633 .594 .792 r
F P
0 g
s
.46402 .48423 m .47514 .49012 L .47704 .4924 L p .625 .458 .636 r
F P
0 g
s
.60885 .60846 m .60884 .62419 L .60886 .62157 L p .784 .652 .096 r
F P
0 g
s
.60884 .62419 m .60911 .62741 L .60828 .62903 L p 0 0 .284 r
F P
0 g
s
.60887 .61131 m .60887 .62232 L .60884 .62419 L p 0 0 .068 r
F P
0 g
s
.60886 .62157 m .60887 .61056 L .60885 .60846 L p .784 .652 .096 r
F P
0 g
s
.60884 .62419 m .60885 .60846 L .60887 .61131 L p 0 0 .068 r
F P
0 g
s
.60911 .62741 m .60884 .62419 L .60887 .62232 L p 0 0 .11 r
F P
0 g
s
.66467 .48784 m .65532 .48479 L .65336 .48192 L p .514 .534 .815 r
F P
0 g
s
.62358 .43624 m .61637 .43074 L .61485 .42965 L p .92 .546 .289 r
F P
0 g
s
.60159 .37411 m .60499 .35885 L .60233 .35422 L p .811 .682 .723 r
F P
0 g
s
.60233 .35422 m .59747 .37604 L .60159 .37411 L p .811 .682 .723 r
F P
0 g
s
.49001 .41673 m .49195 .41608 L .49165 .413 L p .605 .48 .683 r
F P
0 g
s
.44107 .72892 m .41518 .76428 L .41613 .75741 L p .79 .744 .81 r
F P
0 g
s
.40102 .74946 m .41613 .75741 L .41518 .76428 L p .791 .744 .81 r
F P
0 g
s
.41518 .76428 m .39357 .75296 L .40102 .74946 L p .791 .744 .81 r
F P
0 g
s
.41518 .76428 m .44107 .72892 L .4412 .7359 L p .774 .717 .799 r
F P
0 g
s
.39357 .75296 m .41518 .76428 L .40592 .76907 L p .769 .753 .838 r
F P
0 g
s
.6078 .35166 m .61456 .33143 L .61199 .32528 L p .794 .7 .761 r
F P
0 g
s
.61199 .32528 m .60233 .35422 L .6078 .35166 L p .794 .7 .761 r
F P
0 g
s
.4626 .48669 m .47322 .49321 L .4753 .49493 L p .633 .456 .626 r
F P
0 g
s
.66672 .48627 m .65336 .48192 L .65491 .48051 L p .47 .558 .863 r
F P
0 g
s
.65318 .471 m .65491 .48051 L .65336 .48192 L p .461 .543 .854 r
F P
0 g
s
.65336 .48192 m .65088 .46834 L .65318 .471 L p .461 .543 .854 r
F P
0 g
s
.65336 .48192 m .66672 .48627 L .66467 .48784 L p .514 .534 .815 r
F P
0 g
s
.65088 .46834 m .65336 .48192 L .65164 .47918 L p .358 .464 .832 r
F P
0 g
s
.61471 .42366 m .61421 .41978 L .61244 .41768 L p .933 .633 .451 r
F P
0 g
s
.49459 .55566 m .48744 .56655 L .48704 .56935 L p .862 .752 .741 r
F P
0 g
s
.48405 .66299 m .47696 .67595 L .47301 .67714 L p .824 .68 .704 r
F P
0 g
s
.47301 .67714 m .48314 .65862 L .48405 .66299 L p .824 .68 .704 r
F P
0 g
s
.40592 .76907 m .39078 .76119 L .39357 .75296 L p .769 .753 .838 r
F P
0 g
s
.49781 .55121 m .49024 .54909 L .48642 .55077 L p .804 .8 .848 r
F P
0 g
s
.4048 .50878 m .38817 .51192 L .39037 .51166 L p .291 .79 .83 r
F P
0 g
s
.38817 .51192 m .4048 .50878 L .40264 .50924 L p 0 0 0 r
F P
0 g
s
.40437 .51001 m .40264 .50924 L .4048 .50878 L p .187 0 0 r
F P
0 g
s
.4048 .50878 m .40729 .50989 L .40437 .51001 L p .187 0 0 r
F P
0 g
s
.40729 .50989 m .4048 .50878 L .40732 .50846 L p .16 0 0 r
F P
0 g
s
.63671 .45816 m .64064 .46141 L .64232 .46376 L p 0 .269 .775 r
F P
0 g
s
.4965 .43253 m .49165 .413 L .49195 .41608 L p .605 .48 .683 r
F P
0 g
s
.49705 .42913 m .49365 .41546 L .49165 .413 L p .612 .485 .683 r
F P
0 g
s
.49165 .413 m .4965 .43253 L .49705 .42913 L p .612 .485 .683 r
F P
0 g
s
.4999 .41011 m .49165 .413 L .49365 .41546 L p .613 .485 .682 r
F P
0 g
s
.49772 .40717 m .49195 .4092 L .49165 .413 L p .621 .51 .705 r
F P
0 g
s
.49165 .413 m .4999 .41011 L .49772 .40717 L p .621 .51 .705 r
F P
0 g
s
.48116 .46841 m .48134 .4572 L .48372 .45477 L p .589 .447 .656 r
F P
0 g
s
.59889 .39106 m .60015 .37956 L .59747 .37604 L p .824 .66 .679 r
F P
0 g
s
.62384 .43698 m .61665 .43151 L .61514 .43044 L p .908 .51 .231 r
F P
0 g
s
.46119 .48868 m .47109 .49583 L .47294 .49772 L p .638 .455 .619 r
F P
0 g
s
.44642 .4989 m .45441 .49258 L .45448 .49511 L p .648 .427 .569 r
F P
0 g
s
.46189 .50305 m .45448 .49511 L .45441 .49258 L p .671 .445 .569 r
F P
0 g
s
.45441 .49258 m .46501 .50392 L .46189 .50305 L p .671 .445 .569 r
F P
0 g
s
.45441 .49258 m .44642 .4989 L .44608 .49691 L p .579 .321 .489 r
F P
0 g
s
.46 .48987 m .45692 .49343 L .45441 .49258 L p .645 .449 .603 r
F P
0 g
s
.46501 .50392 m .45441 .49258 L .45692 .49343 L p .646 .446 .597 r
F P
0 g
s
.83234 .52766 m .83375 .51212 L .8425 .50881 L p .65 .73 .908 r
F P
0 g
s
.47621 .35835 m .46748 .33532 L .46418 .33083 L p .641 .571 .761 r
F P
0 g
s
.63894 .73661 m .65612 .75913 L .65584 .76662 L p .565 .566 .813 r
F P
0 g
s
.65584 .76662 m .63134 .73451 L .63894 .73661 L p .565 .566 .813 r
F P
0 g
s
.68595 .74678 m .65584 .76662 L .65612 .75913 L p .564 .566 .813 r
F P
0 g
s
.68775 .75566 m .66664 .76949 L .65584 .76662 L p .584 .609 .843 r
F P
0 g
s
.65584 .76662 m .68595 .74678 L .68775 .75566 L p .584 .609 .843 r
F P
0 g
s
.65164 .47918 m .6499 .46968 L .65088 .46834 L p .358 .464 .832 r
F P
0 g
s
.6094 .60143 m .60889 .60272 L .60938 .60547 L p .992 .743 .385 r
F P
0 g
s
.49195 .41608 m .49534 .42975 L .4965 .43253 L p .605 .48 .683 r
F P
0 g
s
.62402 .43743 m .62458 .43898 L .62622 .44048 L p .905 .502 .214 r
F P
0 g
s
.32444 .79278 m .27574 .82723 L .26204 .83262 L p .752 .774 .871 r
F P
0 g
s
.33169 .78332 m .26204 .83262 L .27057 .82401 L p .756 .785 .877 r
F P
0 g
s
.26071 .81718 m .27057 .82401 L .26204 .83262 L p .756 .785 .877 r
F P
0 g
s
.26204 .83262 m .24789 .82292 L .26071 .81718 L p .756 .785 .877 r
F P
0 g
s
.26204 .83262 m .33169 .78332 L .32444 .79278 L p .752 .774 .871 r
F P
0 g
s
.25828 .52473 m .21928 .52562 L .21114 .52808 L p .656 .775 .937 r
F P
0 g
s
.20946 .51096 m .21114 .52808 L .21928 .52562 L p .656 .769 .932 r
F P
0 g
s
.62622 .44048 m .62804 .44386 L .62857 .44502 L p 0 0 .373 r
F P
0 g
s
.62804 .44386 m .62622 .44048 L .625 .43983 L p .853 .395 .05 r
F P
0 g
s
.61797 .4344 m .625 .43983 L .62622 .44048 L p .85 .391 .044 r
F P
0 g
s
.62622 .44048 m .61617 .43271 L .61797 .4344 L p .85 .391 .044 r
F P
0 g
s
.61617 .43271 m .62622 .44048 L .62458 .43898 L p .898 .483 .182 r
F P
0 g
s
.47453 .64762 m .48266 .65481 L .48314 .65862 L p .868 .711 .685 r
F P
0 g
s
.48314 .65862 m .47153 .64836 L .47453 .64762 L p .868 .711 .685 r
F P
0 g
s
.4727 .67289 m .4798 .65992 L .48314 .65862 L p .851 .718 .716 r
F P
0 g
s
.48314 .65862 m .47301 .67714 L .4727 .67289 L p .851 .718 .716 r
F P
0 g
s
.47153 .64836 m .48314 .65862 L .4798 .65992 L p .851 .719 .716 r
F P
0 g
s
.70714 .50989 m .68975 .50782 L .68616 .50508 L p .62 .643 .852 r
F P
0 g
s
.66487 .29538 m .6393 .28231 L .62879 .28676 L p .757 .722 .819 r
F P
0 g
s
.60219 .67639 m .60645 .68653 L .60531 .69057 L p .473 .4 .694 r
F P
0 g
s
.48546 .3653 m .49115 .38414 L .49366 .38776 L p .632 .54 .733 r
F P
0 g
s
.48347 .47079 m .48372 .45477 L .48539 .4569 L p .599 .455 .657 r
F P
0 g
s
.49244 .45529 m .48539 .4569 L .48372 .45477 L p .593 .454 .661 r
F P
0 g
s
.48372 .45477 m .49379 .45246 L .49244 .45529 L p .593 .454 .661 r
F P
0 g
s
.48372 .45477 m .48347 .47079 L .48116 .46841 L p .589 .447 .656 r
F P
0 g
s
.49379 .45246 m .48372 .45477 L .48485 .45176 L p .595 .46 .667 r
F P
0 g
s
.43591 .5025 m .44365 .49874 L .44642 .4989 L p .577 .26 .394 r
F P
0 g
s
.49032 .43146 m .4924 .43077 L .49352 .43357 L p .602 .478 .684 r
F P
0 g
s
.49352 .43357 m .49055 .43456 L .49032 .43146 L p .602 .478 .684 r
F P
0 g
s
.48485 .45176 m .4919 .45014 L .49379 .45246 L p .595 .46 .667 r
F P
0 g
s
.46231 .33713 m .45998 .33797 L .45752 .33324 L p .632 .566 .763 r
F P
0 g
s
.49336 .39153 m .49772 .40717 L .4999 .41011 L p .622 .51 .705 r
F P
0 g
s
.4999 .41011 m .49366 .38776 L .49336 .39153 L p .622 .51 .705 r
F P
0 g
s
.60612 .64549 m .60779 .65064 L .60733 .65386 L p .152 .116 .56 r
F P
0 g
s
.59884 .56852 m .59235 .55816 L .58985 .55606 L p .862 .557 .469 r
F P
0 g
s
.49365 .41546 m .49943 .41344 L .4999 .41011 L p .613 .485 .682 r
F P
0 g
s
.501 .40608 m .49664 .39043 L .49366 .38776 L p .637 .519 .703 r
F P
0 g
s
.49366 .38776 m .4999 .41011 L .501 .40608 L p .637 .519 .703 r
F P
0 g
s
.50742 .38351 m .49366 .38776 L .49664 .39043 L p .637 .519 .702 r
F P
0 g
s
.49366 .38776 m .48553 .36084 L .48546 .3653 L p .632 .54 .733 r
F P
0 g
s
.50422 .38011 m .49459 .3831 L .49366 .38776 L p .646 .549 .73 r
F P
0 g
s
.49366 .38776 m .50742 .38351 L .50422 .38011 L p .646 .549 .73 r
F P
0 g
s
.48553 .36084 m .49366 .38776 L .49459 .3831 L p .647 .549 .73 r
F P
0 g
s
.45692 .49343 m .46434 .50136 L .46501 .50392 L p .646 .446 .597 r
F P
0 g
s
.61316 .42323 m .61244 .41768 L .61028 .4179 L p .842 .565 .52 r
F P
0 g
s
.59938 .41488 m .61028 .4179 L .61244 .41768 L p .841 .563 .517 r
F P
0 g
s
.61244 .41768 m .59688 .41336 L .59938 .41488 L p .841 .563 .517 r
F P
0 g
s
.61244 .41768 m .61316 .42323 L .61471 .42366 L p .933 .633 .451 r
F P
0 g
s
.59688 .41336 m .61244 .41768 L .61004 .41577 L p .842 .6 .574 r
F P
0 g
s
.4919 .45014 m .48963 .43761 L .49055 .43456 L p .593 .459 .668 r
F P
0 g
s
.61047 .7082 m .60343 .69486 L .60531 .69057 L p .584 .496 .721 r
F P
0 g
s
.40732 .50846 m .40907 .50923 L .40729 .50989 L p .16 0 0 r
F P
0 g
s
.49379 .45246 m .49055 .43456 L .49152 .43708 L p .597 .462 .668 r
F P
0 g
s
.4936 .4364 m .49152 .43708 L .49055 .43456 L p .596 .462 .668 r
F P
0 g
s
.49055 .43456 m .49352 .43357 L .4936 .4364 L p .596 .462 .668 r
F P
0 g
s
.49055 .43456 m .49379 .45246 L .4919 .45014 L p .593 .459 .668 r
F P
0 g
s
.60887 .62232 m .60905 .62458 L .60911 .62741 L p 0 0 .11 r
F P
0 g
s
.59566 .39248 m .59747 .37604 L .5938 .37819 L p .77 .61 .68 r
F P
0 g
s
.57695 .3762 m .5938 .37819 L .59747 .37604 L p .77 .609 .679 r
F P
0 g
s
.59747 .37604 m .5734 .37319 L .57695 .3762 L p .77 .609 .679 r
F P
0 g
s
.59747 .37604 m .59566 .39248 L .59889 .39106 L p .824 .66 .679 r
F P
0 g
s
.59773 .35691 m .59433 .37219 L .59747 .37604 L p .766 .637 .718 r
F P
0 g
s
.59747 .37604 m .60233 .35422 L .59773 .35691 L p .766 .637 .718 r
F P
0 g
s
.5734 .37319 m .59747 .37604 L .59433 .37219 L p .766 .637 .718 r
F P
0 g
s
.5783 .3535 m .59773 .35691 L .60233 .35422 L p .766 .636 .718 r
F P
0 g
s
.60233 .35422 m .57458 .34934 L .5783 .3535 L p .766 .636 .718 r
F P
0 g
s
.60597 .32871 m .59921 .34898 L .60233 .35422 L p .758 .66 .753 r
F P
0 g
s
.60233 .35422 m .61199 .32528 L .60597 .32871 L p .758 .66 .753 r
F P
0 g
s
.57458 .34934 m .60233 .35422 L .59921 .34898 L p .758 .66 .753 r
F P
0 g
s
.45752 .33324 m .46085 .33204 L .46231 .33713 L p .632 .566 .763 r
F P
0 g
s
.44134 .29803 m .45513 .32689 L .45752 .33324 L p .641 .598 .79 r
F P
0 g
s
.45752 .33324 m .43782 .29203 L .44134 .29803 L p .641 .598 .79 r
F P
0 g
s
.46085 .33204 m .45752 .33324 L .45513 .32689 L p .641 .598 .79 r
F P
0 g
s
.43782 .29203 m .45752 .33324 L .45301 .32774 L p .633 .594 .793 r
F P
0 g
s
.27303 .52475 m .2725 .51538 L .26596 .51341 L p .656 .783 .942 r
F P
0 g
s
.45448 .49511 m .44888 .49954 L .44642 .4989 L p .648 .427 .569 r
F P
0 g
s
.71103 .50803 m .68616 .50508 L .68965 .50314 L p .61 .657 .872 r
F P
0 g
s
.68877 .49233 m .68965 .50314 L .68616 .50508 L p .605 .643 .862 r
F P
0 g
s
.68616 .50508 m .68489 .48965 L .68877 .49233 L p .605 .643 .862 r
F P
0 g
s
.68616 .50508 m .71103 .50803 L .70714 .50989 L p .62 .643 .852 r
F P
0 g
s
.68489 .48965 m .68616 .50508 L .68317 .50223 L p .565 .612 .858 r
F P
0 g
s
.60918 .60839 m .60931 .60793 L .60938 .60547 L p .896 .772 .278 r
F P
0 g
s
.58985 .55606 m .59913 .57087 L .59884 .56852 L p .862 .557 .469 r
F P
0 g
s
.58727 .55904 m .5907 .55846 L .58985 .55606 L p .89 .544 .385 r
F P
0 g
s
.58985 .55606 m .58495 .55688 L .58727 .55904 L p .89 .544 .385 r
F P
0 g
s
.59913 .57087 m .58985 .55606 L .5907 .55846 L p .894 .546 .378 r
F P
0 g
s
.58495 .55688 m .58985 .55606 L .5875 .55441 L p .817 .393 .237 r
F P
0 g
s
.37053 .51417 m .38492 .51278 L .38817 .51192 L p .514 .869 .988 r
F P
0 g
s
.49459 .3831 m .48889 .36424 L .48553 .36084 L p .647 .549 .73 r
F P
0 g
s
.5875 .55441 m .58406 .55498 L .58495 .55688 L p .817 .393 .237 r
F P
0 g
s
.62458 .43898 m .61755 .43354 L .61617 .43271 L p .898 .483 .182 r
F P
0 g
s
.48539 .4569 m .48522 .46812 L .48347 .47079 L p .599 .455 .657 r
F P
0 g
s
.61004 .41577 m .59914 .41275 L .59688 .41336 L p .842 .6 .574 r
F P
0 g
s
.49664 .39043 m .50626 .38746 L .50742 .38351 L p .637 .519 .702 r
F P
0 g
s
.49152 .43708 m .49379 .44962 L .49379 .45246 L p .597 .462 .668 r
F P
0 g
s
.43536 .50428 m .44642 .4989 L .44549 .50096 L p .642 .371 .494 r
F P
0 g
s
.44985 .50791 m .44549 .50096 L .44642 .4989 L p .682 .416 .513 r
F P
0 g
s
.44642 .4989 m .45265 .50883 L .44985 .50791 L p .682 .416 .513 r
F P
0 g
s
.44642 .4989 m .43536 .50428 L .43591 .5025 L p .577 .26 .394 r
F P
0 g
s
.45265 .50883 m .44642 .4989 L .44888 .49954 L p .651 .408 .538 r
F P
0 g
s
.49534 .42975 m .49326 .43048 L .49352 .43357 L p .605 .48 .683 r
F P
0 g
s
.50044 .35668 m .48553 .36084 L .48889 .36424 L p .647 .549 .73 r
F P
0 g
s
.47459 .33308 m .48242 .35632 L .48553 .36084 L p .641 .571 .761 r
F P
0 g
s
.48553 .36084 m .47433 .32763 L .47459 .33308 L p .641 .571 .761 r
F P
0 g
s
.49669 .3523 m .48625 .35522 L .48553 .36084 L p .654 .579 .758 r
F P
0 g
s
.48553 .36084 m .50044 .35668 L .49669 .3523 L p .654 .579 .758 r
F P
0 g
s
.47433 .32763 m .48553 .36084 L .48625 .35522 L p .654 .579 .758 r
F P
0 g
s
.40264 .50924 m .39099 .51144 L .38817 .51192 L p 0 0 0 r
F P
0 g
s
.46325 .33679 m .46558 .33594 L .46418 .33083 L p .632 .566 .763 r
F P
0 g
s
.46418 .33083 m .46085 .33204 L .46325 .33679 L p .632 .566 .763 r
F P
0 g
s
.40632 .29667 m .41851 .29054 L .4264 .2969 L p .63 .62 .821 r
F P
0 g
s
.39078 .76119 m .36046 .79047 L .35023 .79485 L p .769 .753 .838 r
F P
0 g
s
.33745 .8008 m .32444 .79278 L .33169 .78332 L p .752 .774 .871 r
F P
0 g
s
.33169 .78332 m .35023 .79485 L .33745 .8008 L p .752 .774 .871 r
F P
0 g
s
.47968 .58442 m .48704 .56935 L .48635 .57215 L p .912 .781 .704 r
F P
0 g
s
.48275 .5662 m .48704 .56935 L .48744 .56655 L p .882 .771 .736 r
F P
0 g
s
.48242 .56899 m .48542 .57119 L .48704 .56935 L p .898 .759 .699 r
F P
0 g
s
.48704 .56935 m .48275 .5662 L .48242 .56899 L p .898 .759 .699 r
F P
0 g
s
.47968 .58442 m .48704 .56935 L .48542 .57119 L p .901 .764 .701 r
F P
0 g
s
.49718 .44853 m .49456 .43607 L .49352 .43357 L p .599 .463 .668 r
F P
0 g
s
.49352 .43357 m .49726 .45138 L .49718 .44853 L p .599 .463 .668 r
F P
0 g
s
.4965 .43253 m .49352 .43357 L .49456 .43607 L p .599 .464 .668 r
F P
0 g
s
.49352 .43357 m .4965 .43253 L .49534 .42975 L p .605 .48 .683 r
F P
0 g
s
.49622 .44886 m .4936 .4364 L .49352 .43357 L p .597 .462 .668 r
F P
0 g
s
.49352 .43357 m .49726 .45138 L .49622 .44886 L p .597 .462 .668 r
F P
0 g
s
.45301 .32774 m .43922 .2989 L .43782 .29203 L p .633 .594 .793 r
F P
0 g
s
.59433 .37219 m .57748 .37019 L .5734 .37319 L p .766 .637 .718 r
F P
0 g
s
.60938 .60547 m .6092 .60613 L .60918 .60839 L p .896 .772 .278 r
F P
0 g
s
.48889 .36424 m .49933 .36134 L .50044 .35668 L p .647 .549 .73 r
F P
0 g
s
.51797 .52951 m .49419 .51198 L .49244 .50834 L p .745 .636 .739 r
F P
0 g
s
.65491 .48051 m .66427 .48355 L .66672 .48627 L p .47 .558 .863 r
F P
0 g
s
.62013 .67763 m .60531 .69057 L .60645 .68653 L p .471 .398 .693 r
F P
0 g
s
.60531 .69057 m .61538 .70964 L .61047 .7082 L p .584 .496 .721 r
F P
0 g
s
.61965 .68233 m .60926 .69138 L .60531 .69057 L p .51 .462 .739 r
F P
0 g
s
.60531 .69057 m .62013 .67763 L .61965 .68233 L p .51 .462 .739 r
F P
0 g
s
.61538 .70964 m .60531 .69057 L .60926 .69138 L p .51 .462 .739 r
F P
0 g
s
.68317 .50223 m .68227 .49143 L .68489 .48965 L p .565 .612 .858 r
F P
0 g
s
.48635 .57215 m .4812 .5827 L .47968 .58442 L p .912 .781 .704 r
F P
0 g
s
.59841 .40366 m .59832 .39514 L .59566 .39248 L p .835 .63 .626 r
F P
0 g
s
.5662 .54251 m .56377 .54218 L .56685 .54324 L p .347 0 0 r
F P
0 g
s
.56685 .54324 m .5703 .54371 L .5662 .54251 L p .347 0 0 r
F P
0 g
s
.60509 .58895 m .60938 .60547 L .60889 .60272 L p .994 .751 .427 r
F P
0 g
s
.6057 .59153 m .6087 .6031 L .60938 .60547 L p .989 .735 .368 r
F P
0 g
s
.60938 .60547 m .60509 .58895 L .6057 .59153 L p .989 .735 .368 r
F P
0 g
s
.6092 .60613 m .60938 .60547 L .6087 .6031 L p .982 .721 .33 r
F P
0 g
s
.5938 .37819 m .59253 .3897 L .59566 .39248 L p .77 .61 .68 r
F P
0 g
s
.625 .43983 m .62627 .4422 L .62804 .44386 L p .853 .395 .05 r
F P
0 g
s
.47871 .48165 m .48056 .47229 L .48347 .47079 L p .603 .454 .652 r
F P
0 g
s
.58406 .55498 m .57381 .54576 L .5703 .54371 L p .798 .386 .268 r
F P
0 g
s
.46089 .32479 m .45856 .32564 L .46085 .33204 L p .641 .598 .79 r
F P
0 g
s
.46085 .33204 m .46418 .33083 L .46089 .32479 L p .641 .598 .79 r
F P
0 g
s
.44185 .29053 m .46085 .33204 L .45856 .32564 L p .641 .598 .79 r
F P
0 g
s
.45513 .32689 m .45746 .32604 L .46085 .33204 L p .641 .598 .79 r
F P
0 g
s
.44185 .29053 m .46085 .33204 L .45746 .32604 L p .641 .598 .79 r
F P
0 g
s
.48744 .56655 m .48444 .56435 L .48275 .5662 L p .882 .771 .736 r
F P
0 g
s
.60907 .60897 m .60915 .60858 L .6092 .60613 L p .866 .74 .225 r
F P
0 g
s
.60928 .63376 m .60849 .63027 L .60911 .62741 L p 0 0 .422 r
F P
0 g
s
.4798 .65992 m .47166 .65274 L .47153 .64836 L p .851 .719 .716 r
F P
0 g
s
.60889 .60272 m .60589 .59116 L .60509 .58895 L p .994 .751 .427 r
F P
0 g
s
.44888 .49954 m .45324 .50649 L .45265 .50883 L p .651 .408 .538 r
F P
0 g
s
.60592 .58442 m .60084 .57302 L .59913 .57087 L p .93 .662 .509 r
F P
0 g
s
.59913 .57087 m .60639 .58717 L .60592 .58442 L p .93 .662 .509 r
F P
0 g
s
.63154 .44913 m .62933 .44616 L .62804 .44386 L p 0 0 .561 r
F P
0 g
s
.61028 .4179 m .61078 .42179 L .61316 .42323 L p .842 .565 .52 r
F P
0 g
s
.41613 .75741 m .43427 .73263 L .44107 .72892 L p .79 .744 .81 r
F P
0 g
s
.5703 .54371 m .58495 .55688 L .58406 .55498 L p .798 .386 .268 r
F P
0 g
s
.56974 .54536 m .57215 .54569 L .5703 .54371 L p .776 .275 0 r
F P
0 g
s
.5703 .54371 m .56685 .54324 L .56974 .54536 L p .776 .275 0 r
F P
0 g
s
.58495 .55688 m .5703 .54371 L .57215 .54569 L p .782 .289 .038 r
F P
0 g
s
.6499 .46968 m .64391 .46647 L .64232 .46376 L p .344 .444 .82 r
F P
0 g
s
.52035 .52695 m .50898 .50601 L .51016 .50349 L p .654 .637 .821 r
F P
0 g
s
.50525 .42918 m .4999 .41011 L .49943 .41344 L p .612 .484 .682 r
F P
0 g
s
.50648 .42552 m .50274 .41217 L .4999 .41011 L p .626 .492 .68 r
F P
0 g
s
.4999 .41011 m .50525 .42918 L .50648 .42552 L p .626 .492 .68 r
F P
0 g
s
.51337 .40537 m .4999 .41011 L .50274 .41217 L p .627 .492 .678 r
F P
0 g
s
.51043 .40276 m .501 .40608 L .4999 .41011 L p .636 .518 .702 r
F P
0 g
s
.4999 .41011 m .51337 .40537 L .51043 .40276 L p .636 .518 .702 r
F P
0 g
s
.48072 .63647 m .47453 .64762 L .47153 .64836 L p .868 .714 .688 r
F P
0 g
s
.47153 .64836 m .48037 .63243 L .48072 .63647 L p .868 .714 .688 r
F P
0 g
s
.61548 .42757 m .61489 .425 L .61316 .42323 L p .93 .59 .367 r
F P
0 g
s
.78659 .82632 m .7369 .79435 L .73356 .78301 L p .6 .647 .869 r
F P
0 g
s
.73356 .78301 m .80471 .82886 L .78659 .82632 L p .6 .647 .869 r
F P
0 g
s
.49943 .41344 m .50317 .42679 L .50525 .42918 L p .612 .484 .682 r
F P
0 g
s
.39357 .75296 m .35023 .79485 L .35425 .78705 L p .777 .77 .846 r
F P
0 g
s
.3413 .77893 m .35425 .78705 L .35023 .79485 L p .777 .77 .846 r
F P
0 g
s
.35023 .79485 m .33169 .78332 L .3413 .77893 L p .777 .77 .846 r
F P
0 g
s
.35023 .79485 m .39357 .75296 L .39078 .76119 L p .769 .753 .838 r
F P
0 g
s
.49456 .43607 m .49665 .43534 L .4965 .43253 L p .599 .464 .668 r
F P
0 g
s
.5907 .55846 m .59719 .56883 L .59913 .57087 L p .894 .546 .378 r
F P
0 g
s
.59921 .34898 m .57978 .34555 L .57458 .34934 L p .758 .66 .753 r
F P
0 g
s
.60944 .6643 m .6062 .65717 L .60733 .65386 L p .424 .322 .635 r
F P
0 g
s
.62479 .73245 m .61363 .71506 L .61538 .70964 L p .6 .541 .76 r
F P
0 g
s
.3676 .51391 m .38817 .51192 L .38535 .51186 L p .436 .85 .963 r
F P
0 g
s
.38661 .51095 m .38535 .51186 L .38817 .51192 L p .257 .759 .889 r
F P
0 g
s
.38817 .51192 m .38999 .51063 L .38661 .51095 L p .257 .759 .889 r
F P
0 g
s
.38817 .51192 m .3676 .51391 L .37053 .51417 L p .514 .869 .988 r
F P
0 g
s
.38999 .51063 m .38817 .51192 L .39099 .51144 L p .284 .782 .867 r
F P
0 g
s
.61538 .70964 m .63134 .73451 L .62479 .73245 L p .6 .541 .76 r
F P
0 g
s
.4748 .62265 m .48032 .62901 L .48037 .63243 L p .902 .742 .674 r
F P
0 g
s
.48037 .63243 m .47248 .62334 L .4748 .62265 L p .902 .742 .674 r
F P
0 g
s
.47165 .6447 m .47785 .63354 L .48037 .63243 L p .888 .743 .696 r
F P
0 g
s
.48037 .63243 m .47153 .64836 L .47165 .6447 L p .888 .743 .696 r
F P
0 g
s
.47248 .62334 m .48037 .63243 L .47785 .63354 L p .888 .746 .698 r
F P
0 g
s
.42349 .50662 m .43266 .50411 L .43536 .50428 L p .536 .129 .216 r
F P
0 g
s
.21928 .52562 m .21817 .51364 L .20946 .51096 L p .656 .769 .932 r
F P
0 g
s
.6092 .60613 m .60908 .6067 L .60907 .60897 L p .866 .74 .225 r
F P
0 g
s
.50317 .42679 m .49705 .42913 L .4965 .43253 L p .611 .484 .682 r
F P
0 g
s
.60892 .61169 m .60911 .62741 L .60905 .62458 L p 0 0 .06 r
F P
0 g
s
.60911 .62741 m .61024 .6324 L .60928 .63376 L p 0 0 .422 r
F P
0 g
s
.60911 .61481 m .60924 .62582 L .60911 .62741 L p 0 0 .281 r
F P
0 g
s
.60911 .62741 m .60892 .61169 L .60911 .61481 L p 0 0 .281 r
F P
0 g
s
.61024 .6324 m .60911 .62741 L .60924 .62582 L p 0 0 .303 r
F P
0 g
s
.33982 .26177 m .35798 .24891 L .37127 .25571 L p .629 .644 .846 r
F P
0 g
s
.65088 .46834 m .64232 .46376 L .6427 .46276 L p .191 .442 .869 r
F P
0 g
s
.63863 .45497 m .6427 .46276 L .64232 .46376 L p .184 .433 .865 r
F P
0 g
s
.64232 .46376 m .63652 .45264 L .63863 .45497 L p .184 .433 .865 r
F P
0 g
s
.64232 .46376 m .65088 .46834 L .6499 .46968 L p .344 .444 .82 r
F P
0 g
s
.63652 .45264 m .64232 .46376 L .64064 .46141 L p 0 .253 .765 r
F P
0 g
s
.50071 .45013 m .4965 .43253 L .49665 .43534 L p .599 .463 .668 r
F P
0 g
s
.50147 .44691 m .49852 .43459 L .4965 .43253 L p .603 .466 .668 r
F P
0 g
s
.4965 .43253 m .50071 .45013 L .50147 .44691 L p .603 .466 .668 r
F P
0 g
s
.50525 .42918 m .4965 .43253 L .49852 .43459 L p .604 .466 .666 r
F P
0 g
s
.4965 .43253 m .50525 .42918 L .50317 .42679 L p .611 .484 .682 r
F P
0 g
s
.48625 .35522 m .47841 .33197 L .47433 .32763 L p .654 .579 .758 r
F P
0 g
s
.59579 .40465 m .59566 .39248 L .59261 .39419 L p .771 .578 .638 r
F P
0 g
s
.57759 .39331 m .59261 .39419 L .59566 .39248 L p .77 .577 .637 r
F P
0 g
s
.59566 .39248 m .57421 .39121 L .57759 .39331 L p .77 .577 .637 r
F P
0 g
s
.59566 .39248 m .59579 .40465 L .59841 .40366 L p .835 .63 .626 r
F P
0 g
s
.57421 .39121 m .59566 .39248 L .59253 .3897 L p .771 .61 .679 r
F P
0 g
s
.48083 .48416 m .48347 .47079 L .48529 .47287 L p .618 .469 .656 r
F P
0 g
s
.49422 .47197 m .48529 .47287 L .48347 .47079 L p .605 .467 .666 r
F P
0 g
s
.48347 .47079 m .49623 .4695 L .49422 .47197 L p .605 .467 .666 r
F P
0 g
s
.48347 .47079 m .48083 .48416 L .47871 .48165 L p .603 .454 .652 r
F P
0 g
s
.49623 .4695 m .48347 .47079 L .48522 .46812 L p .605 .463 .662 r
F P
0 g
s
.44549 .50096 m .43774 .50473 L .43536 .50428 L p .642 .371 .494 r
F P
0 g
s
.6087 .6031 m .60857 .60356 L .6092 .60613 L p .982 .721 .33 r
F P
0 g
s
.60589 .59116 m .6068 .58991 L .60639 .58717 L p .995 .761 .459 r
F P
0 g
s
.51769 .53293 m .48887 .54121 L .48583 .54401 L p .752 .643 .74 r
F P
0 g
s
.60639 .58717 m .60509 .58895 L .60589 .59116 L p .995 .761 .459 r
F P
0 g
s
.59994 .57357 m .60503 .58498 L .60639 .58717 L p .954 .655 .43 r
F P
0 g
s
.60639 .58717 m .59913 .57087 L .59994 .57357 L p .954 .655 .43 r
F P
0 g
s
.60509 .58895 m .60639 .58717 L .60503 .58498 L p .956 .648 .406 r
F P
0 g
s
.48542 .57119 m .48027 .58174 L .47968 .58442 L p .901 .764 .701 r
F P
0 g
s
.46748 .33532 m .47459 .33308 L .47433 .32763 L p .641 .571 .761 r
F P
0 g
s
.47433 .32763 m .46418 .33083 L .46748 .33532 L p .641 .571 .761 r
F P
0 g
s
.60475 .5896 m .6092 .60613 L .60857 .60356 L p .989 .733 .368 r
F P
0 g
s
.60539 .59217 m .60851 .60374 L .6092 .60613 L p .983 .721 .333 r
F P
0 g
s
.6092 .60613 m .60475 .5896 L .60539 .59217 L p .983 .721 .333 r
F P
0 g
s
.60908 .6067 m .6092 .60613 L .60851 .60374 L p .975 .707 .297 r
F P
0 g
s
.48522 .46812 m .49414 .46721 L .49623 .4695 L p .605 .463 .662 r
F P
0 g
s
.6312 .44811 m .63154 .44913 L p .63035 .44734 L 0 0 .561 r
F P
0 g
s
.62804 .44386 m .6312 .44811 L p .63035 .44734 L 0 0 .561 r
F P
0 g
s
.63657 .45362 m .63285 .45045 L .6312 .44811 L p 0 .242 .757 r
F P
0 g
s
.6312 .44811 m .63054 .44762 L p .63214 .44897 L .485 0 0 r
F P
0 g
s
.6312 .44811 m .63652 .45264 L .63657 .45362 L p 0 .242 .757 r
F P
0 g
s
.63652 .45264 m .6312 .44811 L p .63214 .44897 L .485 0 0 r
F P
0 g
s
.6312 .44811 m .62804 .44386 L .62704 .44335 L p .755 .25 0 r
F P
0 g
s
.62012 .43799 m .62704 .44335 L .62804 .44386 L p .746 .236 0 r
F P
0 g
s
.62804 .44386 m .61814 .4362 L .62012 .43799 L p .746 .236 0 r
F P
0 g
s
.61814 .4362 m .62804 .44386 L .62627 .4422 L p .85 .39 .042 r
F P
0 g
s
.60645 .68653 m .61682 .67747 L .62013 .67763 L p .471 .398 .693 r
F P
0 g
s
.49665 .43534 m .49959 .44766 L .50071 .45013 L p .599 .463 .668 r
F P
0 g
s
.60887 .61056 m .60903 .60933 L .60908 .6067 L p .817 .687 .145 r
F P
0 g
s
.61946 .32193 m .63122 .29501 L .62879 .28676 L p .776 .713 .793 r
F P
0 g
s
.62879 .28676 m .61199 .32528 L .61946 .32193 L p .776 .713 .793 r
F P
0 g
s
.44808 .29554 m .46089 .32479 L .46418 .33083 L p .641 .598 .79 r
F P
0 g
s
.46418 .33083 m .44588 .28903 L .44808 .29554 L p .641 .598 .79 r
F P
0 g
s
.47024 .32181 m .46313 .32406 L .46418 .33083 L p .648 .602 .788 r
F P
0 g
s
.46418 .33083 m .47433 .32763 L .47024 .32181 L p .648 .602 .788 r
F P
0 g
s
.44588 .28903 m .46418 .33083 L .46313 .32406 L p .648 .602 .788 r
F P
0 g
s
.61304 .63956 m .60733 .65386 L .60779 .65064 L p .137 .102 .552 r
F P
0 g
s
.60733 .65386 m .61197 .66405 L .60944 .6643 L p .424 .322 .635 r
F P
0 g
s
.61294 .64321 m .60894 .65322 L .60733 .65386 L p .258 .236 .643 r
F P
0 g
s
.60733 .65386 m .61304 .63956 L .61294 .64321 L p .258 .236 .643 r
F P
0 g
s
.61197 .66405 m .60733 .65386 L .60894 .65322 L p .259 .238 .645 r
F P
0 g
s
.50274 .41217 m .51217 .40885 L .51337 .40537 L p .627 .492 .678 r
F P
0 g
s
.47514 .49012 m .47779 .48436 L .48083 .48416 L p .618 .457 .642 r
F P
0 g
s
.59253 .3897 m .57752 .38881 L .57421 .39121 L p .771 .61 .679 r
F P
0 g
s
.4812 .5827 m .48285 .58462 L .48204 .58716 L p .909 .774 .701 r
F P
0 g
s
.60905 .62458 m .60892 .61358 L .60892 .61169 L p 0 0 .06 r
F P
0 g
s
.45746 .32604 m .44416 .29699 L .44185 .29053 L p .641 .598 .79 r
F P
0 g
s
.64064 .46141 m .63657 .45362 L .63652 .45264 L p 0 .253 .765 r
F P
0 g
s
.61401 .4269 m .61316 .42323 L .6111 .42322 L p .84 .534 .471 r
F P
0 g
s
.60068 .42054 m .6111 .42322 L .61316 .42323 L p .838 .527 .464 r
F P
0 g
s
.61316 .42323 m .59828 .41939 L .60068 .42054 L p .838 .527 .464 r
F P
0 g
s
.61316 .42323 m .61401 .4269 L .61548 .42757 L p .93 .59 .367 r
F P
0 g
s
.59828 .41939 m .61316 .42323 L .61078 .42179 L p .842 .564 .516 r
F P
0 g
s
.68965 .50314 m .70708 .5052 L .71103 .50803 L p .61 .657 .872 r
F P
0 g
s
.47376 .68213 m .46432 .69835 L .45951 .70033 L p .808 .691 .736 r
F P
0 g
s
.45951 .70033 m .47301 .67714 L .47376 .68213 L p .808 .691 .736 r
F P
0 g
s
.4802 .61229 m .4748 .62265 L .47248 .62334 L p .902 .747 .679 r
F P
0 g
s
.47248 .62334 m .48021 .60855 L .4802 .61229 L p .902 .747 .679 r
F P
0 g
s
.60857 .60356 m .60546 .59199 L .60475 .5896 L p .989 .733 .368 r
F P
0 g
s
.39099 .51144 m .39227 .51053 L .38999 .51063 L p .284 .782 .867 r
F P
0 g
s
.47682 .60089 m .48049 .60553 L .48021 .60855 L p .917 .763 .676 r
F P
0 g
s
.48178 .59057 m .47682 .60089 L .47496 .60191 L p .919 .772 .682 r
F P
0 g
s
.47496 .60191 m .48204 .58716 L .48178 .59057 L p .919 .772 .682 r
F P
0 g
s
.49933 .36134 m .50422 .38011 L .50742 .38351 L p .647 .549 .73 r
F P
0 g
s
.42224 .50787 m .43536 .50428 L .43383 .50562 L p .607 .251 .341 r
F P
0 g
s
.43627 .51042 m .43383 .50562 L .43536 .50428 L p .667 .335 .401 r
F P
0 g
s
.43536 .50428 m .43885 .51114 L .43627 .51042 L p .667 .335 .401 r
F P
0 g
s
.43536 .50428 m .42224 .50787 L .42349 .50662 L p .536 .129 .216 r
F P
0 g
s
.43885 .51114 m .43536 .50428 L .43774 .50473 L p .637 .323 .423 r
F P
0 g
s
.48529 .47287 m .48344 .48223 L .48083 .48416 L p .618 .469 .656 r
F P
0 g
s
.53403 .53442 m .56289 .54187 L .56685 .54324 L p .217 .639 .954 r
F P
0 g
s
.48021 .60855 m .47496 .60191 L .47682 .60089 L p .917 .763 .676 r
F P
0 g
s
.47287 .62022 m .47829 .60986 L .48021 .60855 L p .912 .761 .682 r
F P
0 g
s
.48021 .60855 m .47248 .62334 L .47287 .62022 L p .912 .761 .682 r
F P
0 g
s
.47496 .60191 m .48021 .60855 L .47829 .60986 L p .912 .765 .684 r
F P
0 g
s
.49379 .44962 m .49622 .44886 L .49726 .45138 L p .597 .462 .668 r
F P
0 g
s
.49726 .45138 m .49379 .45246 L .49379 .44962 L p .597 .462 .668 r
F P
0 g
s
.48204 .58716 m .47968 .58442 L .4812 .5827 L p .909 .774 .701 r
F P
0 g
s
.4757 .59933 m .48066 .58901 L .48204 .58716 L p .917 .769 .682 r
F P
0 g
s
.48204 .58716 m .47496 .60191 L .4757 .59933 L p .917 .769 .682 r
F P
0 g
s
.47968 .58442 m .48204 .58716 L .48066 .58901 L p .918 .77 .683 r
F P
0 g
s
.48083 .48416 m .47704 .4924 L .47514 .49012 L p .618 .457 .642 r
F P
0 g
s
.49852 .43459 m .50464 .43224 L .50525 .42918 L p .604 .466 .666 r
F P
0 g
s
.57215 .54569 m .5824 .55491 L .58495 .55688 L p .782 .289 .038 r
F P
0 g
s
.52462 .52557 m .51325 .50462 L .51016 .50349 L p .637 .63 .826 r
F P
0 g
s
.50626 .38746 m .51043 .40276 L .51337 .40537 L p .637 .518 .702 r
F P
0 g
s
.51337 .40537 m .50742 .38351 L .50626 .38746 L p .637 .518 .702 r
F P
0 g
s
.60503 .58498 m .60412 .58623 L .60509 .58895 L p .956 .648 .406 r
F P
0 g
s
.45856 .32564 m .44526 .29658 L .44185 .29053 L p .641 .598 .79 r
F P
0 g
s
.60851 .60374 m .60842 .60414 L .60908 .6067 L p .975 .707 .297 r
F P
0 g
s
.6045 .59017 m .60908 .6067 L .60842 .60414 L p .983 .72 .333 r
F P
0 g
s
.60908 .6067 m .60885 .60846 L .60887 .61056 L p .817 .687 .145 r
F P
0 g
s
.60514 .59292 m .60834 .60449 L .60908 .6067 L p .968 .696 .273 r
F P
0 g
s
.60908 .6067 m .6045 .59017 L .60514 .59292 L p .968 .696 .273 r
F P
0 g
s
.60885 .60846 m .60908 .6067 L .60834 .60449 L p .958 .681 .242 r
F P
0 g
s
.65612 .75913 m .67716 .7452 L .68595 .74678 L p .564 .566 .813 r
F P
0 g
s
.47322 .49321 m .47444 .49144 L .47704 .4924 L p .629 .457 .631 r
F P
0 g
s
.49414 .46721 m .49244 .45529 L .49379 .45246 L p .6 .462 .665 r
F P
0 g
s
.59261 .39419 m .5927 .40272 L .59579 .40465 L p .771 .578 .638 r
F P
0 g
s
.60779 .65064 m .61179 .64063 L .61304 .63956 L p .137 .102 .552 r
F P
0 g
s
.62627 .4422 m .61935 .43684 L .61814 .4362 L p .85 .39 .042 r
F P
0 g
s
.47704 .4924 m .4753 .49493 L .47322 .49321 L p .629 .457 .631 r
F P
0 g
s
.51522 .40128 m .51105 .38598 L .50742 .38351 L p .659 .532 .698 r
F P
0 g
s
.50742 .38351 m .51337 .40537 L .51522 .40128 L p .659 .532 .698 r
F P
0 g
s
.5262 .37868 m .50742 .38351 L .51105 .38598 L p .659 .532 .697 r
F P
0 g
s
.50742 .38351 m .50044 .35668 L .49933 .36134 L p .647 .549 .73 r
F P
0 g
s
.52247 .37541 m .50932 .3788 L .50742 .38351 L p .667 .561 .726 r
F P
0 g
s
.50742 .38351 m .5262 .37868 L .52247 .37541 L p .667 .561 .726 r
F P
0 g
s
.50044 .35668 m .50742 .38351 L .50932 .3788 L p .667 .561 .726 r
F P
0 g
s
.59829 .5747 m .59994 .57357 L .59913 .57087 L p .95 .655 .444 r
F P
0 g
s
.59913 .57087 m .59677 .57248 L .59829 .5747 L p .95 .655 .444 r
F P
0 g
s
.59677 .57248 m .59913 .57087 L .59719 .56883 L p .895 .538 .359 r
F P
0 g
s
.49623 .4695 m .49379 .45246 L .49475 .45484 L p .598 .46 .665 r
F P
0 g
s
.49718 .45408 m .49475 .45484 L .49379 .45246 L p .596 .459 .665 r
F P
0 g
s
.49379 .45246 m .49726 .45138 L .49718 .45408 L p .596 .459 .665 r
F P
0 g
s
.49379 .45246 m .49623 .4695 L .49414 .46721 L p .6 .462 .665 r
F P
0 g
s
.73853 .51192 m .71579 .51073 L .71103 .50803 L p .634 .679 .875 r
F P
0 g
s
.47109 .49583 m .47274 .49388 L .4753 .49493 L p .636 .455 .621 r
F P
0 g
s
.34563 .51561 m .36366 .51497 L .3676 .51391 L p .597 .842 .991 r
F P
0 g
s
.61078 .42179 m .60036 .4191 L .59828 .41939 L p .842 .564 .516 r
F P
0 g
s
.47704 .4924 m .48083 .48416 L .48293 .4863 L p .651 .495 .659 r
F P
0 g
s
.49471 .48792 m .48293 .4863 L .48083 .48416 L p .627 .494 .68 r
F P
0 g
s
.48083 .48416 m .49766 .48646 L .49471 .48792 L p .627 .494 .68 r
F P
0 g
s
.49766 .48646 m .48083 .48416 L .48344 .48223 L p .628 .486 .669 r
F P
0 g
s
.58265 .32357 m .60597 .32871 L .61199 .32528 L p .758 .66 .753 r
F P
0 g
s
.61199 .32528 m .57866 .31791 L .58265 .32357 L p .758 .66 .753 r
F P
0 g
s
.62065 .29121 m .6089 .3182 L .61199 .32528 L p .748 .679 .784 r
F P
0 g
s
.61199 .32528 m .62879 .28676 L .62065 .29121 L p .748 .679 .784 r
F P
0 g
s
.57866 .31791 m .61199 .32528 L .6089 .3182 L p .748 .679 .784 r
F P
0 g
s
.27057 .82401 m .31936 .78946 L .33169 .78332 L p .756 .785 .877 r
F P
0 g
s
.4753 .49493 m .47294 .49772 L .47109 .49583 L p .636 .455 .621 r
F P
0 g
s
.61611 .42986 m .61567 .42841 L .61401 .4269 L p .922 .552 .3 r
F P
0 g
s
.46002 .70614 m .44712 .72613 L .44107 .72892 L p .792 .704 .768 r
F P
0 g
s
.43774 .50473 m .4402 .50953 L .43885 .51114 L p .637 .323 .423 r
F P
0 g
s
.60926 .69138 m .61632 .70475 L .61538 .70964 L p .51 .462 .739 r
F P
0 g
s
.46434 .50136 m .46989 .49703 L .47294 .49772 L p .65 .448 .596 r
F P
0 g
s
.60842 .60414 m .60522 .59257 L .6045 .59017 L p .983 .72 .333 r
F P
0 g
s
.59719 .56883 m .59554 .56995 L .59677 .57248 L p .895 .538 .359 r
F P
0 g
s
.38535 .51186 m .37093 .51325 L .3676 .51391 L p .436 .85 .963 r
F P
0 g
s
.63344 .69528 m .61538 .70964 L .61632 .70475 L p .509 .462 .739 r
F P
0 g
s
.63347 .70103 m .62081 .71106 L .61538 .70964 L p .541 .517 .779 r
F P
0 g
s
.61538 .70964 m .63344 .69528 L .63347 .70103 L p .541 .517 .779 r
F P
0 g
s
.63134 .73451 m .61538 .70964 L .62081 .71106 L p .541 .517 .779 r
F P
0 g
s
.62081 .71106 m .632 .72849 L .63134 .73451 L p .541 .517 .779 r
F P
0 g
s
.65426 .718 m .63134 .73451 L .632 .72849 L p .54 .517 .779 r
F P
0 g
s
.65502 .72509 m .63894 .73661 L .63134 .73451 L p .565 .566 .813 r
F P
0 g
s
.63134 .73451 m .65426 .718 L .65502 .72509 L p .565 .566 .813 r
F P
0 g
s
.46372 .6663 m .4727 .67289 L .47301 .67714 L p .85 .717 .716 r
F P
0 g
s
.47301 .67714 m .46016 .66774 L .46372 .6663 L p .85 .717 .716 r
F P
0 g
s
.45948 .69545 m .46894 .67921 L .47301 .67714 L p .832 .725 .747 r
F P
0 g
s
.47301 .67714 m .45951 .70033 L .45948 .69545 L p .832 .725 .747 r
F P
0 g
s
.46016 .66774 m .47301 .67714 L .46894 .67921 L p .832 .726 .748 r
F P
0 g
s
.50932 .3788 m .50444 .36001 L .50044 .35668 L p .667 .561 .726 r
F P
0 g
s
.47785 .63354 m .47232 .62718 L .47248 .62334 L p .888 .746 .698 r
F P
0 g
s
.48344 .48223 m .49522 .48384 L .49766 .48646 L p .628 .486 .669 r
F P
0 g
s
.49475 .45484 m .49646 .46677 L .49623 .4695 L p .598 .46 .665 r
F P
0 g
s
.51105 .38598 m .5242 .3826 L .5262 .37868 L p .659 .532 .697 r
F P
0 g
s
.60924 .62582 m .61004 .6293 L .61024 .6324 L p 0 0 .303 r
F P
0 g
s
.4753 .49493 m .47704 .4924 L .47947 .49452 L p .676 .518 .664 r
F P
0 g
s
.49263 .50141 m .47947 .49452 L .47704 .4924 L p .655 .521 .687 r
F P
0 g
s
.47704 .4924 m .49584 .50225 L .49263 .50141 L p .655 .521 .687 r
F P
0 g
s
.48293 .4863 m .48027 .49207 L .47704 .4924 L p .651 .495 .659 r
F P
0 g
s
.49584 .50225 m .47704 .4924 L .48027 .49207 L p .655 .521 .689 r
F P
0 g
s
.59914 .41275 m .59838 .40666 L .59579 .40465 L p .841 .597 .571 r
F P
0 g
s
.49959 .44766 m .49718 .44853 L .49726 .45138 L p .598 .463 .668 r
F P
0 g
s
.6111 .42322 m .61169 .42579 L .61401 .4269 L p .84 .534 .471 r
F P
0 g
s
.48066 .58901 m .479 .58709 L .47968 .58442 L p .918 .77 .683 r
F P
0 g
s
.68227 .49143 m .66956 .48906 L .66672 .48627 L p .556 .594 .846 r
F P
0 g
s
.48444 .56435 m .48701 .55355 L .48642 .55077 L p .868 .743 .723 r
F P
0 g
s
.47294 .49772 m .4753 .49493 L .47721 .49753 L p .688 .53 .666 r
F P
0 g
s
.48921 .50692 m .47721 .49753 L .4753 .49493 L p .678 .528 .674 r
F P
0 g
s
.4753 .49493 m .49244 .50834 L .48921 .50692 L p .678 .528 .674 r
F P
0 g
s
.47947 .49452 m .47825 .49629 L .4753 .49493 L p .676 .518 .664 r
F P
0 g
s
.49244 .50834 m .4753 .49493 L .47825 .49629 L p .664 .531 .692 r
F P
0 g
s
.60834 .60449 m .60818 .60573 L .60885 .60846 L p .958 .681 .242 r
F P
0 g
s
.62704 .44335 m .62926 .44633 L .6312 .44811 L p .755 .25 0 r
F P
0 g
s
.49024 .54909 m .48983 .54436 L .48583 .54401 L p .778 .672 .747 r
F P
0 g
s
.48583 .54401 m .48642 .55077 L .49024 .54909 L p .778 .672 .747 r
F P
0 g
s
.52109 .35229 m .50044 .35668 L .50444 .36001 L p .668 .561 .726 r
F P
0 g
s
.49038 .3288 m .49669 .3523 L .50044 .35668 L p .654 .579 .759 r
F P
0 g
s
.50044 .35668 m .49143 .32309 L .49038 .3288 L p .654 .579 .759 r
F P
0 g
s
.5169 .34792 m .50243 .351 L .50044 .35668 L p .673 .591 .755 r
F P
0 g
s
.50044 .35668 m .52109 .35229 L .5169 .34792 L p .673 .591 .755 r
F P
0 g
s
.49143 .32309 m .50044 .35668 L .50243 .351 L p .674 .591 .755 r
F P
0 g
s
.44107 .72892 m .45951 .70033 L .46002 .70614 L p .792 .704 .768 r
F P
0 g
s
.48642 .55077 m .48275 .5662 L .48444 .56435 L p .868 .743 .723 r
F P
0 g
s
.43383 .50562 m .42464 .50814 L .42224 .50787 L p .607 .251 .341 r
F P
0 g
s
.47294 .49772 m .46501 .50392 L .46434 .50136 L p .65 .448 .596 r
F P
0 g
s
.6427 .46276 m .64869 .46596 L .65088 .46834 L p .191 .442 .869 r
F P
0 g
s
.52755 .52643 m .52686 .50134 L .52538 .49758 L p .433 .47 .798 r
F P
0 g
s
.61401 .4269 m .61464 .42897 L .61611 .42986 L p .922 .552 .3 r
F P
0 g
s
.71961 .25753 m .7632 .21441 L .7666 .19859 L p .752 .753 .853 r
F P
0 g
s
.7666 .19859 m .70423 .26048 L .71961 .25753 L p .752 .753 .853 r
F P
0 g
s
.5008 .46549 m .49837 .45368 L .49726 .45138 L p .596 .459 .666 r
F P
0 g
s
.49726 .45138 m .50073 .46824 L .5008 .46549 L p .596 .459 .666 r
F P
0 g
s
.50071 .45013 m .49726 .45138 L .49837 .45368 L p .597 .46 .665 r
F P
0 g
s
.49726 .45138 m .50071 .45013 L .49959 .44766 L p .598 .463 .668 r
F P
0 g
s
.49961 .46588 m .49718 .45408 L .49726 .45138 L p .598 .461 .666 r
F P
0 g
s
.49726 .45138 m .50073 .46824 L .49961 .46588 L p .598 .461 .666 r
F P
0 g
s
.46313 .32406 m .45032 .29479 L .44588 .28903 L p .648 .602 .788 r
F P
0 g
s
.46501 .50392 m .47294 .49772 L .47312 .50083 L p .695 .525 .652 r
F P
0 g
s
.48228 .51184 m .47312 .50083 L .47294 .49772 L p .711 .537 .651 r
F P
0 g
s
.47294 .49772 m .48603 .51345 L .48228 .51184 L p .711 .537 .651 r
F P
0 g
s
.47721 .49753 m .47556 .49948 L .47294 .49772 L p .688 .53 .666 r
F P
0 g
s
.48603 .51345 m .47294 .49772 L .47556 .49948 L p .681 .533 .678 r
F P
0 g
s
.40907 .50923 m .41953 .50782 L .42224 .50787 L p .372 0 0 r
F P
0 g
s
.74355 .50973 m .71103 .50803 L .71559 .5057 L p .628 .689 .888 r
F P
0 g
s
.71437 .49414 m .71559 .5057 L .71103 .50803 L p .624 .678 .881 r
F P
0 g
s
.71103 .50803 m .70925 .49152 L .71437 .49414 L p .624 .678 .881 r
F P
0 g
s
.71103 .50803 m .74355 .50973 L .73853 .51192 L p .634 .679 .875 r
F P
0 g
s
.70925 .49152 m .71103 .50803 L .70708 .5052 L p .595 .656 .88 r
F P
0 g
s
.50444 .36001 m .5189 .35695 L .52109 .35229 L p .668 .561 .726 r
F P
0 g
s
.48027 .49207 m .49343 .49896 L .49584 .50225 L p .655 .521 .689 r
F P
0 g
s
.51051 .44573 m .50525 .42918 L .50464 .43224 L p .601 .463 .665 r
F P
0 g
s
.51182 .44219 m .50813 .43061 L .50525 .42918 L p .612 .469 .663 r
F P
0 g
s
.50525 .42918 m .51051 .44573 L .51182 .44219 L p .612 .469 .663 r
F P
0 g
s
.51899 .42326 m .50525 .42918 L .50813 .43061 L p .614 .468 .659 r
F P
0 g
s
.5161 .42137 m .50648 .42552 L .50525 .42918 L p .624 .49 .679 r
F P
0 g
s
.50525 .42918 m .51899 .42326 L .5161 .42137 L p .624 .49 .679 r
F P
0 g
s
.61637 .43074 m .61622 .43026 L .61464 .42897 L p .922 .551 .297 r
F P
0 g
s
.68489 .48965 m .66672 .48627 L .66885 .48461 L p .531 .618 .884 r
F P
0 g
s
.66647 .47476 m .66885 .48461 L .66672 .48627 L p .524 .605 .876 r
F P
0 g
s
.66672 .48627 m .66329 .47221 L .66647 .47476 L p .524 .605 .876 r
F P
0 g
s
.66672 .48627 m .68489 .48965 L .68227 .49143 L p .556 .594 .846 r
F P
0 g
s
.66329 .47221 m .66672 .48627 L .66427 .48355 L p .447 .549 .867 r
F P
0 g
s
.47829 .60986 m .47461 .60522 L .47496 .60191 L p .912 .765 .684 r
F P
0 g
s
.45324 .50649 m .46189 .50305 L .46501 .50392 L p .674 .43 .545 r
F P
0 g
s
.43922 .2989 m .43122 .3023 L .4264 .2969 L p .632 .594 .793 r
F P
0 g
s
.34181 .51481 m .3676 .51391 L .36396 .51334 L p .574 .846 .996 r
F P
0 g
s
.36502 .51083 m .36396 .51334 L .3676 .51391 L p .498 .831 .999 r
F P
0 g
s
.3676 .51391 m .36914 .51033 L .36502 .51083 L p .498 .831 .999 r
F P
0 g
s
.3676 .51391 m .34181 .51481 L .34563 .51561 L p .597 .842 .991 r
F P
0 g
s
.36914 .51033 m .3676 .51391 L .37093 .51325 L p .52 .853 .996 r
F P
0 g
s
.61464 .42897 m .61401 .4269 L .61197 .42667 L p .837 .509 .433 r
F P
0 g
s
.60188 .42414 m .61197 .42667 L .61401 .4269 L p .833 .496 .418 r
F P
0 g
s
.61401 .4269 m .59959 .42327 L .60188 .42414 L p .833 .496 .418 r
F P
0 g
s
.59959 .42327 m .61401 .4269 L .61169 .42579 L p .84 .528 .462 r
F P
0 g
s
.47825 .49629 m .49025 .50568 L .49244 .50834 L p .664 .531 .692 r
F P
0 g
s
.59688 .41336 m .59579 .40465 L .59312 .40599 L p .768 .546 .596 r
F P
0 g
s
.5794 .40587 m .59312 .40599 L .59579 .40465 L p .767 .542 .593 r
F P
0 g
s
.59579 .40465 m .57618 .40448 L .5794 .40587 L p .767 .542 .593 r
F P
0 g
s
.59579 .40465 m .59688 .41336 L .59914 .41275 L p .841 .597 .571 r
F P
0 g
s
.57618 .40448 m .59579 .40465 L .5927 .40272 L p .771 .578 .637 r
F P
0 g
s
.50464 .43224 m .50832 .44382 L .51051 .44573 L p .601 .463 .665 r
F P
0 g
s
.51217 .40885 m .5161 .42137 L .51899 .42326 L p .625 .49 .677 r
F P
0 g
s
.51899 .42326 m .51337 .40537 L .51217 .40885 L p .625 .49 .677 r
F P
0 g
s
.52078 .41956 m .51684 .40703 L .51337 .40537 L p .647 .502 .672 r
F P
0 g
s
.51337 .40537 m .51899 .42326 L .52078 .41956 L p .647 .502 .672 r
F P
0 g
s
.5312 .39945 m .51337 .40537 L .51684 .40703 L p .648 .502 .67 r
F P
0 g
s
.5277 .39714 m .51522 .40128 L .51337 .40537 L p .658 .531 .697 r
F P
0 g
s
.51337 .40537 m .5312 .39945 L .5277 .39714 L p .658 .531 .697 r
F P
0 g
s
.47556 .49948 m .48472 .51049 L .48603 .51345 L p .681 .533 .678 r
F P
0 g
s
.45951 .70033 m .44107 .72892 L .44144 .72319 L p .811 .734 .779 r
F P
0 g
s
.42926 .71617 m .44144 .72319 L .44107 .72892 L p .811 .733 .779 r
F P
0 g
s
.44107 .72892 m .42365 .71891 L .42926 .71617 L p .811 .733 .779 r
F P
0 g
s
.42365 .71891 m .44107 .72892 L .43427 .73263 L p .79 .743 .809 r
F P
0 g
s
.60894 .65322 m .61219 .66035 L .61197 .66405 L p .259 .238 .645 r
F P
0 g
s
.57748 .37019 m .5783 .3535 L .57458 .34934 L p .766 .636 .718 r
F P
0 g
s
.57458 .34934 m .5734 .37319 L .57748 .37019 L p .766 .636 .718 r
F P
0 g
s
.61464 .42897 m .61485 .42965 L .61637 .43074 L p .922 .551 .297 r
F P
0 g
s
.74909 .78503 m .79904 .81725 L .80471 .82886 L p .569 .645 .886 r
F P
0 g
s
.80471 .82886 m .73356 .78301 L .74909 .78503 L p .569 .645 .886 r
F P
0 g
s
.84401 .7918 m .80471 .82886 L .79904 .81725 L p .569 .645 .886 r
F P
0 g
s
.48337 .54587 m .48378 .55061 L .48642 .55077 L p .855 .727 .722 r
F P
0 g
s
.48642 .55077 m .48583 .54401 L .48337 .54587 L p .855 .727 .722 r
F P
0 g
s
.4694 .55458 m .48642 .55077 L .48378 .55061 L p .856 .715 .705 r
F P
0 g
s
.47176 .55585 m .48367 .55318 L .48642 .55077 L p .857 .716 .706 r
F P
0 g
s
.48642 .55077 m .4694 .55458 L .47176 .55585 L p .857 .716 .706 r
F P
0 g
s
.48275 .5662 m .48642 .55077 L .48367 .55318 L p .869 .744 .722 r
F P
0 g
s
.47312 .50083 m .46757 .50517 L .46501 .50392 L p .695 .525 .652 r
F P
0 g
s
.60892 .61358 m .60887 .61131 L .60885 .60846 L p 0 0 .023 r
F P
0 g
s
.35425 .78705 m .38461 .75769 L .39357 .75296 L p .777 .77 .846 r
F P
0 g
s
.61665 .43151 m .61644 .43095 L .61485 .42965 L p .91 .514 .237 r
F P
0 g
s
.49837 .45368 m .50078 .45281 L .50071 .45013 L p .597 .46 .665 r
F P
0 g
s
.5927 .40272 m .57898 .40259 L .57618 .40448 L p .771 .578 .637 r
F P
0 g
s
.57752 .38881 m .57695 .3762 L .5734 .37319 L p .77 .608 .678 r
F P
0 g
s
.47844 .58008 m .48242 .56899 L .48275 .5662 L p .902 .763 .698 r
F P
0 g
s
.48367 .55318 m .4811 .56399 L .48275 .5662 L p .869 .744 .722 r
F P
0 g
s
.47027 .5637 m .48275 .5662 L .4811 .56399 L p .884 .743 .7 r
F P
0 g
s
.48275 .5662 m .47707 .58205 L .47844 .58008 L p .902 .763 .698 r
F P
0 g
s
.47162 .5663 m .48036 .56804 L .48275 .5662 L p .887 .733 .686 r
F P
0 g
s
.48275 .5662 m .47027 .5637 L .47162 .5663 L p .887 .733 .686 r
F P
0 g
s
.47707 .58205 m .48275 .5662 L .48036 .56804 L p .893 .751 .697 r
F P
0 g
s
.66427 .48355 m .66187 .47371 L .66329 .47221 L p .447 .549 .867 r
F P
0 g
s
.47841 .33197 m .49038 .3288 L .49143 .32309 L p .654 .579 .758 r
F P
0 g
s
.49143 .32309 m .47433 .32763 L .47841 .33197 L p .654 .579 .758 r
F P
0 g
s
.60546 .59199 m .6057 .59153 L .60509 .58895 L p .993 .743 .396 r
F P
0 g
s
.61632 .70475 m .62895 .69468 L .63344 .69528 L p .509 .462 .739 r
F P
0 g
s
.45265 .50883 m .46501 .50392 L .4637 .50629 L p .704 .497 .605 r
F P
0 g
s
.46731 .51569 m .4637 .50629 L .46501 .50392 L p .731 .53 .62 r
F P
0 g
s
.46501 .50392 m .47018 .51734 L .46731 .51569 L p .731 .53 .62 r
F P
0 g
s
.46501 .50392 m .45265 .50883 L .45324 .50649 L p .674 .43 .545 r
F P
0 g
s
.47018 .51734 m .46501 .50392 L .46757 .50517 L p .703 .516 .633 r
F P
0 g
s
.45895 .29205 m .47024 .32181 L .47433 .32763 L p .648 .602 .788 r
F P
0 g
s
.47433 .32763 m .45821 .28509 L .45895 .29205 L p .648 .602 .788 r
F P
0 g
s
.48674 .31735 m .47476 .32054 L .47433 .32763 L p .659 .608 .786 r
F P
0 g
s
.47433 .32763 m .49143 .32309 L .48674 .31735 L p .659 .608 .786 r
F P
0 g
s
.45821 .28509 m .47433 .32763 L .47476 .32054 L p .66 .608 .786 r
F P
0 g
s
.4264 .2969 m .43782 .29203 L .43922 .2989 L p .632 .594 .793 r
F P
0 g
s
.4003 .2511 m .42343 .28819 L .4264 .2969 L p .642 .624 .817 r
F P
0 g
s
.4264 .2969 m .39335 .24394 L .4003 .2511 L p .642 .624 .817 r
F P
0 g
s
.43782 .29203 m .4264 .2969 L .42343 .28819 L p .641 .624 .817 r
F P
0 g
s
.39335 .24394 m .4264 .2969 L .41851 .29054 L p .631 .62 .821 r
F P
0 g
s
.40729 .50989 m .42224 .50787 L .42031 .50857 L p .477 0 .014 r
F P
0 g
s
.42188 .51128 m .42031 .50857 L .42224 .50787 L p .597 .153 .167 r
F P
0 g
s
.42224 .50787 m .4245 .51175 L .42188 .51128 L p .597 .153 .167 r
F P
0 g
s
.42224 .50787 m .40729 .50989 L .40907 .50923 L p .372 0 0 r
F P
0 g
s
.4245 .51175 m .42224 .50787 L .42464 .50814 L p .569 .143 .192 r
F P
0 g
s
.46894 .67921 m .45994 .67264 L .46016 .66774 L p .832 .726 .748 r
F P
0 g
s
.48027 .58174 m .47844 .58008 L .47707 .58205 L p .906 .769 .7 r
F P
0 g
s
.47707 .58205 m .47968 .58442 L .48027 .58174 L p .906 .769 .7 r
F P
0 g
s
.50832 .44382 m .50147 .44691 L .50071 .45013 L p .6 .463 .667 r
F P
0 g
s
.61485 .42965 m .61514 .43044 L .61665 .43151 L p .91 .514 .237 r
F P
0 g
s
.60412 .58623 m .59829 .5747 L .59677 .57248 L p .951 .649 .426 r
F P
0 g
s
.59677 .57248 m .60509 .58895 L .60412 .58623 L p .951 .649 .426 r
F P
0 g
s
.50243 .351 m .49613 .32748 L .49143 .32309 L p .674 .591 .755 r
F P
0 g
s
.60398 .59199 m .60885 .60846 L .60818 .60573 L p .968 .694 .274 r
F P
0 g
s
.60892 .61169 m .60892 .61358 L p .60889 .61091 L 0 0 .023 r
F P
0 g
s
.60892 .61169 m .60832 .61005 L p .60896 .6126 L .779 .478 0 r
F P
0 g
s
.60987 .61834 m .60911 .61481 L .60892 .61169 L p 0 0 .255 r
F P
0 g
s
.60892 .61169 m .61 .61673 L .60987 .61834 L p 0 0 .255 r
F P
0 g
s
.61 .61673 m .60892 .61169 L p .60896 .6126 L .779 .478 0 r
F P
0 g
s
.60885 .60846 m .60892 .61169 L p .60889 .61091 L 0 0 .023 r
F P
0 g
s
.6047 .59497 m .60811 .6065 L .60885 .60846 L p .914 .625 .136 r
F P
0 g
s
.60885 .60846 m .60398 .59199 L .6047 .59497 L p .914 .625 .136 r
F P
0 g
s
.60892 .61169 m .60885 .60846 L .60811 .6065 L p .908 .616 .121 r
F P
0 g
s
.53173 .53189 m .54829 .52565 L .54928 .52368 L p .446 .581 .895 r
F P
0 g
s
.61169 .42579 m .6016 .42325 L .59959 .42327 L p .84 .528 .462 r
F P
0 g
s
.50511 .46653 m .50071 .45013 L .50078 .45281 L p .595 .459 .665 r
F P
0 g
s
.50604 .46323 m .50295 .45175 L .50071 .45013 L p .593 .457 .665 r
F P
0 g
s
.50071 .45013 m .50511 .46653 L .50604 .46323 L p .593 .457 .665 r
F P
0 g
s
.51051 .44573 m .50071 .45013 L .50295 .45175 L p .597 .456 .661 r
F P
0 g
s
.50071 .45013 m .51051 .44573 L .50832 .44382 L p .6 .463 .667 r
F P
0 g
s
.70708 .5052 m .70581 .49365 L .70925 .49152 L p .595 .656 .88 r
F P
0 g
s
.47651 .58475 m .47834 .58641 L .47968 .58442 L p .913 .764 .682 r
F P
0 g
s
.47968 .58442 m .47707 .58205 L .47651 .58475 L p .913 .764 .682 r
F P
0 g
s
.47303 .59986 m .47968 .58442 L .47834 .58641 L p .914 .766 .683 r
F P
0 g
s
.47303 .59986 m .47968 .58442 L .479 .58709 L p .916 .769 .683 r
F P
0 g
s
.46757 .50517 m .47119 .51456 L .47018 .51734 L p .703 .516 .633 r
F P
0 g
s
.37093 .51325 m .37202 .51074 L .36914 .51033 L p .52 .853 .996 r
F P
0 g
s
.57421 .39121 m .5734 .37319 L .57002 .37621 L p .725 .573 .683 r
F P
0 g
s
.55282 .37718 m .57002 .37621 L .5734 .37319 L p .725 .573 .683 r
F P
0 g
s
.5734 .37319 m .54883 .37458 L .55282 .37718 L p .725 .573 .683 r
F P
0 g
s
.5734 .37319 m .57421 .39121 L .57752 .38881 L p .77 .608 .678 r
F P
0 g
s
.57046 .35301 m .56964 .36971 L .5734 .37319 L p .727 .603 .718 r
F P
0 g
s
.5734 .37319 m .57458 .34934 L .57046 .35301 L p .727 .603 .718 r
F P
0 g
s
.54883 .37458 m .5734 .37319 L .56964 .36971 L p .727 .603 .718 r
F P
0 g
s
.51684 .40703 m .52933 .40289 L .5312 .39945 L p .648 .502 .67 r
F P
0 g
s
.50813 .43061 m .51775 .42646 L .51899 .42326 L p .614 .468 .659 r
F P
0 g
s
.60509 .58895 m .60475 .5896 L .60546 .59199 L p .993 .743 .396 r
F P
0 g
s
.59795 .57505 m .60377 .58658 L .60509 .58895 L p .957 .636 .369 r
F P
0 g
s
.60509 .58895 m .59677 .57248 L .59795 .57505 L p .957 .636 .369 r
F P
0 g
s
.60475 .5896 m .60509 .58895 L .60377 .58658 L p .958 .633 .361 r
F P
0 g
s
.43427 .73263 m .42206 .72565 L .42365 .71891 L p .79 .743 .809 r
F P
0 g
s
.61755 .43354 m .61683 .43196 L .61514 .43044 L p .889 .464 .155 r
F P
0 g
s
.49522 .48384 m .49422 .47197 L .49623 .4695 L p .619 .485 .678 r
F P
0 g
s
.50078 .45281 m .50386 .46429 L .50511 .46653 L p .595 .459 .665 r
F P
0 g
s
.5189 .35695 m .52247 .37541 L .5262 .37868 L p .667 .561 .725 r
F P
0 g
s
.44927 .6889 m .45948 .69545 L .45951 .70033 L p .831 .725 .747 r
F P
0 g
s
.45951 .70033 m .4449 .69099 L .44927 .6889 L p .831 .725 .747 r
F P
0 g
s
.44144 .72319 m .45436 .70316 L .45951 .70033 L p .811 .734 .779 r
F P
0 g
s
.4449 .69099 m .45951 .70033 L .45436 .70316 L p .812 .735 .779 r
F P
0 g
s
.60818 .60573 m .60477 .5942 L .60398 .59199 L p .968 .694 .274 r
F P
0 g
s
.59312 .40599 m .59388 .41209 L .59688 .41336 L p .768 .546 .596 r
F P
0 g
s
.61485 .42965 m .61464 .42897 L .61257 .42854 L p .838 .509 .43 r
F P
0 g
s
.60269 .42607 m .61257 .42854 L .61464 .42897 L p .834 .494 .41 r
F P
0 g
s
.61464 .42897 m .60053 .42543 L .60269 .42607 L p .834 .494 .41 r
F P
0 g
s
.61197 .42667 m .61241 .42812 L .61464 .42897 L p .837 .509 .433 r
F P
0 g
s
.60053 .42543 m .61464 .42897 L .61241 .42812 L p .835 .497 .415 r
F P
0 g
s
.5242 .3826 m .5277 .39714 L .5312 .39945 L p .659 .531 .697 r
F P
0 g
s
.5312 .39945 m .5262 .37868 L .5242 .3826 L p .659 .531 .697 r
F P
0 g
s
.49646 .46677 m .49961 .46588 L .50073 .46824 L p .599 .462 .665 r
F P
0 g
s
.50073 .46824 m .49623 .4695 L .49646 .46677 L p .599 .462 .665 r
F P
0 g
s
.479 .58709 m .47435 .59789 L .47303 .59986 L p .916 .769 .683 r
F P
0 g
s
.42464 .50814 m .42622 .51085 L .4245 .51175 L p .569 .143 .192 r
F P
0 g
s
.48887 .54121 m .48632 .53641 L .48219 .53715 L p .764 .664 .752 r
F P
0 g
s
.48219 .53715 m .48583 .54401 L .48887 .54121 L p .764 .664 .752 r
F P
0 g
s
.6089 .3182 m .58556 .31302 L .57866 .31791 L p .748 .679 .784 r
F P
0 g
s
.56964 .36971 m .55243 .37068 L .54883 .37458 L p .727 .603 .718 r
F P
0 g
s
.31379 .51598 m .33687 .51612 L .34181 .51481 L p .629 .808 .969 r
F P
0 g
s
.632 .72849 m .64802 .71691 L .65426 .718 L p .54 .517 .779 r
F P
0 g
s
.61179 .64063 m .60983 .63561 L .61024 .6324 L p .132 .094 .545 r
F P
0 g
s
.57002 .37621 m .57059 .38882 L .57421 .39121 L p .725 .573 .683 r
F P
0 g
s
.4637 .50629 m .45504 .50973 L .45265 .50883 L p .704 .497 .605 r
F P
0 g
s
.52978 .52906 m .53787 .51304 L .53718 .50975 L p .398 .436 .783 r
F P
0 g
s
.62373 .44225 m .63054 .44762 L .6312 .44811 L p .472 0 0 r
F P
0 g
s
.6312 .44811 m .62147 .44043 L .62373 .44225 L p .472 0 0 r
F P
0 g
s
.62147 .44043 m .6312 .44811 L .62926 .44633 L p .741 .232 0 r
F P
0 g
s
.53371 .39562 m .53021 .38108 L .5262 .37868 L p .688 .549 .691 r
F P
0 g
s
.5262 .37868 m .5312 .39945 L .53371 .39562 L p .688 .549 .691 r
F P
0 g
s
.54883 .37458 m .5262 .37868 L .53021 .38108 L p .689 .549 .69 r
F P
0 g
s
.5262 .37868 m .52109 .35229 L .5189 .35695 L p .667 .561 .725 r
F P
0 g
s
.54487 .37132 m .52904 .37419 L .5262 .37868 L p .694 .579 .721 r
F P
0 g
s
.5262 .37868 m .54883 .37458 L .54487 .37132 L p .694 .579 .721 r
F P
0 g
s
.52109 .35229 m .5262 .37868 L .52904 .37419 L p .695 .579 .721 r
F P
0 g
s
.57978 .34555 m .58265 .32357 L .57866 .31791 L p .758 .66 .753 r
F P
0 g
s
.57866 .31791 m .57458 .34934 L .57978 .34555 L p .758 .66 .753 r
F P
0 g
s
.49766 .48646 m .49623 .4695 L .4973 .47185 L p .608 .478 .677 r
F P
0 g
s
.50045 .47097 m .4973 .47185 L .49623 .4695 L p .604 .475 .679 r
F P
0 g
s
.49623 .4695 m .50073 .46824 L .50045 .47097 L p .604 .475 .679 r
F P
0 g
s
.49623 .4695 m .49766 .48646 L .49522 .48384 L p .619 .485 .678 r
F P
0 g
s
.48035 .53957 m .4829 .54437 L .48583 .54401 L p .84 .687 .693 r
F P
0 g
s
.48583 .54401 m .48219 .53715 L .48035 .53957 L p .84 .687 .693 r
F P
0 g
s
.46865 .55159 m .48583 .54401 L .4829 .54437 L p .839 .681 .686 r
F P
0 g
s
.47134 .55118 m .48337 .54587 L .48583 .54401 L p .847 .709 .71 r
F P
0 g
s
.48583 .54401 m .46865 .55159 L .47134 .55118 L p .847 .709 .71 r
F P
0 g
s
.60377 .58658 m .60353 .58704 L .60475 .5896 L p .958 .633 .361 r
F P
0 g
s
.59554 .56995 m .58727 .55904 L .58495 .55688 L p .891 .538 .372 r
F P
0 g
s
.47245 .52247 m .48523 .52472 L .4881 .52664 L p .756 .613 .7 r
F P
0 g
s
.4881 .52664 m .46983 .52344 L .47245 .52247 L p .756 .613 .7 r
F P
0 g
s
.48603 .51345 m .4881 .52664 L .48523 .52472 L p .746 .618 .717 r
F P
0 g
s
.4881 .52664 m .48603 .51345 L .48971 .51556 L p .747 .619 .717 r
F P
0 g
s
.61514 .43044 m .61485 .42965 L .61281 .42925 L p .834 .486 .397 r
F P
0 g
s
.603 .42678 m .61281 .42925 L .61485 .42965 L p .83 .474 .381 r
F P
0 g
s
.61485 .42965 m .60083 .42612 L .603 .42678 L p .83 .474 .381 r
F P
0 g
s
.61257 .42854 m .61271 .42902 L .61485 .42965 L p .838 .509 .43 r
F P
0 g
s
.60083 .42612 m .61485 .42965 L .61271 .42902 L p .835 .494 .409 r
F P
0 g
s
.60522 .59257 m .60539 .59217 L .60475 .5896 L p .988 .73 .36 r
F P
0 g
s
.65878 .2458 m .69212 .26391 L .70423 .26048 L p .757 .722 .819 r
F P
0 g
s
.70423 .26048 m .65661 .23448 L .65878 .2458 L p .757 .722 .819 r
F P
0 g
s
.74886 .2032 m .70517 .24667 L .70423 .26048 L p .739 .727 .841 r
F P
0 g
s
.70423 .26048 m .7666 .19859 L .74886 .2032 L p .739 .727 .841 r
F P
0 g
s
.65661 .23448 m .70423 .26048 L .70517 .24667 L p .739 .727 .841 r
F P
0 g
s
.4402 .50953 m .44985 .50791 L .45265 .50883 L p .684 .385 .46 r
F P
0 g
s
.52904 .37419 m .52546 .35572 L .52109 .35229 L p .695 .579 .721 r
F P
0 g
s
.49419 .51198 m .48971 .51556 L .48603 .51345 L p .729 .629 .747 r
F P
0 g
s
.5508 .35295 m .57046 .35301 L .57458 .34934 L p .727 .603 .718 r
F P
0 g
s
.57458 .34934 m .54649 .34925 L .5508 .35295 L p .727 .603 .718 r
F P
0 g
s
.57344 .32251 m .57059 .34451 L .57458 .34934 L p .726 .629 .751 r
F P
0 g
s
.57458 .34934 m .57866 .31791 L .57344 .32251 L p .726 .629 .751 r
F P
0 g
s
.54649 .34925 m .57458 .34934 L .57059 .34451 L p .726 .629 .751 r
F P
0 g
s
.50295 .45175 m .50981 .44867 L .51051 .44573 L p .597 .456 .661 r
F P
0 g
s
.41851 .29054 m .39537 .25351 L .39335 .24394 L p .631 .62 .821 r
F P
0 g
s
.53021 .38108 m .54605 .37821 L .54883 .37458 L p .689 .549 .69 r
F P
0 g
s
.36396 .51334 m .34589 .51397 L .34181 .51481 L p .574 .846 .996 r
F P
0 g
s
.4811 .56399 m .47236 .56223 L .47027 .5637 L p .884 .743 .7 r
F P
0 g
s
.48378 .55061 m .47187 .55327 L .4694 .55458 L p .856 .715 .705 r
F P
0 g
s
.61 .61673 m .61024 .6324 L .61004 .6293 L p 0 0 .274 r
F P
0 g
s
.61024 .6324 m .61304 .63956 L .61179 .64063 L p .132 .094 .545 r
F P
0 g
s
.61048 .62017 m .61064 .63114 L .61024 .6324 L p 0 0 .483 r
F P
0 g
s
.61024 .6324 m .61 .61673 L .61048 .62017 L p 0 0 .483 r
F P
0 g
s
.61304 .63956 m .61024 .6324 L .61064 .63114 L p 0 0 .49 r
F P
0 g
s
.47834 .58641 m .47368 .59722 L .47303 .59986 L p .914 .766 .683 r
F P
0 g
s
.48603 .51345 m .49244 .50834 L .49419 .51198 L p .729 .629 .747 r
F P
0 g
s
.57898 .40259 m .57759 .39331 L .57421 .39121 L p .771 .577 .636 r
F P
0 g
s
.48472 .51049 m .48921 .50692 L .49244 .50834 L p .676 .53 .68 r
F P
0 g
s
.49244 .50834 m .48603 .51345 L .48472 .51049 L p .676 .53 .68 r
F P
0 g
s
.5824 .55491 m .58161 .55531 L .58382 .55745 L p .804 .343 .14 r
F P
0 g
s
.58382 .55745 m .58495 .55688 L .5824 .55491 L p .804 .343 .14 r
F P
0 g
s
.4973 .47185 m .49831 .48372 L .49766 .48646 L p .608 .478 .677 r
F P
0 g
s
.42031 .50857 m .40983 .50998 L .40729 .50989 L p .477 0 .014 r
F P
0 g
s
.58161 .55531 m .56974 .54536 L .56685 .54324 L p .794 .308 .056 r
F P
0 g
s
.48523 .52472 m .48379 .51548 L .48603 .51345 L p .746 .618 .717 r
F P
0 g
s
.77961 .51271 m .7498 .51248 L .74355 .50973 L p .643 .706 .892 r
F P
0 g
s
.60036 .4191 m .59938 .41488 L .59688 .41336 L p .841 .561 .514 r
F P
0 g
s
.61617 .43271 m .61514 .43044 L .61323 .43027 L p .826 .456 .355 r
F P
0 g
s
.60349 .42782 m .61323 .43027 L .61514 .43044 L p .824 .45 .347 r
F P
0 g
s
.61514 .43044 m .60123 .42694 L .60349 .42782 L p .824 .45 .347 r
F P
0 g
s
.61514 .43044 m .61617 .43271 L .61755 .43354 L p .889 .464 .155 r
F P
0 g
s
.61281 .42925 m .61301 .4298 L .61514 .43044 L p .834 .486 .397 r
F P
0 g
s
.60123 .42694 m .61514 .43044 L .61301 .4298 L p .831 .474 .38 r
F P
0 g
s
.61241 .42812 m .60254 .42565 L .60053 .42543 L p .835 .497 .415 r
F P
0 g
s
.58495 .55688 m .59677 .57248 L .59554 .56995 L p .891 .538 .372 r
F P
0 g
s
.62926 .44633 m .62244 .44095 L .62147 .44043 L p .741 .232 0 r
F P
0 g
s
.49025 .50568 m .49263 .50141 L .49584 .50225 L p .652 .529 .701 r
F P
0 g
s
.49584 .50225 m .49244 .50834 L .49025 .50568 L p .652 .529 .701 r
F P
0 g
s
.47119 .51456 m .48228 .51184 L .48603 .51345 L p .715 .53 .638 r
F P
0 g
s
.59617 .57313 m .60475 .5896 L .60353 .58704 L p .957 .635 .369 r
F P
0 g
s
.60475 .5896 m .6045 .59017 L .60522 .59257 L p .988 .73 .36 r
F P
0 g
s
.59741 .57569 m .60341 .58722 L .60475 .5896 L p .958 .627 .341 r
F P
0 g
s
.60475 .5896 m .59617 .57313 L .59741 .57569 L p .958 .627 .341 r
F P
0 g
s
.6045 .59017 m .60475 .5896 L .60341 .58722 L p .958 .625 .336 r
F P
0 g
s
.48036 .56804 m .47638 .57915 L .47707 .58205 L p .893 .751 .697 r
F P
0 g
s
.61682 .67747 m .61112 .66797 L .61197 .66405 L p .472 .398 .692 r
F P
0 g
s
.5858 .55971 m .58659 .55931 L .58495 .55688 L p .899 .507 .268 r
F P
0 g
s
.58495 .55688 m .58382 .55745 L .5858 .55971 L p .899 .507 .268 r
F P
0 g
s
.59677 .57248 m .58495 .55688 L .58659 .55931 L p .898 .511 .283 r
F P
0 g
s
.48632 .53641 m .49086 .52823 L .48867 .52545 L p .76 .631 .718 r
F P
0 g
s
.60811 .6065 m .60816 .60876 L .60892 .61169 L p .908 .616 .121 r
F P
0 g
s
.56685 .54324 m .58382 .55745 L .58161 .55531 L p .794 .308 .056 r
F P
0 g
s
.56901 .54578 m .56931 .54545 L .56685 .54324 L p .642 .101 0 r
F P
0 g
s
.56685 .54324 m .56641 .54371 L .56901 .54578 L p .642 .101 0 r
F P
0 g
s
.58382 .55745 m .56685 .54324 L .56931 .54545 L p .717 .185 0 r
F P
0 g
s
.56641 .54371 m .56685 .54324 L .56289 .54187 L p .425 0 0 r
F P
0 g
s
.47166 .65274 m .46372 .6663 L .46016 .66774 L p .85 .718 .717 r
F P
0 g
s
.46016 .66774 m .47153 .64836 L .47166 .65274 L p .85 .718 .717 r
F P
0 g
s
.49896 .50514 m .49658 .50941 L .49244 .50834 L p .718 .612 .738 r
F P
0 g
s
.57618 .40448 m .57421 .39121 L .57132 .39372 L p .719 .541 .648 r
F P
0 g
s
.5558 .39569 m .57132 .39372 L .57421 .39121 L p .718 .54 .648 r
F P
0 g
s
.57421 .39121 m .55205 .39403 L .5558 .39569 L p .718 .54 .648 r
F P
0 g
s
.57421 .39121 m .57618 .40448 L .57898 .40259 L p .771 .577 .636 r
F P
0 g
s
.55205 .39403 m .57421 .39121 L .57059 .38882 L p .725 .573 .683 r
F P
0 g
s
.60353 .58704 m .59753 .57551 L .59617 .57313 L p .957 .635 .369 r
F P
0 g
s
.66885 .48461 m .68158 .48697 L .68489 .48965 L p .531 .618 .884 r
F P
0 g
s
.71559 .5057 m .73838 .50689 L .74355 .50973 L p .628 .689 .888 r
F P
0 g
s
.43885 .51114 m .45265 .50883 L .45082 .51019 L p .704 .435 .514 r
F P
0 g
s
.45219 .51615 m .45082 .51019 L .45265 .50883 L p .734 .484 .551 r
F P
0 g
s
.45265 .50883 m .45461 .51734 L .45219 .51615 L p .734 .484 .551 r
F P
0 g
s
.45265 .50883 m .43885 .51114 L .4402 .50953 L p .684 .385 .46 r
F P
0 g
s
.45461 .51734 m .45265 .50883 L .45504 .50973 L p .712 .471 .558 r
F P
0 g
s
.57059 .38882 m .55507 .39079 L .55205 .39403 L p .725 .573 .683 r
F P
0 g
s
.47018 .51734 m .48603 .51345 L .48379 .51548 L p .733 .596 .703 r
F P
0 g
s
.48603 .51345 m .47018 .51734 L .47119 .51456 L p .715 .53 .638 r
F P
0 g
s
.39227 .51053 m .40437 .51001 L .40729 .50989 L p 0 0 0 r
F P
0 g
s
.61004 .6293 m .60987 .61834 L .61 .61673 L p 0 0 .274 r
F P
0 g
s
.45436 .70316 m .44412 .69664 L .4449 .69099 L p .812 .735 .779 r
F P
0 g
s
.55243 .37068 m .5508 .35295 L .54649 .34925 L p .727 .603 .718 r
F P
0 g
s
.54649 .34925 m .54883 .37458 L .55243 .37068 L p .727 .603 .718 r
F P
0 g
s
.49343 .49896 m .49471 .48792 L .49766 .48646 L p .637 .517 .699 r
F P
0 g
s
.49766 .48646 m .49584 .50225 L .49343 .49896 L p .637 .517 .699 r
F P
0 g
s
.54649 .34925 m .52109 .35229 L .52546 .35572 L p .695 .579 .721 r
F P
0 g
s
.51293 .32439 m .5169 .34792 L .52109 .35229 L p .674 .591 .755 r
F P
0 g
s
.52109 .35229 m .51544 .31867 L .51293 .32439 L p .674 .591 .755 r
F P
0 g
s
.54217 .34472 m .52438 .34686 L .52109 .35229 L p .697 .607 .752 r
F P
0 g
s
.52109 .35229 m .54649 .34925 L .54217 .34472 L p .697 .607 .752 r
F P
0 g
s
.51544 .31867 m .52109 .35229 L .52438 .34686 L p .697 .607 .752 r
F P
0 g
s
.52546 .35572 m .54324 .35359 L .54649 .34925 L p .695 .579 .721 r
F P
0 g
s
.55507 .39079 m .55282 .37718 L .54883 .37458 L p .725 .573 .684 r
F P
0 g
s
.54324 .35359 m .54487 .37132 L .54883 .37458 L p .695 .579 .721 r
F P
0 g
s
.50386 .46429 m .5008 .46549 L .50073 .46824 L p .594 .458 .666 r
F P
0 g
s
.49244 .50834 m .49584 .50225 L .49896 .50514 L p .718 .612 .738 r
F P
0 g
s
.55205 .39403 m .54883 .37458 L .54605 .37821 L p .688 .548 .69 r
F P
0 g
s
.54883 .37458 m .55205 .39403 L .55507 .39079 L p .725 .573 .684 r
F P
0 g
s
.54883 .37458 m .54649 .34925 L .54324 .35359 L p .695 .579 .721 r
F P
0 g
s
.48379 .51548 m .47269 .5182 L .47018 .51734 L p .733 .596 .703 r
F P
0 g
s
.45504 .50973 m .45641 .51569 L .45461 .51734 L p .712 .471 .558 r
F P
0 g
s
.54605 .37821 m .5483 .39182 L .55205 .39403 L p .688 .548 .69 r
F P
0 g
s
.61271 .42902 m .60291 .42655 L .60083 .42612 L p .835 .494 .409 r
F P
0 g
s
.58659 .55931 m .59487 .57023 L .59677 .57248 L p .898 .511 .283 r
F P
0 g
s
.66187 .47371 m .65318 .471 L .65088 .46834 L p .437 .534 .858 r
F P
0 g
s
.50898 .50601 m .49896 .50514 L .49584 .50225 L p .629 .607 .809 r
F P
0 g
s
.48867 .52545 m .48219 .53715 L .48632 .53641 L p .76 .631 .718 r
F P
0 g
s
.60341 .58722 m .60324 .58762 L .6045 .59017 L p .958 .625 .336 r
F P
0 g
s
.61935 .43684 m .61797 .4344 L .61617 .43271 L p .848 .386 .036 r
F P
0 g
s
.47256 .52404 m .48536 .52629 L .48867 .52545 L p .756 .613 .7 r
F P
0 g
s
.47269 .5182 m .47245 .52247 L .46983 .52344 L p .744 .575 .666 r
F P
0 g
s
.46983 .52344 m .47018 .51734 L .47269 .5182 L p .744 .575 .666 r
F P
0 g
s
.48867 .52545 m .4704 .52223 L .47256 .52404 L p .756 .613 .7 r
F P
0 g
s
.48219 .53715 m .48867 .52545 L .48536 .52629 L p .761 .633 .719 r
F P
0 g
s
.47476 .32054 m .46348 .29075 L .45821 .28509 L p .66 .608 .786 r
F P
0 g
s
.30881 .51462 m .34181 .51481 L .33707 .51374 L p .62 .813 .974 r
F P
0 g
s
.33796 .50963 m .33707 .51374 L .34181 .51481 L p .587 .813 .986 r
F P
0 g
s
.34181 .51481 m .34312 .50895 L .33796 .50963 L p .587 .813 .986 r
F P
0 g
s
.34181 .51481 m .30881 .51462 L .31379 .51598 L p .629 .808 .969 r
F P
0 g
s
.34312 .50895 m .34181 .51481 L .34589 .51397 L p .601 .826 .986 r
F P
0 g
s
.5483 .39182 m .53371 .39562 L .5312 .39945 L p .688 .548 .691 r
F P
0 g
s
.59828 .41939 m .59688 .41336 L .59443 .41439 L p .764 .514 .555 r
F P
0 g
s
.58166 .41481 m .59443 .41439 L .59688 .41336 L p .761 .507 .549 r
F P
0 g
s
.59688 .41336 m .57864 .41396 L .58166 .41481 L p .761 .507 .549 r
F P
0 g
s
.59688 .41336 m .59828 .41939 L .60036 .4191 L p .841 .561 .514 r
F P
0 g
s
.57864 .41396 m .59688 .41336 L .59388 .41209 L p .769 .544 .592 r
F P
0 g
s
.57059 .34451 m .55092 .34445 L .54649 .34925 L p .726 .629 .751 r
F P
0 g
s
.60477 .5942 m .60514 .59292 L .6045 .59017 L p .975 .706 .298 r
F P
0 g
s
.56289 .54187 m .56257 .5422 L .56641 .54371 L p .425 0 0 r
F P
0 g
s
.4659 .63919 m .47165 .6447 L .47153 .64836 L p .885 .741 .697 r
F P
0 g
s
.47153 .64836 m .4633 .6405 L .4659 .63919 L p .885 .741 .697 r
F P
0 g
s
.4606 .66369 m .46856 .65012 L .47153 .64836 L p .869 .747 .726 r
F P
0 g
s
.47153 .64836 m .46016 .66774 L .4606 .66369 L p .869 .747 .726 r
F P
0 g
s
.4633 .6405 m .47153 .64836 L .46856 .65012 L p .869 .748 .726 r
F P
0 g
s
.53632 .41566 m .5312 .39945 L .52933 .40289 L p .646 .499 .669 r
F P
0 g
s
.53858 .41229 m .53499 .40095 L .5312 .39945 L p .678 .517 .66 r
F P
0 g
s
.5312 .39945 m .53632 .41566 L .53858 .41229 L p .678 .517 .66 r
F P
0 g
s
.55205 .39403 m .5312 .39945 L .53499 .40095 L p .678 .516 .659 r
F P
0 g
s
.5312 .39945 m .55205 .39403 L .5483 .39182 L p .688 .548 .691 r
F P
0 g
s
.50486 .48224 m .50212 .47041 L .50073 .46824 L p .595 .471 .681 r
F P
0 g
s
.50073 .46824 m .50464 .48514 L .50486 .48224 L p .595 .471 .681 r
F P
0 g
s
.50511 .46653 m .50073 .46824 L .50212 .47041 L p .6 .473 .679 r
F P
0 g
s
.50073 .46824 m .50511 .46653 L .50386 .46429 L p .594 .458 .666 r
F P
0 g
s
.50319 .48279 m .50045 .47097 L .50073 .46824 L p .609 .48 .68 r
F P
0 g
s
.50073 .46824 m .50464 .48514 L .50319 .48279 L p .609 .48 .68 r
F P
0 g
s
.52933 .40289 m .53291 .41424 L .53632 .41566 L p .646 .499 .669 r
F P
0 g
s
.59753 .57551 m .59795 .57505 L .59677 .57248 L p .957 .637 .375 r
F P
0 g
s
.57132 .39372 m .5727 .40301 L .57618 .40448 L p .719 .541 .648 r
F P
0 g
s
.4829 .54437 m .47087 .54967 L .46865 .55159 L p .839 .681 .686 r
F P
0 g
s
.61859 .64933 m .61197 .66405 L .61219 .66035 L p .255 .235 .643 r
F P
0 g
s
.61197 .66405 m .62013 .67763 L .61682 .67747 L p .472 .398 .692 r
F P
0 g
s
.61893 .65353 m .61429 .66383 L .61197 .66405 L p .35 .344 .712 r
F P
0 g
s
.61197 .66405 m .61859 .64933 L .61893 .65353 L p .35 .344 .712 r
F P
0 g
s
.62013 .67763 m .61197 .66405 L .61429 .66383 L p .35 .345 .713 r
F P
0 g
s
.66329 .47221 m .65088 .46834 L .65174 .46715 L p .358 .559 .912 r
F P
0 g
s
.64733 .4591 m .65174 .46715 L .65088 .46834 L p .354 .553 .909 r
F P
0 g
s
.65088 .46834 m .64457 .45685 L .64733 .4591 L p .354 .553 .909 r
F P
0 g
s
.65088 .46834 m .66329 .47221 L .66187 .47371 L p .437 .534 .858 r
F P
0 g
s
.64457 .45685 m .65088 .46834 L .64869 .46596 L p .172 .432 .866 r
F P
0 g
s
.59677 .57248 m .59617 .57313 L .59753 .57551 L p .957 .637 .375 r
F P
0 g
s
.59617 .57313 m .59677 .57248 L .59487 .57023 L p .898 .52 .307 r
F P
0 g
s
.61301 .4298 m .60327 .42735 L .60123 .42694 L p .831 .474 .38 r
F P
0 g
s
.53291 .41424 m .52078 .41956 L .51899 .42326 L p .645 .5 .671 r
F P
0 g
s
.59388 .41209 m .58112 .41251 L .57864 .41396 L p .769 .544 .592 r
F P
0 g
s
.49584 .50225 m .51016 .50349 L .50898 .50601 L p .629 .607 .809 r
F P
0 g
s
.49898 .48882 m .4977 .49987 L .49584 .50225 L p .638 .517 .7 r
F P
0 g
s
.49584 .50225 m .49766 .48646 L .49898 .48882 L p .638 .517 .7 r
F P
0 g
s
.51016 .50349 m .49584 .50225 L .4977 .49987 L p .648 .531 .707 r
F P
0 g
s
.59574 .57371 m .6045 .59017 L .60324 .58762 L p .958 .627 .341 r
F P
0 g
s
.6045 .59017 m .60398 .59199 L .60477 .5942 L p .975 .706 .298 r
F P
0 g
s
.59696 .57647 m .60309 .58799 L .6045 .59017 L p .954 .608 .285 r
F P
0 g
s
.6045 .59017 m .59574 .57371 L .59696 .57647 L p .954 .608 .285 r
F P
0 g
s
.60398 .59199 m .6045 .59017 L .60309 .58799 L p .956 .612 .296 r
F P
0 g
s
.56931 .54545 m .58119 .5554 L .58382 .55745 L p .717 .185 0 r
F P
0 g
s
.52478 .4376 m .51899 .42326 L .51775 .42646 L p .609 .462 .657 r
F P
0 g
s
.52646 .43413 m .5224 .4241 L .51899 .42326 L p .632 .473 .65 r
F P
0 g
s
.51899 .42326 m .52478 .4376 L .52646 .43413 L p .632 .473 .65 r
F P
0 g
s
.53632 .41566 m .51899 .42326 L .5224 .4241 L p .632 .471 .646 r
F P
0 g
s
.51899 .42326 m .53632 .41566 L .53291 .41424 L p .645 .5 .671 r
F P
0 g
s
.59487 .57023 m .59445 .57069 L .59617 .57313 L p .898 .52 .307 r
F P
0 g
s
.51775 .42646 m .5218 .4365 L .52478 .4376 L p .609 .462 .657 r
F P
0 g
s
.47435 .59789 m .4757 .59933 L .47496 .60191 L p .915 .766 .682 r
F P
0 g
s
.49831 .48372 m .50319 .48279 L .50464 .48514 L p .612 .481 .678 r
F P
0 g
s
.50464 .48514 m .49766 .48646 L .49831 .48372 L p .612 .481 .678 r
F P
0 g
s
.38999 .51063 m .40729 .50989 L .40495 .51005 L p .087 0 0 r
F P
0 g
s
.40618 .51104 m .40495 .51005 L .40729 .50989 L p .342 0 0 r
F P
0 g
s
.40729 .50989 m .40905 .51129 L .40618 .51104 L p .342 0 0 r
F P
0 g
s
.40729 .50989 m .38999 .51063 L .39227 .51053 L p 0 0 0 r
F P
0 g
s
.40905 .51129 m .40729 .50989 L .40983 .50998 L p .323 0 0 r
F P
0 g
s
.45082 .51019 m .44116 .5118 L .43885 .51114 L p .704 .435 .514 r
F P
0 g
s
.50387 .4879 m .49898 .48882 L .49766 .48646 L p .619 .51 .708 r
F P
0 g
s
.49766 .48646 m .50464 .48514 L .50387 .4879 L p .619 .51 .708 r
F P
0 g
s
.48536 .52629 m .48082 .53448 L .48219 .53715 L p .761 .633 .719 r
F P
0 g
s
.60324 .58762 m .59711 .5761 L .59574 .57371 L p .958 .627 .341 r
F P
0 g
s
.61323 .43027 m .61395 .43186 L .61617 .43271 L p .826 .456 .355 r
F P
0 g
s
.46918 .5282 m .48219 .53715 L .48082 .53448 L p .777 .639 .708 r
F P
0 g
s
.46951 .53121 m .47862 .53748 L .48219 .53715 L p .81 .617 .642 r
F P
0 g
s
.48219 .53715 m .46918 .5282 L .46951 .53121 L p .81 .617 .642 r
F P
0 g
s
.46742 .54815 m .48219 .53715 L .47862 .53748 L p .812 .63 .656 r
F P
0 g
s
.47001 .54727 m .48035 .53957 L .48219 .53715 L p .835 .679 .69 r
F P
0 g
s
.48219 .53715 m .46742 .54815 L .47001 .54727 L p .835 .679 .69 r
F P
0 g
s
.53499 .40095 m .54959 .39715 L .55205 .39403 L p .678 .516 .659 r
F P
0 g
s
.46888 .57746 m .47707 .58205 L .47638 .57915 L p .908 .758 .683 r
F P
0 g
s
.4723 .59588 m .47651 .58475 L .47707 .58205 L p .915 .766 .682 r
F P
0 g
s
.47707 .58205 m .47105 .59795 L .4723 .59588 L p .915 .766 .682 r
F P
0 g
s
.46937 .58052 m .47511 .58373 L .47707 .58205 L p .91 .755 .677 r
F P
0 g
s
.47707 .58205 m .46888 .57746 L .46937 .58052 L p .91 .755 .677 r
F P
0 g
s
.47105 .59795 m .47707 .58205 L .47511 .58373 L p .913 .763 .682 r
F P
0 g
s
.63054 .44762 m .63426 .45079 L .63652 .45264 L p .485 0 0 r
F P
0 g
s
.52438 .34686 m .52044 .32332 L .51544 .31867 L p .697 .607 .752 r
F P
0 g
s
.4977 .49987 m .50773 .50074 L .51016 .50349 L p .648 .531 .707 r
F P
0 g
s
.50212 .47041 m .50519 .46922 L .50511 .46653 L p .6 .473 .679 r
F P
0 g
s
.64869 .46596 m .64427 .45792 L .64457 .45685 L p .172 .432 .866 r
F P
0 g
s
.5218 .4365 m .51182 .44219 L .51051 .44573 L p .607 .464 .661 r
F P
0 g
s
.7862 .51004 m .74355 .50973 L .74956 .50688 L p .639 .713 .901 r
F P
0 g
s
.74807 .49412 m .74956 .50688 L .74355 .50973 L p .637 .705 .895 r
F P
0 g
s
.74355 .50973 m .74136 .49152 L .74807 .49412 L p .637 .705 .895 r
F P
0 g
s
.74355 .50973 m .7862 .51004 L .77961 .51271 L p .643 .706 .892 r
F P
0 g
s
.74136 .49152 m .74355 .50973 L .73838 .50689 L p .617 .69 .895 r
F P
0 g
s
.61814 .4362 m .61617 .43271 L .61445 .43272 L p .814 .413 .291 r
F P
0 g
s
.60486 .43034 m .61445 .43272 L .61617 .43271 L p .804 .393 .269 r
F P
0 g
s
.61617 .43271 m .60247 .42931 L .60486 .43034 L p .804 .393 .269 r
F P
0 g
s
.61617 .43271 m .61814 .4362 L .61935 .43684 L p .848 .386 .036 r
F P
0 g
s
.60247 .42931 m .61617 .43271 L .61395 .43186 L p .825 .45 .345 r
F P
0 g
s
.44416 .29699 m .44134 .29803 L .43782 .29203 L p .641 .598 .79 r
F P
0 g
s
.5165 .45974 m .51051 .44573 L .50981 .44867 L p .589 .448 .658 r
F P
0 g
s
.51773 .45616 m .51353 .44635 L .51051 .44573 L p .597 .452 .656 r
F P
0 g
s
.51051 .44573 m .5165 .45974 L .51773 .45616 L p .597 .452 .656 r
F P
0 g
s
.52478 .4376 m .51051 .44573 L .51353 .44635 L p .599 .447 .647 r
F P
0 g
s
.51051 .44573 m .52478 .4376 L .5218 .4365 L p .607 .464 .661 r
F P
0 g
s
.45641 .51569 m .46731 .51569 L .47018 .51734 L p .742 .517 .589 r
F P
0 g
s
.47496 .60191 m .47303 .59986 L .47435 .59789 L p .915 .766 .682 r
F P
0 g
s
.46835 .61529 m .47357 .60403 L .47496 .60191 L p .913 .767 .686 r
F P
0 g
s
.47496 .60191 m .4675 .61799 L .46835 .61529 L p .913 .767 .686 r
F P
0 g
s
.47303 .59986 m .47496 .60191 L .47357 .60403 L p .913 .767 .686 r
F P
0 g
s
.4675 .61799 m .47496 .60191 L .47461 .60522 L p .91 .762 .685 r
F P
0 g
s
.54132 .32169 m .54217 .34472 L .54649 .34925 L p .697 .607 .752 r
F P
0 g
s
.54649 .34925 m .54528 .31634 L .54132 .32169 L p .697 .607 .752 r
F P
0 g
s
.54528 .31634 m .54649 .34925 L .55092 .34445 L p .726 .629 .751 r
F P
0 g
s
.47461 .60522 m .4694 .61647 L .4675 .61799 L p .91 .762 .685 r
F P
0 g
s
.50981 .44867 m .51401 .45848 L .5165 .45974 L p .589 .448 .658 r
F P
0 g
s
.34589 .51397 m .34682 .50987 L .34312 .50895 L p .601 .826 .986 r
F P
0 g
s
.61219 .66035 m .61682 .65005 L .61859 .64933 L p .255 .235 .643 r
F P
0 g
s
.48082 .53448 m .47172 .52821 L .46918 .5282 L p .777 .639 .708 r
F P
0 g
s
.42343 .28819 m .43143 .28476 L .43782 .29203 L p .641 .624 .817 r
F P
0 g
s
.45461 .51734 m .47018 .51734 L .4678 .51805 L p .748 .564 .646 r
F P
0 g
s
.46755 .52232 m .4678 .51805 L .47018 .51734 L p .755 .585 .666 r
F P
0 g
s
.47018 .51734 m .46983 .52344 L .46755 .52232 L p .755 .585 .666 r
F P
0 g
s
.47018 .51734 m .45461 .51734 L .45641 .51569 L p .742 .517 .589 r
F P
0 g
s
.40983 .50998 m .41107 .51096 L .40905 .51129 L p .323 0 0 r
F P
0 g
s
.55582 .40863 m .55205 .39403 L .54959 .39715 L p .677 .515 .658 r
F P
0 g
s
.55845 .40591 m .5558 .39569 L .55205 .39403 L p .719 .54 .647 r
F P
0 g
s
.55205 .39403 m .55582 .40863 L .55845 .40591 L p .719 .54 .647 r
F P
0 g
s
.59443 .41439 m .59541 .41861 L .59828 .41939 L p .764 .514 .555 r
F P
0 g
s
.47232 .62718 m .4659 .63919 L .4633 .6405 L p .886 .744 .699 r
F P
0 g
s
.4633 .6405 m .47248 .62334 L .47232 .62718 L p .886 .744 .699 r
F P
0 g
s
.42622 .51085 m .43627 .51042 L .43885 .51114 L p .658 .27 .3 r
F P
0 g
s
.60309 .58799 m .60272 .58927 L .60398 .59199 L p .956 .612 .296 r
F P
0 g
s
.61064 .63114 m .6126 .63615 L .61304 .63956 L p 0 0 .49 r
F P
0 g
s
.4694 .61647 m .47287 .62022 L .47248 .62334 L p .909 .759 .683 r
F P
0 g
s
.5224 .4241 m .53454 .41877 L .53632 .41566 L p .632 .471 .646 r
F P
0 g
s
.49613 .32748 m .51293 .32439 L .51544 .31867 L p .674 .591 .755 r
F P
0 g
s
.51544 .31867 m .49143 .32309 L .49613 .32748 L p .674 .591 .755 r
F P
0 g
s
.55092 .34445 m .55009 .32141 L .54528 .31634 L p .726 .629 .751 r
F P
0 g
s
.54959 .39715 m .55222 .40737 L .55582 .40863 L p .677 .515 .658 r
F P
0 g
s
.2725 .51538 m .30245 .51622 L .30881 .51462 L p .643 .785 .95 r
F P
0 g
s
.51401 .45848 m .50604 .46323 L .50511 .46653 L p .586 .45 .663 r
F P
0 g
s
.47248 .62334 m .4675 .61799 L .4694 .61647 L p .909 .759 .683 r
F P
0 g
s
.46395 .63716 m .47037 .62515 L .47248 .62334 L p .898 .762 .703 r
F P
0 g
s
.47248 .62334 m .4633 .6405 L .46395 .63716 L p .898 .762 .703 r
F P
0 g
s
.4675 .61799 m .47248 .62334 L .47037 .62515 L p .898 .763 .704 r
F P
0 g
s
.51099 .48206 m .50511 .46653 L .50519 .46922 L p .594 .468 .679 r
F P
0 g
s
.51189 .47832 m .50777 .46745 L .50511 .46653 L p .584 .463 .681 r
F P
0 g
s
.50511 .46653 m .51099 .48206 L .51189 .47832 L p .584 .463 .681 r
F P
0 g
s
.5165 .45974 m .50511 .46653 L .50777 .46745 L p .589 .456 .667 r
F P
0 g
s
.50511 .46653 m .5165 .45974 L .51401 .45848 L p .586 .45 .663 r
F P
0 g
s
.47638 .57915 m .47064 .57593 L .46888 .57746 L p .908 .758 .683 r
F P
0 g
s
.59445 .57069 m .5858 .55971 L .58382 .55745 L p .9 .514 .285 r
F P
0 g
s
.58382 .55745 m .59617 .57313 L .59445 .57069 L p .9 .514 .285 r
F P
0 g
s
.4678 .51805 m .4569 .51805 L .45461 .51734 L p .748 .564 .646 r
F P
0 g
s
.59711 .5761 m .59741 .57569 L .59617 .57313 L p .958 .628 .344 r
F P
0 g
s
.47808 .28693 m .48674 .31735 L .49143 .32309 L p .66 .608 .785 r
F P
0 g
s
.49143 .32309 m .47908 .27962 L .47808 .28693 L p .66 .608 .785 r
F P
0 g
s
.5104 .31281 m .49358 .31591 L .49143 .32309 L p .677 .619 .782 r
F P
0 g
s
.49143 .32309 m .51544 .31867 L .5104 .31281 L p .677 .619 .782 r
F P
0 g
s
.47908 .27962 m .49143 .32309 L .49358 .31591 L p .677 .618 .782 r
F P
0 g
s
.50519 .46922 m .5093 .48008 L .51099 .48206 L p .594 .468 .679 r
F P
0 g
s
.6016 .42325 m .60068 .42054 L .59828 .41939 L p .838 .522 .455 r
F P
0 g
s
.61395 .43186 m .60436 .42947 L .60247 .42931 L p .825 .45 .345 r
F P
0 g
s
.58112 .41251 m .5794 .40587 L .57618 .40448 L p .767 .54 .59 r
F P
0 g
s
.46856 .65012 m .4628 .64462 L .4633 .6405 L p .869 .748 .726 r
F P
0 g
s
.43782 .29203 m .44185 .29053 L .44416 .29699 L p .641 .598 .79 r
F P
0 g
s
.59617 .57313 m .59574 .57371 L .59711 .5761 L p .958 .628 .344 r
F P
0 g
s
.58559 .55989 m .59424 .57087 L .59617 .57313 L p .898 .496 .237 r
F P
0 g
s
.59617 .57313 m .58382 .55745 L .58559 .55989 L p .898 .496 .237 r
F P
0 g
s
.59574 .57371 m .59617 .57313 L .59424 .57087 L p .901 .517 .288 r
F P
0 g
s
.4245 .51175 m .43885 .51114 L .43686 .5118 L p .677 .315 .351 r
F P
0 g
s
.43766 .51531 m .43686 .5118 L .43885 .51114 L p .721 .395 .427 r
F P
0 g
s
.43885 .51114 m .44 .51614 L .43766 .51531 L p .721 .395 .427 r
F P
0 g
s
.43885 .51114 m .4245 .51175 L .42622 .51085 L p .658 .27 .3 r
F P
0 g
s
.44 .51614 m .43885 .51114 L .44116 .5118 L p .704 .384 .434 r
F P
0 g
s
.58512 .56031 m .58559 .55989 L .58382 .55745 L p .896 .484 .204 r
F P
0 g
s
.58382 .55745 m .58315 .55805 L .58512 .56031 L p .896 .484 .204 r
F P
0 g
s
.58315 .55805 m .58382 .55745 L .58119 .5554 L p .818 .354 .121 r
F P
0 g
s
.5727 .40301 m .55845 .40591 L .55582 .40863 L p .719 .54 .647 r
F P
0 g
s
.55582 .40863 m .57618 .40448 L .5727 .40301 L p .719 .54 .647 r
F P
0 g
s
.40495 .51005 m .39283 .51058 L .38999 .51063 L p .087 0 0 r
F P
0 g
s
.45666 .52041 m .46755 .52232 L .46983 .52344 L p .762 .576 .646 r
F P
0 g
s
.46983 .52344 m .45427 .52071 L .45666 .52041 L p .762 .576 .646 r
F P
0 g
s
.6038 .59542 m .60892 .61169 L .60816 .60876 L p .916 .625 .138 r
F P
0 g
s
.60474 .59865 m .60832 .61005 L .60892 .61169 L p .778 .477 0 r
F P
0 g
s
.60892 .61169 m .6038 .59542 L .60474 .59865 L p .778 .477 0 r
F P
0 g
s
.57864 .41396 m .57618 .40448 L .57361 .40659 L p .71 .506 .611 r
F P
0 g
s
.55935 .40951 m .57361 .40659 L .57618 .40448 L p .709 .504 .61 r
F P
0 g
s
.57618 .40448 m .55582 .40863 L .55935 .40951 L p .709 .504 .61 r
F P
0 g
s
.57618 .40448 m .57864 .41396 L .58112 .41251 L p .767 .54 .59 r
F P
0 g
s
.51353 .44635 m .52353 .44066 L .52478 .4376 L p .599 .447 .647 r
F P
0 g
s
.47357 .60403 m .47222 .60259 L .47303 .59986 L p .913 .767 .686 r
F P
0 g
s
.33707 .51374 m .31394 .5136 L .30881 .51462 L p .62 .813 .974 r
F P
0 g
s
.58119 .5554 m .58072 .55582 L .58315 .55805 L p .818 .354 .121 r
F P
0 g
s
.41318 .24551 m .43407 .28367 L .43782 .29203 L p .648 .627 .815 r
F P
0 g
s
.43782 .29203 m .40797 .23752 L .41318 .24551 L p .648 .627 .815 r
F P
0 g
s
.44185 .29053 m .43782 .29203 L .43407 .28367 L p .648 .627 .815 r
F P
0 g
s
.40797 .23752 m .43782 .29203 L .43143 .28476 L p .642 .624 .817 r
F P
0 g
s
.59424 .57087 m .59394 .57127 L .59574 .57371 L p .901 .517 .288 r
F P
0 g
s
.44116 .5118 m .44196 .51531 L .44 .51614 L p .704 .384 .434 r
F P
0 g
s
.44526 .29658 m .44808 .29554 L .44588 .28903 L p .641 .598 .79 r
F P
0 g
s
.44588 .28903 m .44185 .29053 L .44526 .29658 L p .641 .598 .79 r
F P
0 g
s
.47862 .53748 m .46827 .54518 L .46742 .54815 L p .812 .63 .656 r
F P
0 g
s
.70581 .49365 m .68877 .49233 L .68489 .48965 L p .59 .642 .871 r
F P
0 g
s
.60816 .60876 m .60458 .59737 L .6038 .59542 L p .916 .625 .138 r
F P
0 g
s
.73838 .50689 m .73682 .49414 L .74136 .49152 L p .617 .69 .895 r
F P
0 g
s
.50773 .50074 m .50387 .4879 L .50464 .48514 L p .638 .53 .715 r
F P
0 g
s
.61445 .43272 m .61583 .43517 L .61814 .4362 L p .814 .413 .291 r
F P
0 g
s
.47511 .58373 m .47089 .59486 L .47105 .59795 L p .913 .763 .682 r
F P
0 g
s
.37202 .51074 m .38661 .51095 L .38999 .51063 L p .396 .809 .976 r
F P
0 g
s
.5093 .48008 m .50486 .48224 L .50464 .48514 L p .591 .468 .68 r
F P
0 g
s
.59959 .42327 m .59828 .41939 L .59594 .42014 L p .758 .482 .515 r
F P
0 g
s
.58387 .42087 m .59594 .42014 L .59828 .41939 L p .754 .473 .507 r
F P
0 g
s
.59828 .41939 m .58103 .42043 L .58387 .42087 L p .754 .473 .507 r
F P
0 g
s
.59828 .41939 m .59959 .42327 L .6016 .42325 L p .838 .522 .455 r
F P
0 g
s
.58103 .42043 m .59828 .41939 L .59541 .41861 L p .764 .509 .548 r
F P
0 g
s
.50464 .48514 m .51016 .50349 L .50773 .50074 L p .638 .53 .715 r
F P
0 g
s
.51054 .49982 m .50668 .48697 L .50464 .48514 L p .591 .502 .722 r
F P
0 g
s
.50464 .48514 m .51016 .50349 L .51054 .49982 L p .591 .502 .722 r
F P
0 g
s
.51099 .48206 m .50464 .48514 L .50668 .48697 L p .606 .502 .709 r
F P
0 g
s
.50464 .48514 m .51099 .48206 L .5093 .48008 L p .591 .468 .68 r
F P
0 g
s
.47368 .59722 m .4723 .59588 L .47105 .59795 L p .916 .768 .682 r
F P
0 g
s
.47105 .59795 m .47303 .59986 L .47368 .59722 L p .916 .768 .682 r
F P
0 g
s
.50777 .46745 m .51574 .4627 L .5165 .45974 L p .589 .456 .667 r
F P
0 g
s
.65174 .46715 m .66044 .46985 L .66329 .47221 L p .358 .559 .912 r
F P
0 g
s
.55222 .40737 m .53858 .41229 L .53632 .41566 L p .677 .515 .659 r
F P
0 g
s
.57361 .40659 m .57532 .41324 L .57864 .41396 L p .71 .506 .611 r
F P
0 g
s
.62244 .44095 m .62012 .43799 L .61814 .4362 L p .731 .218 0 r
F P
0 g
s
.47172 .52821 m .47256 .52404 L .4704 .52223 L p .777 .607 .668 r
F P
0 g
s
.83375 .51212 m .7944 .51297 L .7862 .51004 L p .649 .724 .904 r
F P
0 g
s
.43686 .5118 m .42681 .51223 L .4245 .51175 L p .677 .315 .351 r
F P
0 g
s
.61429 .66383 m .62001 .67334 L .62013 .67763 L p .35 .345 .713 r
F P
0 g
s
.70925 .49152 m .68489 .48965 L .68781 .4876 L p .575 .662 .897 r
F P
0 g
s
.6848 .47713 m .68781 .4876 L .68489 .48965 L p .571 .652 .891 r
F P
0 g
s
.68489 .48965 m .68057 .47469 L .6848 .47713 L p .571 .652 .891 r
F P
0 g
s
.68489 .48965 m .70925 .49152 L .70581 .49365 L p .59 .642 .871 r
F P
0 g
s
.68057 .47469 m .68489 .48965 L .68158 .48697 L p .515 .614 .889 r
F P
0 g
s
.59541 .41861 m .58334 .41933 L .58103 .42043 L p .764 .509 .548 r
F P
0 g
s
.47029 .60071 m .47167 .60204 L .47303 .59986 L p .914 .769 .686 r
F P
0 g
s
.47303 .59986 m .47105 .59795 L .47029 .60071 L p .914 .769 .686 r
F P
0 g
s
.46581 .61626 m .47303 .59986 L .47167 .60204 L p .915 .769 .686 r
F P
0 g
s
.46581 .61626 m .47303 .59986 L .47222 .60259 L p .913 .767 .686 r
F P
0 g
s
.42206 .72565 m .40102 .74946 L .39357 .75296 L p .791 .743 .809 r
F P
0 g
s
.47037 .62515 m .46689 .62141 L .4675 .61799 L p .898 .763 .704 r
F P
0 g
s
.59394 .57127 m .58512 .56031 L .58315 .55805 L p .9 .5 .24 r
F P
0 g
s
.58315 .55805 m .59574 .57371 L .59394 .57127 L p .9 .5 .24 r
F P
0 g
s
.54148 .42772 m .53632 .41566 L .53454 .41877 L p .628 .465 .643 r
F P
0 g
s
.54353 .42473 m .53992 .41629 L .53632 .41566 L p .663 .482 .629 r
F P
0 g
s
.53632 .41566 m .54148 .42772 L .54353 .42473 L p .663 .482 .629 r
F P
0 g
s
.55582 .40863 m .53632 .41566 L .53992 .41629 L p .663 .481 .628 r
F P
0 g
s
.53632 .41566 m .55582 .40863 L .55222 .40737 L p .677 .515 .659 r
F P
0 g
s
.64427 .45792 m .63863 .45497 L .63652 .45264 L p .165 .423 .861 r
F P
0 g
s
.45706 .52061 m .46796 .52253 L .4704 .52223 L p .762 .576 .646 r
F P
0 g
s
.4569 .51805 m .45666 .52041 L .45427 .52071 L p .754 .541 .608 r
F P
0 g
s
.45427 .52071 m .45461 .51734 L .4569 .51805 L p .754 .541 .608 r
F P
0 g
s
.4704 .52223 m .45483 .5195 L .45706 .52061 L p .762 .576 .646 r
F P
0 g
s
.46918 .5282 m .4704 .52223 L .46796 .52253 L p .766 .595 .667 r
F P
0 g
s
.4704 .52223 m .46918 .5282 L .47172 .52821 L p .777 .607 .668 r
F P
0 g
s
.26596 .51341 m .30881 .51462 L .30257 .51302 L p .639 .788 .953 r
F P
0 g
s
.30337 .5073 m .30257 .51302 L .30881 .51462 L p .622 .79 .962 r
F P
0 g
s
.30881 .51462 m .30999 .50645 L .30337 .5073 L p .622 .79 .962 r
F P
0 g
s
.30881 .51462 m .26596 .51341 L .2725 .51538 L p .643 .785 .95 r
F P
0 g
s
.30999 .50645 m .30881 .51462 L .31394 .5136 L p .63 .797 .963 r
F P
0 g
s
.59637 .57788 m .59696 .57647 L .59574 .57371 L p .954 .605 .277 r
F P
0 g
s
.59574 .57371 m .5949 .57572 L .59637 .57788 L p .954 .605 .277 r
F P
0 g
s
.58492 .56074 m .59375 .57171 L .59574 .57371 L p .89 .466 .161 r
F P
0 g
s
.59574 .57371 m .58315 .55805 L .58492 .56074 L p .89 .466 .161 r
F P
0 g
s
.5949 .57572 m .59574 .57371 L .59375 .57171 L p .907 .512 .247 r
F P
0 g
s
.51998 .49433 m .51016 .50349 L .51325 .50462 L p .654 .619 .802 r
F P
0 g
s
.51742 .49341 m .51054 .49982 L .51016 .50349 L p .575 .487 .718 r
F P
0 g
s
.51016 .50349 m .51998 .49433 L .51742 .49341 L p .575 .487 .718 r
F P
0 g
s
.50668 .48697 m .51113 .48481 L .51099 .48206 L p .606 .502 .709 r
F P
0 g
s
.60458 .59737 m .6047 .59497 L .60398 .59199 L p .921 .632 .149 r
F P
0 g
s
.51325 .50462 m .52013 .49822 L .51998 .49433 L p .654 .619 .802 r
F P
0 g
s
.53454 .41877 m .53814 .42722 L .54148 .42772 L p .628 .465 .643 r
F P
0 g
s
.44196 .51531 m .45219 .51615 L .45461 .51734 L p .743 .459 .5 r
F P
0 g
s
.55009 .32141 m .57344 .32251 L .57866 .31791 L p .725 .629 .751 r
F P
0 g
s
.5949 .57572 m .60398 .59199 L .60272 .58927 L p .955 .609 .285 r
F P
0 g
s
.60398 .59199 m .6038 .59542 L .60458 .59737 L p .921 .632 .149 r
F P
0 g
s
.59624 .57873 m .6026 .59012 L .60398 .59199 L p .931 .557 .165 r
F P
0 g
s
.60398 .59199 m .5949 .57572 L .59624 .57873 L p .931 .557 .165 r
F P
0 g
s
.6038 .59542 m .60398 .59199 L .6026 .59012 L p .94 .575 .196 r
F P
0 g
s
.36914 .51033 m .38999 .51063 L .3871 .51036 L p .35 .793 .959 r
F P
0 g
s
.38816 .50989 m .3871 .51036 L .38999 .51063 L p .151 .682 .863 r
F P
0 g
s
.38999 .51063 m .39153 .50997 L .38816 .50989 L p .151 .682 .863 r
F P
0 g
s
.38999 .51063 m .36914 .51033 L .37202 .51074 L p .396 .809 .976 r
F P
0 g
s
.39153 .50997 m .38999 .51063 L .39283 .51058 L p .165 .696 .852 r
F P
0 g
s
.44109 .28105 m .43827 .2821 L .44185 .29053 L p .648 .627 .815 r
F P
0 g
s
.44185 .29053 m .44588 .28903 L .44109 .28105 L p .648 .627 .815 r
F P
0 g
s
.41314 .23554 m .44185 .29053 L .43827 .2821 L p .648 .627 .815 r
F P
0 g
s
.43407 .28367 m .43689 .28261 L .44185 .29053 L p .648 .627 .815 r
F P
0 g
s
.41314 .23554 m .44185 .29053 L .43689 .28261 L p .648 .627 .815 r
F P
0 g
s
.60272 .58927 m .59637 .57788 L .5949 .57572 L p .955 .609 .285 r
F P
0 g
s
.47222 .60259 m .46717 .61408 L .46581 .61626 L p .913 .767 .686 r
F P
0 g
s
.44 .51614 m .45461 .51734 L .45238 .51756 L p .753 .521 .58 r
F P
0 g
s
.45214 .51992 m .45238 .51756 L .45461 .51734 L p .759 .546 .608 r
F P
0 g
s
.45461 .51734 m .45427 .52071 L .45214 .51992 L p .759 .546 .608 r
F P
0 g
s
.45461 .51734 m .44 .51614 L .44196 .51531 L p .743 .459 .5 r
F P
0 g
s
.62147 .44043 m .61814 .4362 L .61669 .43631 L p .778 .318 .154 r
F P
0 g
s
.60739 .43393 m .61669 .43631 L .61814 .4362 L p .762 .291 .128 r
F P
0 g
s
.61814 .4362 m .60486 .43279 L .60739 .43393 L p .762 .291 .128 r
F P
0 g
s
.61814 .4362 m .62147 .44043 L .62244 .44095 L p .731 .218 0 r
F P
0 g
s
.60486 .43279 m .61814 .4362 L .61583 .43517 L p .808 .392 .259 r
F P
0 g
s
.58072 .55582 m .56901 .54578 L .56641 .54371 L p .737 .214 0 r
F P
0 g
s
.56641 .54371 m .58315 .55805 L .58072 .55582 L p .737 .214 0 r
F P
0 g
s
.68158 .48697 m .67855 .47651 L .68057 .47469 L p .515 .614 .889 r
F P
0 g
s
.56257 .5422 m .55511 .53624 L .55574 .53519 L p .363 .601 .938 r
F P
0 g
s
.55574 .53519 m .56641 .54371 L .56257 .5422 L p .363 .601 .938 r
F P
0 g
s
.60254 .42565 m .60188 .42414 L .59959 .42327 L p .831 .485 .4 r
F P
0 g
s
.64457 .45685 m .63652 .45264 L .63626 .45204 L p 0 .354 .8 r
F P
0 g
s
.62946 .4465 m .63626 .45204 L .63652 .45264 L p 0 .367 .807 r
F P
0 g
s
.6268 .44472 m .63652 .45264 L .63426 .45079 L p .458 0 0 r
F P
0 g
s
.63426 .45079 m .62746 .44525 L .6268 .44472 L p .458 0 0 r
F P
0 g
s
.63652 .45264 m .6268 .44472 L .62946 .4465 L p 0 .367 .807 r
F P
0 g
s
.63652 .45264 m .64457 .45685 L .64427 .45792 L p .165 .423 .861 r
F P
0 g
s
.39537 .25351 m .37991 .2617 L .37127 .25571 L p .631 .62 .821 r
F P
0 g
s
.59594 .42014 m .59686 .42286 L .59959 .42327 L p .758 .482 .515 r
F P
0 g
s
.57866 .31791 m .54528 .31634 L .55009 .32141 L p .725 .629 .751 r
F P
0 g
s
.58014 .28203 m .57431 .31131 L .57866 .31791 L p .721 .652 .78 r
F P
0 g
s
.57866 .31791 m .58702 .27611 L .58014 .28203 L p .721 .652 .78 r
F P
0 g
s
.54528 .31634 m .57866 .31791 L .57431 .31131 L p .721 .652 .78 r
F P
0 g
s
.58702 .27611 m .57866 .31791 L .58556 .31302 L p .748 .679 .784 r
F P
0 g
s
.45032 .29479 m .45895 .29205 L .45821 .28509 L p .648 .602 .788 r
F P
0 g
s
.45821 .28509 m .44588 .28903 L .45032 .29479 L p .648 .602 .788 r
F P
0 g
s
.46796 .52253 m .46711 .5267 L .46918 .5282 L p .766 .595 .667 r
F P
0 g
s
.45994 .67264 m .44927 .6889 L .4449 .69099 L p .831 .726 .748 r
F P
0 g
s
.4449 .69099 m .46016 .66774 L .45994 .67264 L p .831 .726 .748 r
F P
0 g
s
.53992 .41629 m .55357 .41137 L .55582 .40863 L p .663 .481 .628 r
F P
0 g
s
.3214 .77574 m .24789 .82292 L .25826 .81544 L p .757 .791 .88 r
F P
0 g
s
.2551 .81304 m .25826 .81544 L .24789 .82292 L p .757 .79 .88 r
F P
0 g
s
.24789 .82292 m .24336 .81951 L .2551 .81304 L p .757 .79 .88 r
F P
0 g
s
.31213 .78419 m .26071 .81718 L .24789 .82292 L p .756 .785 .877 r
F P
0 g
s
.24789 .82292 m .3214 .77574 L .31213 .78419 L p .756 .785 .877 r
F P
0 g
s
.41107 .51096 m .42188 .51128 L .4245 .51175 L p .525 .003 0 r
F P
0 g
s
.49358 .31591 m .48495 .28547 L .47908 .27962 L p .677 .618 .782 r
F P
0 g
s
.60832 .61005 m .60908 .61358 L .61 .61673 L p .779 .478 0 r
F P
0 g
s
.5597 .41913 m .55582 .40863 L .55357 .41137 L p .662 .479 .627 r
F P
0 g
s
.56207 .41685 m .55935 .40951 L .55582 .40863 L p .709 .503 .608 r
F P
0 g
s
.55582 .40863 m .5597 .41913 L .56207 .41685 L p .709 .503 .608 r
F P
0 g
s
.74956 .50688 m .77946 .50709 L .7862 .51004 L p .639 .713 .901 r
F P
0 g
s
.58556 .31302 m .59143 .28378 L .58702 .27611 L p .748 .679 .784 r
F P
0 g
s
.6393 .28231 m .65878 .2458 L .65661 .23448 L p .757 .722 .819 r
F P
0 g
s
.65661 .23448 m .62879 .28676 L .6393 .28231 L p .757 .722 .819 r
F P
0 g
s
.39283 .51058 m .39391 .51012 L .39153 .50997 L p .165 .696 .852 r
F P
0 g
s
.43143 .28476 m .41053 .24663 L .40797 .23752 L p .642 .624 .817 r
F P
0 g
s
.58448 .56253 m .58492 .56074 L .58315 .55805 L p .879 .443 .099 r
F P
0 g
s
.58315 .55805 m .58251 .5606 L .58448 .56253 L p .879 .443 .099 r
F P
0 g
s
.56917 .54642 m .58089 .55647 L .58315 .55805 L p .73 .205 0 r
F P
0 g
s
.58315 .55805 m .56641 .54371 L .56917 .54642 L p .73 .205 0 r
F P
0 g
s
.58251 .5606 m .58315 .55805 L .58089 .55647 L p .84 .377 .082 r
F P
0 g
s
.47167 .60204 m .46662 .61353 L .46581 .61626 L p .915 .769 .686 r
F P
0 g
s
.45238 .51756 m .44215 .51673 L .44 .51614 L p .753 .521 .58 r
F P
0 g
s
.59375 .57171 m .59315 .57311 L .5949 .57572 L p .907 .512 .247 r
F P
0 g
s
.45462 .52289 m .46918 .5282 L .46711 .5267 L p .776 .589 .647 r
F P
0 g
s
.45611 .52513 m .4663 .52884 L .46918 .5282 L p .786 .556 .588 r
F P
0 g
s
.46918 .5282 m .45462 .52289 L .45611 .52513 L p .786 .556 .588 r
F P
0 g
s
.46219 .53959 m .46918 .5282 L .4663 .52884 L p .796 .589 .622 r
F P
0 g
s
.46461 .53919 m .46951 .53121 L .46918 .5282 L p .823 .626 .637 r
F P
0 g
s
.46918 .5282 m .46219 .53959 L .46461 .53919 L p .823 .626 .637 r
F P
0 g
s
.42365 .71891 m .39357 .75296 L .39616 .74656 L p .803 .766 .819 r
F P
0 g
s
.38626 .73989 m .39616 .74656 L .39357 .75296 L p .802 .765 .819 r
F P
0 g
s
.39357 .75296 m .37941 .74347 L .38626 .73989 L p .802 .765 .819 r
F P
0 g
s
.39357 .75296 m .42365 .71891 L .42206 .72565 L p .791 .743 .809 r
F P
0 g
s
.37941 .74347 m .39357 .75296 L .38461 .75769 L p .777 .77 .846 r
F P
0 g
s
.53814 .42722 m .52646 .43413 L .52478 .4376 L p .627 .468 .647 r
F P
0 g
s
.61583 .43517 m .60654 .43278 L .60486 .43279 L p .808 .392 .259 r
F P
0 g
s
.31394 .5136 m .31479 .50788 L .30999 .50645 L p .63 .797 .963 r
F P
0 g
s
.61682 .65005 m .61294 .64321 L .61304 .63956 L p .254 .233 .641 r
F P
0 g
s
.55357 .41137 m .55629 .41872 L .5597 .41913 L p .662 .479 .627 r
F P
0 g
s
.62895 .69468 m .61965 .68233 L .62013 .67763 L p .51 .461 .739 r
F P
0 g
s
.59143 .28378 m .62065 .29121 L .62879 .28676 L p .748 .679 .784 r
F P
0 g
s
.62879 .28676 m .58702 .27611 L .59143 .28378 L p .748 .679 .784 r
F P
0 g
s
.64519 .24041 m .62575 .27706 L .62879 .28676 L p .736 .694 .811 r
F P
0 g
s
.62879 .28676 m .65661 .23448 L .64519 .24041 L p .736 .694 .811 r
F P
0 g
s
.58702 .27611 m .62879 .28676 L .62575 .27706 L p .736 .694 .811 r
F P
0 g
s
.52044 .32332 m .54132 .32169 L .54528 .31634 L p .697 .607 .752 r
F P
0 g
s
.54528 .31634 m .51544 .31867 L .52044 .32332 L p .697 .607 .752 r
F P
0 g
s
.40905 .51129 m .4245 .51175 L .42233 .51196 L p .557 .054 .015 r
F P
0 g
s
.423 .51383 m .42233 .51196 L .4245 .51175 L p .657 .214 .188 r
F P
0 g
s
.4245 .51175 m .42546 .51442 L .423 .51383 L p .657 .214 .188 r
F P
0 g
s
.4245 .51175 m .40905 .51129 L .41107 .51096 L p .525 .003 0 r
F P
0 g
s
.42546 .51442 m .4245 .51175 L .42681 .51223 L p .643 .206 .196 r
F P
0 g
s
.5307 .44815 m .52478 .4376 L .52353 .44066 L p .586 .433 .641 r
F P
0 g
s
.53223 .44491 m .52808 .43753 L .52478 .4376 L p .612 .443 .629 r
F P
0 g
s
.52478 .4376 m .5307 .44815 L .53223 .44491 L p .612 .443 .629 r
F P
0 g
s
.54148 .42772 m .52478 .4376 L .52808 .43753 L p .612 .438 .623 r
F P
0 g
s
.52478 .4376 m .54148 .42772 L .53814 .42722 L p .627 .468 .647 r
F P
0 g
s
.46711 .5267 m .45692 .52299 L .45462 .52289 L p .776 .589 .647 r
F P
0 g
s
.37127 .25571 m .39335 .24394 L .39537 .25351 L p .631 .62 .821 r
F P
0 g
s
.32516 .1959 m .3664 .24357 L .37127 .25571 L p .641 .647 .841 r
F P
0 g
s
.37127 .25571 m .31236 .18771 L .32516 .1959 L p .641 .647 .841 r
F P
0 g
s
.39335 .24394 m .37127 .25571 L .3664 .24357 L p .64 .647 .841 r
F P
0 g
s
.31236 .18771 m .37127 .25571 L .35798 .24891 L p .629 .644 .846 r
F P
0 g
s
.38461 .75769 m .37467 .75108 L .37941 .74347 L p .777 .77 .846 r
F P
0 g
s
.59959 .42327 m .60053 .42543 L .60254 .42565 L p .831 .485 .4 r
F P
0 g
s
.60053 .42543 m .59959 .42327 L .59727 .42379 L p .751 .454 .481 r
F P
0 g
s
.58565 .42467 m .59727 .42379 L .59959 .42327 L p .747 .445 .472 r
F P
0 g
s
.59959 .42327 m .58299 .42453 L .58565 .42467 L p .747 .445 .472 r
F P
0 g
s
.58299 .42453 m .59959 .42327 L .59686 .42286 L p .757 .474 .505 r
F P
0 g
s
.52353 .44066 m .52767 .44804 L .5307 .44815 L p .586 .433 .641 r
F P
0 g
s
.57195 .5499 m .56917 .54642 L .56641 .54371 L p .617 .09 0 r
F P
0 g
s
.56641 .54371 m .57038 .54867 L .57195 .5499 L p .617 .09 0 r
F P
0 g
s
.55842 .53753 m .56589 .54349 L .56641 .54371 L p .575 .034 0 r
F P
0 g
s
.56641 .54371 m .55574 .53519 L .55842 .53753 L p .575 .034 0 r
F P
0 g
s
.57038 .54867 m .56641 .54371 L .56589 .54349 L p .618 .09 0 r
F P
0 g
s
.45451 .65851 m .4606 .66369 L .46016 .66774 L p .868 .746 .726 r
F P
0 g
s
.46016 .66774 m .45145 .66035 L .45451 .65851 L p .868 .746 .726 r
F P
0 g
s
.44581 .68639 m .4565 .67011 L .46016 .66774 L p .849 .753 .757 r
F P
0 g
s
.46016 .66774 m .4449 .69099 L .44581 .68639 L p .849 .753 .757 r
F P
0 g
s
.45145 .66035 m .46016 .66774 L .4565 .67011 L p .849 .754 .758 r
F P
0 g
s
.58334 .41933 m .58166 .41481 L .57864 .41396 L p .761 .502 .542 r
F P
0 g
s
.21817 .51364 m .25766 .51535 L .26596 .51341 L p .649 .77 .937 r
F P
0 g
s
.42681 .51223 m .42749 .5141 L .42546 .51442 L p .643 .206 .196 r
F P
0 g
s
.44199 .51814 m .45214 .51992 L .45427 .52071 L p .764 .53 .58 r
F P
0 g
s
.45427 .52071 m .43976 .51816 L .44199 .51814 L p .764 .53 .58 r
F P
0 g
s
.42179 .24222 m .44109 .28105 L .44588 .28903 L p .648 .627 .815 r
F P
0 g
s
.44588 .28903 m .41831 .23355 L .42179 .24222 L p .648 .627 .815 r
F P
0 g
s
.45252 .27733 m .44388 .28011 L .44588 .28903 L p .654 .63 .813 r
F P
0 g
s
.44588 .28903 m .45821 .28509 L .45252 .27733 L p .654 .63 .813 r
F P
0 g
s
.41831 .23355 m .44588 .28903 L .44388 .28011 L p .654 .63 .813 r
F P
0 g
s
.60291 .42655 m .60269 .42607 L .60053 .42543 L p .831 .479 .389 r
F P
0 g
s
.51113 .48481 m .51742 .49341 L .51998 .49433 L p .58 .482 .707 r
F P
0 g
s
.51998 .49433 m .51099 .48206 L .51113 .48481 L p .58 .482 .707 r
F P
0 g
s
.52024 .49016 m .51394 .48156 L .51099 .48206 L p .581 .482 .707 r
F P
0 g
s
.51099 .48206 m .51998 .49433 L .52024 .49016 L p .581 .482 .707 r
F P
0 g
s
.52337 .47003 m .51099 .48206 L .51394 .48156 L p .577 .461 .685 r
F P
0 g
s
.52055 .4699 m .51189 .47832 L .51099 .48206 L p .567 .446 .674 r
F P
0 g
s
.51099 .48206 m .52337 .47003 L .52055 .4699 L p .567 .446 .674 r
F P
0 g
s
.57532 .41324 m .56207 .41685 L .5597 .41913 L p .71 .505 .609 r
F P
0 g
s
.5597 .41913 m .57864 .41396 L .57532 .41324 L p .71 .505 .609 r
F P
0 g
s
.6026 .59012 m .60247 .59251 L .6038 .59542 L p .94 .575 .196 r
F P
0 g
s
.61306 .624 m .61304 .63956 L .6126 .63615 L p 0 0 .481 r
F P
0 g
s
.61304 .63956 m .61859 .64933 L .61682 .65005 L p .254 .233 .641 r
F P
0 g
s
.61394 .62781 m .61392 .6387 L .61304 .63956 L p .022 .124 .632 r
F P
0 g
s
.61304 .63956 m .61306 .624 L .61394 .62781 L p .022 .124 .632 r
F P
0 g
s
.61859 .64933 m .61304 .63956 L .61392 .6387 L p .023 .126 .634 r
F P
0 g
s
.3871 .51036 m .37249 .51014 L .36914 .51033 L p .35 .793 .959 r
F P
0 g
s
.8425 .50881 m .7862 .51004 L .79423 .50649 L p .647 .729 .909 r
F P
0 g
s
.79258 .49191 m .79423 .50649 L .7862 .51004 L p .646 .723 .905 r
F P
0 g
s
.7862 .51004 m .78375 .48924 L .79258 .49191 L p .646 .723 .905 r
F P
0 g
s
.7862 .51004 m .8425 .50881 L .83375 .51212 L p .649 .724 .904 r
F P
0 g
s
.78375 .48924 m .7862 .51004 L .77946 .50709 L p .633 .714 .905 r
F P
0 g
s
.79904 .81725 m .82635 .79118 L .84401 .7918 L p .569 .645 .886 r
F P
0 g
s
.58103 .42043 m .57864 .41396 L .57625 .41575 L p .699 .472 .576 r
F P
0 g
s
.56299 .41937 m .57625 .41575 L .57864 .41396 L p .696 .467 .572 r
F P
0 g
s
.57864 .41396 m .5597 .41913 L .56299 .41937 L p .696 .467 .572 r
F P
0 g
s
.57864 .41396 m .58103 .42043 L .58334 .41933 L p .761 .502 .542 r
F P
0 g
s
.50554 .28207 m .5104 .31281 L .51544 .31867 L p .677 .618 .783 r
F P
0 g
s
.51544 .31867 m .50852 .27473 L .50554 .28207 L p .677 .618 .783 r
F P
0 g
s
.54031 .31015 m .5194 .31179 L .51544 .31867 L p .697 .632 .78 r
F P
0 g
s
.51544 .31867 m .54528 .31634 L .54031 .31015 L p .697 .632 .78 r
F P
0 g
s
.50852 .27473 m .51544 .31867 L .5194 .31179 L p .697 .633 .781 r
F P
0 g
s
.59686 .42286 m .58524 .42374 L .58299 .42453 L p .757 .474 .505 r
F P
0 g
s
.52767 .44804 m .51773 .45616 L .5165 .45974 L p .586 .441 .651 r
F P
0 g
s
.60053 .42543 m .60083 .42612 L .60291 .42655 L p .831 .479 .389 r
F P
0 g
s
.46506 .5932 m .47105 .59795 L .47089 .59486 L p .92 .768 .676 r
F P
0 g
s
.46543 .61236 m .47029 .60071 L .47105 .59795 L p .915 .769 .686 r
F P
0 g
s
.47105 .59795 m .46411 .61459 L .46543 .61236 L p .915 .769 .686 r
F P
0 g
s
.465 .59642 m .46919 .59974 L .47105 .59795 L p .917 .771 .685 r
F P
0 g
s
.47105 .59795 m .46506 .5932 L .465 .59642 L p .917 .771 .685 r
F P
0 g
s
.46411 .61459 m .47105 .59795 L .46919 .59974 L p .918 .774 .686 r
F P
0 g
s
.52337 .47003 m .5165 .45974 L .51574 .4627 L p .567 .434 .659 r
F P
0 g
s
.52434 .46647 m .51953 .45927 L .5165 .45974 L p .58 .438 .653 r
F P
0 g
s
.5165 .45974 m .52337 .47003 L .52434 .46647 L p .58 .438 .653 r
F P
0 g
s
.5307 .44815 m .5165 .45974 L .51953 .45927 L p .577 .426 .639 r
F P
0 g
s
.5165 .45974 m .5307 .44815 L .52767 .44804 L p .586 .441 .651 r
F P
0 g
s
.51574 .4627 m .52055 .4699 L .52337 .47003 L p .567 .434 .659 r
F P
0 g
s
.60327 .42735 m .603 .42678 L .60083 .42612 L p .827 .463 .365 r
F P
0 g
s
.61669 .43631 m .61901 .43927 L .62147 .44043 L p .778 .318 .154 r
F P
0 g
s
.4663 .52884 m .4614 .53682 L .46219 .53959 L p .796 .589 .622 r
F P
0 g
s
.52808 .43753 m .53977 .43061 L .54148 .42772 L p .612 .438 .623 r
F P
0 g
s
.6126 .63615 m .61262 .62526 L .61306 .624 L p 0 0 .481 r
F P
0 g
s
.58089 .55647 m .58044 .55825 L .58251 .5606 L p .84 .377 .082 r
F P
0 g
s
.42233 .51196 m .41151 .51164 L .40905 .51129 L p .557 .054 .015 r
F P
0 g
s
.30257 .51302 m .27255 .51217 L .26596 .51341 L p .639 .788 .953 r
F P
0 g
s
.47089 .59486 m .4667 .59154 L .46506 .5932 L p .92 .768 .676 r
F P
0 g
s
.59727 .42379 m .59793 .4253 L .60053 .42543 L p .751 .454 .481 r
F P
0 g
s
.60083 .42612 m .60123 .42694 L .60327 .42735 L p .827 .463 .365 r
F P
0 g
s
.62828 .66225 m .62013 .67763 L .62001 .67334 L p .347 .342 .712 r
F P
0 g
s
.62013 .67763 m .63344 .69528 L .62895 .69468 L p .51 .461 .739 r
F P
0 g
s
.62922 .66712 m .62351 .67788 L .62013 .67763 L p .418 .429 .764 r
F P
0 g
s
.62013 .67763 m .62828 .66225 L .62922 .66712 L p .418 .429 .764 r
F P
0 g
s
.63344 .69528 m .62013 .67763 L .62351 .67788 L p .418 .429 .764 r
F P
0 g
s
.35798 .24891 m .31677 .20143 L .31236 .18771 L p .629 .644 .846 r
F P
0 g
s
.34682 .50987 m .36502 .51083 L .36914 .51033 L p .546 .819 .996 r
F P
0 g
s
.45692 .52299 m .45706 .52061 L .45483 .5195 L p .773 .558 .608 r
F P
0 g
s
.68781 .4876 m .70488 .48891 L .70925 .49152 L p .575 .662 .897 r
F P
0 g
s
.57431 .31131 m .55092 .31019 L .54528 .31634 L p .721 .652 .78 r
F P
0 g
s
.57625 .41575 m .57792 .42028 L .58103 .42043 L p .699 .472 .576 r
F P
0 g
s
.42749 .5141 m .43766 .51531 L .44 .51614 L p .716 .339 .334 r
F P
0 g
s
.60083 .42612 m .60053 .42543 L .59815 .42574 L p .75 .448 .473 r
F P
0 g
s
.58675 .42669 m .59815 .42574 L .60053 .42543 L p .745 .435 .458 r
F P
0 g
s
.60053 .42543 m .58424 .42679 L .58675 .42669 L p .745 .435 .458 r
F P
0 g
s
.58424 .42679 m .60053 .42543 L .59793 .4253 L p .748 .445 .47 r
F P
0 g
s
.44215 .51673 m .44199 .51814 L .43976 .51816 L p .755 .49 .532 r
F P
0 g
s
.43976 .51816 m .44 .51614 L .44215 .51673 L p .755 .49 .532 r
F P
0 g
s
.44248 .51774 m .45265 .51953 L .45483 .5195 L p .764 .53 .58 r
F P
0 g
s
.45483 .5195 m .44031 .51695 L .44248 .51774 L p .764 .53 .58 r
F P
0 g
s
.45462 .52289 m .45483 .5195 L .45265 .51953 L p .768 .554 .608 r
F P
0 g
s
.45483 .5195 m .45462 .52289 L .45692 .52299 L p .773 .558 .608 r
F P
0 g
s
.60436 .42947 m .60349 .42782 L .60123 .42694 L p .822 .444 .338 r
F P
0 g
s
.47236 .56223 m .47176 .55585 L .4694 .55458 L p .869 .7 .671 r
F P
0 g
s
.4694 .55458 m .47027 .5637 L .47236 .56223 L p .869 .7 .671 r
F P
0 g
s
.46717 .61408 m .46835 .61529 L .4675 .61799 L p .913 .767 .686 r
F P
0 g
s
.43689 .28261 m .41679 .24413 L .41314 .23554 L p .648 .627 .815 r
F P
0 g
s
.63626 .45204 m .6419 .45499 L .64457 .45685 L p 0 .354 .8 r
F P
0 g
s
.51394 .48156 m .52261 .47315 L .52337 .47003 L p .577 .461 .685 r
F P
0 g
s
.42546 .51442 m .44 .51614 L .43779 .51613 L p .748 .455 .487 r
F P
0 g
s
.43763 .51754 m .43779 .51613 L .44 .51614 L p .758 .493 .532 r
F P
0 g
s
.44 .51614 m .43976 .51816 L .43763 .51754 L p .758 .493 .532 r
F P
0 g
s
.44 .51614 m .42546 .51442 L .42749 .5141 L p .716 .339 .334 r
F P
0 g
s
.44412 .69664 m .42926 .71617 L .42365 .71891 L p .811 .734 .779 r
F P
0 g
s
.42365 .71891 m .4449 .69099 L .44412 .69664 L p .811 .734 .779 r
F P
0 g
s
.4565 .67011 m .4504 .66495 L .45145 .66035 L p .849 .754 .758 r
F P
0 g
s
.47187 .55327 m .47134 .55118 L .46865 .55159 L p .843 .676 .675 r
F P
0 g
s
.46865 .55159 m .4694 .55458 L .47187 .55327 L p .843 .676 .675 r
F P
0 g
s
.39616 .74656 m .41723 .7227 L .42365 .71891 L p .803 .766 .819 r
F P
0 g
s
.47064 .57593 m .47162 .5663 L .47027 .5637 L p .899 .735 .67 r
F P
0 g
s
.25826 .81544 m .30973 .7824 L .3214 .77574 L p .757 .791 .88 r
F P
0 g
s
.70517 .24667 m .67183 .22834 L .65661 .23448 L p .739 .727 .841 r
F P
0 g
s
.60123 .42694 m .60083 .42612 L .59848 .42646 L p .746 .436 .459 r
F P
0 g
s
.58717 .42742 m .59848 .42646 L .60083 .42612 L p .742 .427 .449 r
F P
0 g
s
.60083 .42612 m .58467 .4275 L .58717 .42742 L p .742 .427 .449 r
F P
0 g
s
.59815 .42574 m .59836 .42623 L .60083 .42612 L p .75 .448 .473 r
F P
0 g
s
.58467 .4275 m .60083 .42612 L .59836 .42623 L p .745 .435 .458 r
F P
0 g
s
.54037 .27957 m .54031 .31015 L .54528 .31634 L p .697 .632 .78 r
F P
0 g
s
.54528 .31634 m .54541 .27265 L .54037 .27957 L p .697 .632 .78 r
F P
0 g
s
.54541 .27265 m .54528 .31634 L .55092 .31019 L p .721 .652 .78 r
F P
0 g
s
.67855 .47651 m .66647 .47476 L .66329 .47221 L p .508 .602 .882 r
F P
0 g
s
.51953 .45927 m .52947 .45115 L .5307 .44815 L p .577 .426 .639 r
F P
0 g
s
.43827 .2821 m .41817 .2436 L .41314 .23554 L p .648 .627 .815 r
F P
0 g
s
.55629 .41872 m .54353 .42473 L .54148 .42772 L p .662 .48 .628 r
F P
0 g
s
.45265 .51953 m .4525 .5219 L .45462 .52289 L p .768 .554 .608 r
F P
0 g
s
.59793 .4253 m .58653 .42625 L .58424 .42679 L p .748 .445 .47 r
F P
0 g
s
.4675 .61799 m .46581 .61626 L .46717 .61408 L p .913 .767 .686 r
F P
0 g
s
.45956 .63283 m .4659 .6204 L .4675 .61799 L p .903 .772 .706 r
F P
0 g
s
.4675 .61799 m .45845 .63575 L .45956 .63283 L p .903 .772 .706 r
F P
0 g
s
.46581 .61626 m .4675 .61799 L .4659 .6204 L p .903 .772 .706 r
F P
0 g
s
.45845 .63575 m .4675 .61799 L .46689 .62141 L p .897 .762 .704 r
F P
0 g
s
.46689 .62141 m .46055 .63384 L .45845 .63575 L p .897 .762 .704 r
F P
0 g
s
.72102 .78096 m .68775 .75566 L .68595 .74678 L p .584 .609 .843 r
F P
0 g
s
.68595 .74678 m .73356 .78301 L .72102 .78096 L p .584 .609 .843 r
F P
0 g
s
.34312 .50895 m .36914 .51033 L .36548 .50963 L p .532 .819 .998 r
F P
0 g
s
.36649 .50792 m .36548 .50963 L .36914 .51033 L p .448 .8 .998 r
F P
0 g
s
.36914 .51033 m .3706 .50788 L .36649 .50792 L p .448 .8 .998 r
F P
0 g
s
.36914 .51033 m .34312 .50895 L .34682 .50987 L p .546 .819 .996 r
F P
0 g
s
.3706 .50788 m .36914 .51033 L .37249 .51014 L p .46 .813 .997 r
F P
0 g
s
.43779 .51613 m .42761 .51492 L .42546 .51442 L p .748 .455 .487 r
F P
0 g
s
.39391 .51012 m .40618 .51104 L .40905 .51129 L p .119 0 0 r
F P
0 g
s
.62001 .67334 m .6257 .66257 L .62828 .66225 L p .347 .342 .712 r
F P
0 g
s
.20946 .51096 m .26596 .51341 L .25767 .5112 L p .647 .772 .939 r
F P
0 g
s
.25836 .50363 m .25767 .5112 L .26596 .51341 L p .639 .774 .945 r
F P
0 g
s
.26596 .51341 m .267 .5026 L .25836 .50363 L p .639 .774 .945 r
F P
0 g
s
.26596 .51341 m .20946 .51096 L .21817 .51364 L p .649 .77 .937 r
F P
0 g
s
.267 .5026 m .26596 .51341 L .27255 .51217 L p .644 .778 .945 r
F P
0 g
s
.54148 .42772 m .5597 .41913 L .55629 .41872 L p .662 .48 .628 r
F P
0 g
s
.47087 .54967 m .47001 .54727 L .46742 .54815 L p .831 .664 .676 r
F P
0 g
s
.46742 .54815 m .46865 .55159 L .47087 .54967 L p .831 .664 .676 r
F P
0 g
s
.4628 .64462 m .45451 .65851 L .45145 .66035 L p .869 .747 .726 r
F P
0 g
s
.45145 .66035 m .4633 .6405 L .4628 .64462 L p .869 .747 .726 r
F P
0 g
s
.52013 .49822 m .5239 .50049 L .52538 .49758 L p .495 .491 .782 r
F P
0 g
s
.52538 .49758 m .51998 .49433 L .52013 .49822 L p .495 .491 .782 r
F P
0 g
s
.46919 .59974 m .46433 .6114 L .46411 .61459 L p .918 .774 .686 r
F P
0 g
s
.56589 .54349 m .56866 .54696 L .57038 .54867 L p .618 .09 0 r
F P
0 g
s
.68057 .47469 m .66329 .47221 L .66475 .47067 L p .468 .633 .926 r
F P
0 g
s
.65987 .46212 m .66475 .47067 L .66329 .47221 L p .465 .627 .923 r
F P
0 g
s
.66329 .47221 m .6563 .45999 L .65987 .46212 L p .465 .627 .923 r
F P
0 g
s
.66329 .47221 m .68057 .47469 L .67855 .47651 L p .508 .602 .882 r
F P
0 g
s
.6563 .45999 m .66329 .47221 L .66044 .46985 L p .346 .555 .912 r
F P
0 g
s
.60247 .42931 m .60123 .42694 L .59904 .42751 L p .743 .423 .441 r
F P
0 g
s
.58781 .4285 m .59904 .42751 L .60123 .42694 L p .734 .405 .424 r
F P
0 g
s
.60123 .42694 m .58518 .42836 L .58781 .4285 L p .734 .405 .424 r
F P
0 g
s
.60123 .42694 m .60247 .42931 L .60436 .42947 L p .822 .444 .338 r
F P
0 g
s
.59848 .42646 m .59876 .42703 L .60123 .42694 L p .746 .436 .459 r
F P
0 g
s
.58518 .42836 m .60123 .42694 L .59876 .42703 L p .743 .427 .448 r
F P
0 g
s
.77946 .50709 m .7777 .49254 L .78375 .48924 L p .633 .714 .905 r
F P
0 g
s
.31936 .78946 m .31213 .78419 L .3214 .77574 L p .756 .785 .877 r
F P
0 g
s
.3214 .77574 m .33169 .78332 L .31936 .78946 L p .756 .785 .877 r
F P
0 g
s
.62746 .44525 m .62373 .44225 L .62147 .44043 L p .444 0 0 r
F P
0 g
s
.54623 .43597 m .54148 .42772 L .53977 .43061 L p .605 .43 .618 r
F P
0 g
s
.54816 .43336 m .54483 .42758 L .54148 .42772 L p .645 .444 .597 r
F P
0 g
s
.54148 .42772 m .54623 .43597 L .54816 .43336 L p .645 .444 .597 r
F P
0 g
s
.5597 .41913 m .54148 .42772 L .54483 .42758 L p .645 .444 .597 r
F P
0 g
s
.46055 .63384 m .46395 .63716 L .4633 .6405 L p .897 .761 .704 r
F P
0 g
s
.37467 .75108 m .3413 .77893 L .33169 .78332 L p .777 .77 .846 r
F P
0 g
s
.5194 .31179 m .51458 .28103 L .50852 .27473 L p .697 .633 .781 r
F P
0 g
s
.59315 .57311 m .58448 .56253 L .58251 .5606 L p .899 .483 .166 r
F P
0 g
s
.58251 .5606 m .5949 .57572 L .59315 .57311 L p .899 .483 .166 r
F P
0 g
s
.47027 .5637 m .46888 .57746 L .47064 .57593 L p .899 .735 .67 r
F P
0 g
s
.44045 .51903 m .45462 .52289 L .4525 .5219 L p .774 .539 .579 r
F P
0 g
s
.44236 .52055 m .45229 .52326 L .45462 .52289 L p .775 .486 .497 r
F P
0 g
s
.45462 .52289 m .44045 .51903 L .44236 .52055 L p .775 .486 .497 r
F P
0 g
s
.45226 .53072 m .45462 .52289 L .45229 .52326 L p .791 .534 .548 r
F P
0 g
s
.45446 .53061 m .45611 .52513 L .45462 .52289 L p .813 .558 .553 r
F P
0 g
s
.45462 .52289 m .45226 .53072 L .45446 .53061 L p .813 .558 .553 r
F P
0 g
s
.59836 .42623 m .58705 .42719 L .58467 .4275 L p .745 .435 .458 r
F P
0 g
s
.4633 .6405 m .45845 .63575 L .46055 .63384 L p .897 .761 .704 r
F P
0 g
s
.45249 .65668 m .46079 .64277 L .4633 .6405 L p .881 .767 .732 r
F P
0 g
s
.4633 .6405 m .45145 .66035 L .45249 .65668 L p .881 .767 .732 r
F P
0 g
s
.45845 .63575 m .4633 .6405 L .46079 .64277 L p .881 .768 .732 r
F P
0 g
s
.37249 .51014 m .37352 .50843 L .3706 .50788 L p .46 .813 .997 r
F P
0 g
s
.53977 .43061 m .5431 .43639 L .54623 .43597 L p .605 .43 .618 r
F P
0 g
s
.39153 .50997 m .40905 .51129 L .40658 .51115 L p .17 0 0 r
F P
0 g
s
.40725 .51185 m .40658 .51115 L .40905 .51129 L p .41 0 0 r
F P
0 g
s
.40905 .51129 m .41001 .51229 L .40725 .51185 L p .41 0 0 r
F P
0 g
s
.40905 .51129 m .39153 .50997 L .39391 .51012 L p .119 0 0 r
F P
0 g
s
.41001 .51229 m .40905 .51129 L .41151 .51164 L p .402 0 0 r
F P
0 g
s
.42751 .51576 m .43763 .51754 L .43976 .51816 L p .758 .464 .488 r
F P
0 g
s
.43976 .51816 m .42531 .51562 L .42751 .51576 L p .758 .464 .488 r
F P
0 g
s
.4525 .5219 m .44258 .5192 L .44045 .51903 L p .774 .539 .579 r
F P
0 g
s
.56322 .42622 m .5597 .41913 L .55759 .42157 L p .645 .444 .596 r
F P
0 g
s
.54483 .42758 m .55759 .42157 L .5597 .41913 L p .645 .444 .597 r
F P
0 g
s
.56545 .42433 m .56299 .41937 L .5597 .41913 L p .696 .464 .568 r
F P
0 g
s
.5597 .41913 m .56322 .42622 L .56545 .42433 L p .696 .464 .568 r
F P
0 g
s
.46348 .29075 m .47808 .28693 L .47908 .27962 L p .66 .608 .785 r
F P
0 g
s
.47908 .27962 m .45821 .28509 L .46348 .29075 L p .66 .608 .785 r
F P
0 g
s
.58524 .42374 m .58387 .42087 L .58103 .42043 L p .753 .466 .497 r
F P
0 g
s
.66044 .46985 m .65554 .46131 L .6563 .45999 L p .346 .555 .912 r
F P
0 g
s
.59618 .58158 m .59624 .57873 L .5949 .57572 L p .923 .547 .138 r
F P
0 g
s
.5949 .57572 m .5948 .5798 L .59618 .58158 L p .923 .547 .138 r
F P
0 g
s
.58449 .56361 m .59317 .5742 L .5949 .57572 L p .871 .429 .062 r
F P
0 g
s
.5949 .57572 m .58251 .5606 L .58449 .56361 L p .871 .429 .062 r
F P
0 g
s
.5948 .5798 m .5949 .57572 L .59317 .5742 L p .905 .493 .157 r
F P
0 g
s
.61262 .62526 m .61048 .62017 L .61 .61673 L p 0 0 .474 r
F P
0 g
s
.41151 .51164 m .41219 .51233 L .41001 .51229 L p .402 0 0 r
F P
0 g
s
.46759 .55627 m .46819 .56266 L .47027 .5637 L p .902 .724 .651 r
F P
0 g
s
.47027 .5637 m .4694 .55458 L .46759 .55627 L p .902 .724 .651 r
F P
0 g
s
.4573 .56431 m .47027 .5637 L .46819 .56266 L p .905 .717 .637 r
F P
0 g
s
.45918 .56601 m .46825 .56557 L .47027 .5637 L p .907 .732 .654 r
F P
0 g
s
.47027 .5637 m .4573 .56431 L .45918 .56601 L p .907 .732 .654 r
F P
0 g
s
.46888 .57746 m .47027 .5637 L .46825 .56557 L p .913 .749 .664 r
F P
0 g
s
.6268 .44472 m .62147 .44043 L .62036 .44051 L p .66 .114 0 r
F P
0 g
s
.61137 .43803 m .62036 .44051 L .62147 .44043 L p .635 .08 0 r
F P
0 g
s
.62147 .44043 m .60862 .43688 L .61137 .43803 L p .635 .08 0 r
F P
0 g
s
.6268 .44472 m .62609 .44462 L p .62737 .44518 L .384 0 0 r
F P
0 g
s
.6268 .44472 m .62746 .44525 L p .62627 .44429 L .444 0 0 r
F P
0 g
s
.63496 .44907 m .62946 .4465 L .6268 .44472 L p 0 .386 .824 r
F P
0 g
s
.6268 .44472 m .63467 .44839 L .63496 .44907 L p 0 .386 .824 r
F P
0 g
s
.63467 .44839 m .6268 .44472 L p .62737 .44518 L .384 0 0 r
F P
0 g
s
.62147 .44043 m .6268 .44472 L p .62627 .44429 L .444 0 0 r
F P
0 g
s
.60862 .43688 m .62147 .44043 L .61901 .43927 L p .764 .286 .106 r
F P
0 g
s
.46827 .54518 m .46461 .53919 L .46219 .53959 L p .827 .647 .659 r
F P
0 g
s
.46219 .53959 m .46742 .54815 L .46827 .54518 L p .827 .647 .659 r
F P
0 g
s
.4659 .6204 m .46471 .61919 L .46581 .61626 L p .903 .772 .706 r
F P
0 g
s
.61392 .6387 m .61781 .64554 L .61859 .64933 L p .023 .126 .634 r
F P
0 g
s
.59876 .42703 m .58753 .42802 L .58518 .42836 L p .743 .427 .448 r
F P
0 g
s
.43899 .68116 m .44581 .68639 L .4449 .69099 L p .848 .752 .757 r
F P
0 g
s
.4449 .69099 m .43514 .68353 L .43899 .68116 L p .848 .752 .757 r
F P
0 g
s
.42525 .71356 m .44014 .69401 L .4449 .69099 L p .826 .76 .789 r
F P
0 g
s
.4449 .69099 m .42365 .71891 L .42525 .71356 L p .826 .76 .789 r
F P
0 g
s
.43514 .68353 m .4449 .69099 L .44014 .69401 L p .826 .759 .789 r
F P
0 g
s
.55092 .31019 m .55103 .27962 L .54541 .27265 L p .721 .652 .78 r
F P
0 g
s
.46682 .55267 m .46736 .55477 L .4694 .55458 L p .894 .702 .636 r
F P
0 g
s
.4694 .55458 m .46865 .55159 L .46682 .55267 L p .894 .702 .636 r
F P
0 g
s
.45629 .55833 m .4694 .55458 L .46736 .55477 L p .893 .695 .628 r
F P
0 g
s
.45841 .5589 m .46759 .55627 L .4694 .55458 L p .897 .711 .643 r
F P
0 g
s
.4694 .55458 m .45629 .55833 L .45841 .5589 L p .897 .711 .643 r
F P
0 g
s
.37941 .74347 m .33169 .78332 L .33745 .77635 L p .783 .784 .853 r
F P
0 g
s
.33028 .77102 m .33745 .77635 L .33169 .78332 L p .783 .784 .854 r
F P
0 g
s
.33169 .78332 m .3214 .77574 L .33028 .77102 L p .783 .784 .854 r
F P
0 g
s
.33169 .78332 m .37941 .74347 L .37467 .75108 L p .777 .77 .846 r
F P
0 g
s
.60654 .43278 m .60486 .43034 L .60247 .42931 L p .798 .372 .237 r
F P
0 g
s
.60494 .60092 m .61 .61673 L .60908 .61358 L p .778 .477 0 r
F P
0 g
s
.61 .61673 m .61306 .624 L .61262 .62526 L p 0 0 .474 r
F P
0 g
s
.60908 .61358 m .60553 .60251 L .60494 .60092 L p .778 .477 0 r
F P
0 g
s
.60619 .60443 m .60974 .6155 L .61 .61673 L p 0 0 .354 r
F P
0 g
s
.61 .61673 m .60494 .60092 L .60619 .60443 L p 0 0 .354 r
F P
0 g
s
.61306 .624 m .61 .61673 L .60974 .6155 L p 0 0 .346 r
F P
0 g
s
.57792 .42028 m .56545 .42433 L .56322 .42622 L p .698 .468 .571 r
F P
0 g
s
.56322 .42622 m .58103 .42043 L .57792 .42028 L p .698 .468 .571 r
F P
0 g
s
.55759 .42157 m .56005 .42653 L .56322 .42622 L p .645 .444 .596 r
F P
0 g
s
.58299 .42453 m .58103 .42043 L .57872 .42193 L p .688 .441 .543 r
F P
0 g
s
.56624 .42599 m .57872 .42193 L .58103 .42043 L p .683 .433 .537 r
F P
0 g
s
.58103 .42043 m .56322 .42622 L .56624 .42599 L p .683 .433 .537 r
F P
0 g
s
.58103 .42043 m .58299 .42453 L .58524 .42374 L p .753 .466 .497 r
F P
0 g
s
.46662 .61353 m .46543 .61236 L .46411 .61459 L p .915 .77 .686 r
F P
0 g
s
.46411 .61459 m .46581 .61626 L .46662 .61353 L p .915 .77 .686 r
F P
0 g
s
.41728 .70787 m .42525 .71356 L .42365 .71891 L p .827 .76 .789 r
F P
0 g
s
.42365 .71891 m .41224 .71079 L .41728 .70787 L p .827 .76 .789 r
F P
0 g
s
.41224 .71079 m .42365 .71891 L .41723 .7227 L p .803 .766 .819 r
F P
0 g
s
.46572 .54947 m .46659 .55188 L .46865 .55159 L p .888 .687 .624 r
F P
0 g
s
.46865 .55159 m .46742 .54815 L .46572 .54947 L p .888 .687 .624 r
F P
0 g
s
.4558 .55639 m .46865 .55159 L .46659 .55188 L p .888 .683 .62 r
F P
0 g
s
.45783 .55604 m .46682 .55267 L .46865 .55159 L p .891 .695 .63 r
F P
0 g
s
.46865 .55159 m .4558 .55639 L .45783 .55604 L p .891 .695 .63 r
F P
0 g
s
.59904 .42751 m .59991 .42916 L .60247 .42931 L p .743 .423 .441 r
F P
0 g
s
.4667 .59154 m .46937 .58052 L .46888 .57746 L p .916 .759 .671 r
F P
0 g
s
.30746 .78054 m .2551 .81304 L .24336 .81951 L p .757 .791 .88 r
F P
0 g
s
.24336 .81951 m .31818 .77307 L .30746 .78054 L p .757 .791 .88 r
F P
0 g
s
.30632 .77961 m .25394 .81213 L .24336 .81951 L p .758 .792 .881 r
F P
0 g
s
.24336 .81951 m .31818 .77307 L .30632 .77961 L p .758 .792 .881 r
F P
0 g
s
.23895 .81604 m .24336 .81951 L .25394 .81213 L p .758 .793 .881 r
F P
0 g
s
.27255 .51217 m .27331 .50461 L .267 .5026 L p .644 .778 .945 r
F P
0 g
s
.61901 .43927 m .61002 .43679 L .60862 .43688 L p .764 .286 .106 r
F P
0 g
s
.73682 .49414 m .71437 .49414 L .70925 .49152 L p .614 .679 .888 r
F P
0 g
s
.45229 .52326 m .45063 .52873 L .45226 .53072 L p .791 .534 .548 r
F P
0 g
s
.52567 .49408 m .52189 .49181 L .51998 .49433 L p .565 .475 .712 r
F P
0 g
s
.51998 .49433 m .52538 .49758 L .52567 .49408 L p .565 .475 .712 r
F P
0 g
s
.52903 .4752 m .51998 .49433 L .52189 .49181 L p .549 .454 .699 r
F P
0 g
s
.52656 .47677 m .52024 .49016 L .51998 .49433 L p .55 .456 .7 r
F P
0 g
s
.51998 .49433 m .52903 .4752 L .52656 .47677 L p .55 .456 .7 r
F P
0 g
s
.44388 .28011 m .42459 .24126 L .41831 .23355 L p .654 .63 .813 r
F P
0 g
s
.43564 .2376 m .45252 .27733 L .45821 .28509 L p .654 .63 .813 r
F P
0 g
s
.45821 .28509 m .43411 .2283 L .43564 .2376 L p .654 .63 .813 r
F P
0 g
s
.47282 .27188 m .45819 .27574 L .45821 .28509 L p .665 .635 .811 r
F P
0 g
s
.45821 .28509 m .47908 .27962 L .47282 .27188 L p .665 .635 .811 r
F P
0 g
s
.43411 .2283 m .45821 .28509 L .45819 .27574 L p .664 .635 .811 r
F P
0 g
s
.36548 .50963 m .34725 .50866 L .34312 .50895 L p .532 .819 .998 r
F P
0 g
s
.44258 .5192 m .44248 .51774 L .44031 .51695 L p .769 .502 .531 r
F P
0 g
s
.46303 .61753 m .46422 .6187 L .46581 .61626 L p .906 .775 .706 r
F P
0 g
s
.46581 .61626 m .46411 .61459 L .46303 .61753 L p .906 .775 .706 r
F P
0 g
s
.45684 .63419 m .46581 .61626 L .46422 .6187 L p .906 .775 .706 r
F P
0 g
s
.45684 .63419 m .46581 .61626 L .46471 .61919 L p .903 .772 .706 r
F P
0 g
s
.40658 .51115 m .39431 .51023 L .39153 .50997 L p .17 0 0 r
F P
0 g
s
.46133 .54192 m .465 .54792 L .46742 .54815 L p .876 .651 .593 r
F P
0 g
s
.46742 .54815 m .46219 .53959 L .46133 .54192 L p .876 .651 .593 r
F P
0 g
s
.45513 .5541 m .46742 .54815 L .465 .54792 L p .877 .655 .598 r
F P
0 g
s
.45712 .55364 m .46572 .54947 L .46742 .54815 L p .887 .683 .621 r
F P
0 g
s
.46742 .54815 m .45513 .5541 L .45712 .55364 L p .887 .683 .621 r
F P
0 g
s
.41219 .51233 m .423 .51383 L .42546 .51442 L p .591 .073 0 r
F P
0 g
s
.42761 .51492 m .42751 .51576 L .42531 .51562 L p .741 .404 .412 r
F P
0 g
s
.42531 .51562 m .42546 .51442 L .42761 .51492 L p .741 .404 .412 r
F P
0 g
s
.60486 .43279 m .60247 .42931 L .60053 .43004 L p .727 .375 .381 r
F P
0 g
s
.58958 .43103 m .60053 .43004 L .60247 .42931 L p .716 .354 .363 r
F P
0 g
s
.60247 .42931 m .58683 .43073 L .58958 .43103 L p .716 .354 .363 r
F P
0 g
s
.60247 .42931 m .60486 .43279 L .60654 .43278 L p .798 .372 .237 r
F P
0 g
s
.58683 .43073 m .60247 .42931 L .59991 .42916 L p .738 .406 .42 r
F P
0 g
s
.42805 .51504 m .43818 .51682 L .44031 .51695 L p .758 .464 .487 r
F P
0 g
s
.44031 .51695 m .42585 .5144 L .42805 .51504 L p .758 .464 .487 r
F P
0 g
s
.44045 .51903 m .44031 .51695 L .43818 .51682 L p .766 .5 .532 r
F P
0 g
s
.44031 .51695 m .44045 .51903 L .44258 .5192 L p .769 .502 .531 r
F P
0 g
s
.60247 .59251 m .59618 .58158 L .5948 .5798 L p .931 .562 .163 r
F P
0 g
s
.5948 .5798 m .6038 .59542 L .60247 .59251 L p .931 .562 .163 r
F P
0 g
s
.46079 .64277 m .45739 .63945 L .45845 .63575 L p .881 .768 .732 r
F P
0 g
s
.60553 .60251 m .60474 .59865 L .6038 .59542 L p .777 .476 0 r
F P
0 g
s
.57872 .42193 m .58008 .42481 L .58299 .42453 L p .688 .441 .543 r
F P
0 g
s
.5431 .43639 m .53223 .44491 L .5307 .44815 L p .606 .436 .626 r
F P
0 g
s
.60494 .60092 m .60432 .60003 L p .60473 .60089 L .716 .322 0 r
F P
0 g
s
.60867 .60995 m .60619 .60443 L .60494 .60092 L p 0 0 .366 r
F P
0 g
s
.60494 .60092 m .60847 .6088 L .60867 .60995 L p 0 0 .366 r
F P
0 g
s
.60847 .6088 m .60494 .60092 L p .60473 .60089 L .716 .322 0 r
F P
0 g
s
.60494 .60092 m .60553 .60251 L p .60515 .60095 L .777 .476 0 r
F P
0 g
s
.6038 .59542 m .60494 .60092 L p .60515 .60095 L .777 .476 0 r
F P
0 g
s
.59638 .58305 m .60268 .59399 L .6038 .59542 L p .857 .46 0 r
F P
0 g
s
.6038 .59542 m .5948 .5798 L .59638 .58305 L p .857 .46 0 r
F P
0 g
s
.60494 .60092 m .6038 .59542 L .60268 .59399 L p .877 .49 .023 r
F P
0 g
s
.64802 .71691 m .63347 .70103 L .63344 .69528 L p .54 .517 .779 r
F P
0 g
s
.46825 .56557 m .46728 .57522 L .46888 .57746 L p .913 .749 .664 r
F P
0 g
s
.45765 .5744 m .46888 .57746 L .46728 .57522 L p .922 .746 .646 r
F P
0 g
s
.46888 .57746 m .46506 .5932 L .4667 .59154 L p .916 .759 .671 r
F P
0 g
s
.45893 .57706 m .4668 .57919 L .46888 .57746 L p .92 .756 .662 r
F P
0 g
s
.46888 .57746 m .45765 .5744 L .45893 .57706 L p .92 .756 .662 r
F P
0 g
s
.46506 .5932 m .46888 .57746 L .4668 .57919 L p .925 .769 .669 r
F P
0 g
s
.62351 .67788 m .63283 .69025 L .63344 .69528 L p .418 .429 .764 r
F P
0 g
s
.41001 .51229 m .42546 .51442 L .42313 .51424 L p .718 .334 .322 r
F P
0 g
s
.42303 .51508 m .42313 .51424 L .42546 .51442 L p .743 .406 .412 r
F P
0 g
s
.42546 .51442 m .42531 .51562 L .42303 .51508 L p .743 .406 .412 r
F P
0 g
s
.42546 .51442 m .41001 .51229 L .41219 .51233 L p .591 .073 0 r
F P
0 g
s
.79423 .50649 m .83372 .50562 L .8425 .50881 L p .647 .729 .909 r
F P
0 g
s
.62575 .27706 m .59648 .26955 L .58702 .27611 L p .736 .694 .811 r
F P
0 g
s
.46471 .61919 m .45844 .63174 L .45684 .63419 L p .903 .772 .706 r
F P
0 g
s
.41723 .7227 m .40923 .71704 L .41224 .71079 L p .803 .766 .819 r
F P
0 g
s
.5359 .4547 m .5307 .44815 L .52947 .45115 L p .556 .403 .629 r
F P
0 g
s
.53735 .45177 m .5337 .44719 L .5307 .44815 L p .589 .409 .606 r
F P
0 g
s
.5307 .44815 m .5359 .4547 L .53735 .45177 L p .589 .409 .606 r
F P
0 g
s
.54623 .43597 m .5307 .44815 L .5337 .44719 L p .587 .404 .601 r
F P
0 g
s
.5307 .44815 m .54623 .43597 L .5431 .43639 L p .606 .436 .626 r
F P
0 g
s
.44014 .69401 m .4333 .6888 L .43514 .68353 L p .826 .759 .789 r
F P
0 g
s
.52947 .45115 m .53311 .45574 L .5359 .4547 L p .556 .403 .629 r
F P
0 g
s
.56575 .54395 m .55842 .53753 L .55574 .53519 L p .474 0 0 r
F P
0 g
s
.55574 .53519 m .56621 .54437 L .56575 .54395 L p .474 0 0 r
F P
0 g
s
.55125 .52962 m .55282 .5337 L .55574 .53519 L p .313 .614 .955 r
F P
0 g
s
.55574 .53519 m .55352 .52936 L .55125 .52962 L p .313 .614 .955 r
F P
0 g
s
.56425 .54228 m .55692 .53586 L .55574 .53519 L p 0 .179 .706 r
F P
0 g
s
.55574 .53519 m .56621 .54437 L .56425 .54228 L p 0 .179 .706 r
F P
0 g
s
.55352 .52936 m .55574 .53519 L .55692 .53586 L p 0 .17 .705 r
F P
0 g
s
.43818 .51682 m .43827 .51827 L .44045 .51903 L p .766 .5 .532 r
F P
0 g
s
.59991 .42916 m .58896 .43016 L .58683 .43073 L p .738 .406 .42 r
F P
0 g
s
.59317 .5742 m .59309 .57705 L .5948 .5798 L p .905 .493 .157 r
F P
0 g
s
.74136 .49152 m .70925 .49152 L .71318 .48894 L p .605 .694 .906 r
F P
0 g
s
.70947 .47751 m .71318 .48894 L .70925 .49152 L p .603 .686 .901 r
F P
0 g
s
.70925 .49152 m .70392 .47521 L .70947 .47751 L p .603 .686 .901 r
F P
0 g
s
.70925 .49152 m .74136 .49152 L .73682 .49414 L p .614 .679 .888 r
F P
0 g
s
.70392 .47521 m .70925 .49152 L .70488 .48891 L p .564 .662 .903 r
F P
0 g
s
.31677 .20143 m .29277 .21936 L .27813 .21351 L p .629 .644 .846 r
F P
0 g
s
.46819 .56266 m .45912 .56308 L .4573 .56431 L p .905 .717 .637 r
F P
0 g
s
.52189 .49181 m .52823 .47842 L .52903 .4752 L p .549 .454 .699 r
F P
0 g
s
.42313 .51424 m .41231 .51275 L .41001 .51229 L p .718 .334 .322 r
F P
0 g
s
.31479 .50788 m .33796 .50963 L .34312 .50895 L p .604 .797 .974 r
F P
0 g
s
.4614 .53682 m .45446 .53061 L .45226 .53072 L p .824 .604 .605 r
F P
0 g
s
.45226 .53072 m .46219 .53959 L .4614 .53682 L p .824 .604 .605 r
F P
0 g
s
.46422 .6187 m .45794 .63125 L .45684 .63419 L p .906 .775 .706 r
F P
0 g
s
.58653 .42625 m .58565 .42467 L .58299 .42453 L p .744 .437 .461 r
F P
0 g
s
.46736 .55477 m .45817 .55739 L .45629 .55833 L p .893 .695 .628 r
F P
0 g
s
.25767 .5112 m .21808 .50948 L .20946 .51096 L p .647 .772 .939 r
F P
0 g
s
.52261 .47315 m .52656 .47677 L .52903 .4752 L p .529 .414 .667 r
F P
0 g
s
.52903 .4752 m .52337 .47003 L .52261 .47315 L p .529 .414 .667 r
F P
0 g
s
.65554 .46131 m .64733 .4591 L .64457 .45685 L p .341 .549 .909 r
F P
0 g
s
.53311 .45574 m .52434 .46647 L .52337 .47003 L p .564 .422 .647 r
F P
0 g
s
.27813 .21351 m .31236 .18771 L .31677 .20143 L p .629 .644 .846 r
F P
0 g
s
.62036 .44051 m .62409 .44352 L .6268 .44472 L p .66 .114 0 r
F P
0 g
s
.84029 .48416 m .8425 .50881 L .83372 .50562 L p .643 .729 .912 r
F P
0 g
s
.66475 .47067 m .67686 .47241 L .68057 .47469 L p .468 .633 .926 r
F P
0 g
s
.42615 .51568 m .44045 .51903 L .43827 .51827 L p .767 .471 .485 r
F P
0 g
s
.42829 .51673 m .4383 .51908 L .44045 .51903 L p .744 .36 .326 r
F P
0 g
s
.44045 .51903 m .42615 .51568 L .42829 .51673 L p .744 .36 .326 r
F P
0 g
s
.43996 .52379 m .44045 .51903 L .4383 .51908 L p .777 .44 .417 r
F P
0 g
s
.44202 .52388 m .44236 .52055 L .44045 .51903 L p .795 .458 .418 r
F P
0 g
s
.44045 .51903 m .43996 .52379 L .44202 .52388 L p .795 .458 .418 r
F P
0 g
s
.46659 .55188 m .45759 .55524 L .4558 .55639 L p .888 .683 .62 r
F P
0 g
s
.52989 .47198 m .52592 .46837 L .52337 .47003 L p .555 .414 .644 r
F P
0 g
s
.52337 .47003 m .52903 .4752 L .52989 .47198 L p .555 .414 .644 r
F P
0 g
s
.5359 .4547 m .52337 .47003 L .52592 .46837 L p .547 .4 .632 r
F P
0 g
s
.52337 .47003 m .5359 .4547 L .53311 .45574 L p .564 .422 .647 r
F P
0 g
s
.52686 .50134 m .53126 .50203 L .53167 .49857 L p .481 .499 .799 r
F P
0 g
s
.53167 .49857 m .52538 .49758 L .52686 .50134 L p .481 .499 .799 r
F P
0 g
s
.5337 .44719 m .54457 .43867 L .54623 .43597 L p .587 .404 .601 r
F P
0 g
s
.37352 .50843 m .38816 .50989 L .39153 .50997 L p .32 .759 .967 r
F P
0 g
s
.45262 .53326 m .45958 .53948 L .46219 .53959 L p .85 .582 .533 r
F P
0 g
s
.46219 .53959 m .45226 .53072 L .45262 .53326 L p .85 .582 .533 r
F P
0 g
s
.45253 .5477 m .46219 .53959 L .45958 .53948 L p .855 .606 .562 r
F P
0 g
s
.45458 .5476 m .46133 .54192 L .46219 .53959 L p .88 .655 .594 r
F P
0 g
s
.46219 .53959 m .45253 .5477 L .45458 .5476 L p .88 .655 .594 r
F P
0 g
s
.60053 .43004 m .6022 .43248 L .60486 .43279 L p .727 .375 .381 r
F P
0 g
s
.69647 .74838 m .72988 .77382 L .73356 .78301 L p .544 .604 .864 r
F P
0 g
s
.73356 .78301 m .68595 .74678 L .69647 .74838 L p .544 .604 .864 r
F P
0 g
s
.76056 .75446 m .73356 .78301 L .72988 .77382 L p .544 .604 .864 r
F P
0 g
s
.76813 .76514 m .74909 .78503 L .73356 .78301 L p .569 .645 .886 r
F P
0 g
s
.73356 .78301 m .76056 .75446 L .76813 .76514 L p .569 .645 .886 r
F P
0 g
s
.41226 .51319 m .42303 .51508 L .42531 .51562 L p .728 .344 .323 r
F P
0 g
s
.42531 .51562 m .40994 .51292 L .41226 .51319 L p .728 .344 .323 r
F P
0 g
s
.43827 .51827 m .42827 .51593 L .42615 .51568 L p .767 .471 .485 r
F P
0 g
s
.6563 .45999 m .64457 .45685 L .6448 .45598 L p .205 .564 .937 r
F P
0 g
s
.63787 .45006 m .6448 .45598 L .64457 .45685 L p .212 .572 .94 r
F P
0 g
s
.64457 .45685 m .63467 .44839 L .63787 .45006 L p .212 .572 .94 r
F P
0 g
s
.64457 .45685 m .6563 .45999 L .65554 .46131 L p .341 .549 .909 r
F P
0 g
s
.63467 .44839 m .64457 .45685 L .6419 .45499 L p 0 .374 .817 r
F P
0 g
s
.58424 .42679 m .58299 .42453 L .58066 .42579 L p .679 .417 .518 r
F P
0 g
s
.56873 .43006 m .58066 .42579 L .58299 .42453 L p .673 .406 .509 r
F P
0 g
s
.58299 .42453 m .56595 .43063 L .56873 .43006 L p .673 .406 .509 r
F P
0 g
s
.58299 .42453 m .58424 .42679 L .58653 .42625 L p .744 .437 .461 r
F P
0 g
s
.56595 .43063 m .58299 .42453 L .58008 .42481 L p .686 .434 .535 r
F P
0 g
s
.33745 .77635 m .37087 .74843 L .37941 .74347 L p .783 .784 .853 r
F P
0 g
s
.56005 .42653 m .54816 .43336 L .54623 .43597 L p .645 .444 .597 r
F P
0 g
s
.54623 .43597 m .56322 .42622 L .56005 .42653 L p .645 .444 .597 r
F P
0 g
s
.58044 .55825 m .57195 .5499 L .57038 .54867 L p .736 .233 0 r
F P
0 g
s
.57038 .54867 m .58251 .5606 L .58044 .55825 L p .736 .233 0 r
F P
0 g
s
.70488 .48891 m .70112 .47749 L .70392 .47521 L p .564 .662 .903 r
F P
0 g
s
.465 .54792 m .45639 .55208 L .45513 .5541 L p .877 .655 .598 r
F P
0 g
s
.58008 .42481 m .56816 .42908 L .56595 .43063 L p .686 .434 .535 r
F P
0 g
s
.45916 .61003 m .46411 .61459 L .46433 .6114 L p .921 .777 .685 r
F P
0 g
s
.45684 .63015 m .46303 .61753 L .46411 .61459 L p .906 .775 .706 r
F P
0 g
s
.46411 .61459 m .45526 .63262 L .45684 .63015 L p .906 .775 .706 r
F P
0 g
s
.45861 .61342 m .46208 .61661 L .46411 .61459 L p .911 .784 .707 r
F P
0 g
s
.46411 .61459 m .45916 .61003 L .45861 .61342 L p .911 .784 .707 r
F P
0 g
s
.45526 .63262 m .46411 .61459 L .46208 .61661 L p .912 .785 .708 r
F P
0 g
s
.46728 .57522 m .45942 .57306 L .45765 .5744 L p .922 .746 .646 r
F P
0 g
s
.60974 .6155 m .61188 .62059 L .61306 .624 L p 0 0 .346 r
F P
0 g
s
.30999 .50645 m .34312 .50895 L .33842 .50782 L p .599 .799 .976 r
F P
0 g
s
.33954 .5049 m .33842 .50782 L .34312 .50895 L p .563 .798 .987 r
F P
0 g
s
.34312 .50895 m .34474 .50478 L .33954 .5049 L p .563 .798 .987 r
F P
0 g
s
.34312 .50895 m .30999 .50645 L .31479 .50788 L p .604 .797 .974 r
F P
0 g
s
.34474 .50478 m .34312 .50895 L .34725 .50866 L p .57 .806 .988 r
F P
0 g
s
.3706 .50788 m .39153 .50997 L .38856 .50953 L p .298 .75 .958 r
F P
0 g
s
.38931 .50933 m .38856 .50953 L .39153 .50997 L p .09 .631 .849 r
F P
0 g
s
.39153 .50997 m .39259 .50968 L .38931 .50933 L p .09 .631 .849 r
F P
0 g
s
.39153 .50997 m .3706 .50788 L .37352 .50843 L p .32 .759 .967 r
F P
0 g
s
.39259 .50968 m .39153 .50997 L .39431 .51023 L p .094 .637 .846 r
F P
0 g
s
.46433 .6114 m .46087 .6082 L .45916 .61003 L p .921 .777 .685 r
F P
0 g
s
.25394 .81213 m .25087 .80969 L .23895 .81604 L p .758 .793 .881 r
F P
0 g
s
.3664 .24357 m .38186 .23527 L .39335 .24394 L p .64 .647 .841 r
F P
0 g
s
.6419 .45499 m .63496 .44907 L .63467 .44839 L p 0 .374 .817 r
F P
0 g
s
.39431 .51023 m .39506 .51002 L .39259 .50968 L p .094 .637 .846 r
F P
0 g
s
.56816 .42908 m .56624 .42599 L .56322 .42622 L p .681 .427 .53 r
F P
0 g
s
.64397 .67865 m .63344 .69528 L .63283 .69025 L p .417 .428 .764 r
F P
0 g
s
.63344 .69528 m .65426 .718 L .64802 .71691 L p .54 .517 .779 r
F P
0 g
s
.64577 .68439 m .63837 .69602 L .63344 .69528 L p .471 .498 .805 r
F P
0 g
s
.63344 .69528 m .64397 .67865 L .64577 .68439 L p .471 .498 .805 r
F P
0 g
s
.65426 .718 m .63344 .69528 L .63837 .69602 L p .471 .498 .805 r
F P
0 g
s
.53129 .49528 m .52689 .49459 L .52538 .49758 L p .512 .427 .696 r
F P
0 g
s
.52538 .49758 m .53167 .49857 L .53129 .49528 L p .512 .427 .696 r
F P
0 g
s
.53109 .4765 m .52538 .49758 L .52689 .49459 L p .502 .415 .69 r
F P
0 g
s
.52967 .47933 m .52567 .49408 L .52538 .49758 L p .542 .456 .707 r
F P
0 g
s
.52538 .49758 m .53109 .4765 L .52967 .47933 L p .542 .456 .707 r
F P
0 g
s
.56595 .43063 m .56322 .42622 L .56116 .42839 L p .628 .411 .569 r
F P
0 g
s
.54927 .43522 m .56116 .42839 L .56322 .42622 L p .625 .408 .567 r
F P
0 g
s
.56322 .42622 m .54623 .43597 L .54927 .43522 L p .625 .408 .567 r
F P
0 g
s
.56322 .42622 m .56595 .43063 L .56816 .42908 L p .681 .427 .53 r
F P
0 g
s
.52592 .46837 m .5347 .45763 L .5359 .4547 L p .547 .4 .632 r
F P
0 g
s
.4668 .57919 m .46412 .59022 L .46506 .5932 L p .925 .769 .669 r
F P
0 g
s
.60268 .59399 m .60348 .59784 L .60494 .60092 L p .877 .49 .023 r
F P
0 g
s
.58566 .56767 m .58449 .56361 L .58251 .5606 L p .839 .387 0 r
F P
0 g
s
.58251 .5606 m .58418 .5664 L .58566 .56767 L p .839 .387 0 r
F P
0 g
s
.57277 .55157 m .58126 .55993 L .58251 .5606 L p .796 .309 0 r
F P
0 g
s
.58251 .5606 m .57038 .54867 L .57277 .55157 L p .796 .309 0 r
F P
0 g
s
.58418 .5664 m .58251 .5606 L .58126 .55993 L p .839 .377 0 r
F P
0 g
s
.58705 .42719 m .58675 .42669 L .58424 .42679 L p .74 .422 .444 r
F P
0 g
s
.4383 .51908 m .43795 .52241 L .43996 .52379 L p .777 .44 .417 r
F P
0 g
s
.58066 .42579 m .58154 .42737 L .58424 .42679 L p .679 .417 .518 r
F P
0 g
s
.61002 .43679 m .60739 .43393 L .60486 .43279 L p .747 .259 .079 r
F P
0 g
s
.34725 .50866 m .3484 .50575 L .34474 .50478 L p .57 .806 .988 r
F P
0 g
s
.42827 .51593 m .42805 .51504 L .42585 .5144 L p .753 .413 .409 r
F P
0 g
s
.55 .44101 m .54623 .43597 L .54457 .43867 L p .58 .397 .597 r
F P
0 g
s
.5519 .43874 m .54927 .43522 L .54623 .43597 L p .625 .406 .565 r
F P
0 g
s
.54623 .43597 m .55 .44101 L .5519 .43874 L p .625 .406 .565 r
F P
0 g
s
.67716 .7452 m .65502 .72509 L .65426 .718 L p .565 .565 .813 r
F P
0 g
s
.21033 .49703 m .20946 .51096 L .21808 .50948 L p .65 .766 .934 r
F P
0 g
s
.58424 .42679 m .58467 .4275 L .58705 .42719 L p .74 .422 .444 r
F P
0 g
s
.6257 .66257 m .61893 .65353 L .61859 .64933 L p .346 .341 .711 r
F P
0 g
s
.56116 .42839 m .56307 .43148 L .56595 .43063 L p .628 .411 .569 r
F P
0 g
s
.41282 .51225 m .4236 .51415 L .42585 .5144 L p .728 .344 .322 r
F P
0 g
s
.42585 .5144 m .41046 .5117 L .41282 .51225 L p .728 .344 .322 r
F P
0 g
s
.42615 .51568 m .42585 .5144 L .4236 .51415 L p .751 .412 .41 r
F P
0 g
s
.42585 .5144 m .42615 .51568 L .42827 .51593 L p .753 .413 .409 r
F P
0 g
s
.54457 .43867 m .54721 .44219 L .55 .44101 L p .58 .397 .597 r
F P
0 g
s
.58753 .42802 m .58717 .42742 L .58467 .4275 L p .739 .418 .438 r
F P
0 g
s
.41231 .51275 m .41226 .51319 L .40994 .51292 L p .675 .221 .167 r
F P
0 g
s
.40994 .51292 m .41001 .51229 L .41231 .51275 L p .675 .221 .167 r
F P
0 g
s
.65426 .718 m .68595 .74678 L .67716 .7452 L p .565 .565 .813 r
F P
0 g
s
.39506 .51002 m .40725 .51185 L .41001 .51229 L p .19 0 0 r
F P
0 g
s
.46087 .6082 m .465 .59642 L .46506 .5932 L p .919 .773 .683 r
F P
0 g
s
.4504 .66495 m .43899 .68116 L .43514 .68353 L p .848 .753 .758 r
F P
0 g
s
.43514 .68353 m .45145 .66035 L .4504 .66495 L p .848 .753 .758 r
F P
0 g
s
.45844 .63174 m .45956 .63283 L .45845 .63575 L p .903 .772 .706 r
F P
0 g
s
.60862 .43688 m .60486 .43279 L .60322 .43358 L p .7 .301 .288 r
F P
0 g
s
.59263 .43455 m .60322 .43358 L .60486 .43279 L p .678 .267 .259 r
F P
0 g
s
.60486 .43279 m .58975 .43417 L .59263 .43455 L p .678 .267 .259 r
F P
0 g
s
.60486 .43279 m .60862 .43688 L .61002 .43679 L p .747 .259 .079 r
F P
0 g
s
.58975 .43417 m .60486 .43279 L .6022 .43248 L p .721 .354 .355 r
F P
0 g
s
.39259 .50968 m .41001 .51229 L .40739 .51196 L p .58 .051 0 r
F P
0 g
s
.40734 .5124 m .40739 .51196 L .41001 .51229 L p .677 .223 .168 r
F P
0 g
s
.41001 .51229 m .40994 .51292 L .40734 .5124 L p .677 .223 .168 r
F P
0 g
s
.41001 .51229 m .39259 .50968 L .39506 .51002 L p .19 0 0 r
F P
0 g
s
.58467 .4275 m .58424 .42679 L .58184 .42783 L p .674 .405 .506 r
F P
0 g
s
.57024 .43217 m .58184 .42783 L .58424 .42679 L p .667 .392 .494 r
F P
0 g
s
.58424 .42679 m .56767 .433 L .57024 .43217 L p .667 .392 .494 r
F P
0 g
s
.56767 .433 m .58424 .42679 L .58154 .42737 L p .674 .406 .508 r
F P
0 g
s
.38856 .50953 m .37391 .50807 L .3706 .50788 L p .298 .75 .958 r
F P
0 g
s
.45958 .53948 m .45282 .54514 L .45253 .5477 L p .855 .606 .562 r
F P
0 g
s
.45601 .58791 m .46506 .5932 L .46412 .59022 L p .933 .771 .657 r
F P
0 g
s
.46506 .5932 m .45916 .61003 L .46087 .6082 L p .919 .773 .683 r
F P
0 g
s
.45661 .59116 m .46294 .59485 L .46506 .5932 L p .928 .781 .678 r
F P
0 g
s
.46506 .5932 m .45601 .58791 L .45661 .59116 L p .928 .781 .678 r
F P
0 g
s
.45916 .61003 m .46506 .5932 L .46294 .59485 L p .93 .788 .682 r
F P
0 g
s
.45063 .52873 m .44202 .52388 L .43996 .52379 L p .816 .529 .504 r
F P
0 g
s
.43996 .52379 m .45226 .53072 L .45063 .52873 L p .816 .529 .504 r
F P
0 g
s
.58467 .4275 m .58518 .42836 L .58753 .42802 L p .739 .418 .438 r
F P
0 g
s
.52689 .49459 m .53089 .47983 L .53109 .4765 L p .502 .415 .69 r
F P
0 g
s
.4236 .51415 m .42381 .51504 L .42615 .51568 L p .751 .412 .41 r
F P
0 g
s
.55692 .53586 m .55537 .53177 L .55352 .52936 L p 0 .17 .705 r
F P
0 g
s
.46208 .61661 m .45588 .62923 L .45526 .63262 L p .912 .785 .708 r
F P
0 g
s
.58154 .42737 m .56994 .43172 L .56767 .433 L p .674 .406 .508 r
F P
0 g
s
.48495 .28547 m .50554 .28207 L .50852 .27473 L p .676 .618 .783 r
F P
0 g
s
.50852 .27473 m .47908 .27962 L .48495 .28547 L p .676 .618 .783 r
F P
0 g
s
.61929 .63381 m .61859 .64933 L .61781 .64554 L p .018 .122 .632 r
F P
0 g
s
.61859 .64933 m .62828 .66225 L .6257 .66257 L p .346 .341 .711 r
F P
0 g
s
.62071 .63805 m .62022 .64891 L .61859 .64933 L p .184 .279 .728 r
F P
0 g
s
.61859 .64933 m .61929 .63381 L .62071 .63805 L p .184 .279 .728 r
F P
0 g
s
.62828 .66225 m .61859 .64933 L .62022 .64891 L p .184 .278 .728 r
F P
0 g
s
.6022 .43248 m .59162 .43344 L .58975 .43417 L p .721 .354 .355 r
F P
0 g
s
.45845 .63575 m .45684 .63419 L .45844 .63174 L p .903 .772 .706 r
F P
0 g
s
.44799 .65258 m .45641 .63852 L .45845 .63575 L p .884 .772 .733 r
F P
0 g
s
.45845 .63575 m .44643 .65584 L .44799 .65258 L p .884 .772 .733 r
F P
0 g
s
.45684 .63419 m .45845 .63575 L .45641 .63852 L p .887 .778 .735 r
F P
0 g
s
.44643 .65584 m .45845 .63575 L .45739 .63945 L p .881 .767 .732 r
F P
0 g
s
.45739 .63945 m .44898 .65351 L .44643 .65584 L p .881 .767 .732 r
F P
0 g
s
.58896 .43016 m .58781 .4285 L .58518 .42836 L p .729 .389 .403 r
F P
0 g
s
.44126 .52589 m .44987 .53074 L .45226 .53072 L p .821 .496 .44 r
F P
0 g
s
.45226 .53072 m .43996 .52379 L .44126 .52589 L p .821 .496 .44 r
F P
0 g
s
.44691 .53885 m .45226 .53072 L .44987 .53074 L p .837 .547 .498 r
F P
0 g
s
.44888 .53895 m .45262 .53326 L .45226 .53072 L p .871 .597 .521 r
F P
0 g
s
.45226 .53072 m .44691 .53885 L .44888 .53895 L p .871 .597 .521 r
F P
0 g
s
.58518 .42836 m .58467 .4275 L .5823 .42857 L p .673 .401 .501 r
F P
0 g
s
.57081 .43293 m .5823 .42857 L .58467 .4275 L p .664 .383 .485 r
F P
0 g
s
.58467 .4275 m .56825 .43374 L .57081 .43293 L p .664 .383 .485 r
F P
0 g
s
.58184 .42783 m .58214 .42833 L .58467 .4275 L p .674 .405 .506 r
F P
0 g
s
.56825 .43374 m .58467 .4275 L .58214 .42833 L p .668 .392 .494 r
F P
0 g
s
.44898 .65351 m .45249 .65668 L .45145 .66035 L p .881 .767 .732 r
F P
0 g
s
.45145 .66035 m .44643 .65584 L .44898 .65351 L p .881 .767 .732 r
F P
0 g
s
.4368 .67936 m .44823 .66313 L .45145 .66035 L p .86 .773 .765 r
F P
0 g
s
.45145 .66035 m .43514 .68353 L .4368 .67936 L p .86 .773 .765 r
F P
0 g
s
.44643 .65584 m .45145 .66035 L .44823 .66313 L p .86 .774 .765 r
F P
0 g
s
.83372 .50562 m .83209 .48838 L .84029 .48416 L p .643 .729 .912 r
F P
0 g
s
.63283 .69025 m .64019 .6786 L .64397 .67865 L p .417 .428 .764 r
F P
0 g
s
.40739 .51196 m .3952 .51014 L .39259 .50968 L p .58 .051 0 r
F P
0 g
s
.45819 .27574 m .44135 .23596 L .43411 .2283 L p .664 .635 .811 r
F P
0 g
s
.33842 .50782 m .31521 .50607 L .30999 .50645 L p .599 .799 .976 r
F P
0 g
s
.41086 .51241 m .42615 .51568 L .42381 .51504 L p .737 .349 .316 r
F P
0 g
s
.41324 .51317 m .42395 .51546 L .42615 .51568 L p .615 .09 0 r
F P
0 g
s
.42615 .51568 m .41086 .51241 L .41324 .51317 L p .615 .09 0 r
F P
0 g
s
.42651 .51827 m .42615 .51568 L .42395 .51546 L p .711 .254 .162 r
F P
0 g
s
.42854 .51854 m .42829 .51673 L .42615 .51568 L p .726 .266 .158 r
F P
0 g
s
.42615 .51568 m .42651 .51827 L .42854 .51854 L p .726 .266 .158 r
F P
0 g
s
.31494 .77039 m .23895 .81604 L .25087 .80969 L p .758 .792 .881 r
F P
0 g
s
.30194 .77585 m .2487 .80784 L .23895 .81604 L p .759 .798 .885 r
F P
0 g
s
.23895 .81604 m .31494 .77039 L .30194 .77585 L p .759 .798 .885 r
F P
0 g
s
.22675 .80546 m .23895 .81604 L .2487 .80784 L p .759 .798 .885 r
F P
0 g
s
.58214 .42833 m .57064 .4327 L .56825 .43374 L p .668 .392 .494 r
F P
0 g
s
.71318 .48894 m .73568 .48893 L .74136 .49152 L p .605 .694 .906 r
F P
0 g
s
.42381 .51504 m .4131 .51275 L .41086 .51241 L p .737 .349 .316 r
F P
0 g
s
.21808 .50948 m .21873 .49974 L .21033 .49703 L p .65 .766 .934 r
F P
0 g
s
.61781 .64554 m .61829 .63467 L .61929 .63381 L p .018 .122 .632 r
F P
0 g
s
.53788 .51054 m .53167 .49857 L .53126 .50203 L p .401 .424 .769 r
F P
0 g
s
.58683 .43073 m .58518 .42836 L .58304 .42965 L p .664 .379 .478 r
F P
0 g
s
.57168 .43402 m .58304 .42965 L .58518 .42836 L p .653 .361 .463 r
F P
0 g
s
.58518 .42836 m .56896 .4346 L .57168 .43402 L p .653 .361 .463 r
F P
0 g
s
.58518 .42836 m .58683 .43073 L .58896 .43016 L p .729 .389 .403 r
F P
0 g
s
.5823 .42857 m .58266 .42916 L .58518 .42836 L p .673 .401 .501 r
F P
0 g
s
.56896 .4346 m .58518 .42836 L .58266 .42916 L p .665 .384 .484 r
F P
0 g
s
.6448 .45598 m .65302 .45818 L .6563 .45999 L p .205 .564 .937 r
F P
0 g
s
.39514 .51026 m .40734 .5124 L .40994 .51292 L p .593 .064 0 r
F P
0 g
s
.40994 .51292 m .39251 .50986 L .39514 .51026 L p .593 .064 0 r
F P
0 g
s
.54721 .44219 m .53735 .45177 L .5359 .4547 L p .584 .404 .604 r
F P
0 g
s
.46412 .59022 m .45779 .58651 L .45601 .58791 L p .933 .771 .657 r
F P
0 g
s
.45641 .63852 m .45528 .63743 L .45684 .63419 L p .887 .778 .735 r
F P
0 g
s
.52823 .47842 m .52967 .47933 L .53109 .4765 L p .495 .4 .677 r
F P
0 g
s
.53109 .4765 m .52903 .4752 L .52823 .47842 L p .495 .4 .677 r
F P
0 g
s
.56307 .43148 m .5519 .43874 L .55 .44101 L p .626 .408 .566 r
F P
0 g
s
.55 .44101 m .56595 .43063 L .56307 .43148 L p .626 .408 .566 r
F P
0 g
s
.61723 .44187 m .62609 .44462 L .6268 .44472 L p .339 0 0 r
F P
0 g
s
.6268 .44472 m .61415 .4408 L .61723 .44187 L p .339 0 0 r
F P
0 g
s
.61415 .4408 m .6268 .44472 L .62409 .44352 L p .626 .064 0 r
F P
0 g
s
.58126 .55993 m .58243 .56398 L .58418 .5664 L p .839 .377 0 r
F P
0 g
s
.46021 .23108 m .47282 .27188 L .47908 .27962 L p .664 .635 .811 r
F P
0 g
s
.47908 .27962 m .46109 .22129 L .46021 .23108 L p .664 .635 .811 r
F P
0 g
s
.50209 .26671 m .48145 .27015 L .47908 .27962 L p .677 .643 .808 r
F P
0 g
s
.47908 .27962 m .50852 .27473 L .50209 .26671 L p .677 .643 .808 r
F P
0 g
s
.46109 .22129 m .47908 .27962 L .48145 .27015 L p .677 .643 .808 r
F P
0 g
s
.56994 .43172 m .56873 .43006 L .56595 .43063 L p .669 .396 .499 r
F P
0 g
s
.5347 .45763 m .53711 .45988 L .53935 .45792 L p .525 .376 .621 r
F P
0 g
s
.53935 .45792 m .5359 .4547 L .5347 .45763 L p .525 .376 .621 r
F P
0 g
s
.54086 .45533 m .53845 .45308 L .5359 .4547 L p .564 .375 .584 r
F P
0 g
s
.5359 .4547 m .53935 .45792 L .54086 .45533 L p .564 .375 .584 r
F P
0 g
s
.55 .44101 m .5359 .4547 L .53845 .45308 L p .563 .373 .582 r
F P
0 g
s
.5359 .4547 m .55 .44101 L .54721 .44219 L p .584 .404 .604 r
F P
0 g
s
.58266 .42916 m .57131 .43354 L .56896 .4346 L p .665 .384 .484 r
F P
0 g
s
.60322 .43358 m .60584 .43645 L .60862 .43688 L p .7 .301 .288 r
F P
0 g
s
.41053 .24663 m .4003 .2511 L .39335 .24394 L p .642 .624 .817 r
F P
0 g
s
.45794 .63125 m .45684 .63015 L .45526 .63262 L p .906 .775 .706 r
F P
0 g
s
.45526 .63262 m .45684 .63419 L .45794 .63125 L p .906 .775 .706 r
F P
0 g
s
.56767 .433 m .56595 .43063 L .56387 .43256 L p .614 .386 .548 r
F P
0 g
s
.5527 .43982 m .56387 .43256 L .56595 .43063 L p .609 .379 .542 r
F P
0 g
s
.56595 .43063 m .55 .44101 L .5527 .43982 L p .609 .379 .542 r
F P
0 g
s
.56595 .43063 m .56767 .433 L .56994 .43172 L p .669 .396 .499 r
F P
0 g
s
.42395 .51546 m .4242 .51727 L .42651 .51827 L p .711 .254 .162 r
F P
0 g
s
.44823 .66313 m .44471 .65997 L .44643 .65584 L p .86 .774 .765 r
F P
0 g
s
.53711 .45988 m .52989 .47198 L .52903 .4752 L p .541 .4 .638 r
F P
0 g
s
.3484 .50575 m .36649 .50792 L .3706 .50788 L p .511 .797 .997 r
F P
0 g
s
.25087 .80969 m .30404 .77774 L .31494 .77039 L p .758 .792 .881 r
F P
0 g
s
.62409 .44352 m .61524 .44077 L .61415 .4408 L p .626 .064 0 r
F P
0 g
s
.58304 .42965 m .58419 .43131 L .58683 .43073 L p .664 .379 .478 r
F P
0 g
s
.53226 .47369 m .53082 .47278 L .52903 .4752 L p .531 .388 .632 r
F P
0 g
s
.52903 .4752 m .53109 .4765 L .53226 .47369 L p .531 .388 .632 r
F P
0 g
s
.53935 .45792 m .52903 .4752 L .53082 .47278 L p .522 .377 .625 r
F P
0 g
s
.52903 .4752 m .53935 .45792 L .53711 .45988 L p .541 .4 .638 r
F P
0 g
s
.55103 .27962 m .58014 .28203 L .58702 .27611 L p .721 .652 .78 r
F P
0 g
s
.44987 .53074 m .44612 .53643 L .44691 .53885 L p .837 .547 .498 r
F P
0 g
s
.53845 .45308 m .54832 .4435 L .55 .44101 L p .563 .373 .582 r
F P
0 g
s
.27331 .50461 m .30337 .5073 L .30999 .50645 L p .63 .779 .953 r
F P
0 g
s
.4131 .51275 m .41282 .51225 L .41046 .5117 L p .686 .229 .161 r
F P
0 g
s
.45369 .63586 m .4548 .63696 L .45684 .63419 L p .889 .782 .736 r
F P
0 g
s
.45684 .63419 m .45526 .63262 L .45369 .63586 L p .889 .782 .736 r
F P
0 g
s
.44475 .65424 m .45684 .63419 L .4548 .63696 L p .893 .788 .738 r
F P
0 g
s
.44475 .65424 m .45684 .63419 L .45528 .63743 L p .884 .773 .734 r
F P
0 g
s
.56387 .43256 m .56507 .43422 L .56767 .433 L p .614 .386 .548 r
F P
0 g
s
.46294 .59485 m .45881 .60664 L .45916 .61003 L p .93 .788 .682 r
F P
0 g
s
.70112 .47749 m .6848 .47713 L .68057 .47469 L p .559 .651 .897 r
F P
0 g
s
.63837 .69602 m .65297 .71194 L .65426 .718 L p .471 .498 .805 r
F P
0 g
s
.34474 .50478 m .3706 .50788 L .36692 .50712 L p .506 .797 .998 r
F P
0 g
s
.36774 .50612 m .36692 .50712 L .3706 .50788 L p .422 .778 .996 r
F P
0 g
s
.3706 .50788 m .37178 .50645 L .36774 .50612 L p .422 .778 .996 r
F P
0 g
s
.3706 .50788 m .34474 .50478 L .3484 .50575 L p .511 .797 .997 r
F P
0 g
s
.37178 .50645 m .3706 .50788 L .37391 .50807 L p .426 .783 .996 r
F P
0 g
s
.39571 .50917 m .40792 .51131 L .41046 .5117 L p .592 .063 0 r
F P
0 g
s
.41046 .5117 m .39302 .50863 L .39571 .50917 L p .592 .063 0 r
F P
0 g
s
.41086 .51241 m .41046 .5117 L .40792 .51131 L p .685 .229 .163 r
F P
0 g
s
.41046 .5117 m .41086 .51241 L .4131 .51275 L p .686 .229 .161 r
F P
0 g
s
.40923 .71704 m .38626 .73989 L .37941 .74347 L p .803 .766 .819 r
F P
0 g
s
.37391 .50807 m .37474 .50707 L .37178 .50645 L p .426 .783 .996 r
F P
0 g
s
.43795 .52241 m .42854 .51854 L .42651 .51827 L p .785 .398 .322 r
F P
0 g
s
.42651 .51827 m .43996 .52379 L .43795 .52241 L p .785 .398 .322 r
F P
0 g
s
.66831 .69898 m .65426 .718 L .65297 .71194 L p .471 .498 .805 r
F P
0 g
s
.67133 .7059 m .66145 .71919 L .65426 .718 L p .512 .555 .837 r
F P
0 g
s
.65426 .718 m .66831 .69898 L .67133 .7059 L p .512 .555 .837 r
F P
0 g
s
.68595 .74678 m .65426 .718 L .66145 .71919 L p .512 .555 .837 r
F P
0 g
s
.53082 .47278 m .53804 .46068 L .53935 .45792 L p .522 .377 .625 r
F P
0 g
s
.59162 .43344 m .58958 .43103 L .58683 .43073 L p .709 .334 .337 r
F P
0 g
s
.59309 .57705 m .58566 .56767 L .58418 .5664 L p .876 .445 .046 r
F P
0 g
s
.58418 .5664 m .5948 .5798 L .59309 .57705 L p .876 .445 .046 r
F P
0 g
s
.45528 .63743 m .44682 .65146 L .44475 .65424 L p .884 .773 .734 r
F P
0 g
s
.55235 .44361 m .55 .44101 L .54832 .4435 L p .56 .369 .58 r
F P
0 g
s
.55435 .44165 m .5527 .43982 L .55 .44101 L p .606 .373 .537 r
F P
0 g
s
.55 .44101 m .55235 .44361 L .55435 .44165 L p .606 .373 .537 r
F P
0 g
s
.42839 .51981 m .43781 .52368 L .43996 .52379 L p .775 .359 .261 r
F P
0 g
s
.43996 .52379 m .42651 .51827 L .42839 .51981 L p .775 .359 .261 r
F P
0 g
s
.43802 .52984 m .43996 .52379 L .43781 .52368 L p .815 .452 .368 r
F P
0 g
s
.4399 .53013 m .44126 .52589 L .43996 .52379 L p .851 .494 .378 r
F P
0 g
s
.43996 .52379 m .43802 .52984 L .4399 .53013 L p .851 .494 .378 r
F P
0 g
s
.3952 .51014 m .39514 .51026 L .39251 .50986 L p .387 0 0 r
F P
0 g
s
.39251 .50986 m .39259 .50968 L .3952 .51014 L p .387 0 0 r
F P
0 g
s
.70392 .47521 m .68057 .47469 L .68277 .47266 L p .539 .678 .928 r
F P
0 g
s
.67719 .46331 m .68277 .47266 L .68057 .47469 L p .537 .675 .926 r
F P
0 g
s
.68057 .47469 m .67258 .46135 L .67719 .46331 L p .537 .675 .926 r
F P
0 g
s
.68057 .47469 m .70392 .47521 L .70112 .47749 L p .559 .651 .897 r
F P
0 g
s
.67258 .46135 m .68057 .47469 L .67686 .47241 L p .46 .631 .928 r
F P
0 g
s
.54832 .4435 m .54997 .44532 L .55235 .44361 L p .56 .369 .58 r
F P
0 g
s
.59774 .58773 m .59638 .58305 L .5948 .5798 L p .83 .433 0 r
F P
0 g
s
.5948 .5798 m .59673 .58647 L .59774 .58773 L p .83 .433 0 r
F P
0 g
s
.58623 .56956 m .59367 .57895 L .5948 .5798 L p .834 .386 0 r
F P
0 g
s
.5948 .5798 m .58418 .5664 L .58623 .56956 L p .834 .386 0 r
F P
0 g
s
.59673 .58647 m .5948 .5798 L .59367 .57895 L p .861 .43 .002 r
F P
0 g
s
.53262 .48068 m .53129 .49528 L .53167 .49857 L p .5 .418 .695 r
F P
0 g
s
.58975 .43417 m .58683 .43073 L .58497 .43216 L p .648 .339 .434 r
F P
0 g
s
.57398 .43654 m .58497 .43216 L .58683 .43073 L p .631 .314 .415 r
F P
0 g
s
.58683 .43073 m .57113 .43698 L .57398 .43654 L p .631 .314 .415 r
F P
0 g
s
.58683 .43073 m .58975 .43417 L .59162 .43344 L p .709 .334 .337 r
F P
0 g
s
.57113 .43698 m .58683 .43073 L .58419 .43131 L p .657 .361 .46 r
F P
0 g
s
.66145 .71919 m .68367 .73937 L .68595 .74678 L p .512 .555 .837 r
F P
0 g
s
.7051 .72392 m .68595 .74678 L .68367 .73937 L p .512 .555 .837 r
F P
0 g
s
.70995 .73244 m .69647 .74838 L .68595 .74678 L p .544 .604 .864 r
F P
0 g
s
.68595 .74678 m .7051 .72392 L .70995 .73244 L p .544 .604 .864 r
F P
0 g
s
.37474 .50707 m .38931 .50933 L .39259 .50968 L p .282 .728 .961 r
F P
0 g
s
.57064 .4327 m .57024 .43217 L .56767 .433 L p .662 .38 .483 r
F P
0 g
s
.40792 .51131 m .4082 .51181 L .41086 .51241 L p .685 .229 .163 r
F P
0 g
s
.4333 .6888 m .41728 .70787 L .41224 .71079 L p .826 .76 .789 r
F P
0 g
s
.41224 .71079 m .43514 .68353 L .4333 .6888 L p .826 .76 .789 r
F P
0 g
s
.541 .49422 m .53167 .49857 L .53371 .49921 L p .421 .413 .744 r
F P
0 g
s
.53806 .5076 m .53371 .49921 L .53167 .49857 L p .405 .426 .769 r
F P
0 g
s
.53167 .49857 m .53788 .51054 L .53806 .5076 L p .405 .426 .769 r
F P
0 g
s
.53968 .49217 m .53315 .49523 L .53167 .49857 L p .373 .298 .643 r
F P
0 g
s
.53167 .49857 m .541 .49422 L .53968 .49217 L p .373 .298 .643 r
F P
0 g
s
.53356 .47771 m .53167 .49857 L .53315 .49523 L p .404 .334 .664 r
F P
0 g
s
.53167 .49857 m .53356 .47771 L .53262 .48068 L p .5 .418 .695 r
F P
0 g
s
.39259 .50968 m .37178 .50645 L .37474 .50707 L p .282 .728 .961 r
F P
0 g
s
.38941 .50932 m .39251 .50986 L p .38218 .50805 L 0 .496 .728 r
F P
0 g
s
.37494 .50678 m .38218 .50805 L p .38218 .50805 L 0 .496 .728 r
F P
0 g
s
.38218 .50805 m .38941 .50932 L p .38218 .50805 L 0 .496 .728 r
F P
0 g
s
.39259 .50968 m .38948 .5092 L p .3822 .50807 L 0 .51 .731 r
F P
0 g
s
.37178 .50645 m .3822 .50807 L p .3822 .50807 L 0 .51 .731 r
F P
0 g
s
.3822 .50807 m .39259 .50968 L p .3822 .50807 L 0 .51 .731 r
F P
0 g
s
.38941 .50932 m .38948 .5092 L .39259 .50968 L p .388 0 0 r
F P
0 g
s
.39259 .50968 m .39251 .50986 L .38941 .50932 L p .388 0 0 r
F P
0 g
s
.7777 .49254 m .74807 .49412 L .74136 .49152 L p .631 .706 .901 r
F P
0 g
s
.56866 .54696 m .56575 .54395 L .56621 .54437 L p 0 .018 .525 r
F P
0 g
s
.56621 .54437 m .57038 .54867 L .56866 .54696 L p 0 .018 .525 r
F P
0 g
s
.4548 .63696 m .44633 .65099 L .44475 .65424 L p .893 .788 .738 r
F P
0 g
s
.53089 .47983 m .53262 .48068 L .53356 .47771 L p .474 .391 .682 r
F P
0 g
s
.53356 .47771 m .53109 .4765 L .53089 .47983 L p .474 .391 .682 r
F P
0 g
s
.267 .5026 m .30999 .50645 L .30384 .50484 L p .628 .78 .954 r
F P
0 g
s
.30503 .50068 m .30384 .50484 L .30999 .50645 L p .61 .782 .964 r
F P
0 g
s
.30999 .50645 m .31173 .50052 L .30503 .50068 L p .61 .782 .964 r
F P
0 g
s
.30999 .50645 m .267 .5026 L .27331 .50461 L p .63 .779 .953 r
F P
0 g
s
.31173 .50052 m .30999 .50645 L .31521 .50607 L p .614 .787 .964 r
F P
0 g
s
.58419 .43131 m .57321 .43568 L .57113 .43698 L p .657 .361 .46 r
F P
0 g
s
.58702 .27611 m .54541 .27265 L .55103 .27962 L p .721 .652 .78 r
F P
0 g
s
.59245 .22685 m .58208 .26694 L .58702 .27611 L p .715 .671 .806 r
F P
0 g
s
.58702 .27611 m .60191 .21886 L .59245 .22685 L p .715 .671 .806 r
F P
0 g
s
.54541 .27265 m .58702 .27611 L .58208 .26694 L p .714 .671 .807 r
F P
0 g
s
.60191 .21886 m .58702 .27611 L .59648 .26955 L p .736 .694 .81 r
F P
0 g
s
.61829 .63467 m .61394 .62781 L .61306 .624 L p .017 .12 .63 r
F P
0 g
s
.53787 .51304 m .54404 .51784 L .54601 .51661 L p .364 .411 .776 r
F P
0 g
s
.54195 .49986 m .53806 .5076 L .53788 .51054 L p .347 .373 .746 r
F P
0 g
s
.53788 .51054 m .54345 .49949 L .54195 .49986 L p .347 .373 .746 r
F P
0 g
s
.54601 .51661 m .53718 .50975 L .53787 .51304 L p .364 .411 .776 r
F P
0 g
s
.56507 .43422 m .55435 .44165 L .55235 .44361 L p .61 .379 .541 r
F P
0 g
s
.55235 .44361 m .56767 .433 L .56507 .43422 L p .61 .379 .541 r
F P
0 g
s
.53453 .47487 m .53279 .47402 L .53109 .4765 L p .511 .367 .621 r
F P
0 g
s
.53109 .4765 m .53356 .47771 L .53453 .47487 L p .511 .367 .621 r
F P
0 g
s
.54052 .45883 m .53109 .4765 L .53279 .47402 L p .506 .36 .617 r
F P
0 g
s
.53886 .46132 m .53226 .47369 L .53109 .4765 L p .521 .378 .627 r
F P
0 g
s
.53109 .4765 m .54052 .45883 L .53886 .46132 L p .521 .378 .627 r
F P
0 g
s
.56767 .433 m .56825 .43374 L .57064 .4327 L p .662 .38 .483 r
F P
0 g
s
.67686 .47241 m .67125 .46308 L .67258 .46135 L p .46 .631 .928 r
F P
0 g
s
.56825 .43374 m .56767 .433 L .56548 .4347 L p .607 .373 .536 r
F P
0 g
s
.55476 .44213 m .56548 .4347 L .56767 .433 L p .6 .362 .528 r
F P
0 g
s
.56767 .433 m .55235 .44361 L .55476 .44213 L p .6 .362 .528 r
F P
0 g
s
.62022 .64891 m .62701 .65796 L .62828 .66225 L p .184 .278 .728 r
F P
0 g
s
.39335 .24394 m .40797 .23752 L .41053 .24663 L p .642 .624 .817 r
F P
0 g
s
.3523 .18097 m .3883 .23204 L .39335 .24394 L p .649 .65 .838 r
F P
0 g
s
.39335 .24394 m .34189 .17104 L .3523 .18097 L p .649 .65 .838 r
F P
0 g
s
.40797 .23752 m .39335 .24394 L .3883 .23204 L p .649 .65 .838 r
F P
0 g
s
.34189 .17104 m .39335 .24394 L .38186 .23527 L p .641 .647 .841 r
F P
0 g
s
.39356 .50892 m .41086 .51241 L .4082 .51181 L p .596 .062 0 r
F P
0 g
s
.3963 .50949 m .40841 .51194 L .41086 .51241 L p .202 0 0 r
F P
0 g
s
.41086 .51241 m .39356 .50892 L .3963 .50949 L p .202 0 0 r
F P
0 g
s
.41169 .51339 m .41086 .51241 L .40841 .51194 L p .448 0 0 r
F P
0 g
s
.41383 .51385 m .41324 .51317 L .41086 .51241 L p .457 0 0 r
F P
0 g
s
.41086 .51241 m .41169 .51339 L .41383 .51385 L p .457 0 0 r
F P
0 g
s
.72988 .77382 m .74867 .75377 L .76056 .75446 L p .544 .604 .864 r
F P
0 g
s
.57131 .43354 m .57081 .43293 L .56825 .43374 L p .656 .367 .47 r
F P
0 g
s
.36692 .50712 m .34881 .50495 L .34474 .50478 L p .506 .797 .998 r
F P
0 g
s
.41224 .71079 m .37941 .74347 L .38325 .73774 L p .81 .782 .826 r
F P
0 g
s
.37771 .73344 m .38325 .73774 L .37941 .74347 L p .81 .781 .826 r
F P
0 g
s
.37941 .74347 m .37148 .73736 L .37771 .73344 L p .81 .781 .826 r
F P
0 g
s
.37941 .74347 m .41224 .71079 L .40923 .71704 L p .803 .766 .819 r
F P
0 g
s
.37148 .73736 m .37941 .74347 L .37087 .74843 L p .783 .784 .853 r
F P
0 g
s
.60847 .6088 m .61306 .624 L .61188 .62059 L p 0 0 .359 r
F P
0 g
s
.61306 .624 m .61929 .63381 L .61829 .63467 L p .017 .12 .63 r
F P
0 g
s
.61015 .61259 m .61336 .62323 L .61306 .624 L p 0 .004 .579 r
F P
0 g
s
.61306 .624 m .60847 .6088 L .61015 .61259 L p 0 .004 .579 r
F P
0 g
s
.61929 .63381 m .61306 .624 L .61336 .62323 L p 0 0 .574 r
F P
0 g
s
.31521 .50607 m .31644 .50192 L .31173 .50052 L p .614 .787 .964 r
F P
0 g
s
.56548 .4347 m .56589 .43523 L .56825 .43374 L p .607 .373 .536 r
F P
0 g
s
.37087 .74843 m .36531 .74417 L .37148 .73736 L p .783 .784 .853 r
F P
0 g
s
.4082 .51181 m .39609 .50937 L .39356 .50892 L p .596 .062 0 r
F P
0 g
s
.37183 .50623 m .37494 .50678 L p .38218 .50805 L 0 .496 .728 r
F P
0 g
s
.39251 .50986 m .38218 .50804 L p .38218 .50805 L 0 .496 .728 r
F P
0 g
s
.38218 .50804 m .37183 .50623 L p .38218 .50805 L 0 .496 .728 r
F P
0 g
s
.37491 .50693 m .37178 .50645 L p .3822 .50807 L 0 .51 .731 r
F P
0 g
s
.38948 .5092 m .3822 .50806 L p .3822 .50807 L 0 .51 .731 r
F P
0 g
s
.3822 .50806 m .37491 .50693 L p .3822 .50807 L 0 .51 .731 r
F P
0 g
s
.62609 .44462 m .6316 .44719 L .63467 .44839 L p .384 0 0 r
F P
0 g
s
.61524 .44077 m .61137 .43803 L .60862 .43688 L p .599 .03 0 r
F P
0 g
s
.45075 .62816 m .45526 .63262 L .45588 .62923 L p .912 .785 .707 r
F P
0 g
s
.44526 .64994 m .45369 .63586 L .45526 .63262 L p .893 .788 .737 r
F P
0 g
s
.45526 .63262 m .44322 .65274 L .44526 .64994 L p .893 .788 .737 r
F P
0 g
s
.44963 .63183 m .45279 .63495 L .45526 .63262 L p .896 .793 .738 r
F P
0 g
s
.45526 .63262 m .45075 .62816 L .44963 .63183 L p .896 .793 .738 r
F P
0 g
s
.44322 .65274 m .45526 .63262 L .45279 .63495 L p .896 .793 .738 r
F P
0 g
s
.61188 .62059 m .60867 .60995 L .60847 .6088 L p 0 0 .359 r
F P
0 g
s
.53279 .47402 m .53939 .46165 L .54052 .45883 L p .506 .36 .617 r
F P
0 g
s
.45588 .62923 m .45273 .62611 L .45075 .62816 L p .912 .785 .707 r
F P
0 g
s
.30973 .7824 m .30746 .78054 L .31818 .77307 L p .757 .791 .881 r
F P
0 g
s
.31818 .77307 m .3214 .77574 L .30973 .7824 L p .757 .791 .881 r
F P
0 g
s
.56896 .4346 m .56825 .43374 L .56611 .43547 L p .602 .363 .528 r
F P
0 g
s
.55554 .44293 m .56611 .43547 L .56825 .43374 L p .594 .351 .518 r
F P
0 g
s
.56825 .43374 m .55315 .4444 L .55554 .44293 L p .594 .351 .518 r
F P
0 g
s
.56825 .43374 m .56896 .4346 L .57131 .43354 L p .656 .367 .47 r
F P
0 g
s
.55315 .4444 m .56825 .43374 L .56589 .43523 L p .601 .362 .527 r
F P
0 g
s
.54997 .44532 m .54086 .45533 L .53935 .45792 L p .562 .373 .582 r
F P
0 g
s
.51458 .28103 m .54037 .27957 L .54541 .27265 L p .698 .633 .78 r
F P
0 g
s
.54541 .27265 m .50852 .27473 L .51458 .28103 L p .698 .633 .78 r
F P
0 g
s
.58497 .43216 m .58701 .43457 L .58975 .43417 L p .648 .339 .434 r
F P
0 g
s
.43298 .67604 m .4368 .67936 L .43514 .68353 L p .86 .773 .764 r
F P
0 g
s
.43514 .68353 m .42967 .67879 L .43298 .67604 L p .86 .773 .764 r
F P
0 g
s
.41479 .70596 m .43082 .68687 L .43514 .68353 L p .836 .778 .796 r
F P
0 g
s
.43514 .68353 m .41224 .71079 L .41479 .70596 L p .836 .778 .796 r
F P
0 g
s
.42967 .67879 m .43514 .68353 L .43082 .68687 L p .836 .778 .796 r
F P
0 g
s
.2487 .80784 m .24022 .8004 L .22675 .80546 L p .759 .798 .885 r
F P
0 g
s
.53804 .46068 m .53886 .46132 L .54052 .45883 L p .506 .36 .616 r
F P
0 g
s
.54052 .45883 m .53935 .45792 L .53804 .46068 L p .506 .36 .616 r
F P
0 g
s
.56589 .43523 m .55531 .44269 L .55315 .4444 L p .601 .362 .527 r
F P
0 g
s
.61415 .4408 m .60862 .43688 L .60732 .43756 L p .631 .153 .1 r
F P
0 g
s
.59719 .4383 m .60732 .43756 L .60862 .43688 L p .59 .099 .058 r
F P
0 g
s
.60862 .43688 m .59415 .43792 L .59719 .4383 L p .59 .099 .058 r
F P
0 g
s
.60862 .43688 m .61415 .4408 L .61524 .44077 L p .599 .03 0 r
F P
0 g
s
.59415 .43792 m .60862 .43688 L .60584 .43645 L p .685 .262 .236 r
F P
0 g
s
.57694 .55789 m .57277 .55157 L .57038 .54867 L p .735 .241 0 r
F P
0 g
s
.57038 .54867 m .57633 .5577 L .57694 .55789 L p .735 .241 0 r
F P
0 g
s
.56785 .54648 m .57077 .54949 L .57038 .54867 L p .713 .224 0 r
F P
0 g
s
.57038 .54867 m .56621 .54437 L .56785 .54648 L p .713 .224 0 r
F P
0 g
s
.57633 .5577 m .57038 .54867 L .57077 .54949 L p .712 .227 0 r
F P
0 g
s
.45273 .62611 m .45861 .61342 L .45916 .61003 L p .912 .784 .707 r
F P
0 g
s
.43781 .52368 m .43644 .52792 L .43802 .52984 L p .815 .452 .368 r
F P
0 g
s
.54227 .45654 m .54144 .4559 L .53935 .45792 L p .547 .352 .568 r
F P
0 g
s
.53935 .45792 m .54052 .45883 L .54227 .45654 L p .547 .352 .568 r
F P
0 g
s
.55235 .44361 m .53935 .45792 L .54144 .4559 L p .548 .353 .569 r
F P
0 g
s
.53935 .45792 m .55235 .44361 L .54997 .44532 L p .562 .373 .582 r
F P
0 g
s
.60348 .59784 m .59774 .58773 L .59673 .58647 L p .848 .46 0 r
F P
0 g
s
.59673 .58647 m .60494 .60092 L .60348 .59784 L p .848 .46 0 r
F P
0 g
s
.45167 .60377 m .45916 .61003 L .45881 .60664 L p .935 .791 .677 r
F P
0 g
s
.45916 .61003 m .45075 .62816 L .45273 .62611 L p .912 .784 .707 r
F P
0 g
s
.4516 .60739 m .45685 .61177 L .45916 .61003 L p .924 .801 .706 r
F P
0 g
s
.45916 .61003 m .45167 .60377 L .4516 .60739 L p .924 .801 .706 r
F P
0 g
s
.45075 .62816 m .45916 .61003 L .45685 .61177 L p .925 .804 .708 r
F P
0 g
s
.56611 .43547 m .56661 .43607 L .56896 .4346 L p .602 .363 .528 r
F P
0 g
s
.54025 .49617 m .54195 .49986 L .54345 .49949 L p .333 .315 .689 r
F P
0 g
s
.54345 .49949 m .541 .49422 L .54025 .49617 L p .333 .315 .689 r
F P
0 g
s
.54273 .49869 m .53718 .50975 L .53887 .50897 L p .346 .373 .746 r
F P
0 g
s
.54506 .51377 m .53887 .50897 L .53718 .50975 L p .36 .41 .778 r
F P
0 g
s
.53718 .50975 m .54601 .51661 L .54506 .51377 L p .36 .41 .778 r
F P
0 g
s
.59858 .58991 m .60432 .60003 L .60494 .60092 L p .699 .298 0 r
F P
0 g
s
.60494 .60092 m .59673 .58647 L .59858 .58991 L p .699 .298 0 r
F P
0 g
s
.57321 .43568 m .57168 .43402 L .56896 .4346 L p .646 .344 .446 r
F P
0 g
s
.54144 .4559 m .55055 .44589 L .55235 .44361 L p .548 .353 .569 r
F P
0 g
s
.78375 .48924 m .74136 .49152 L .74668 .48822 L p .626 .716 .911 r
F P
0 g
s
.74234 .47531 m .74668 .48822 L .74136 .49152 L p .624 .711 .908 r
F P
0 g
s
.74136 .49152 m .73511 .4731 L .74234 .47531 L p .624 .711 .908 r
F P
0 g
s
.74136 .49152 m .78375 .48924 L .7777 .49254 L p .631 .706 .901 r
F P
0 g
s
.73511 .4731 m .74136 .49152 L .73568 .48893 L p .598 .695 .91 r
F P
0 g
s
.60584 .43645 m .59571 .43718 L .59415 .43792 L p .685 .262 .236 r
F P
0 g
s
.53315 .49523 m .53448 .48062 L .53356 .47771 L p .404 .334 .664 r
F P
0 g
s
.40841 .51194 m .40899 .51262 L .41169 .51339 L p .448 0 0 r
F P
0 g
s
.59648 .26955 m .60696 .22954 L .60191 .21886 L p .736 .694 .81 r
F P
0 g
s
.65297 .71194 m .66277 .69861 L .66831 .69898 L p .471 .498 .805 r
F P
0 g
s
.53371 .49921 m .54025 .49617 L .541 .49422 L p .421 .413 .744 r
F P
0 g
s
.55531 .44269 m .55476 .44213 L .55235 .44361 L p .595 .354 .521 r
F P
0 g
s
.57113 .43698 m .56896 .4346 L .56712 .43656 L p .592 .345 .511 r
F P
0 g
s
.55673 .44405 m .56712 .43656 L .56896 .4346 L p .58 .328 .499 r
F P
0 g
s
.56896 .4346 m .55412 .4453 L .55673 .44405 L p .58 .328 .499 r
F P
0 g
s
.56896 .4346 m .57113 .43698 L .57321 .43568 L p .646 .344 .446 r
F P
0 g
s
.55412 .4453 m .56896 .4346 L .56661 .43607 L p .595 .351 .518 r
F P
0 g
s
.55315 .4444 m .55235 .44361 L .55055 .44589 L p .549 .355 .57 r
F P
0 g
s
.55235 .44361 m .55315 .4444 L .55531 .44269 L p .595 .354 .521 r
F P
0 g
s
.55055 .44589 m .55111 .44644 L .55315 .4444 L p .549 .355 .57 r
F P
0 g
s
.56661 .43607 m .55622 .44356 L .55412 .4453 L p .595 .351 .518 r
F P
0 g
s
.4242 .51727 m .41383 .51385 L .41169 .51339 L p .652 .12 0 r
F P
0 g
s
.41169 .51339 m .42651 .51827 L .4242 .51727 L p .652 .12 0 r
F P
0 g
s
.44682 .65146 m .44799 .65258 L .44643 .65584 L p .88 .767 .732 r
F P
0 g
s
.38325 .73774 m .40625 .71485 L .41224 .71079 L p .81 .782 .826 r
F P
0 g
s
.36531 .74417 m .33028 .77102 L .3214 .77574 L p .783 .784 .853 r
F P
0 g
s
.54829 .52565 m .55125 .52962 L .55352 .52936 L p .338 .447 .826 r
F P
0 g
s
.41401 .51449 m .42439 .5179 L .42651 .51827 L p .62 .069 0 r
F P
0 g
s
.42651 .51827 m .41169 .51339 L .41401 .51449 L p .62 .069 0 r
F P
0 g
s
.42658 .52184 m .42651 .51827 L .42439 .5179 L p .737 .254 .095 r
F P
0 g
s
.42844 .52232 m .42839 .51981 L .42651 .51827 L p .769 .288 .092 r
F P
0 g
s
.42651 .51827 m .42658 .52184 L .42844 .52232 L p .769 .288 .092 r
F P
0 g
s
.43082 .68687 m .42698 .68356 L .42967 .67879 L p .836 .778 .796 r
F P
0 g
s
.55352 .52936 m .54928 .52368 L .54829 .52565 L p .338 .447 .826 r
F P
0 g
s
.45881 .60664 m .45357 .60225 L .45167 .60377 L p .935 .791 .677 r
F P
0 g
s
.39609 .50937 m .39571 .50917 L .39302 .50863 L p .393 0 0 r
F P
0 g
s
.54039 .46235 m .53453 .47487 L .53356 .47771 L p .505 .361 .619 r
F P
0 g
s
.55111 .44644 m .54227 .45654 L .54052 .45883 L p .548 .353 .569 r
F P
0 g
s
.44471 .65997 m .43298 .67604 L .42967 .67879 L p .86 .773 .765 r
F P
0 g
s
.42967 .67879 m .44643 .65584 L .44471 .65997 L p .86 .773 .765 r
F P
0 g
s
.54026 .47914 m .53356 .47771 L .53448 .48062 L p .442 .356 .664 r
F P
0 g
s
.54032 .47631 m .53563 .47531 L .53356 .47771 L p .458 .307 .588 r
F P
0 g
s
.53356 .47771 m .54026 .47914 L .54032 .47631 L p .458 .307 .588 r
F P
0 g
s
.54194 .45984 m .53356 .47771 L .53563 .47531 L p .464 .315 .594 r
F P
0 g
s
.53356 .47771 m .54194 .45984 L .54039 .46235 L p .505 .361 .619 r
F P
0 g
s
.53939 .46165 m .54039 .46235 L .54194 .45984 L p .497 .351 .612 r
F P
0 g
s
.54194 .45984 m .54052 .45883 L .53939 .46165 L p .497 .351 .612 r
F P
0 g
s
.59367 .57895 m .59501 .58361 L .59673 .58647 L p .861 .43 .002 r
F P
0 g
s
.54359 .45751 m .54259 .45681 L .54052 .45883 L p .537 .339 .559 r
F P
0 g
s
.54052 .45883 m .54194 .45984 L .54359 .45751 L p .537 .339 .559 r
F P
0 g
s
.55315 .4444 m .54052 .45883 L .54259 .45681 L p .539 .341 .561 r
F P
0 g
s
.54052 .45883 m .55315 .4444 L .55111 .44644 L p .548 .353 .569 r
F P
0 g
s
.30384 .50484 m .27373 .50214 L .267 .5026 L p .628 .78 .954 r
F P
0 g
s
.56712 .43656 m .56864 .43822 L .57113 .43698 L p .592 .345 .511 r
F P
0 g
s
.37148 .73736 m .3214 .77574 L .32847 .76964 L p .786 .793 .858 r
F P
0 g
s
.32621 .76776 m .32847 .76964 L .3214 .77574 L p .786 .793 .858 r
F P
0 g
s
.3214 .77574 m .31818 .77307 L .32621 .76776 L p .786 .793 .858 r
F P
0 g
s
.3214 .77574 m .37148 .73736 L .36531 .74417 L p .783 .784 .853 r
F P
0 g
s
.44643 .65584 m .44475 .65424 L .44682 .65146 L p .88 .767 .732 r
F P
0 g
s
.43193 .6751 m .44367 .65903 L .44643 .65584 L p .863 .779 .767 r
F P
0 g
s
.44643 .65584 m .42967 .67879 L .43193 .6751 L p .863 .779 .767 r
F P
0 g
s
.44475 .65424 m .44643 .65584 L .44367 .65903 L p .86 .772 .764 r
F P
0 g
s
.45279 .63495 m .44436 .64904 L .44322 .65274 L p .896 .793 .738 r
F P
0 g
s
.55622 .44356 m .55554 .44293 L .55315 .4444 L p .588 .341 .51 r
F P
0 g
s
.48145 .27015 m .46889 .2293 L .46109 .22129 L p .677 .643 .808 r
F P
0 g
s
.54259 .45681 m .55143 .44671 L .55315 .4444 L p .539 .341 .561 r
F P
0 g
s
.37591 .50546 m .37288 .50486 L p .38319 .50688 L 0 .498 .742 r
F P
0 g
s
.3869 .50756 m .38271 .50682 L .38274 .50682 L 0 .497 .729 r
F
.39038 .5083 m .38315 .50688 L p .38319 .50688 L 0 .498 .742 r
F P
0 g
s
.38315 .50688 m .37591 .50546 L p .38319 .50688 L 0 .498 .742 r
F P
0 g
s
.37233 .505 m .37552 .50555 L p .38274 .50682 L 0 .497 .729 r
F P
0 g
s
.38271 .50682 m .37233 .505 L .38274 .50682 L 0 .497 .729 r
F
.39302 .50863 m .38677 .50753 L p .3869 .50756 L F P
0 g
s
.38677 .50753 m .37233 .505 L p .3869 .50756 L 0 .497 .729 r
F P
0 g
s
.39464 .50862 m .39413 .50876 L p .39065 .50818 L .066 .596 .865 r
F P
0 g
s
.39356 .50892 m .39302 .50863 L .39001 .5081 L p .394 0 0 r
F P
0 g
s
.39413 .50876 m .39356 .50892 L .39065 .50818 L p .066 .596 .865 r
F P
0 g
s
.39065 .50818 m .39065 .50818 L p .39413 .50876 L .066 .596 .865 r
F P
0 g
s
.39356 .50892 m .39038 .5083 L p .38319 .50688 L 0 .498 .742 r
F P
0 g
s
.37288 .50486 m .38323 .50689 L p .38319 .50688 L 0 .498 .742 r
F P
0 g
s
.38323 .50689 m .39356 .50892 L p .38319 .50688 L 0 .498 .742 r
F P
0 g
s
.39001 .5081 m .39302 .50863 L p .38274 .50682 L 0 .497 .729 r
F P
0 g
s
.37552 .50555 m .38277 .50683 L p .38274 .50682 L 0 .497 .729 r
F P
0 g
s
.38277 .50683 m .39001 .5081 L p .38274 .50682 L 0 .497 .729 r
F P
0 g
s
.39302 .50863 m .39356 .50892 L .39609 .50937 L p .393 0 0 r
F P
0 g
s
.55412 .4453 m .55315 .4444 L .55143 .44671 L p .542 .345 .563 r
F P
0 g
s
.55315 .4444 m .55412 .4453 L .55622 .44356 L p .588 .341 .51 r
F P
0 g
s
.4103 .70232 m .41479 .70596 L .41224 .71079 L p .836 .778 .796 r
F P
0 g
s
.41224 .71079 m .40582 .70561 L .4103 .70232 L p .836 .778 .796 r
F P
0 g
s
.40582 .70561 m .41224 .71079 L .40625 .71485 L p .81 .782 .827 r
F P
0 g
s
.55143 .44671 m .55211 .44734 L .55412 .4453 L p .542 .345 .563 r
F P
0 g
s
.67125 .46308 m .65987 .46212 L .6563 .45999 L p .456 .626 .926 r
F P
0 g
s
.4956 .22505 m .50209 .26671 L .50852 .27473 L p .677 .643 .808 r
F P
0 g
s
.50852 .27473 m .49931 .21518 L .4956 .22505 L p .677 .643 .808 r
F P
0 g
s
.53937 .26413 m .5135 .2656 L .50852 .27473 L p .695 .656 .806 r
F P
0 g
s
.50852 .27473 m .54541 .27265 L .53937 .26413 L p .695 .656 .806 r
F P
0 g
s
.49931 .21518 m .50852 .27473 L .5135 .2656 L p .695 .655 .806 r
F P
0 g
s
.73568 .48893 m .73127 .47605 L .73511 .4731 L p .598 .695 .91 r
F P
0 g
s
.54404 .51784 m .54633 .52278 L .54928 .52368 L p .395 .478 .827 r
F P
0 g
s
.59571 .43718 m .59263 .43455 L .58975 .43417 L p .662 .228 .207 r
F P
0 g
s
.67258 .46135 m .6563 .45999 L .6571 .45868 L p .399 .662 .966 r
F P
0 g
s
.64978 .45209 m .6571 .45868 L .6563 .45999 L p .404 .669 .968 r
F P
0 g
s
.6563 .45999 m .64583 .45058 L .64978 .45209 L p .404 .669 .968 r
F P
0 g
s
.6563 .45999 m .67258 .46135 L .67125 .46308 L p .456 .626 .926 r
F P
0 g
s
.64583 .45058 m .6563 .45999 L .65302 .45818 L p .224 .572 .941 r
F P
0 g
s
.68277 .47266 m .69913 .47301 L .70392 .47521 L p .539 .678 .928 r
F P
0 g
s
.45912 .56308 m .45841 .5589 L .45629 .55833 L p .898 .698 .623 r
F P
0 g
s
.53448 .48062 m .53917 .48162 L .54026 .47914 L p .442 .356 .664 r
F P
0 g
s
.31644 .50192 m .33954 .5049 L .34474 .50478 L p .587 .787 .975 r
F P
0 g
s
.45817 .55739 m .45783 .55604 L .4558 .55639 L p .889 .683 .619 r
F P
0 g
s
.4558 .55639 m .45629 .55833 L .45817 .55739 L p .889 .683 .619 r
F P
0 g
s
.45629 .55833 m .4573 .56431 L .45912 .56308 L p .898 .698 .623 r
F P
0 g
s
.60732 .43756 m .61119 .44031 L .61415 .4408 L p .631 .153 .1 r
F P
0 g
s
.53563 .47531 m .5415 .46279 L .54194 .45984 L p .464 .315 .594 r
F P
0 g
s
.45759 .55524 m .45712 .55364 L .45513 .5541 L p .885 .677 .615 r
F P
0 g
s
.45513 .5541 m .4558 .55639 L .45759 .55524 L p .885 .677 .615 r
F P
0 g
s
.59415 .43792 m .58975 .43417 L .58823 .43559 L p .615 .263 .35 r
F P
0 g
s
.57777 .43984 m .58823 .43559 L .58975 .43417 L p .584 .223 .322 r
F P
0 g
s
.58975 .43417 m .57481 .44023 L .57777 .43984 L p .584 .223 .322 r
F P
0 g
s
.58975 .43417 m .59415 .43792 L .59571 .43718 L p .662 .228 .207 r
F P
0 g
s
.57481 .44023 m .58975 .43417 L .58701 .43457 L p .637 .312 .405 r
F P
0 g
s
.39001 .5081 m .39038 .5083 L .39356 .50892 L p .394 0 0 r
F P
0 g
s
.44367 .65903 m .44249 .65791 L .44475 .65424 L p .86 .772 .764 r
F P
0 g
s
.40625 .71485 m .40174 .71123 L .40582 .70561 L p .81 .782 .827 r
F P
0 g
s
.57077 .54949 m .57493 .55581 L .57633 .5577 L p .712 .227 0 r
F P
0 g
s
.38186 .23527 m .34583 .18432 L .34189 .17104 L p .641 .647 .841 r
F P
0 g
s
.45942 .57306 m .45918 .56601 L .4573 .56431 L p .914 .725 .632 r
F P
0 g
s
.68367 .73937 m .69702 .72333 L .7051 .72392 L p .512 .555 .837 r
F P
0 g
s
.55211 .44734 m .54359 .45751 L .54194 .45984 L p .539 .341 .561 r
F P
0 g
s
.54194 .45984 m .55412 .4453 L .55211 .44734 L p .539 .341 .561 r
F P
0 g
s
.58701 .43457 m .57656 .43882 L .57481 .44023 L p .637 .312 .405 r
F P
0 g
s
.37491 .50693 m .37494 .50678 L .37183 .50623 L p .215 .694 .934 r
F P
0 g
s
.37183 .50623 m .37178 .50645 L .37491 .50693 L p .215 .694 .934 r
F P
0 g
s
.45639 .55208 m .45458 .5476 L .45253 .5477 L p .881 .661 .601 r
F P
0 g
s
.45253 .5477 m .45513 .5541 L .45639 .55208 L p .881 .661 .601 r
F P
0 g
s
.45685 .61177 m .45095 .62446 L .45075 .62816 L p .925 .804 .708 r
F P
0 g
s
.55702 .44767 m .55412 .4453 L .55282 .44783 L p .527 .324 .547 r
F P
0 g
s
.54429 .45801 m .55282 .44783 L .55412 .4453 L p .516 .311 .54 r
F P
0 g
s
.55412 .4453 m .54194 .45984 L .54429 .45801 L p .516 .311 .54 r
F P
0 g
s
.55876 .44571 m .55673 .44405 L .55412 .4453 L p .571 .313 .486 r
F P
0 g
s
.55412 .4453 m .55702 .44767 L .55876 .44571 L p .571 .313 .486 r
F P
0 g
s
.65302 .45818 m .64569 .45159 L .64583 .45058 L p .224 .572 .941 r
F P
0 g
s
.54612 .46212 m .54194 .45984 L .5415 .46279 L p .474 .325 .597 r
F P
0 g
s
.54722 .4596 m .54429 .45801 L .54194 .45984 L p .509 .3 .532 r
F P
0 g
s
.54194 .45984 m .54612 .46212 L .54722 .4596 L p .509 .3 .532 r
F P
0 g
s
.31173 .50052 m .34474 .50478 L .34001 .50368 L p .586 .787 .975 r
F P
0 g
s
.34092 .50192 m .34001 .50368 L .34474 .50478 L p .55 .787 .987 r
F P
0 g
s
.34474 .50478 m .34605 .50226 L .34092 .50192 L p .55 .787 .987 r
F P
0 g
s
.34474 .50478 m .31173 .50052 L .31644 .50192 L p .587 .787 .975 r
F P
0 g
s
.34605 .50226 m .34474 .50478 L .34881 .50495 L p .552 .789 .987 r
F P
0 g
s
.41679 .24413 m .41318 .24551 L .40797 .23752 L p .648 .627 .815 r
F P
0 g
s
.61336 .62323 m .61772 .63009 L .61929 .63381 L p 0 0 .574 r
F P
0 g
s
.37617 .50534 m .39065 .50818 L .39356 .50892 L p .271 .711 .963 r
F P
0 g
s
.39356 .50892 m .37288 .50486 L .37617 .50534 L p .271 .711 .963 r
F P
0 g
s
.39706 .50929 m .3963 .50949 L .39356 .50892 L p .062 .59 .867 r
F P
0 g
s
.39356 .50892 m .39464 .50862 L .39706 .50929 L p .062 .59 .867 r
F P
0 g
s
.44633 .65099 m .44526 .64994 L .44322 .65274 L p .897 .794 .739 r
F P
0 g
s
.44322 .65274 m .44475 .65424 L .44633 .65099 L p .897 .794 .739 r
F P
0 g
s
.34881 .50495 m .34973 .50319 L .34605 .50226 L p .552 .789 .987 r
F P
0 g
s
.42439 .5179 m .42443 .5204 L .42658 .52184 L p .737 .254 .095 r
F P
0 g
s
.32847 .76964 m .36353 .74276 L .37148 .73736 L p .786 .793 .858 r
F P
0 g
s
.53887 .50897 m .54276 .50123 L .54273 .49869 L p .346 .373 .746 r
F P
0 g
s
.34973 .50319 m .36774 .50612 L .37178 .50645 L p .495 .782 .996 r
F P
0 g
s
.34605 .50226 m .37178 .50645 L .36794 .50576 L p .376 .759 .989 r
F P
0 g
s
.36797 .50561 m .36794 .50576 L .37178 .50645 L p .213 .692 .934 r
F P
0 g
s
.37178 .50645 m .37183 .50623 L .36797 .50561 L p .213 .692 .934 r
F P
0 g
s
.37178 .50645 m .34605 .50226 L .34973 .50319 L p .495 .782 .996 r
F P
0 g
s
.4573 .56431 m .45765 .5744 L .45942 .57306 L p .914 .725 .632 r
F P
0 g
s
.64019 .6786 m .62922 .66712 L .62828 .66225 L p .417 .428 .764 r
F P
0 g
s
.57656 .43882 m .57398 .43654 L .57113 .43698 L p .62 .288 .387 r
F P
0 g
s
.56864 .43822 m .55876 .44571 L .55702 .44767 L p .583 .328 .495 r
F P
0 g
s
.55702 .44767 m .57113 .43698 L .56864 .43822 L p .583 .328 .495 r
F P
0 g
s
.57481 .44023 m .57113 .43698 L .56965 .43903 L p .571 .302 .471 r
F P
0 g
s
.55977 .44652 m .56965 .43903 L .57113 .43698 L p .547 .274 .453 r
F P
0 g
s
.57113 .43698 m .55702 .44767 L .55977 .44652 L p .547 .274 .453 r
F P
0 g
s
.57113 .43698 m .57481 .44023 L .57656 .43882 L p .62 .288 .387 r
F P
0 g
s
.54077 .22256 m .53937 .26413 L .54541 .27265 L p .695 .655 .806 r
F P
0 g
s
.54541 .27265 m .54749 .21324 L .54077 .22256 L p .695 .655 .806 r
F P
0 g
s
.58208 .26694 m .5529 .2645 L .54541 .27265 L p .714 .671 .807 r
F P
0 g
s
.54749 .21324 m .54541 .27265 L .5529 .2645 L p .715 .672 .807 r
F P
0 g
s
.55282 .44783 m .55485 .44949 L .55702 .44767 L p .527 .324 .547 r
F P
0 g
s
.45282 .54514 m .44888 .53895 L .44691 .53885 L p .877 .628 .559 r
F P
0 g
s
.44691 .53885 m .45253 .5477 L .45282 .54514 L p .877 .628 .559 r
F P
0 g
s
.60432 .60003 m .6068 .60555 L .60847 .6088 L p .716 .322 0 r
F P
0 g
s
.5415 .46279 m .54442 .4644 L .54612 .46212 L p .474 .325 .597 r
F P
0 g
s
.44091 .65639 m .44199 .65743 L .44475 .65424 L p .875 .8 .773 r
F P
0 g
s
.44475 .65424 m .44322 .65274 L .44091 .65639 L p .875 .8 .773 r
F P
0 g
s
.42793 .67716 m .44475 .65424 L .44199 .65743 L p .871 .793 .77 r
F P
0 g
s
.42793 .67716 m .44475 .65424 L .44249 .65791 L p .864 .779 .766 r
F P
0 g
s
.45779 .58651 m .45893 .57706 L .45765 .5744 L p .929 .757 .648 r
F P
0 g
s
.21873 .49974 m .25836 .50363 L .267 .5026 L p .642 .767 .939 r
F P
0 g
s
.30404 .77774 m .30632 .77961 L .31818 .77307 L p .757 .791 .881 r
F P
0 g
s
.54928 .52368 m .54601 .51661 L .54404 .51784 L p .395 .478 .827 r
F P
0 g
s
.44249 .65791 m .43072 .67396 L .42793 .67716 L p .864 .779 .766 r
F P
0 g
s
.56217 .53973 m .56425 .54228 L .56621 .54437 L p 0 .056 .582 r
F P
0 g
s
.55537 .53177 m .56217 .53973 L .56325 .54073 L p 0 .08 .627 r
F P
0 g
s
.56325 .54073 m .55352 .52936 L .55537 .53177 L p 0 .08 .627 r
F P
0 g
s
.40899 .51262 m .39706 .50929 L .39464 .50862 L p .222 0 0 r
F P
0 g
s
.39464 .50862 m .41169 .51339 L .40899 .51262 L p .222 0 0 r
F P
0 g
s
.36794 .50576 m .34993 .50283 L .34605 .50226 L p .376 .759 .989 r
F P
0 g
s
.58823 .43559 m .59131 .43822 L .59415 .43792 L p .615 .263 .35 r
F P
0 g
s
.39744 .50939 m .40938 .51273 L .41169 .51339 L p 0 .417 .7 r
F P
0 g
s
.41169 .51339 m .39464 .50862 L .39744 .50939 L p 0 .417 .7 r
F P
0 g
s
.41291 .51472 m .41169 .51339 L .40938 .51273 L p .435 0 0 r
F P
0 g
s
.41487 .51543 m .41401 .51449 L .41169 .51339 L p .454 0 0 r
F P
0 g
s
.41169 .51339 m .41291 .51472 L .41487 .51543 L p .454 0 0 r
F P
0 g
s
.40797 .23752 m .41314 .23554 L .41679 .24413 L p .648 .627 .815 r
F P
0 g
s
.39065 .50818 m .3914 .50797 L .39464 .50862 L p .066 .596 .865 r
F P
0 g
s
.45446 .55694 m .45481 .55829 L .45629 .55833 L p .948 .709 .544 r
F P
0 g
s
.45629 .55833 m .4558 .55639 L .45446 .55694 L p .948 .709 .544 r
F P
0 g
s
.44673 .55983 m .45629 .55833 L .45481 .55829 L p .948 .71 .545 r
F P
0 g
s
.4483 .56039 m .45499 .55934 L .45629 .55833 L p .951 .726 .562 r
F P
0 g
s
.45629 .55833 m .44673 .55983 L .4483 .56039 L p .951 .726 .562 r
F P
0 g
s
.4573 .56431 m .45629 .55833 L .45499 .55934 L p .952 .729 .563 r
F P
0 g
s
.57318 .55388 m .56785 .54648 L .56621 .54437 L p .694 .208 0 r
F P
0 g
s
.56621 .54437 m .57383 .55494 L .57318 .55388 L p .694 .208 0 r
F P
0 g
s
.56621 .54437 m .56325 .54073 L .56217 .53973 L p 0 .056 .582 r
F P
0 g
s
.57229 .55288 m .56696 .54548 L .56621 .54437 L p .639 .171 0 r
F P
0 g
s
.56621 .54437 m .57383 .55494 L .57229 .55288 L p .639 .171 0 r
F P
0 g
s
.56325 .54073 m .56621 .54437 L .56696 .54548 L p .631 .169 0 r
F P
0 g
s
.45385 .55478 m .45433 .55638 L .4558 .55639 L p .946 .699 .533 r
F P
0 g
s
.4558 .55639 m .45513 .5541 L .45385 .55478 L p .946 .699 .533 r
F P
0 g
s
.44644 .55835 m .4558 .55639 L .45433 .55638 L p .946 .701 .536 r
F P
0 g
s
.44791 .55831 m .45446 .55694 L .4558 .55639 L p .948 .711 .545 r
F P
0 g
s
.4558 .55639 m .44644 .55835 L .44791 .55831 L p .948 .711 .545 r
F P
0 g
s
.54928 .52368 m .55352 .52936 L .55338 .52838 L p 0 .143 .687 r
F P
0 g
s
.55471 .5268 m .55338 .52838 L .55352 .52936 L p 0 .071 .632 r
F P
0 g
s
.55352 .52936 m .55541 .52711 L .55471 .5268 L p 0 .071 .632 r
F P
0 g
s
.56167 .53845 m .55485 .53048 L .55352 .52936 L p 0 .076 .623 r
F P
0 g
s
.55352 .52936 m .56325 .54073 L .56167 .53845 L p 0 .076 .623 r
F P
0 g
s
.55541 .52711 m .55352 .52936 L .55485 .53048 L p 0 .076 .636 r
F P
0 g
s
.45165 .54912 m .45347 .55361 L .45513 .5541 L p .939 .672 .503 r
F P
0 g
s
.45513 .5541 m .45253 .5477 L .45165 .54912 L p .939 .672 .503 r
F P
0 g
s
.44604 .55659 m .45513 .5541 L .45347 .55361 L p .94 .679 .513 r
F P
0 g
s
.44749 .55652 m .45385 .55478 L .45513 .5541 L p .946 .701 .535 r
F P
0 g
s
.45513 .5541 m .44604 .55659 L .44749 .55652 L p .946 .701 .535 r
F P
0 g
s
.56965 .43903 m .57222 .44131 L .57481 .44023 L p .571 .302 .471 r
F P
0 g
s
.45499 .55934 m .4557 .56353 L .4573 .56431 L p .952 .729 .563 r
F P
0 g
s
.4474 .56437 m .4573 .56431 L .4557 .56353 L p .952 .727 .56 r
F P
0 g
s
.44895 .5657 m .45588 .56565 L .4573 .56431 L p .955 .752 .59 r
F P
0 g
s
.4573 .56431 m .4474 .56437 L .44895 .5657 L p .955 .752 .59 r
F P
0 g
s
.45765 .5744 m .4573 .56431 L .45588 .56565 L p .957 .758 .594 r
F P
0 g
s
.44199 .65743 m .43021 .67348 L .42793 .67716 L p .871 .793 .77 r
F P
0 g
s
.63007 .6463 m .62828 .66225 L .62701 .65796 L p .185 .279 .728 r
F P
0 g
s
.62828 .66225 m .64397 .67865 L .64019 .6786 L p .417 .428 .764 r
F P
0 g
s
.63226 .65108 m .63099 .66224 L .62828 .66225 L p .304 .395 .791 r
F P
0 g
s
.62828 .66225 m .63007 .6463 L .63226 .65108 L p .304 .395 .791 r
F P
0 g
s
.64397 .67865 m .62828 .66225 L .63099 .66224 L p .304 .395 .791 r
F P
0 g
s
.35 .50245 m .36797 .50561 L .37183 .50623 L p .37 .753 .989 r
F P
0 g
s
.37183 .50623 m .34615 .50171 L .35 .50245 L p .37 .753 .989 r
F P
0 g
s
.54601 .51661 m .54928 .52368 L .54965 .52297 L p 0 .107 .66 r
F P
0 g
s
.55301 .52337 m .54965 .52297 L .54928 .52368 L p 0 .082 .64 r
F P
0 g
s
.54928 .52368 m .55409 .52425 L .55301 .52337 L p 0 .082 .64 r
F P
0 g
s
.55338 .52838 m .55041 .5244 L .54928 .52368 L p 0 .143 .687 r
F P
0 g
s
.55409 .52425 m .54928 .52368 L .55041 .5244 L p 0 .135 .682 r
F P
0 g
s
.64569 .45159 m .63787 .45006 L .63467 .44839 L p .232 .58 .944 r
F P
0 g
s
.34001 .50368 m .31689 .50069 L .31173 .50052 L p .586 .787 .975 r
F P
0 g
s
.44612 .53643 m .4399 .53013 L .43802 .52984 L p .87 .563 .465 r
F P
0 g
s
.43802 .52984 m .44691 .53885 L .44612 .53643 L p .87 .563 .465 r
F P
0 g
s
.58243 .56398 m .57694 .55789 L .57633 .5577 L p .774 .302 0 r
F P
0 g
s
.57633 .5577 m .58418 .5664 L .58243 .56398 L p .774 .302 0 r
F P
0 g
s
.41817 .2436 m .42179 .24222 L .41831 .23355 L p .648 .627 .815 r
F P
0 g
s
.41831 .23355 m .41314 .23554 L .41817 .2436 L p .648 .627 .815 r
F P
0 g
s
.44673 .54081 m .45067 .54701 L .45253 .5477 L p .922 .611 .435 r
F P
0 g
s
.45253 .5477 m .44691 .53885 L .44673 .54081 L p .922 .611 .435 r
F P
0 g
s
.44455 .55148 m .45253 .5477 L .45067 .54701 L p .926 .633 .467 r
F P
0 g
s
.44606 .55177 m .45165 .54912 L .45253 .5477 L p .943 .679 .506 r
F P
0 g
s
.45253 .5477 m .44455 .55148 L .44606 .55177 L p .943 .679 .506 r
F P
0 g
s
.64583 .45058 m .63467 .44839 L .63442 .44791 L p .043 .554 .875 r
F P
0 g
s
.62559 .44456 m .63442 .44791 L .63467 .44839 L p .078 .586 .888 r
F P
0 g
s
.62205 .44361 m .63467 .44839 L .6316 .44719 L p .292 0 0 r
F P
0 g
s
.6316 .44719 m .62277 .44384 L .62205 .44361 L p .292 0 0 r
F P
0 g
s
.63467 .44839 m .62205 .44361 L .62559 .44456 L p .078 .586 .888 r
F P
0 g
s
.63467 .44839 m .64583 .45058 L .64569 .45159 L p .232 .58 .944 r
F P
0 g
s
.74668 .48822 m .77639 .48661 L .78375 .48924 L p .626 .716 .911 r
F P
0 g
s
.21033 .49703 m .267 .5026 L .25883 .5004 L p .641 .768 .94 r
F P
0 g
s
.26012 .49483 m .25883 .5004 L .267 .5026 L p .632 .77 .946 r
F P
0 g
s
.267 .5026 m .26889 .49465 L .26012 .49483 L p .632 .77 .946 r
F P
0 g
s
.267 .5026 m .21033 .49703 L .21873 .49974 L p .642 .767 .939 r
F P
0 g
s
.26889 .49465 m .267 .5026 L .27373 .50214 L p .635 .772 .946 r
F P
0 g
s
.45765 .5744 m .45601 .58791 L .45779 .58651 L p .929 .757 .648 r
F P
0 g
s
.36095 .74053 m .32535 .76704 L .31818 .77307 L p .786 .793 .858 r
F P
0 g
s
.31818 .77307 m .36901 .7352 L .36095 .74053 L p .786 .793 .858 r
F P
0 g
s
.31494 .77039 m .31818 .77307 L .32535 .76704 L p .786 .793 .858 r
F P
0 g
s
.31818 .77307 m .31494 .77039 L .30404 .77774 L p .757 .791 .881 r
F P
0 g
s
.36179 .74126 m .32621 .76776 L .31818 .77307 L p .786 .793 .858 r
F P
0 g
s
.31818 .77307 m .36901 .7352 L .36179 .74126 L p .786 .793 .858 r
F P
0 g
s
.45588 .56565 m .45613 .57272 L .45765 .5744 L p .957 .758 .594 r
F P
0 g
s
.44778 .57212 m .45765 .5744 L .45613 .57272 L p .959 .755 .585 r
F P
0 g
s
.44908 .57431 m .45599 .57589 L .45765 .5744 L p .957 .781 .623 r
F P
0 g
s
.45765 .5744 m .44778 .57212 L .44908 .57431 L p .957 .781 .623 r
F P
0 g
s
.45601 .58791 m .45765 .5744 L .45599 .57589 L p .96 .789 .627 r
F P
0 g
s
.62701 .65796 m .62825 .64679 L .63007 .6463 L p .185 .279 .728 r
F P
0 g
s
.58911 .57573 m .58623 .56956 L .58418 .5664 L p .794 .344 0 r
F P
0 g
s
.58418 .5664 m .58829 .5752 L .58911 .57573 L p .794 .344 0 r
F P
0 g
s
.57829 .56047 m .58378 .56656 L .58418 .5664 L p .797 .331 0 r
F P
0 g
s
.58418 .5664 m .57633 .5577 L .57829 .56047 L p .797 .331 0 r
F P
0 g
s
.58829 .5752 m .58418 .5664 L .58378 .56656 L p .807 .35 0 r
F P
0 g
s
.42698 .68356 m .4103 .70232 L .40582 .70561 L p .836 .778 .796 r
F P
0 g
s
.40582 .70561 m .42967 .67879 L .42698 .68356 L p .836 .778 .796 r
F P
0 g
s
.37591 .50546 m .37552 .50555 L .37233 .505 L p .211 .687 .936 r
F P
0 g
s
.43878 .64814 m .44322 .65274 L .44436 .64904 L p .897 .793 .738 r
F P
0 g
s
.429 .67234 m .44091 .65639 L .44322 .65274 L p .87 .793 .771 r
F P
0 g
s
.44322 .65274 m .42619 .67553 L .429 .67234 L p .87 .793 .771 r
F P
0 g
s
.43687 .65223 m .43999 .65544 L .44322 .65274 L p .874 .798 .773 r
F P
0 g
s
.44322 .65274 m .43878 .64814 L .43687 .65223 L p .874 .798 .773 r
F P
0 g
s
.42619 .67553 m .44322 .65274 L .43999 .65544 L p .874 .799 .773 r
F P
0 g
s
.44436 .64904 m .44126 .64581 L .43878 .64814 L p .897 .793 .738 r
F P
0 g
s
.55485 .44949 m .54722 .4596 L .54612 .46212 L p .518 .31 .537 r
F P
0 g
s
.54612 .46212 m .55702 .44767 L .55485 .44949 L p .518 .31 .537 r
F P
0 g
s
.43072 .67396 m .43193 .6751 L .42967 .67879 L p .867 .786 .769 r
F P
0 g
s
.27373 .50214 m .27507 .49658 L .26889 .49465 L p .635 .772 .946 r
F P
0 g
s
.6571 .45868 m .6685 .45963 L .67258 .46135 L p .399 .662 .966 r
F P
0 g
s
.44126 .64581 m .44963 .63183 L .45075 .62816 L p .896 .793 .738 r
F P
0 g
s
.3883 .23204 m .39855 .22751 L .40797 .23752 L p .649 .65 .838 r
F P
0 g
s
.36956 .1731 m .40203 .22601 L .40797 .23752 L p .653 .652 .836 r
F P
0 g
s
.40797 .23752 m .36158 .16196 L .36956 .1731 L p .653 .652 .836 r
F P
0 g
s
.41314 .23554 m .40797 .23752 L .40203 .22601 L p .654 .652 .836 r
F P
0 g
s
.36158 .16196 m .40797 .23752 L .39855 .22751 L p .649 .65 .838 r
F P
0 g
s
.43872 .53189 m .44495 .5382 L .44691 .53885 L p .886 .506 .312 r
F P
0 g
s
.44691 .53885 m .43802 .52984 L .43872 .53189 L p .886 .506 .312 r
F P
0 g
s
.44123 .54369 m .44691 .53885 L .44495 .5382 L p .902 .559 .385 r
F P
0 g
s
.44276 .54421 m .44673 .54081 L .44691 .53885 L p .936 .627 .429 r
F P
0 g
s
.44691 .53885 m .44123 .54369 L .44276 .54421 L p .936 .627 .429 r
F P
0 g
s
.44409 .62139 m .45075 .62816 L .45095 .62446 L p .927 .806 .706 r
F P
0 g
s
.45075 .62816 m .43878 .64814 L .44126 .64581 L p .896 .793 .738 r
F P
0 g
s
.44332 .62537 m .44798 .6301 L .45075 .62816 L p .909 .815 .742 r
F P
0 g
s
.45075 .62816 m .44409 .62139 L .44332 .62537 L p .909 .815 .742 r
F P
0 g
s
.43878 .64814 m .45075 .62816 L .44798 .6301 L p .909 .816 .742 r
F P
0 g
s
.35058 .50111 m .36857 .50428 L .37233 .505 L p .37 .753 .989 r
F P
0 g
s
.37233 .505 m .34663 .50048 L .35058 .50111 L p .37 .753 .989 r
F P
0 g
s
.37288 .50486 m .37233 .505 L .36857 .50428 L p .21 .688 .935 r
F P
0 g
s
.37233 .505 m .37288 .50486 L .37591 .50546 L p .211 .687 .936 r
F P
0 g
s
.56178 .45049 m .55702 .44767 L .55621 .45017 L p .495 .273 .506 r
F P
0 g
s
.54858 .46029 m .55621 .45017 L .55702 .44767 L p .463 .241 .491 r
F P
0 g
s
.55702 .44767 m .54612 .46212 L .54858 .46029 L p .463 .241 .491 r
F P
0 g
s
.5631 .44849 m .55977 .44652 L .55702 .44767 L p .531 .244 .425 r
F P
0 g
s
.55702 .44767 m .56178 .45049 L .5631 .44849 L p .531 .244 .425 r
F P
0 g
s
.40938 .51273 m .41023 .51366 L .41291 .51472 L p .435 0 0 r
F P
0 g
s
.5135 .2656 m .50711 .22391 L .49931 .21518 L p .695 .655 .806 r
F P
0 g
s
.42967 .67879 m .42793 .67716 L .43072 .67396 L p .867 .786 .769 r
F P
0 g
s
.40912 .70132 m .42581 .68255 L .42967 .67879 L p .842 .79 .801 r
F P
0 g
s
.42967 .67879 m .40582 .70561 L .40912 .70132 L p .842 .79 .801 r
F P
0 g
s
.42793 .67716 m .42967 .67879 L .42581 .68255 L p .842 .79 .801 r
F P
0 g
s
.45357 .60225 m .45661 .59116 L .45601 .58791 L p .933 .783 .672 r
F P
0 g
s
.60696 .22954 m .64519 .24041 L .65661 .23448 L p .736 .694 .81 r
F P
0 g
s
.54442 .4644 m .54032 .47631 L .54026 .47914 L p .466 .313 .59 r
F P
0 g
s
.54026 .47914 m .54612 .46212 L .54442 .4644 L p .466 .313 .59 r
F P
0 g
s
.5529 .2645 m .55442 .22294 L .54749 .21324 L p .715 .672 .807 r
F P
0 g
s
.43644 .52792 m .42844 .52232 L .42658 .52184 L p .837 .429 .27 r
F P
0 g
s
.42658 .52184 m .43802 .52984 L .43644 .52792 L p .837 .429 .27 r
F P
0 g
s
.32535 .76704 m .32309 .76516 L .31494 .77039 L p .786 .793 .858 r
F P
0 g
s
.45481 .55829 m .44812 .55935 L .44673 .55983 L p .948 .71 .545 r
F P
0 g
s
.45095 .62446 m .4463 .61972 L .44409 .62139 L p .927 .806 .706 r
F P
0 g
s
.45433 .55638 m .44777 .55775 L .44644 .55835 L p .946 .701 .536 r
F P
0 g
s
.62277 .44384 m .61723 .44187 L .61415 .4408 L p .246 0 0 r
F P
0 g
s
.45347 .55361 m .44711 .55535 L .44604 .55659 L p .94 .679 .513 r
F P
0 g
s
.56696 .54548 m .56488 .54294 L .56325 .54073 L p .631 .169 0 r
F P
0 g
s
.4557 .56353 m .44877 .56356 L .4474 .56437 L p .952 .727 .56 r
F P
0 g
s
.42581 .68255 m .4246 .68141 L .42793 .67716 L p .842 .79 .801 r
F P
0 g
s
.40174 .71123 m .37771 .73344 L .37148 .73736 L p .81 .782 .827 r
F P
0 g
s
.62205 .44361 m .61415 .4408 L .61325 .44117 L p .43 0 0 r
F P
0 g
s
.6035 .44137 m .61325 .44117 L .61415 .4408 L p .365 0 0 r
F P
0 g
s
.61415 .4408 m .60022 .44109 L .6035 .44137 L p .365 0 0 r
F P
0 g
s
.62205 .44361 m .62155 .44348 L p .62164 .44349 L 0 .552 .752 r
F P
0 g
s
.61415 .4408 m .62205 .44361 L p .62245 .44373 L .246 0 0 r
F P
0 g
s
.63282 .44451 m .62205 .44361 L p .62164 .44349 L 0 .552 .752 r
F P
0 g
s
.62205 .44361 m .62277 .44384 L p .62245 .44373 L .246 0 0 r
F P
0 g
s
.60022 .44109 m .61415 .4408 L .61119 .44031 L p .589 .075 0 r
F P
0 g
s
.36857 .50428 m .36896 .50418 L .37288 .50486 L p .21 .688 .935 r
F P
0 g
s
.53917 .48162 m .53968 .49217 L .541 .49422 L p .398 .308 .636 r
F P
0 g
s
.541 .49422 m .54026 .47914 L .53917 .48162 L p .398 .308 .636 r
F P
0 g
s
.45067 .54701 m .44508 .54966 L .44455 .55148 L p .926 .633 .467 r
F P
0 g
s
.54545 .50345 m .54601 .51661 L .54676 .51554 L p 0 .039 .578 r
F P
0 g
s
.55142 .51847 m .54676 .51554 L .54601 .51661 L p 0 .087 .618 r
F P
0 g
s
.54601 .51661 m .55268 .5208 L .55142 .51847 L p 0 .087 .618 r
F P
0 g
s
.54466 .50456 m .54506 .51377 L .54601 .51661 L p .278 .356 .764 r
F P
0 g
s
.54601 .51661 m .54545 .50345 L .54466 .50456 L p .278 .356 .764 r
F P
0 g
s
.54965 .52297 m .54735 .51802 L .54601 .51661 L p 0 .107 .66 r
F P
0 g
s
.55268 .5208 m .54601 .51661 L .54735 .51802 L p 0 .116 .663 r
F P
0 g
s
.55621 .45017 m .55954 .45215 L .56178 .45049 L p .495 .273 .506 r
F P
0 g
s
.61119 .44031 m .60144 .44051 L .60022 .44109 L p .589 .075 0 r
F P
0 g
s
.43999 .65544 m .42806 .6714 L .42619 .67553 L p .874 .799 .773 r
F P
0 g
s
.5524 .46378 m .54612 .46212 L .54629 .46467 L p .424 .257 .549 r
F P
0 g
s
.54219 .47659 m .54629 .46467 L .54612 .46212 L p .372 .219 .54 r
F P
0 g
s
.54612 .46212 m .54026 .47914 L .54219 .47659 L p .372 .219 .54 r
F P
0 g
s
.55298 .46144 m .54858 .46029 L .54612 .46212 L p .439 .205 .461 r
F P
0 g
s
.54612 .46212 m .5524 .46378 L .55298 .46144 L p .439 .205 .461 r
F P
0 g
s
.42459 .24126 m .43564 .2376 L .43411 .2283 L p .654 .63 .813 r
F P
0 g
s
.43411 .2283 m .41831 .23355 L .42459 .24126 L p .654 .63 .813 r
F P
0 g
s
.70368 .17697 m .74886 .2032 L .7666 .19859 L p .739 .727 .841 r
F P
0 g
s
.7666 .19859 m .70206 .16083 L .70368 .17697 L p .739 .727 .841 r
F P
0 g
s
.34723 .50002 m .37288 .50486 L .36896 .50418 L p .369 .749 .989 r
F P
0 g
s
.3513 .50045 m .36927 .50384 L .37288 .50486 L p .488 .773 .995 r
F P
0 g
s
.37288 .50486 m .34723 .50002 L .3513 .50045 L p .488 .773 .995 r
F P
0 g
s
.37421 .50343 m .37288 .50486 L .36927 .50384 L p .403 .751 .994 r
F P
0 g
s
.3771 .50434 m .37617 .50534 L .37288 .50486 L p .399 .745 .993 r
F P
0 g
s
.37288 .50486 m .37421 .50343 L .3771 .50434 L p .399 .745 .993 r
F P
0 g
s
.37148 .73736 m .40582 .70561 L .40174 .71123 L p .81 .782 .827 r
F P
0 g
s
.36353 .74276 m .36179 .74126 L .36901 .7352 L p .786 .793 .858 r
F P
0 g
s
.36901 .7352 m .37148 .73736 L .36353 .74276 L p .786 .793 .858 r
F P
0 g
s
.83209 .48838 m .79258 .49191 L .78375 .48924 L p .642 .725 .909 r
F P
0 g
s
.73127 .47605 m .70947 .47751 L .70392 .47521 L p .595 .688 .906 r
F P
0 g
s
.55041 .5244 m .55378 .5248 L .55409 .52425 L p 0 .135 .682 r
F P
0 g
s
.45599 .57589 m .45484 .58536 L .45601 .58791 L p .96 .789 .627 r
F P
0 g
s
.44689 .58311 m .45601 .58791 L .45484 .58536 L p .964 .788 .617 r
F P
0 g
s
.45601 .58791 m .45167 .60377 L .45357 .60225 L p .933 .783 .672 r
F P
0 g
s
.4477 .58607 m .45408 .58942 L .45601 .58791 L p .956 .81 .658 r
F P
0 g
s
.45601 .58791 m .44689 .58311 L .4477 .58607 L p .956 .81 .658 r
F P
0 g
s
.45167 .60377 m .45601 .58791 L .45408 .58942 L p .958 .817 .662 r
F P
0 g
s
.65661 .23448 m .60191 .21886 L .60696 .22954 L p .736 .694 .81 r
F P
0 g
s
.68546 .16911 m .65373 .22078 L .65661 .23448 L p .723 .705 .833 r
F P
0 g
s
.65661 .23448 m .70206 .16083 L .68546 .16911 L p .723 .705 .833 r
F P
0 g
s
.60191 .21886 m .65661 .23448 L .65373 .22078 L p .723 .705 .833 r
F P
0 g
s
.70206 .16083 m .65661 .23448 L .67183 .22834 L p .739 .727 .841 r
F P
0 g
s
.45613 .57272 m .44922 .57112 L .44778 .57212 L p .959 .755 .585 r
F P
0 g
s
.42808 .52361 m .43609 .52922 L .43802 .52984 L p .802 .325 .084 r
F P
0 g
s
.43802 .52984 m .42658 .52184 L .42808 .52361 L p .802 .325 .084 r
F P
0 g
s
.43529 .53442 m .43802 .52984 L .43609 .52922 L p .858 .439 .227 r
F P
0 g
s
.43682 .5351 m .43872 .53189 L .43802 .52984 L p .905 .514 .261 r
F P
0 g
s
.43802 .52984 m .43529 .53442 L .43682 .5351 L p .905 .514 .261 r
F P
0 g
s
.57222 .44131 m .5631 .44849 L .56178 .45049 L p .553 .271 .441 r
F P
0 g
s
.56178 .45049 m .57481 .44023 L .57222 .44131 L p .553 .271 .441 r
F P
0 g
s
.34993 .50283 m .35 .50245 L .34615 .50171 L p .475 .778 .997 r
F P
0 g
s
.34615 .50171 m .34605 .50226 L .34993 .50283 L p .475 .778 .997 r
F P
0 g
s
.58002 .44337 m .57481 .44023 L .57371 .44214 L p .526 .218 .388 r
F P
0 g
s
.56458 .44933 m .57371 .44214 L .57481 .44023 L p .481 .169 .36 r
F P
0 g
s
.57481 .44023 m .56178 .45049 L .56458 .44933 L p .481 .169 .36 r
F P
0 g
s
.58142 .44203 m .57777 .43984 L .57481 .44023 L p .56 .174 .266 r
F P
0 g
s
.57481 .44023 m .58002 .44337 L .58142 .44203 L p .56 .174 .266 r
F P
0 g
s
.3914 .50797 m .3771 .50434 L .37421 .50343 L p .256 .688 .963 r
F P
0 g
s
.37421 .50343 m .39464 .50862 L .3914 .50797 L p .256 .688 .963 r
F P
0 g
s
.43021 .67348 m .429 .67234 L .42619 .67553 L p .867 .786 .769 r
F P
0 g
s
.42619 .67553 m .42793 .67716 L .43021 .67348 L p .867 .786 .769 r
F P
0 g
s
.55485 .53048 m .55619 .52892 L .55541 .52711 L p 0 .076 .636 r
F P
0 g
s
.40582 .70561 m .37148 .73736 L .37629 .7323 L p .814 .792 .832 r
F P
0 g
s
.37457 .73079 m .37629 .7323 L .37148 .73736 L p .814 .792 .832 r
F P
0 g
s
.37148 .73736 m .36901 .7352 L .37457 .73079 L p .814 .792 .832 r
F P
0 g
s
.37762 .504 m .39193 .50763 L .39464 .50862 L p .278 .697 .97 r
F P
0 g
s
.39464 .50862 m .37421 .50343 L .37762 .504 L p .278 .697 .97 r
F P
0 g
s
.39667 .50803 m .39464 .50862 L .39193 .50763 L p .09 .592 .895 r
F P
0 g
s
.39887 .50898 m .39744 .50939 L .39464 .50862 L p .081 .574 .897 r
F P
0 g
s
.39464 .50862 m .39667 .50803 L .39887 .50898 L p .081 .574 .897 r
F P
0 g
s
.41108 .22251 m .40746 .22391 L .41314 .23554 L p .654 .652 .836 r
F P
0 g
s
.41314 .23554 m .41831 .23355 L .41108 .22251 L p .654 .652 .836 r
F P
0 g
s
.3685 .15909 m .41314 .23554 L .40746 .22391 L p .655 .653 .836 r
F P
0 g
s
.40203 .22601 m .40565 .22461 L .41314 .23554 L p .654 .652 .836 r
F P
0 g
s
.3685 .15909 m .41314 .23554 L .40565 .22461 L p .653 .652 .836 r
F P
0 g
s
.36896 .50418 m .351 .50079 L .34723 .50002 L p .369 .749 .989 r
F P
0 g
s
.60144 .44051 m .59719 .4383 L .59415 .43792 L p .543 .018 0 r
F P
0 g
s
.60022 .44109 m .59415 .43792 L .59299 .43912 L p .542 .117 .184 r
F P
0 g
s
.58309 .44293 m .59299 .43912 L .59415 .43792 L p .486 .053 .141 r
F P
0 g
s
.59415 .43792 m .58002 .44337 L .58309 .44293 L p .486 .053 .141 r
F P
0 g
s
.59415 .43792 m .60022 .44109 L .60144 .44051 L p .543 .018 0 r
F P
0 g
s
.58002 .44337 m .59415 .43792 L .59131 .43822 L p .593 .215 .295 r
F P
0 g
s
.44495 .5382 m .44097 .54158 L .44123 .54369 L p .902 .559 .385 r
F P
0 g
s
.59131 .43822 m .58142 .44203 L .58002 .44337 L p .593 .215 .295 r
F P
0 g
s
.54799 .47745 m .54026 .47914 L .54143 .48073 L p .348 .241 .589 r
F P
0 g
s
.54195 .49129 m .54143 .48073 L .54026 .47914 L p .291 .224 .608 r
F P
0 g
s
.54026 .47914 m .541 .49422 L .54195 .49129 L p .291 .224 .608 r
F P
0 g
s
.5476 .4754 m .54219 .47659 L .54026 .47914 L p .322 .156 .494 r
F P
0 g
s
.54026 .47914 m .54799 .47745 L .5476 .4754 L p .322 .156 .494 r
F P
0 g
s
.63442 .44791 m .64224 .44944 L .64583 .45058 L p .043 .554 .875 r
F P
0 g
s
.25883 .5004 m .21912 .4965 L .21033 .49703 L p .641 .768 .94 r
F P
0 g
s
.67183 .22834 m .70368 .17697 L .70206 .16083 L p .739 .727 .841 r
F P
0 g
s
.42282 .67975 m .42404 .68089 L .42793 .67716 L p .842 .79 .801 r
F P
0 g
s
.42793 .67716 m .42619 .67553 L .42282 .67975 L p .842 .79 .801 r
F P
0 g
s
.40382 .70379 m .42793 .67716 L .42404 .68089 L p .842 .79 .801 r
F P
0 g
s
.40382 .70379 m .42793 .67716 L .4246 .68141 L p .842 .79 .801 r
F P
0 g
s
.44798 .6301 m .4396 .64409 L .43878 .64814 L p .909 .816 .742 r
F P
0 g
s
.4246 .68141 m .40772 .70004 L .40382 .70379 L p .842 .79 .801 r
F P
0 g
s
.58378 .56656 m .58666 .57272 L .58829 .5752 L p .807 .35 0 r
F P
0 g
s
.31317 .49686 m .34605 .50226 L .34115 .50134 L p .539 .782 .988 r
F P
0 g
s
.34122 .50096 m .34115 .50134 L .34605 .50226 L p .474 .777 .997 r
F P
0 g
s
.34605 .50226 m .34615 .50171 L .34122 .50096 L p .474 .777 .997 r
F P
0 g
s
.31792 .49814 m .34092 .50192 L .34605 .50226 L p .579 .779 .974 r
F P
0 g
s
.34605 .50226 m .31317 .49686 L .31792 .49814 L p .579 .779 .974 r
F P
0 g
s
.73511 .4731 m .70392 .47521 L .70709 .47248 L p .586 .707 .927 r
F P
0 g
s
.70069 .46192 m .70709 .47248 L .70392 .47521 L p .585 .704 .925 r
F P
0 g
s
.70392 .47521 m .69474 .46015 L .70069 .46192 L p .585 .704 .925 r
F P
0 g
s
.70392 .47521 m .73511 .4731 L .73127 .47605 L p .595 .688 .906 r
F P
0 g
s
.69474 .46015 m .70392 .47521 L .69913 .47301 L p .535 .678 .93 r
F P
0 g
s
.37629 .7323 m .40034 .71007 L .40582 .70561 L p .814 .792 .832 r
F P
0 g
s
.27507 .49658 m .30503 .50068 L .31173 .50052 L p .621 .773 .954 r
F P
0 g
s
.63099 .66224 m .642 .67373 L .64397 .67865 L p .304 .395 .791 r
F P
0 g
s
.40772 .70004 m .40912 .70132 L .40582 .70561 L p .842 .79 .801 r
F P
0 g
s
.54629 .46467 m .55068 .46583 L .5524 .46378 L p .424 .257 .549 r
F P
0 g
s
.40582 .70561 m .40382 .70379 L .40772 .70004 L p .842 .79 .801 r
F P
0 g
s
.40382 .70379 m .40582 .70561 L .40034 .71007 L p .814 .792 .832 r
F P
0 g
s
.59501 .58361 m .58911 .57573 L .58829 .5752 L p .819 .383 0 r
F P
0 g
s
.58829 .5752 m .59673 .58647 L .59501 .58361 L p .819 .383 0 r
F P
0 g
s
.31689 .50069 m .31792 .49814 L .31317 .49686 L p .605 .778 .963 r
F P
0 g
s
.31317 .49686 m .31173 .50052 L .31689 .50069 L p .605 .778 .963 r
F P
0 g
s
.26889 .49465 m .31173 .50052 L .30555 .499 L p .62 .774 .954 r
F P
0 g
s
.30656 .49644 m .30555 .499 L .31173 .50052 L p .603 .776 .963 r
F P
0 g
s
.31173 .50052 m .31317 .49686 L .30656 .49644 L p .603 .776 .963 r
F P
0 g
s
.31173 .50052 m .26889 .49465 L .27507 .49658 L p .621 .773 .954 r
F P
0 g
s
.42443 .5204 m .41487 .51543 L .41291 .51472 L p .676 .129 0 r
F P
0 g
s
.41291 .51472 m .42658 .52184 L .42443 .5204 L p .676 .129 0 r
F P
0 g
s
.36927 .50384 m .37018 .50284 L .37421 .50343 L p .403 .751 .994 r
F P
0 g
s
.40034 .71007 m .39893 .7088 L .40382 .70379 L p .814 .792 .832 r
F P
0 g
s
.42404 .68089 m .40716 .69953 L .40382 .70379 L p .842 .79 .801 r
F P
0 g
s
.36654 .73304 m .31494 .77039 L .32309 .76516 L p .786 .793 .858 r
F P
0 g
s
.35765 .73753 m .3215 .7637 L .31494 .77039 L p .789 .801 .863 r
F P
0 g
s
.31494 .77039 m .36654 .73304 L .35765 .73753 L p .789 .801 .863 r
F P
0 g
s
.30617 .76219 m .31494 .77039 L .3215 .7637 L p .788 .801 .863 r
F P
0 g
s
.29577 .77014 m .30194 .77585 L .31494 .77039 L p .759 .798 .884 r
F P
0 g
s
.31494 .77039 m .30617 .76219 L .29577 .77014 L p .759 .798 .884 r
F P
0 g
s
.62825 .64679 m .62071 .63805 L .61929 .63381 L p .185 .279 .728 r
F P
0 g
s
.69913 .47301 m .69269 .46248 L .69474 .46015 L p .535 .678 .93 r
F P
0 g
s
.32309 .76516 m .35921 .73902 L .36654 .73304 L p .786 .793 .858 r
F P
0 g
s
.60184 .59634 m .59858 .58991 L .59673 .58647 L p .663 .268 0 r
F P
0 g
s
.59452 .58597 m .60139 .59564 L .59954 .59269 L p .715 .278 0 r
F P
0 g
s
.5968 .58916 m .60092 .59495 L p .60139 .59564 L 0 0 .422 r
F P
0 g
s
.59628 .58627 m .59954 .59269 L .60139 .59564 L p .75 .309 0 r
F P
0 g
s
.60092 .59495 m .60161 .59592 L .60139 .59564 L p 0 0 .422 r
F P
0 g
s
.60139 .59564 m .60184 .59634 L p .60176 .59619 L .663 .268 0 r
F P
0 g
s
.59673 .58647 m .60139 .59564 L p .60176 .59619 L .663 .268 0 r
F P
0 g
s
.59037 .57838 m .59628 .58627 L .59673 .58647 L p .739 .291 0 r
F P
0 g
s
.59673 .58647 m .58829 .5752 L .59037 .57838 L p .739 .291 0 r
F P
0 g
s
.60139 .59564 m .59673 .58647 L .59628 .58627 L p .75 .309 0 r
F P
0 g
s
.45484 .58536 m .44846 .58199 L .44689 .58311 L p .964 .788 .617 r
F P
0 g
s
.57371 .44214 m .57735 .44434 L .58002 .44337 L p .526 .218 .388 r
F P
0 g
s
.54735 .51802 m .55202 .52096 L .55268 .5208 L p 0 .116 .663 r
F P
0 g
s
.84029 .48416 m .78375 .48924 L .79103 .48498 L p .639 .731 .915 r
F P
0 g
s
.78614 .46992 m .79103 .48498 L .78375 .48924 L p .638 .727 .913 r
F P
0 g
s
.78375 .48924 m .77667 .46775 L .78614 .46992 L p .638 .727 .913 r
F P
0 g
s
.78375 .48924 m .84029 .48416 L .83209 .48838 L p .642 .725 .909 r
F P
0 g
s
.77667 .46775 m .78375 .48924 L .77639 .48661 L p .622 .717 .915 r
F P
0 g
s
.34115 .50134 m .31814 .49757 L .31317 .49686 L p .539 .782 .988 r
F P
0 g
s
.61325 .44117 m .61878 .44314 L .62205 .44361 L p .43 0 0 r
F P
0 g
s
.43609 .52922 m .43418 .53241 L .43529 .53442 L p .858 .439 .227 r
F P
0 g
s
.61545 .61908 m .61929 .63381 L .61772 .63009 L p 0 .009 .583 r
F P
0 g
s
.61929 .63381 m .63007 .6463 L .62825 .64679 L p .185 .279 .728 r
F P
0 g
s
.6177 .62316 m .62038 .63347 L .61929 .63381 L p 0 .21 .725 r
F P
0 g
s
.61929 .63381 m .61545 .61908 L .6177 .62316 L p 0 .21 .725 r
F P
0 g
s
.63007 .6463 m .61929 .63381 L .62038 .63347 L p 0 .208 .723 r
F P
0 g
s
.41508 .5161 m .42465 .52108 L .42658 .52184 L p .561 0 0 r
F P
0 g
s
.42658 .52184 m .41291 .51472 L .41508 .5161 L p .561 0 0 r
F P
0 g
s
.42645 .5249 m .42658 .52184 L .42465 .52108 L p .725 .195 0 r
F P
0 g
s
.428 .52576 m .42808 .52361 L .42658 .52184 L p .771 .263 0 r
F P
0 g
s
.42658 .52184 m .42645 .5249 L .428 .52576 L p .771 .263 0 r
F P
0 g
s
.55923 .53463 m .56167 .53845 L .56325 .54073 L p 0 0 .454 r
F P
0 g
s
.56325 .54073 m .55976 .53527 L .55923 .53463 L p 0 0 .454 r
F P
0 g
s
.56968 .54982 m .56385 .54164 L .56325 .54073 L p .602 .152 0 r
F P
0 g
s
.56325 .54073 m .57157 .55241 L .56968 .54982 L p .602 .152 0 r
F P
0 g
s
.55976 .53527 m .56325 .54073 L .56385 .54164 L p 0 0 .391 r
F P
0 g
s
.57157 .55241 m .56325 .54073 L .56488 .54294 L p .657 .191 0 r
F P
0 g
s
.39193 .50763 m .39334 .50721 L .39667 .50803 L p .09 .592 .895 r
F P
0 g
s
.31826 .49693 m .34122 .50096 L .34615 .50171 L p .536 .779 .988 r
F P
0 g
s
.34615 .50171 m .31334 .49595 L .31826 .49693 L p .536 .779 .988 r
F P
0 g
s
.38114 .16848 m .41108 .22251 L .41831 .23355 L p .655 .653 .836 r
F P
0 g
s
.41831 .23355 m .37553 .15634 L .38114 .16848 L p .655 .653 .836 r
F P
0 g
s
.42585 .21753 m .41477 .22124 L .41831 .23355 L p .659 .654 .834 r
F P
0 g
s
.41831 .23355 m .43411 .2283 L .42585 .21753 L p .659 .654 .834 r
F P
0 g
s
.37553 .15634 m .41831 .23355 L .41477 .22124 L p .659 .654 .834 r
F P
0 g
s
.61772 .63009 m .61503 .61979 L .61545 .61908 L p 0 .009 .583 r
F P
0 g
s
.54143 .48073 m .54684 .47955 L .54799 .47745 L p .348 .241 .589 r
F P
0 g
s
.59299 .43912 m .59723 .44133 L .60022 .44109 L p .542 .117 .184 r
F P
0 g
s
.45408 .58942 m .45104 .60053 L .45167 .60377 L p .958 .817 .662 r
F P
0 g
s
.54742 .48696 m .541 .49422 L .5422 .49376 L p .277 .253 .651 r
F P
0 g
s
.54392 .49745 m .5422 .49376 L .541 .49422 L p .292 .293 .689 r
F P
0 g
s
.541 .49422 m .54345 .49949 L .54392 .49745 L p .292 .293 .689 r
F P
0 g
s
.54644 .4862 m .54195 .49129 L .541 .49422 L p .172 .103 .531 r
F P
0 g
s
.541 .49422 m .54742 .48696 L .54644 .4862 L p .172 .103 .531 r
F P
0 g
s
.4463 .61972 m .4516 .60739 L .45167 .60377 L p .926 .803 .704 r
F P
0 g
s
.42145 .67066 m .42619 .67553 L .42806 .6714 L p .874 .8 .774 r
F P
0 g
s
.40576 .69825 m .42282 .67975 L .42619 .67553 L p .842 .79 .801 r
F P
0 g
s
.42619 .67553 m .40182 .70196 L .40576 .69825 L p .842 .79 .801 r
F P
0 g
s
.41846 .6753 m .42179 .6787 L .42619 .67553 L p .848 .803 .807 r
F P
0 g
s
.42619 .67553 m .42145 .67066 L .41846 .6753 L p .848 .803 .807 r
F P
0 g
s
.40182 .70196 m .42619 .67553 L .42179 .6787 L p .848 .803 .807 r
F P
0 g
s
.39893 .7088 m .37457 .73079 L .36901 .7352 L p .814 .792 .832 r
F P
0 g
s
.56488 .54294 m .57071 .55111 L .57157 .55241 L p .657 .191 0 r
F P
0 g
s
.35921 .73902 m .36095 .74053 L .36901 .7352 L p .786 .793 .858 r
F P
0 g
s
.39855 .22751 m .36606 .17466 L .36158 .16196 L p .649 .65 .838 r
F P
0 g
s
.54676 .51554 m .54636 .50633 L .54545 .50345 L p 0 .039 .578 r
F P
0 g
s
.42806 .6714 m .42475 .66798 L .42145 .67066 L p .874 .8 .774 r
F P
0 g
s
.36901 .7352 m .40382 .70379 L .39893 .7088 L p .814 .792 .832 r
F P
0 g
s
.351 .50079 m .35058 .50111 L .34663 .50048 L p .472 .773 .997 r
F P
0 g
s
.24022 .8004 m .29577 .77014 L .30617 .76219 L p .759 .798 .885 r
F P
0 g
s
.30617 .76219 m .22675 .80546 L .24022 .8004 L p .759 .798 .885 r
F P
0 g
s
.6068 .60555 m .60184 .59634 L .60139 .59564 L p .676 .288 0 r
F P
0 g
s
.60139 .59564 m .60847 .6088 L .6068 .60555 L p .676 .288 0 r
F P
0 g
s
.39827 .7082 m .3739 .73019 L .36901 .7352 L p .814 .792 .832 r
F P
0 g
s
.36901 .7352 m .40382 .70379 L .39827 .7082 L p .814 .792 .832 r
F P
0 g
s
.36654 .73304 m .36901 .7352 L .3739 .73019 L p .814 .792 .832 r
F P
0 g
s
.36901 .7352 m .36654 .73304 L .35921 .73902 L p .786 .793 .858 r
F P
0 g
s
.61503 .61979 m .61015 .61259 L .60847 .6088 L p 0 .014 .587 r
F P
0 g
s
.60847 .6088 m .61545 .61908 L .61503 .61979 L p 0 .014 .587 r
F P
0 g
s
.60357 .59922 m .60853 .60844 L .60847 .6088 L p 0 0 .496 r
F P
0 g
s
.60847 .6088 m .60139 .59564 L .60357 .59922 L p 0 0 .496 r
F P
0 g
s
.61545 .61908 m .60847 .6088 L .60853 .60844 L p 0 0 .488 r
F P
0 g
s
.30555 .499 m .27555 .4949 L .26889 .49465 L p .62 .774 .954 r
F P
0 g
s
.40716 .69953 m .40576 .69825 L .40182 .70196 L p .842 .79 .801 r
F P
0 g
s
.40182 .70196 m .40382 .70379 L .40716 .69953 L p .842 .79 .801 r
F P
0 g
s
.55954 .45215 m .55298 .46144 L .5524 .46378 L p .468 .232 .472 r
F P
0 g
s
.5524 .46378 m .56178 .45049 L .55954 .45215 L p .468 .232 .472 r
F P
0 g
s
.39686 .70692 m .39827 .7082 L .40382 .70379 L p .814 .792 .832 r
F P
0 g
s
.40382 .70379 m .40182 .70196 L .39686 .70692 L p .814 .792 .832 r
F P
0 g
s
.57493 .55581 m .57318 .55388 L .57383 .55494 L p .686 .207 0 r
F P
0 g
s
.57383 .55494 m .57633 .5577 L .57493 .55581 L p .686 .207 0 r
F P
0 g
s
.44362 .59695 m .45167 .60377 L .45104 .60053 L p .962 .818 .655 r
F P
0 g
s
.45167 .60377 m .44409 .62139 L .4463 .61972 L p .926 .803 .704 r
F P
0 g
s
.44376 .60051 m .4494 .60528 L .45167 .60377 L p .947 .835 .7 r
F P
0 g
s
.45167 .60377 m .44362 .59695 L .44376 .60051 L p .947 .835 .7 r
F P
0 g
s
.44409 .62139 m .45167 .60377 L .4494 .60528 L p .948 .839 .702 r
F P
0 g
s
.3739 .73019 m .37217 .72867 L .36654 .73304 L p .814 .792 .832 r
F P
0 g
s
.3215 .7637 m .3154 .75793 L .30617 .76219 L p .788 .801 .863 r
F P
0 g
s
.31884 .49548 m .34182 .49952 L .34663 .50048 L p .536 .779 .987 r
F P
0 g
s
.34663 .50048 m .3138 .49471 L .31884 .49548 L p .536 .779 .987 r
F P
0 g
s
.34723 .50002 m .34663 .50048 L .34182 .49952 L p .472 .774 .997 r
F P
0 g
s
.34663 .50048 m .34723 .50002 L .351 .50079 L p .472 .773 .997 r
F P
0 g
s
.77639 .48661 m .77139 .47159 L .77667 .46775 L p .622 .717 .915 r
F P
0 g
s
.29209 .76627 m .2364 .79662 L .22675 .80546 L p .761 .809 .891 r
F P
0 g
s
.22675 .80546 m .30617 .76219 L .29209 .76627 L p .761 .809 .891 r
F P
0 g
s
.20956 .78721 m .22675 .80546 L .2364 .79662 L p .761 .809 .891 r
F P
0 g
s
.66277 .69861 m .64577 .68439 L .64397 .67865 L p .471 .498 .805 r
F P
0 g
s
.42475 .66798 m .43687 .65223 L .43878 .64814 L p .874 .799 .773 r
F P
0 g
s
.56796 .45238 m .56178 .45049 L .56136 .45258 L p .429 .166 .412 r
F P
0 g
s
.55479 .46188 m .56136 .45258 L .56178 .45049 L p .362 .109 .389 r
F P
0 g
s
.56178 .45049 m .5524 .46378 L .55479 .46188 L p .362 .109 .389 r
F P
0 g
s
.56892 .45065 m .56458 .44933 L .56178 .45049 L p .441 .102 .294 r
F P
0 g
s
.56178 .45049 m .56796 .45238 L .56892 .45065 L p .441 .102 .294 r
F P
0 g
s
.43233 .6409 m .43878 .64814 L .4396 .64409 L p .91 .816 .742 r
F P
0 g
s
.43878 .64814 m .42145 .67066 L .42475 .66798 L p .874 .799 .773 r
F P
0 g
s
.43069 .6453 m .43521 .65037 L .43878 .64814 L p .885 .822 .78 r
F P
0 g
s
.43878 .64814 m .43233 .6409 L .43069 .6453 L p .885 .822 .78 r
F P
0 g
s
.42145 .67066 m .43878 .64814 L .43521 .65037 L p .885 .822 .78 r
F P
0 g
s
.41023 .51366 m .39887 .50898 L .39667 .50803 L p 0 .372 .719 r
F P
0 g
s
.39667 .50803 m .41291 .51472 L .41023 .51366 L p 0 .372 .719 r
F P
0 g
s
.42465 .52108 m .42456 .52322 L .42645 .5249 L p .725 .195 0 r
F P
0 g
s
.42179 .6787 m .40471 .69721 L .40182 .70196 L p .848 .803 .807 r
F P
0 g
s
.69269 .46248 m .67719 .46331 L .67258 .46135 L p .532 .675 .929 r
F P
0 g
s
.54276 .50123 m .54466 .50456 L .54545 .50345 L p .2 .248 .688 r
F P
0 g
s
.54545 .50345 m .54273 .49869 L .54276 .50123 L p .2 .248 .688 r
F P
0 g
s
.4396 .64409 m .43509 .63902 L .43233 .6409 L p .91 .816 .742 r
F P
0 g
s
.5422 .49376 m .5467 .48868 L .54742 .48696 L p .277 .253 .651 r
F P
0 g
s
.34881 .49752 m .37421 .50343 L .37018 .50284 L p .477 .758 .992 r
F P
0 g
s
.35305 .49793 m .37084 .50208 L .37421 .50343 L p .482 .759 .991 r
F P
0 g
s
.37421 .50343 m .34881 .49752 L .35305 .49793 L p .482 .759 .991 r
F P
0 g
s
.37684 .50113 m .37421 .50343 L .37084 .50208 L p .399 .733 .991 r
F P
0 g
s
.37947 .50239 m .37762 .504 L .37421 .50343 L p .391 .719 .988 r
F P
0 g
s
.37421 .50343 m .37684 .50113 L .37947 .50239 L p .391 .719 .988 r
F P
0 g
s
.58269 .56805 m .57829 .56047 L .57633 .5577 L p .77 .303 0 r
F P
0 g
s
.57633 .5577 m .58262 .56852 L .58269 .56805 L p .77 .303 0 r
F P
0 g
s
.57519 .55702 m .57694 .55895 L .57633 .5577 L p .766 .299 0 r
F P
0 g
s
.57633 .5577 m .57383 .55494 L .57519 .55702 L p .766 .299 0 r
F P
0 g
s
.58262 .56852 m .57633 .5577 L .57694 .55895 L p .764 .299 0 r
F P
0 g
s
.54726 .49081 m .54392 .49745 L .54345 .49949 L p .219 .22 .647 r
F P
0 g
s
.54345 .49949 m .54822 .49001 L .54726 .49081 L p .219 .22 .647 r
F P
0 g
s
.39946 .50902 m .41084 .51372 L .41291 .51472 L p 0 .457 .81 r
F P
0 g
s
.41291 .51472 m .39667 .50803 L .39946 .50902 L p 0 .457 .81 r
F P
0 g
s
.41467 .51574 m .41291 .51472 L .41084 .51372 L p .339 0 0 r
F P
0 g
s
.41632 .51681 m .41508 .5161 L .41291 .51472 L p 0 .19 .613 r
F P
0 g
s
.41291 .51472 m .41467 .51574 L .41632 .51681 L p 0 .19 .613 r
F P
0 g
s
.37018 .50284 m .35241 .4987 L .34881 .49752 L p .477 .758 .992 r
F P
0 g
s
.34182 .49952 m .34224 .4992 L .34723 .50002 L p .472 .774 .997 r
F P
0 g
s
.69474 .46015 m .67258 .46135 L .67408 .4594 L p .511 .707 .96 r
F P
0 g
s
.66614 .45177 m .67408 .4594 L .67258 .46135 L p .513 .712 .961 r
F P
0 g
s
.67258 .46135 m .66122 .45046 L .66614 .45177 L p .513 .712 .961 r
F P
0 g
s
.67258 .46135 m .69474 .46015 L .69269 .46248 L p .532 .675 .929 r
F P
0 g
s
.66122 .45046 m .67258 .46135 L .6685 .45963 L p .411 .665 .964 r
F P
0 g
s
.44135 .23596 m .46021 .23108 L .46109 .22129 L p .664 .635 .811 r
F P
0 g
s
.46109 .22129 m .43411 .2283 L .44135 .23596 L p .664 .635 .811 r
F P
0 g
s
.35241 .4987 m .3513 .50045 L .34723 .50002 L p .535 .768 .983 r
F P
0 g
s
.31448 .49388 m .34723 .50002 L .34224 .4992 L p .534 .776 .987 r
F P
0 g
s
.31966 .49435 m .3426 .49864 L .34723 .50002 L p .574 .773 .973 r
F P
0 g
s
.34723 .50002 m .31448 .49388 L .31966 .49435 L p .574 .773 .973 r
F P
0 g
s
.34881 .49752 m .34723 .50002 L .3426 .49864 L p .537 .771 .984 r
F P
0 g
s
.34723 .50002 m .34881 .49752 L .35241 .4987 L p .535 .768 .983 r
F P
0 g
s
.70709 .47248 m .72895 .47099 L .73511 .4731 L p .586 .707 .927 r
F P
0 g
s
.21222 .48668 m .21033 .49703 L .21912 .4965 L p .645 .763 .934 r
F P
0 g
s
.45104 .60053 m .44541 .59574 L .44362 .59695 L p .962 .818 .655 r
F P
0 g
s
.6685 .45963 m .66055 .45201 L .66122 .45046 L p .411 .665 .964 r
F P
0 g
s
.56385 .54164 m .56142 .53783 L .55976 .53527 L p 0 0 .391 r
F P
0 g
s
.37217 .72867 m .39686 .70692 L .40182 .70196 L p .814 .792 .832 r
F P
0 g
s
.40182 .70196 m .36654 .73304 L .37217 .72867 L p .814 .792 .832 r
F P
0 g
s
.56136 .45258 m .56569 .4539 L .56796 .45238 L p .429 .166 .412 r
F P
0 g
s
.5467 .48868 m .54726 .49081 L .54822 .49001 L p .163 .126 .566 r
F P
0 g
s
.54822 .49001 m .54742 .48696 L .5467 .48868 L p .163 .126 .566 r
F P
0 g
s
.54751 .48919 m .54273 .49869 L .54371 .49786 L p .219 .22 .647 r
F P
0 g
s
.54561 .5012 m .54371 .49786 L .54273 .49869 L p .249 .272 .689 r
F P
0 g
s
.54273 .49869 m .54545 .50345 L .54561 .5012 L p .249 .272 .689 r
F P
0 g
s
.40565 .22461 m .37439 .17112 L .3685 .15909 L p .653 .652 .836 r
F P
0 g
s
.64728 .66158 m .64397 .67865 L .642 .67373 L p .304 .395 .791 r
F P
0 g
s
.64397 .67865 m .66831 .69898 L .66277 .69861 L p .471 .498 .805 r
F P
0 g
s
.65058 .66704 m .64824 .67898 L .64397 .67865 L p .39 .483 .834 r
F P
0 g
s
.64397 .67865 m .64728 .66158 L .65058 .66704 L p .39 .483 .834 r
F P
0 g
s
.66831 .69898 m .64397 .67865 L .64824 .67898 L p .39 .483 .834 r
F P
0 g
s
.62038 .63347 m .62793 .64222 L .63007 .6463 L p 0 .208 .723 r
F P
0 g
s
.34224 .4992 m .31931 .4949 L .31448 .49388 L p .534 .776 .987 r
F P
0 g
s
.39643 .69638 m .40182 .70196 L .40471 .69721 L p .848 .803 .807 r
F P
0 g
s
.39185 .70181 m .39563 .7057 L .40182 .70196 L p .818 .803 .837 r
F P
0 g
s
.40182 .70196 m .39643 .69638 L .39185 .70181 L p .818 .803 .837 r
F P
0 g
s
.36654 .73304 m .40182 .70196 L .39563 .7057 L p .819 .803 .837 r
F P
0 g
s
.21912 .4965 m .22048 .48926 L .21222 .48668 L p .645 .763 .934 r
F P
0 g
s
.39563 .7057 m .37093 .72747 L .36654 .73304 L p .819 .803 .837 r
F P
0 g
s
.35991 .72643 m .36654 .73304 L .37093 .72747 L p .819 .804 .837 r
F P
0 g
s
.35299 .73292 m .35765 .73753 L .36654 .73304 L p .789 .802 .863 r
F P
0 g
s
.36654 .73304 m .35991 .72643 L .35299 .73292 L p .789 .802 .863 r
F P
0 g
s
.55068 .46583 m .5476 .4754 L .54799 .47745 L p .369 .185 .497 r
F P
0 g
s
.54799 .47745 m .5524 .46378 L .55068 .46583 L p .369 .185 .497 r
F P
0 g
s
.57735 .44434 m .56892 .45065 L .56796 .45238 L p .488 .151 .321 r
F P
0 g
s
.56796 .45238 m .58002 .44337 L .57735 .44434 L p .488 .151 .321 r
F P
0 g
s
.43521 .65037 m .42307 .66614 L .42145 .67066 L p .885 .822 .78 r
F P
0 g
s
.4494 .60528 m .44409 .61762 L .44409 .62139 L p .948 .839 .702 r
F P
0 g
s
.40471 .69721 m .40095 .6933 L .39643 .69638 L p .848 .803 .807 r
F P
0 g
s
.40746 .22391 m .37622 .17039 L .3685 .15909 L p .655 .653 .836 r
F P
0 g
s
.31814 .49757 m .31826 .49693 L .31334 .49595 L p .577 .777 .974 r
F P
0 g
s
.31334 .49595 m .31317 .49686 L .31814 .49757 L p .577 .777 .974 r
F P
0 g
s
.58668 .44527 m .58002 .44337 L .57924 .44485 L p .431 .051 .215 r
F P
0 g
s
.5708 .45116 m .57924 .44485 L .58002 .44337 L p .352 0 .174 r
F P
0 g
s
.58002 .44337 m .56796 .45238 L .5708 .45116 L p .352 0 .174 r
F P
0 g
s
.58776 .44426 m .58309 .44293 L .58002 .44337 L p .421 0 .018 r
F P
0 g
s
.58002 .44337 m .58668 .44527 L .58776 .44426 L p .421 0 .018 r
F P
0 g
s
.60853 .60844 m .61341 .61563 L .61545 .61908 L p 0 0 .488 r
F P
0 g
s
.57071 .55111 m .57229 .55288 L .57383 .55494 L p .672 .197 0 r
F P
0 g
s
.66055 .45201 m .64978 .45209 L .64583 .45058 L p .416 .671 .966 r
F P
0 g
s
.37084 .50208 m .37267 .50046 L .37684 .50113 L p .399 .733 .991 r
F P
0 g
s
.55943 .4632 m .5524 .46378 L .55276 .46544 L p .312 .101 .423 r
F P
0 g
s
.54968 .47502 m .55276 .46544 L .5524 .46378 L p .229 .052 .421 r
F P
0 g
s
.5524 .46378 m .54799 .47745 L .54968 .47502 L p .229 .052 .421 r
F P
0 g
s
.55972 .46147 m .55479 .46188 L .5524 .46378 L p .287 .005 .299 r
F P
0 g
s
.5524 .46378 m .55943 .4632 L .55972 .46147 L p .287 .005 .299 r
F P
0 g
s
.3426 .49864 m .34369 .49689 L .34881 .49752 L p .537 .771 .984 r
F P
0 g
s
.57694 .55895 m .58135 .56652 L .58262 .56852 L p .764 .299 0 r
F P
0 g
s
.41084 .51372 m .41207 .51442 L .41467 .51574 L p .339 0 0 r
F P
0 g
s
.66122 .45046 m .64583 .45058 L .64611 .44952 L p .347 .707 .984 r
F P
0 g
s
.637 .44527 m .64611 .44952 L .64583 .45058 L p .366 .726 .988 r
F P
0 g
s
.64583 .45058 m .63282 .44451 L .637 .44527 L p .366 .726 .988 r
F P
0 g
s
.64583 .45058 m .66122 .45046 L .66055 .45201 L p .416 .671 .966 r
F P
0 g
s
.63282 .44451 m .64583 .45058 L .64224 .44944 L p .127 .598 .919 r
F P
0 g
s
.642 .67373 m .64429 .66177 L .64728 .66158 L p .304 .395 .791 r
F P
0 g
s
.37093 .72747 m .36631 .72283 L .35991 .72643 L p .819 .804 .837 r
F P
0 g
s
.27047 .48979 m .31317 .49686 L .30682 .49564 L p .603 .773 .962 r
F P
0 g
s
.30694 .495 m .30682 .49564 L .31317 .49686 L p .577 .777 .974 r
F P
0 g
s
.31317 .49686 m .31334 .49595 L .30694 .495 L p .577 .777 .974 r
F P
0 g
s
.27668 .4915 m .30656 .49644 L .31317 .49686 L p .616 .769 .953 r
F P
0 g
s
.31317 .49686 m .27047 .48979 L .27668 .4915 L p .616 .769 .953 r
F P
0 g
s
.64224 .44944 m .63313 .44519 L .63282 .44451 L p .127 .598 .919 r
F P
0 g
s
.79103 .48498 m .83068 .48141 L .84029 .48416 L p .639 .731 .915 r
F P
0 g
s
.39981 .162 m .42585 .21753 L .43411 .2283 L p .659 .654 .834 r
F P
0 g
s
.43411 .2283 m .39695 .14892 L .39981 .162 L p .659 .654 .834 r
F P
0 g
s
.45229 .21042 m .43336 .21537 L .43411 .2283 L p .667 .659 .832 r
F P
0 g
s
.43411 .2283 m .46109 .22129 L .45229 .21042 L p .667 .659 .832 r
F P
0 g
s
.39695 .14892 m .43411 .2283 L .43336 .21537 L p .667 .658 .832 r
F P
0 g
s
.54371 .49786 m .54705 .49122 L .54751 .48919 L p .219 .22 .647 r
F P
0 g
s
.39334 .50721 m .37947 .50239 L .37684 .50113 L p .258 .659 .965 r
F P
0 g
s
.37684 .50113 m .39667 .50803 L .39334 .50721 L p .258 .659 .965 r
F P
0 g
s
.59723 .44133 m .58776 .44426 L .58668 .44527 L p .485 .016 .066 r
F P
0 g
s
.58668 .44527 m .60022 .44109 L .59723 .44133 L p .485 .016 .066 r
F P
0 g
s
.57383 .55494 m .57157 .55241 L .57071 .55111 L p .672 .197 0 r
F P
0 g
s
.57939 .56433 m .57455 .55631 L .57383 .55494 L p .754 .29 0 r
F P
0 g
s
.57383 .55494 m .58074 .5664 L .57939 .56433 L p .754 .29 0 r
F P
0 g
s
.57157 .55241 m .57383 .55494 L .57455 .55631 L p .751 .289 0 r
F P
0 g
s
.58003 .56504 m .57519 .55702 L .57383 .55494 L p .76 .294 0 r
F P
0 g
s
.57383 .55494 m .58074 .5664 L .58003 .56504 L p .76 .294 0 r
F P
0 g
s
.43509 .63902 m .44332 .62537 L .44409 .62139 L p .91 .816 .742 r
F P
0 g
s
.60818 .4427 m .60022 .44109 L .59938 .44182 L p .358 0 0 r
F P
0 g
s
.5899 .44475 m .59938 .44182 L .60022 .44109 L p .266 0 0 r
F P
0 g
s
.60022 .44109 m .58668 .44527 L .5899 .44475 L p .266 0 0 r
F P
0 g
s
.60907 .4425 m .6035 .44137 L .60022 .44109 L p .249 0 0 r
F P
0 g
s
.60022 .44109 m .60818 .4427 L .60907 .4425 L p .249 0 0 r
F P
0 g
s
.63313 .44519 m .62559 .44456 L .62205 .44361 L p .16 .628 .93 r
F P
0 g
s
.60818 .4427 m .62205 .44361 L .61878 .44314 L p .321 0 0 r
F P
0 g
s
.61184 .44284 m .62155 .44348 L .62205 .44361 L p .043 .609 .775 r
F P
0 g
s
.62205 .44361 m .60818 .4427 L .61184 .44284 L p .043 .609 .775 r
F P
0 g
s
.62205 .44361 m .63282 .44451 L .63313 .44519 L p .16 .628 .93 r
F P
0 g
s
.61878 .44314 m .60907 .4425 L .60818 .4427 L p .321 0 0 r
F P
0 g
s
.38035 .50184 m .39424 .50667 L .39667 .50803 L p .302 .676 .975 r
F P
0 g
s
.39667 .50803 m .37684 .50113 L .38035 .50184 L p .302 .676 .975 r
F P
0 g
s
.39975 .5069 m .39667 .50803 L .39424 .50667 L p .14 .587 .927 r
F P
0 g
s
.40163 .50824 m .39946 .50902 L .39667 .50803 L p .125 .551 .92 r
F P
0 g
s
.39667 .50803 m .39975 .5069 L .40163 .50824 L p .125 .551 .92 r
F P
0 g
s
.65373 .22078 m .61536 .20975 L .60191 .21886 L p .723 .705 .833 r
F P
0 g
s
.22048 .48926 m .26012 .49483 L .26889 .49465 L p .638 .764 .939 r
F P
0 g
s
.2364 .79662 m .22448 .78378 L .20956 .78721 L p .761 .809 .891 r
F P
0 g
s
.54828 .49233 m .54545 .50345 L .54626 .5029 L p 0 0 .457 r
F P
0 g
s
.54941 .50837 m .54626 .5029 L .54545 .50345 L p 0 .019 .544 r
F P
0 g
s
.54545 .50345 m .54995 .51128 L .54941 .50837 L p 0 .019 .544 r
F P
0 g
s
.54759 .49341 m .54561 .5012 L .54545 .50345 L p .154 .185 .641 r
F P
0 g
s
.54545 .50345 m .54828 .49233 L .54759 .49341 L p .154 .185 .641 r
F P
0 g
s
.54995 .51128 m .54545 .50345 L .54636 .50633 L p 0 0 .528 r
F P
0 g
s
.43691 .61314 m .44409 .62139 L .44409 .61762 L p .951 .841 .699 r
F P
0 g
s
.44409 .62139 m .43233 .6409 L .43509 .63902 L p .91 .816 .742 r
F P
0 g
s
.43627 .61721 m .4413 .62298 L .44409 .62139 L p .929 .852 .745 r
F P
0 g
s
.44409 .62139 m .43691 .61314 L .43627 .61721 L p .929 .852 .745 r
F P
0 g
s
.43233 .6409 m .44409 .62139 L .4413 .62298 L p .929 .853 .746 r
F P
0 g
s
.27555 .4949 m .27668 .4915 L .27047 .48979 L p .629 .767 .946 r
F P
0 g
s
.27047 .48979 m .26889 .49465 L .27555 .4949 L p .629 .767 .946 r
F P
0 g
s
.34583 .18432 m .32516 .1959 L .31236 .18771 L p .641 .647 .841 r
F P
0 g
s
.57924 .44485 m .5839 .44619 L .58668 .44527 L p .431 .051 .215 r
F P
0 g
s
.40095 .6933 m .41846 .6753 L .42145 .67066 L p .848 .803 .807 r
F P
0 g
s
.21222 .48668 m .26889 .49465 L .26068 .49263 L p .637 .764 .94 r
F P
0 g
s
.26177 .48922 m .26068 .49263 L .26889 .49465 L p .629 .766 .946 r
F P
0 g
s
.26889 .49465 m .27047 .48979 L .26177 .48922 L p .629 .766 .946 r
F P
0 g
s
.26889 .49465 m .21222 .48668 L .22048 .48926 L p .638 .764 .939 r
F P
0 g
s
.30682 .49564 m .27693 .49069 L .27047 .48979 L p .603 .773 .962 r
F P
0 g
s
.55276 .46544 m .55769 .46504 L .55943 .4632 L p .312 .101 .423 r
F P
0 g
s
.2771 .48976 m .30694 .495 L .31334 .49595 L p .601 .772 .962 r
F P
0 g
s
.31334 .49595 m .27072 .48846 L .2771 .48976 L p .601 .772 .962 r
F P
0 g
s
.67408 .4594 m .68961 .45855 L .69474 .46015 L p .511 .707 .96 r
F P
0 g
s
.41477 .22124 m .38485 .16716 L .37553 .15634 L p .659 .654 .834 r
F P
0 g
s
.58666 .57272 m .58269 .56805 L .58262 .56852 L p .776 .319 0 r
F P
0 g
s
.58262 .56852 m .58829 .5752 L .58666 .57272 L p .776 .319 0 r
F P
0 g
s
.41477 .66263 m .42145 .67066 L .42307 .66614 L p .886 .823 .78 r
F P
0 g
s
.42145 .67066 m .39643 .69638 L .40095 .6933 L p .848 .803 .807 r
F P
0 g
s
.41195 .6676 m .41665 .67321 L .42145 .67066 L p .856 .824 .816 r
F P
0 g
s
.42145 .67066 m .41477 .66263 L .41195 .6676 L p .856 .824 .816 r
F P
0 g
s
.39643 .69638 m .42145 .67066 L .41665 .67321 L p .856 .823 .815 r
F P
0 g
s
.54636 .50633 m .54951 .51181 L .54995 .51128 L p 0 0 .528 r
F P
0 g
s
.54684 .47955 m .54644 .4862 L .54742 .48696 L p .22 .095 .488 r
F P
0 g
s
.54742 .48696 m .54799 .47745 L .54684 .47955 L p .22 .095 .488 r
F P
0 g
s
.44711 .55535 m .44606 .55177 L .44455 .55148 L p .945 .689 .518 r
F P
0 g
s
.44777 .55775 m .44749 .55652 L .44604 .55659 L p .947 .704 .538 r
F P
0 g
s
.44508 .54966 m .44276 .54421 L .44123 .54369 L p .941 .654 .468 r
F P
0 g
s
.44123 .54369 m .44455 .55148 L .44508 .54966 L p .941 .654 .468 r
F P
0 g
s
.44455 .55148 m .44604 .55659 L .44711 .55535 L p .945 .689 .518 r
F P
0 g
s
.44604 .55659 m .44644 .55835 L .44777 .55775 L p .947 .704 .538 r
F P
0 g
s
.44812 .55935 m .44791 .55831 L .44644 .55835 L p .949 .712 .547 r
F P
0 g
s
.44644 .55835 m .44673 .55983 L .44812 .55935 L p .949 .712 .547 r
F P
0 g
s
.44877 .56356 m .4483 .56039 L .44673 .55983 L p .951 .724 .558 r
F P
0 g
s
.31931 .4949 m .31884 .49548 L .3138 .49471 L p .575 .775 .974 r
F P
0 g
s
.44097 .54158 m .43682 .5351 L .43529 .53442 L p .928 .582 .356 r
F P
0 g
s
.43529 .53442 m .44123 .54369 L .44097 .54158 L p .928 .582 .356 r
F P
0 g
s
.44673 .55983 m .4474 .56437 L .44877 .56356 L p .951 .724 .558 r
F P
0 g
s
.44409 .61762 m .43907 .61184 L .43691 .61314 L p .951 .841 .699 r
F P
0 g
s
.57455 .55631 m .57297 .55454 L .57157 .55241 L p .751 .289 0 r
F P
0 g
s
.44922 .57112 m .44895 .5657 L .4474 .56437 L p .957 .748 .58 r
F P
0 g
s
.59473 .58592 m .59037 .57838 L .58829 .5752 L p .707 .262 0 r
F P
0 g
s
.58829 .5752 m .59452 .58597 L .59473 .58592 L p .707 .262 0 r
F P
0 g
s
.58448 .57121 m .58845 .57588 L .58829 .5752 L p .743 .279 0 r
F P
0 g
s
.58829 .5752 m .58262 .56852 L .58448 .57121 L p .743 .279 0 r
F P
0 g
s
.59452 .58597 m .58829 .5752 L .58845 .57588 L p .743 .283 0 r
F P
0 g
s
.42307 .66614 m .4184 .6605 L .41477 .66263 L p .886 .823 .78 r
F P
0 g
s
.64824 .67898 m .66531 .69322 L .66831 .69898 L p .39 .483 .834 r
F P
0 g
s
.55473 .47295 m .54799 .47745 L .5488 .47795 L p .142 0 .392 r
F P
0 g
s
.5484 .48461 m .5488 .47795 L .54799 .47745 L p .105 .003 .443 r
F P
0 g
s
.54799 .47745 m .54742 .48696 L .5484 .48461 L p .105 .003 .443 r
F P
0 g
s
.5544 .47186 m .54968 .47502 L .54799 .47745 L p .078 0 .282 r
F P
0 g
s
.54799 .47745 m .55473 .47295 L .5544 .47186 L p .078 0 .282 r
F P
0 g
s
.27768 .48818 m .30754 .49343 L .3138 .49471 L p .601 .771 .962 r
F P
0 g
s
.3138 .49471 m .27115 .48721 L .27768 .48818 L p .601 .771 .962 r
F P
0 g
s
.31448 .49388 m .3138 .49471 L .30754 .49343 L p .575 .775 .974 r
F P
0 g
s
.3138 .49471 m .31448 .49388 L .31931 .4949 L p .575 .775 .974 r
F P
0 g
s
.31633 .49026 m .34881 .49752 L .34369 .49689 L p .568 .765 .971 r
F P
0 g
s
.32171 .49062 m .34446 .4957 L .34881 .49752 L p .569 .765 .971 r
F P
0 g
s
.34881 .49752 m .31633 .49026 L .32171 .49062 L p .569 .765 .971 r
F P
0 g
s
.35188 .49349 m .34881 .49752 L .34446 .4957 L p .531 .759 .98 r
F P
0 g
s
.35521 .49512 m .35305 .49793 L .34881 .49752 L p .526 .751 .978 r
F P
0 g
s
.34881 .49752 m .35188 .49349 L .35521 .49512 L p .526 .751 .978 r
F P
0 g
s
.59938 .44182 m .60495 .44295 L .60818 .4427 L p .358 0 0 r
F P
0 g
s
.43418 .53241 m .428 .52576 L .42645 .5249 L p .867 .423 .118 r
F P
0 g
s
.42645 .5249 m .43529 .53442 L .43418 .53241 L p .867 .423 .118 r
F P
0 g
s
.4474 .56437 m .44778 .57212 L .44922 .57112 L p .957 .748 .58 r
F P
0 g
s
.39424 .50667 m .39639 .50587 L .39975 .5069 L p .14 .587 .927 r
F P
0 g
s
.77139 .47159 m .74234 .47531 L .73511 .4731 L p .62 .712 .912 r
F P
0 g
s
.64611 .44952 m .65688 .44944 L .66122 .45046 L p .347 .707 .984 r
F P
0 g
s
.34369 .49689 m .32096 .49181 L .31633 .49026 L p .568 .765 .971 r
F P
0 g
s
.44846 .58199 m .44908 .57431 L .44778 .57212 L p .961 .779 .61 r
F P
0 g
s
.69702 .72333 m .67133 .7059 L .66831 .69898 L p .512 .555 .837 r
F P
0 g
s
.62155 .44348 m .62909 .44411 L .63282 .44451 L p 0 .552 .752 r
F P
0 g
s
.56569 .4539 m .55972 .46147 L .55943 .4632 L p .358 .063 .32 r
F P
0 g
s
.55943 .4632 m .56796 .45238 L .56569 .4539 L p .358 .063 .32 r
F P
0 g
s
.5661 .54583 m .56968 .54982 L .57157 .55241 L p .725 .267 0 r
F P
0 g
s
.57157 .55241 m .56647 .54671 L .5661 .54583 L p .725 .267 0 r
F P
0 g
s
.57704 .56178 m .5719 .55338 L .57157 .55241 L p .749 .288 0 r
F P
0 g
s
.57157 .55241 m .5789 .5644 L .57704 .56178 L p .749 .288 0 r
F P
0 g
s
.56647 .54671 m .57157 .55241 L .5719 .55338 L p .747 .295 0 r
F P
0 g
s
.5789 .5644 m .57157 .55241 L .57297 .55454 L p .757 .294 0 r
F P
0 g
s
.54626 .5029 m .54824 .49511 L .54828 .49233 L p 0 0 .457 r
F P
0 g
s
.31236 .18771 m .34189 .17104 L .34583 .18432 L p .641 .647 .841 r
F P
0 g
s
.26068 .49263 m .22099 .48704 L .21222 .48668 L p .637 .764 .94 r
F P
0 g
s
.44113 .54496 m .44346 .55042 L .44455 .55148 L p .945 .591 .202 r
F P
0 g
s
.44455 .55148 m .44123 .54369 L .44113 .54496 L p .945 .591 .202 r
F P
0 g
s
.43991 .55173 m .44455 .55148 L .44346 .55042 L p .96 .628 .256 r
F P
0 g
s
.44079 .5524 m .44404 .55222 L .44455 .55148 L p .978 .683 .314 r
F P
0 g
s
.44455 .55148 m .43991 .55173 L .44079 .5524 L p .978 .683 .314 r
F P
0 g
s
.44604 .55659 m .44455 .55148 L .44404 .55222 L p .974 .67 .307 r
F P
0 g
s
.4413 .62298 m .43306 .63664 L .43233 .6409 L p .929 .853 .746 r
F P
0 g
s
.3154 .75793 m .35299 .73292 L .35991 .72643 L p .788 .801 .863 r
F P
0 g
s
.35991 .72643 m .30617 .76219 L .3154 .75793 L p .788 .801 .863 r
F P
0 g
s
.43582 .53601 m .43998 .54251 L .44123 .54369 L p .864 .436 .008 r
F P
0 g
s
.44123 .54369 m .43529 .53442 L .43582 .53601 L p .864 .436 .008 r
F P
0 g
s
.43786 .54485 m .44123 .54369 L .43998 .54251 L p .911 .516 .116 r
F P
0 g
s
.43878 .54578 m .44113 .54496 L .44123 .54369 L p .946 .605 .194 r
F P
0 g
s
.44123 .54369 m .43786 .54485 L .43878 .54578 L p .946 .605 .194 r
F P
0 g
s
.41665 .67321 m .39911 .69123 L .39643 .69638 L p .856 .823 .815 r
F P
0 g
s
.44404 .55222 m .44508 .55581 L .44604 .55659 L p .974 .67 .307 r
F P
0 g
s
.44078 .55607 m .44604 .55659 L .44508 .55581 L p .98 .688 .334 r
F P
0 g
s
.44163 .55639 m .44531 .55675 L .44604 .55659 L p .987 .713 .363 r
F P
0 g
s
.44604 .55659 m .44078 .55607 L .44163 .55639 L p .987 .713 .363 r
F P
0 g
s
.44644 .55835 m .44604 .55659 L .44531 .55675 L p .984 .702 .352 r
F P
0 g
s
.46889 .2293 m .4956 .22505 L .49931 .21518 L p .678 .643 .808 r
F P
0 g
s
.49931 .21518 m .46109 .22129 L .46889 .2293 L p .678 .643 .808 r
F P
0 g
s
.44531 .55675 m .44559 .55799 L .44644 .55835 L p .984 .702 .352 r
F P
0 g
s
.44101 .55754 m .44644 .55835 L .44559 .55799 L p .987 .714 .368 r
F P
0 g
s
.44186 .55787 m .44567 .55843 L .44644 .55835 L p .99 .727 .383 r
F P
0 g
s
.44644 .55835 m .44101 .55754 L .44186 .55787 L p .99 .727 .383 r
F P
0 g
s
.44673 .55983 m .44644 .55835 L .44567 .55843 L p .988 .717 .373 r
F P
0 g
s
.57505 .45227 m .56796 .45238 L .56774 .45376 L p .285 0 .201 r
F P
0 g
s
.56176 .46134 m .56774 .45376 L .56796 .45238 L p .18 0 .174 r
F P
0 g
s
.56796 .45238 m .55943 .4632 L .56176 .46134 L p .18 0 .174 r
F P
0 g
s
.57577 .45108 m .5708 .45116 L .56796 .45238 L p .245 0 .015 r
F P
0 g
s
.56796 .45238 m .57505 .45227 L .57577 .45108 L p .245 0 .015 r
F P
0 g
s
.44567 .55843 m .44587 .55947 L .44673 .55983 L p .988 .717 .373 r
F P
0 g
s
.44117 .55877 m .44673 .55983 L .44587 .55947 L p .99 .728 .386 r
F P
0 g
s
.44208 .55955 m .44598 .56029 L .44673 .55983 L p .994 .747 .41 r
F P
0 g
s
.44673 .55983 m .44117 .55877 L .44208 .55955 L p .994 .747 .41 r
F P
0 g
s
.4474 .56437 m .44673 .55983 L .44598 .56029 L p .992 .739 .404 r
F P
0 g
s
.32096 .49181 m .31966 .49435 L .31448 .49388 L p .595 .766 .961 r
F P
0 g
s
.77667 .46775 m .73511 .4731 L .73958 .46946 L p .615 .725 .924 r
F P
0 g
s
.73222 .45718 m .73958 .46946 L .73511 .4731 L p .614 .723 .923 r
F P
0 g
s
.73511 .4731 m .72455 .45559 L .73222 .45718 L p .614 .723 .923 r
F P
0 g
s
.73511 .4731 m .77667 .46775 L .77139 .47159 L p .62 .712 .912 r
F P
0 g
s
.72455 .45559 m .73511 .4731 L .72895 .47099 L p .583 .708 .928 r
F P
0 g
s
.30754 .49343 m .30801 .49285 L .31448 .49388 L p .575 .775 .974 r
F P
0 g
s
.27191 .48597 m .31448 .49388 L .30801 .49285 L p .6 .77 .961 r
F P
0 g
s
.27861 .48653 m .30842 .49207 L .31448 .49388 L p .614 .766 .953 r
F P
0 g
s
.31448 .49388 m .27191 .48597 L .27861 .48653 L p .614 .766 .953 r
F P
0 g
s
.31633 .49026 m .31448 .49388 L .30842 .49207 L p .596 .768 .961 r
F P
0 g
s
.31448 .49388 m .31633 .49026 L .32096 .49181 L p .595 .766 .961 r
F P
0 g
s
.44598 .56029 m .44644 .56347 L .4474 .56437 L p .992 .739 .404 r
F P
0 g
s
.4415 .56251 m .4474 .56437 L .44644 .56347 L p .994 .747 .417 r
F P
0 g
s
.44243 .56385 m .44655 .56515 L .4474 .56437 L p .998 .781 .463 r
F P
0 g
s
.4474 .56437 m .4415 .56251 L .44243 .56385 L p .998 .781 .463 r
F P
0 g
s
.44778 .57212 m .4474 .56437 L .44655 .56515 L p .998 .779 .461 r
F P
0 g
s
.42773 .52653 m .43392 .5332 L .43529 .53442 L p .67 .168 0 r
F P
0 g
s
.43529 .53442 m .42645 .5249 L .42773 .52653 L p .67 .168 0 r
F P
0 g
s
.43388 .53602 m .43529 .53442 L .43392 .5332 L p .791 .321 0 r
F P
0 g
s
.43484 .53714 m .43582 .53601 L .43529 .53442 L p .841 .431 0 r
F P
0 g
s
.43529 .53442 m .43388 .53602 L .43484 .53714 L p .841 .431 0 r
F P
0 g
s
.42456 .52322 m .41632 .51681 L .41467 .51574 L p .617 .07 0 r
F P
0 g
s
.41467 .51574 m .42645 .5249 L .42456 .52322 L p .617 .07 0 r
F P
0 g
s
.57297 .55454 m .5781 .56293 L .5789 .5644 L p .757 .294 0 r
F P
0 g
s
.64429 .66177 m .63226 .65108 L .63007 .6463 L p .304 .395 .791 r
F P
0 g
s
.36631 .72283 m .39185 .70181 L .39643 .69638 L p .819 .803 .837 r
F P
0 g
s
.44778 .57212 m .44689 .58311 L .44846 .58199 L p .961 .779 .61 r
F P
0 g
s
.5488 .47795 m .55352 .4748 L .55473 .47295 L p .142 0 .392 r
F P
0 g
s
.8323 .45836 m .84029 .48416 L .83068 .48141 L p .636 .732 .917 r
F P
0 g
s
.37267 .50046 m .35521 .49512 L .35188 .49349 L p .467 .735 .986 r
F P
0 g
s
.35188 .49349 m .37684 .50113 L .37267 .50046 L p .467 .735 .986 r
F P
0 g
s
.35028 .72991 m .31261 .75497 L .30617 .76219 L p .792 .816 .871 r
F P
0 g
s
.30617 .76219 m .35991 .72643 L .35028 .72991 L p .792 .816 .871 r
F P
0 g
s
.29402 .74818 m .30617 .76219 L .31261 .75497 L p .792 .816 .871 r
F P
0 g
s
.2835 .75652 m .29209 .76627 L .30617 .76219 L p .761 .81 .892 r
F P
0 g
s
.30617 .76219 m .29402 .74818 L .2835 .75652 L p .761 .81 .892 r
F P
0 g
s
.58845 .57588 m .59281 .58343 L .59452 .58597 L p .743 .283 0 r
F P
0 g
s
.72895 .47099 m .72153 .45875 L .72455 .45559 L p .583 .708 .928 r
F P
0 g
s
.34446 .4957 m .34659 .49288 L .35188 .49349 L p .531 .759 .98 r
F P
0 g
s
.35631 .49399 m .3738 .49934 L .37684 .50113 L p .483 .738 .983 r
F P
0 g
s
.37684 .50113 m .35188 .49349 L .35631 .49399 L p .483 .738 .983 r
F P
0 g
s
.38092 .49784 m .37684 .50113 L .3738 .49934 L p .407 .709 .985 r
F P
0 g
s
.38322 .49954 m .38035 .50184 L .37684 .50113 L p .394 .685 .977 r
F P
0 g
s
.37684 .50113 m .38092 .49784 L .38322 .49954 L p .394 .685 .977 r
F P
0 g
s
.44655 .56515 m .44682 .57058 L .44778 .57212 L p .998 .779 .461 r
F P
0 g
s
.44159 .56889 m .44778 .57212 L .44682 .57058 L p .998 .781 .467 r
F P
0 g
s
.44239 .57088 m .44673 .57314 L .44778 .57212 L p .999 .822 .53 r
F P
0 g
s
.44778 .57212 m .44159 .56889 L .44239 .57088 L p .999 .822 .53 r
F P
0 g
s
.44689 .58311 m .44778 .57212 L .44673 .57314 L p .999 .823 .53 r
F P
0 g
s
.30801 .49285 m .27821 .48732 L .27191 .48597 L p .6 .77 .961 r
F P
0 g
s
.44541 .59574 m .4477 .58607 L .44689 .58311 L p .961 .811 .65 r
F P
0 g
s
.59954 .59269 m .59473 .58592 L .59452 .58597 L p .715 .278 0 r
F P
0 g
s
.62707 .63155 m .63007 .6463 L .62793 .64222 L p .001 .213 .725 r
F P
0 g
s
.63007 .6463 m .64728 .66158 L .64429 .66177 L p .304 .395 .791 r
F P
0 g
s
.63016 .636 m .63225 .64632 L .63007 .6463 L p .174 .361 .809 r
F P
0 g
s
.63007 .6463 m .62707 .63155 L .63016 .636 L p .174 .361 .809 r
F P
0 g
s
.64728 .66158 m .63007 .6463 L .63225 .64632 L p .175 .361 .809 r
F P
0 g
s
.55442 .22294 m .59245 .22685 L .60191 .21886 L p .715 .672 .807 r
F P
0 g
s
.38881 .68712 m .39643 .69638 L .39911 .69123 L p .856 .823 .815 r
F P
0 g
s
.39643 .69638 m .35991 .72643 L .36631 .72283 L p .819 .803 .837 r
F P
0 g
s
.38435 .69289 m .38971 .69936 L .39643 .69638 L p .824 .82 .845 r
F P
0 g
s
.39643 .69638 m .38881 .68712 L .38435 .69289 L p .824 .82 .845 r
F P
0 g
s
.35991 .72643 m .39643 .69638 L .38971 .69936 L p .825 .821 .846 r
F P
0 g
s
.55378 .5248 m .55471 .5268 L .55541 .52711 L p 0 .014 .588 r
F P
0 g
s
.55541 .52711 m .55409 .52425 L .55378 .5248 L p 0 .014 .588 r
F P
0 g
s
.41672 .51718 m .42497 .5236 L .42645 .5249 L p 0 .204 .673 r
F P
0 g
s
.42645 .5249 m .41467 .51574 L .41672 .51718 L p 0 .204 .673 r
F P
0 g
s
.42727 .52601 m .42645 .5249 L .42497 .5236 L p .518 0 0 r
F P
0 g
s
.42831 .52731 m .42773 .52653 L .42645 .5249 L p .562 .1 0 r
F P
0 g
s
.42645 .5249 m .42727 .52601 L .42831 .52731 L p .562 .1 0 r
F P
0 g
s
.4184 .6605 m .43069 .6453 L .43233 .6409 L p .886 .822 .78 r
F P
0 g
s
.62793 .64222 m .62583 .63189 L .62707 .63155 L p .001 .213 .725 r
F P
0 g
s
.55202 .52096 m .55301 .52337 L .55409 .52425 L p 0 .079 .633 r
F P
0 g
s
.60914 .60704 m .60357 .59922 L .60139 .59564 L p 0 0 .515 r
F P
0 g
s
.60139 .59564 m .60934 .60681 L .60914 .60704 L p 0 0 .515 r
F P
0 g
s
.60139 .59564 m .59452 .58597 L .5968 .58916 L p 0 0 .422 r
F P
0 g
s
.60934 .60681 m .60139 .59564 L .60161 .59592 L p 0 0 .419 r
F P
0 g
s
.44346 .55042 m .44021 .55059 L .43991 .55173 L p .96 .628 .256 r
F P
0 g
s
.55619 .52892 m .55923 .53463 L .55976 .53527 L p 0 0 .45 r
F P
0 g
s
.55976 .53527 m .55541 .52711 L .55619 .52892 L p 0 0 .45 r
F P
0 g
s
.43998 .54251 m .43762 .54331 L .43786 .54485 L p .911 .516 .116 r
F P
0 g
s
.55409 .52425 m .55268 .5208 L .55202 .52096 L p 0 .079 .633 r
F P
0 g
s
.56774 .45376 m .5727 .45369 L .57505 .45227 L p .285 0 .201 r
F P
0 g
s
.44508 .55581 m .4414 .55544 L .44078 .55607 L p .98 .688 .334 r
F P
0 g
s
.67367 .67969 m .66831 .69898 L .66531 .69322 L p .39 .483 .834 r
F P
0 g
s
.66831 .69898 m .7051 .72392 L .69702 .72333 L p .512 .555 .837 r
F P
0 g
s
.67861 .68607 m .67481 .69956 L .66831 .69898 L p .453 .55 .865 r
F P
0 g
s
.66831 .69898 m .67367 .67969 L .67861 .68607 L p .453 .55 .865 r
F P
0 g
s
.7051 .72392 m .66831 .69898 L .67481 .69956 L p .453 .55 .865 r
F P
0 g
s
.44559 .55799 m .44178 .55742 L .44101 .55754 L p .987 .714 .368 r
F P
0 g
s
.55267 .47913 m .54742 .48696 L .54827 .48616 L p .09 .034 .494 r
F P
0 g
s
.54883 .4883 m .54827 .48616 L .54742 .48696 L p .137 .11 .561 r
F P
0 g
s
.54742 .48696 m .54822 .49001 L .54883 .4883 L p .137 .11 .561 r
F P
0 g
s
.55208 .47913 m .5484 .48461 L .54742 .48696 L p 0 0 .266 r
F P
0 g
s
.54742 .48696 m .55267 .47913 L .55208 .47913 L p 0 0 .266 r
F P
0 g
s
.5719 .55338 m .56834 .5494 L .56647 .54671 L p .747 .295 0 r
F P
0 g
s
.44587 .55947 m .44197 .55873 L .44117 .55877 L p .99 .728 .386 r
F P
0 g
s
.42561 .63135 m .43233 .6409 L .43306 .63664 L p .93 .854 .746 r
F P
0 g
s
.43233 .6409 m .41477 .66263 L .4184 .6605 L p .886 .822 .78 r
F P
0 g
s
.42399 .63594 m .42871 .64261 L .43233 .6409 L p .901 .858 .789 r
F P
0 g
s
.43233 .6409 m .42561 .63135 L .42399 .63594 L p .901 .858 .789 r
F P
0 g
s
.41477 .66263 m .43233 .6409 L .42871 .64261 L p .901 .858 .79 r
F P
0 g
s
.30842 .49207 m .3097 .48953 L .31633 .49026 L p .596 .768 .961 r
F P
0 g
s
.39911 .69123 m .3938 .68473 L .38881 .68712 L p .856 .823 .815 r
F P
0 g
s
.43392 .5332 m .43293 .53431 L .43388 .53602 L p .791 .321 0 r
F P
0 g
s
.44644 .56347 m .44232 .56217 L .4415 .56251 L p .994 .747 .417 r
F P
0 g
s
.43302 .15294 m .45229 .21042 L .46109 .22129 L p .667 .659 .832 r
F P
0 g
s
.46109 .22129 m .43364 .13909 L .43302 .15294 L p .667 .659 .832 r
F P
0 g
s
.4906 .20381 m .46376 .20812 L .46109 .22129 L p .677 .665 .83 r
F P
0 g
s
.46109 .22129 m .49931 .21518 L .4906 .20381 L p .677 .665 .83 r
F P
0 g
s
.43364 .13909 m .46109 .22129 L .46376 .20812 L p .678 .665 .83 r
F P
0 g
s
.41207 .51442 m .40163 .50824 L .39975 .5069 L p 0 .39 .807 r
F P
0 g
s
.39975 .5069 m .41467 .51574 L .41207 .51442 L p 0 .39 .807 r
F P
0 g
s
.27693 .49069 m .2771 .48976 L .27072 .48846 L p .619 .768 .951 r
F P
0 g
s
.27072 .48846 m .27047 .48979 L .27693 .49069 L p .619 .768 .951 r
F P
0 g
s
.5839 .44619 m .57577 .45108 L .57505 .45227 L p .337 0 .061 r
F P
0 g
s
.57505 .45227 m .58668 .44527 L .5839 .44619 L p .337 0 .061 r
F P
0 g
s
.83068 .48141 m .82501 .46338 L .8323 .45836 L p .636 .732 .917 r
F P
0 g
s
.44673 .57314 m .4461 .58084 L .44689 .58311 L p .999 .823 .53 r
F P
0 g
s
.44069 .57798 m .44689 .58311 L .4461 .58084 L p .999 .822 .529 r
F P
0 g
s
.44689 .58311 m .44362 .59695 L .44541 .59574 L p .961 .811 .65 r
F P
0 g
s
.44116 .58068 m .44551 .58426 L .44689 .58311 L p .992 .861 .603 r
F P
0 g
s
.44689 .58311 m .44069 .57798 L .44116 .58068 L p .992 .861 .603 r
F P
0 g
s
.44362 .59695 m .44689 .58311 L .44551 .58426 L p .992 .863 .604 r
F P
0 g
s
.38971 .69936 m .36412 .72041 L .35991 .72643 L p .825 .821 .846 r
F P
0 g
s
.35062 .71533 m .35991 .72643 L .36412 .72041 L p .825 .822 .846 r
F P
0 g
s
.34373 .72217 m .35028 .72991 L .35991 .72643 L p .792 .817 .871 r
F P
0 g
s
.35991 .72643 m .35062 .71533 L .34373 .72217 L p .792 .817 .871 r
F P
0 g
s
.62583 .63189 m .6177 .62316 L .61545 .61908 L p .001 .215 .727 r
F P
0 g
s
.54951 .51181 m .55142 .51847 L .55268 .5208 L p 0 .029 .589 r
F P
0 g
s
.61341 .61563 m .60914 .60704 L .60934 .60681 L p 0 0 .509 r
F P
0 g
s
.60934 .60681 m .61545 .61908 L .61341 .61563 L p 0 0 .509 r
F P
0 g
s
.43336 .21537 m .4074 .15976 L .39695 .14892 L p .667 .658 .832 r
F P
0 g
s
.58135 .56652 m .58003 .56504 L .58074 .5664 L p .757 .293 0 r
F P
0 g
s
.58074 .5664 m .58262 .56852 L .58135 .56652 L p .757 .293 0 r
F P
0 g
s
.61545 .61908 m .62707 .63155 L .62583 .63189 L p .001 .215 .727 r
F P
0 g
s
.61205 .61054 m .61632 .61913 L .61545 .61908 L p 0 .142 .687 r
F P
0 g
s
.61545 .61908 m .60934 .60681 L .61205 .61054 L p 0 .142 .687 r
F P
0 g
s
.62707 .63155 m .61545 .61908 L .61632 .61913 L p 0 .14 .686 r
F P
0 g
s
.59466 .44509 m .58668 .44527 L .58612 .44611 L p .204 0 0 r
F P
0 g
s
.57798 .45101 m .58612 .44611 L .58668 .44527 L p .085 0 0 r
F P
0 g
s
.58668 .44527 m .57505 .45227 L .57798 .45101 L p .085 0 0 r
F P
0 g
s
.5955 .44462 m .5899 .44475 L .58668 .44527 L p .106 0 0 r
F P
0 g
s
.58668 .44527 m .59466 .44509 L .5955 .44462 L p .106 0 0 r
F P
0 g
s
.44682 .57058 m .44249 .56831 L .44159 .56889 L p .998 .781 .467 r
F P
0 g
s
.54705 .49122 m .54759 .49341 L .54828 .49233 L p .06 .061 .544 r
F P
0 g
s
.54828 .49233 m .54751 .48919 L .54705 .49122 L p .06 .061 .544 r
F P
0 g
s
.43306 .63664 m .42837 .62995 L .42561 .63135 L p .93 .854 .746 r
F P
0 g
s
.55769 .46504 m .5544 .47186 L .55473 .47295 L p .168 0 .271 r
F P
0 g
s
.55473 .47295 m .55943 .4632 L .55769 .46504 L p .168 0 .271 r
F P
0 g
s
.3738 .49934 m .37664 .49703 L .38092 .49784 L p .407 .709 .985 r
F P
0 g
s
.31261 .75497 m .30416 .74514 L .29402 .74818 L p .792 .816 .871 r
F P
0 g
s
.21394 .48035 m .27047 .48979 L .26208 .48815 L p .63 .764 .943 r
F P
0 g
s
.26224 .48722 m .26208 .48815 L .27047 .48979 L p .619 .767 .951 r
F P
0 g
s
.27047 .48979 m .27072 .48846 L .26224 .48722 L p .619 .767 .951 r
F P
0 g
s
.22222 .48262 m .26177 .48922 L .27047 .48979 L p .635 .762 .939 r
F P
0 g
s
.27047 .48979 m .21394 .48035 L .22222 .48262 L p .635 .762 .939 r
F P
0 g
s
.40257 .50805 m .41302 .51425 L .41467 .51574 L p .096 .508 .905 r
F P
0 g
s
.41467 .51574 m .39975 .5069 L .40257 .50805 L p .096 .508 .905 r
F P
0 g
s
.41765 .51556 m .41467 .51574 L .41302 .51425 L p 0 .367 .811 r
F P
0 g
s
.41881 .51706 m .41672 .51718 L .41467 .51574 L p 0 .293 .781 r
F P
0 g
s
.41467 .51574 m .41765 .51556 L .41881 .51706 L p 0 .293 .781 r
F P
0 g
s
.42497 .5236 m .42554 .52437 L .42727 .52601 L p .518 0 0 r
F P
0 g
s
.55197 .48206 m .54883 .4883 L .54822 .49001 L p .031 0 .479 r
F P
0 g
s
.54822 .49001 m .55271 .48109 L .55197 .48206 L p .031 0 .479 r
F P
0 g
s
.54827 .48616 m .55195 .48068 L .55267 .47913 L p .09 .034 .494 r
F P
0 g
s
.66531 .69322 m .66902 .6797 L .67367 .67969 L p .39 .483 .834 r
F P
0 g
s
.56142 .53783 m .5661 .54583 L .56647 .54671 L p .712 .284 0 r
F P
0 g
s
.56647 .54671 m .55976 .53527 L .56142 .53783 L p .712 .284 0 r
F P
0 g
s
.60191 .21886 m .54749 .21324 L .55442 .22294 L p .715 .672 .807 r
F P
0 g
s
.61356 .14883 m .59604 .20582 L .60191 .21886 L p .707 .688 .829 r
F P
0 g
s
.60191 .21886 m .62714 .13751 L .61356 .14883 L p .707 .688 .829 r
F P
0 g
s
.54749 .21324 m .60191 .21886 L .59604 .20582 L p .707 .688 .829 r
F P
0 g
s
.62714 .13751 m .60191 .21886 L .61536 .20975 L p .723 .705 .833 r
F P
0 g
s
.74867 .75377 m .70995 .73244 L .7051 .72392 L p .544 .604 .864 r
F P
0 g
s
.55409 .52425 m .55541 .52711 L .55504 .52675 L p .77 .392 0 r
F P
0 g
s
.55402 .52676 m .55504 .52675 L .55541 .52711 L p .784 .417 0 r
F P
0 g
s
.55541 .52711 m .55395 .52712 L .55402 .52676 L p .784 .417 0 r
F P
0 g
s
.55875 .53387 m .5557 .52814 L .55541 .52711 L p .775 .365 0 r
F P
0 g
s
.55541 .52711 m .55976 .53527 L .55875 .53387 L p .775 .365 0 r
F P
0 g
s
.55395 .52712 m .55541 .52711 L .5557 .52814 L p .766 .374 0 r
F P
0 g
s
.55268 .5208 m .55409 .52425 L .55379 .52396 L p .772 .418 0 r
F P
0 g
s
.55319 .52465 m .55379 .52396 L .55409 .52425 L p .778 .431 0 r
F P
0 g
s
.55409 .52425 m .55323 .52523 L .55319 .52465 L p .778 .431 0 r
F P
0 g
s
.55504 .52675 m .55411 .52475 L .55409 .52425 L p .77 .392 0 r
F P
0 g
s
.55323 .52523 m .55409 .52425 L .55411 .52475 L p .77 .404 0 r
F P
0 g
s
.56642 .46012 m .55943 .4632 L .5597 .46396 L p .066 0 .12 r
F P
0 g
s
.55641 .47079 m .5597 .46396 L .55943 .4632 L p 0 0 .144 r
F P
0 g
s
.55943 .4632 m .55473 .47295 L .55641 .47079 L p 0 0 .144 r
F P
0 g
s
.56665 .45918 m .56176 .46134 L .55943 .4632 L p 0 0 0 r
F P
0 g
s
.55943 .4632 m .56642 .46012 L .56665 .45918 L p 0 0 0 r
F P
0 g
s
.72153 .45875 m .70069 .46192 L .69474 .46015 L p .582 .705 .927 r
F P
0 g
s
.58957 .57949 m .58448 .57121 L .58262 .56852 L p .729 .266 0 r
F P
0 g
s
.58262 .56852 m .58989 .58035 L .58957 .57949 L p .729 .266 0 r
F P
0 g
s
.58213 .56851 m .58345 .56999 L .58262 .56852 L p .742 .275 0 r
F P
0 g
s
.58262 .56852 m .58074 .5664 L .58213 .56851 L p .742 .275 0 r
F P
0 g
s
.58989 .58035 m .58262 .56852 L .58345 .56999 L p .741 .275 0 r
F P
0 g
s
.43907 .61184 m .44376 .60051 L .44362 .59695 L p .95 .837 .696 r
F P
0 g
s
.55268 .5208 m .54995 .51128 L .54951 .51181 L p 0 .029 .589 r
F P
0 g
s
.54995 .51128 m .55268 .5208 L .55227 .51991 L p .783 .49 0 r
F P
0 g
s
.55208 .5214 m .55227 .51991 L .55268 .5208 L p .772 .473 0 r
F P
0 g
s
.55268 .5208 m .5524 .52294 L .55208 .5214 L p .772 .473 0 r
F P
0 g
s
.55379 .52396 m .5528 .52155 L .55268 .5208 L p .772 .418 0 r
F P
0 g
s
.5524 .52294 m .55268 .5208 L .5528 .52155 L p .769 .422 0 r
F P
0 g
s
.36412 .72041 m .35765 .71262 L .35062 .71533 L p .825 .822 .846 r
F P
0 g
s
.552 .48027 m .54751 .48919 L .54823 .48826 L p .03 0 .478 r
F P
0 g
s
.54877 .49046 m .54823 .48826 L .54751 .48919 L p .091 .081 .551 r
F P
0 g
s
.54751 .48919 m .54828 .49233 L .54877 .49046 L p .091 .081 .551 r
F P
0 g
s
.50711 .22391 m .54077 .22256 L .54749 .21324 L p .695 .655 .806 r
F P
0 g
s
.54749 .21324 m .49931 .21518 L .50711 .22391 L p .695 .655 .806 r
F P
0 g
s
.82635 .79118 m .76813 .76514 L .76056 .75446 L p .569 .645 .886 r
F P
0 g
s
.76056 .75446 m .84401 .7918 L .82635 .79118 L p .569 .645 .886 r
F P
0 g
s
.72455 .45559 m .69474 .46015 L .69712 .45736 L p .573 .729 .948 r
F P
0 g
s
.68818 .44831 m .69712 .45736 L .69474 .46015 L p .575 .731 .949 r
F P
0 g
s
.69474 .46015 m .68195 .44725 L .68818 .44831 L p .575 .731 .949 r
F P
0 g
s
.69474 .46015 m .72455 .45559 L .72153 .45875 L p .582 .705 .927 r
F P
0 g
s
.68195 .44725 m .69474 .46015 L .68961 .45855 L p .516 .707 .958 r
F P
0 g
s
.73958 .46946 m .76871 .4657 L .77667 .46775 L p .615 .725 .924 r
F P
0 g
s
.60161 .59592 m .60718 .60374 L .60934 .60681 L p 0 0 .419 r
F P
0 g
s
.4461 .58084 m .44176 .57724 L .44069 .57798 L p .999 .822 .529 r
F P
0 g
s
.60495 .44295 m .5955 .44462 L .59466 .44509 L p .211 0 0 r
F P
0 g
s
.59466 .44509 m .60818 .4427 L .60495 .44295 L p .211 0 0 r
F P
0 g
s
.55634 .53212 m .55875 .53387 L .55976 .53527 L p .818 .422 0 r
F P
0 g
s
.55976 .53527 m .55632 .53279 L .55634 .53212 L p .818 .422 0 r
F P
0 g
s
.56477 .54445 m .56007 .53643 L .55976 .53527 L p .79 .351 0 r
F P
0 g
s
.55976 .53527 m .56647 .54671 L .56477 .54445 L p .79 .351 0 r
F P
0 g
s
.55632 .53279 m .55976 .53527 L .56007 .53643 L p .784 .364 0 r
F P
0 g
s
.42871 .64261 m .4164 .65784 L .41477 .66263 L p .901 .858 .79 r
F P
0 g
s
.68961 .45855 m .68064 .44953 L .68195 .44725 L p .516 .707 .958 r
F P
0 g
s
.63225 .64632 m .64431 .65702 L .64728 .66158 L p .175 .361 .809 r
F P
0 g
s
.59819 .44445 m .60765 .44277 L .60818 .4427 L p .138 .681 .708 r
F P
0 g
s
.60818 .4427 m .59466 .44509 L .59819 .44445 L p .138 .681 .708 r
F P
0 g
s
.61906 .44227 m .61184 .44284 L .60818 .4427 L p .185 .7 .889 r
F P
0 g
s
.60818 .4427 m .61849 .44187 L .61906 .44227 L p .185 .7 .889 r
F P
0 g
s
.61849 .44187 m .60818 .4427 L .60765 .44277 L p 0 0 0 r
F P
0 g
s
.22273 .48028 m .26224 .48722 L .27072 .48846 L p .629 .763 .943 r
F P
0 g
s
.27072 .48846 m .21426 .47855 L .22273 .48028 L p .629 .763 .943 r
F P
0 g
s
.26208 .48815 m .2225 .48154 L .21394 .48035 L p .63 .764 .943 r
F P
0 g
s
.5781 .56293 m .57939 .56433 L .58074 .5664 L p .761 .296 0 r
F P
0 g
s
.58612 .44611 m .59171 .44598 L .59466 .44509 L p .204 0 0 r
F P
0 g
s
.44551 .58426 m .44321 .59396 L .44362 .59695 L p .992 .863 .604 r
F P
0 g
s
.27403 .48114 m .31633 .49026 L .3097 .48953 L p .61 .762 .952 r
F P
0 g
s
.28097 .4815 m .3106 .48789 L .31633 .49026 L p .61 .762 .952 r
F P
0 g
s
.31633 .49026 m .27403 .48114 L .28097 .4815 L p .61 .762 .952 r
F P
0 g
s
.31991 .48449 m .31633 .49026 L .3106 .48789 L p .591 .761 .96 r
F P
0 g
s
.32423 .48658 m .32171 .49062 L .31633 .49026 L p .588 .756 .958 r
F P
0 g
s
.31633 .49026 m .31991 .48449 L .32423 .48658 L p .588 .756 .958 r
F P
0 g
s
.43779 .58975 m .44362 .59695 L .44321 .59396 L p .993 .862 .6 r
F P
0 g
s
.44362 .59695 m .43691 .61314 L .43907 .61184 L p .95 .837 .696 r
F P
0 g
s
.4377 .59312 m .44179 .59815 L .44362 .59695 L p .976 .891 .675 r
F P
0 g
s
.44362 .59695 m .43779 .58975 L .4377 .59312 L p .976 .891 .675 r
F P
0 g
s
.43691 .61314 m .44362 .59695 L .44179 .59815 L p .976 .893 .676 r
F P
0 g
s
.27821 .48732 m .27768 .48818 L .27115 .48721 L p .617 .766 .951 r
F P
0 g
s
.39639 .50587 m .38322 .49954 L .38092 .49784 L p .278 .627 .962 r
F P
0 g
s
.38092 .49784 m .39975 .5069 L .39639 .50587 L p .278 .627 .962 r
F P
0 g
s
.41302 .51425 m .41509 .51411 L .41765 .51556 L p 0 .367 .811 r
F P
0 g
s
.22099 .48704 m .22222 .48262 L .21394 .48035 L p .642 .76 .934 r
F P
0 g
s
.21394 .48035 m .21222 .48668 L .22099 .48704 L p .642 .76 .934 r
F P
0 g
s
.54824 .49511 m .54878 .49996 L .54904 .49926 L p 0 0 .22 r
F P
0 g
s
.54904 .49926 m .54828 .49233 L .54824 .49511 L p 0 0 .22 r
F P
0 g
s
.3097 .48953 m .28011 .48315 L .27403 .48114 L p .61 .762 .952 r
F P
0 g
s
.55192 .48247 m .54828 .49233 L .54876 .49177 L p 0 0 .144 r
F P
0 g
s
.5493 .49662 m .54876 .49177 L .54828 .49233 L p 0 0 .288 r
F P
0 g
s
.54828 .49233 m .54904 .49926 L .5493 .49662 L p 0 0 .288 r
F P
0 g
s
.55132 .48356 m .54877 .49046 L .54828 .49233 L p 0 0 .455 r
F P
0 g
s
.54828 .49233 m .55192 .48247 L .55132 .48356 L p 0 0 .455 r
F P
0 g
s
.54823 .48826 m .55137 .48202 L .552 .48027 L p .03 0 .478 r
F P
0 g
s
.62909 .44411 m .61906 .44227 L .61849 .44187 L p .121 .65 .871 r
F P
0 g
s
.61849 .44187 m .63282 .44451 L .62909 .44411 L p .121 .65 .871 r
F P
0 g
s
.68064 .44953 m .66614 .45177 L .66122 .45046 L p .519 .711 .959 r
F P
0 g
s
.58345 .56999 m .58853 .57828 L .58989 .58035 L p .741 .275 0 r
F P
0 g
s
.5597 .46396 m .56459 .46181 L .56642 .46012 L p .066 0 .12 r
F P
0 g
s
.64715 .44264 m .63282 .44451 L .63274 .44368 L p .343 .761 .978 r
F P
0 g
s
.62271 .44183 m .63274 .44368 L .63282 .44451 L p .381 .792 .98 r
F P
0 g
s
.63282 .44451 m .61849 .44187 L .62271 .44183 L p .381 .792 .98 r
F P
0 g
s
.64703 .44397 m .637 .44527 L .63282 .44451 L p .407 .732 .991 r
F P
0 g
s
.63282 .44451 m .64715 .44264 L .64703 .44397 L p .407 .732 .991 r
F P
0 g
s
.68195 .44725 m .66122 .45046 L .66209 .44865 L p .498 .748 .984 r
F P
0 g
s
.65225 .44317 m .66209 .44865 L .66122 .45046 L p .51 .761 .987 r
F P
0 g
s
.66122 .45046 m .64715 .44264 L .65225 .44317 L p .51 .761 .987 r
F P
0 g
s
.66122 .45046 m .68195 .44725 L .68064 .44953 L p .519 .711 .959 r
F P
0 g
s
.64715 .44264 m .66122 .45046 L .65688 .44944 L p .388 .715 .987 r
F P
0 g
s
.65688 .44944 m .64703 .44397 L .64715 .44264 L p .388 .715 .987 r
F P
0 g
s
.61632 .61913 m .62446 .62785 L .62707 .63155 L p 0 .14 .686 r
F P
0 g
s
.58074 .5664 m .5789 .5644 L .5781 .56293 L p .761 .296 0 r
F P
0 g
s
.58689 .57644 m .58161 .56793 L .58074 .5664 L p .747 .278 0 r
F P
0 g
s
.58074 .5664 m .58828 .57855 L .58689 .57644 L p .747 .278 0 r
F P
0 g
s
.5789 .5644 m .58074 .5664 L .58161 .56793 L p .746 .278 0 r
F P
0 g
s
.58741 .57701 m .58213 .56851 L .58074 .5664 L p .741 .274 0 r
F P
0 g
s
.58074 .5664 m .58828 .57855 L .58741 .57701 L p .741 .274 0 r
F P
0 g
s
.54878 .49996 m .54941 .50837 L .54995 .51128 L p 0 0 .401 r
F P
0 g
s
.7051 .72392 m .76056 .75446 L .74867 .75377 L p .544 .604 .864 r
F P
0 g
s
.55411 .52475 m .55351 .52544 L .55323 .52523 L p .77 .404 0 r
F P
0 g
s
.67481 .69956 m .70061 .71704 L .7051 .72392 L p .453 .55 .865 r
F P
0 g
s
.5557 .52814 m .55468 .52816 L .55395 .52712 L p .766 .374 0 r
F P
0 g
s
.38457 .49872 m .39776 .50507 L .39975 .5069 L p .355 .654 .969 r
F P
0 g
s
.39975 .5069 m .38092 .49784 L .38457 .49872 L p .355 .654 .969 r
F P
0 g
s
.40451 .50481 m .39975 .5069 L .39776 .50507 L p .243 .591 .948 r
F P
0 g
s
.40591 .5066 m .40257 .50805 L .39975 .5069 L p .225 .539 .926 r
F P
0 g
s
.39975 .5069 m .40451 .50481 L .40591 .5066 L p .225 .539 .926 r
F P
0 g
s
.34659 .49288 m .32423 .48658 L .31991 .48449 L p .559 .752 .967 r
F P
0 g
s
.31991 .48449 m .35188 .49349 L .34659 .49288 L p .559 .752 .967 r
F P
0 g
s
.22329 .47855 m .26284 .48551 L .27115 .48721 L p .629 .763 .943 r
F P
0 g
s
.27115 .48721 m .21466 .47728 L .22329 .47855 L p .629 .763 .943 r
F P
0 g
s
.27191 .48597 m .27115 .48721 L .26284 .48551 L p .618 .766 .951 r
F P
0 g
s
.27115 .48721 m .27191 .48597 L .27821 .48732 L p .617 .766 .951 r
F P
0 g
s
.32555 .48485 m .34794 .49117 L .35188 .49349 L p .565 .752 .965 r
F P
0 g
s
.35188 .49349 m .31991 .48449 L .32555 .48485 L p .565 .752 .965 r
F P
0 g
s
.35698 .48803 m .35188 .49349 L .34794 .49117 L p .53 .742 .973 r
F P
0 g
s
.3599 .49017 m .35631 .49399 L .35188 .49349 L p .521 .728 .968 r
F P
0 g
s
.35188 .49349 m .35698 .48803 L .3599 .49017 L p .521 .728 .968 r
F P
0 g
s
.3938 .68473 m .41195 .6676 L .41477 .66263 L p .856 .823 .815 r
F P
0 g
s
.5528 .52155 m .55261 .52305 L .5524 .52294 L p .769 .422 0 r
F P
0 g
s
.54995 .51128 m .54904 .49926 L .54878 .49996 L p 0 0 .401 r
F P
0 g
s
.54904 .49926 m .54995 .51128 L .54977 .51036 L p .785 .61 .046 r
F P
0 g
s
.55003 .51382 m .54977 .51036 L .54995 .51128 L p .737 .527 0 r
F P
0 g
s
.54995 .51128 m .55031 .51624 L .55003 .51382 L p .737 .527 0 r
F P
0 g
s
.55227 .51991 m .55036 .51323 L .54995 .51128 L p .783 .49 0 r
F P
0 g
s
.55031 .51624 m .54995 .51128 L .55036 .51323 L p .799 .498 0 r
F P
0 g
s
.61536 .20975 m .63314 .15293 L .62714 .13751 L p .723 .705 .833 r
F P
0 g
s
.55352 .4748 m .55208 .47913 L .55267 .47913 L p 0 0 .15 r
F P
0 g
s
.55267 .47913 m .55473 .47295 L .55352 .4748 L p 0 0 .15 r
F P
0 g
s
.44321 .59396 m .43913 .58891 L .43779 .58975 L p .993 .862 .6 r
F P
0 g
s
.40797 .65168 m .41477 .66263 L .4164 .65784 L p .902 .859 .79 r
F P
0 g
s
.41477 .66263 m .38881 .68712 L .3938 .68473 L p .856 .823 .815 r
F P
0 g
s
.40505 .65686 m .40984 .66451 L .41477 .66263 L p .867 .856 .828 r
F P
0 g
s
.41477 .66263 m .40797 .65168 L .40505 .65686 L p .867 .856 .828 r
F P
0 g
s
.38881 .68712 m .41477 .66263 L .40984 .66451 L p .867 .857 .829 r
F P
0 g
s
.56007 .53643 m .55767 .5347 L .55632 .53279 L p .784 .364 0 r
F P
0 g
s
.60765 .44277 m .61487 .4422 L .61849 .44187 L p 0 0 0 r
F P
0 g
s
.28011 .48315 m .27861 .48653 L .27191 .48597 L p .624 .761 .944 r
F P
0 g
s
.48119 .1447 m .4906 .20381 L .49931 .21518 L p .678 .665 .83 r
F P
0 g
s
.49931 .21518 m .48601 .13066 L .48119 .1447 L p .678 .665 .83 r
F P
0 g
s
.53968 .20108 m .50584 .20245 L .49931 .21518 L p .692 .675 .829 r
F P
0 g
s
.49931 .21518 m .54749 .21324 L .53968 .20108 L p .692 .675 .829 r
F P
0 g
s
.48601 .13066 m .49931 .21518 L .50584 .20245 L p .691 .674 .829 r
F P
0 g
s
.5727 .45369 m .56665 .45918 L .56642 .46012 L p .11 0 0 r
F P
0 g
s
.56642 .46012 m .57505 .45227 L .5727 .45369 L p .11 0 0 r
F P
0 g
s
.71358 .70094 m .7051 .72392 L .70061 .71704 L p .453 .55 .865 r
F P
0 g
s
.72097 .70857 m .71494 .72462 L .7051 .72392 L p .501 .605 .888 r
F P
0 g
s
.7051 .72392 m .71358 .70094 L .72097 .70857 L p .501 .605 .888 r
F P
0 g
s
.76056 .75446 m .7051 .72392 L .71494 .72462 L p .502 .604 .888 r
F P
0 g
s
.54876 .49177 m .55131 .48487 L .55192 .48247 L p 0 0 .144 r
F P
0 g
s
.3106 .48789 m .31309 .48384 L .31991 .48449 L p .591 .761 .96 r
F P
0 g
s
.2155 .47556 m .27191 .48597 L .26337 .48464 L p .628 .762 .943 r
F P
0 g
s
.26284 .48551 m .26337 .48464 L .27191 .48597 L p .618 .766 .951 r
F P
0 g
s
.22433 .4763 m .26384 .48359 L .27191 .48597 L p .634 .76 .939 r
F P
0 g
s
.27191 .48597 m .2155 .47556 L .22433 .4763 L p .634 .76 .939 r
F P
0 g
s
.27403 .48114 m .27191 .48597 L .26384 .48359 L p .625 .762 .945 r
F P
0 g
s
.27191 .48597 m .27403 .48114 L .28011 .48315 L p .624 .761 .944 r
F P
0 g
s
.56078 .46673 m .55473 .47295 L .55525 .47279 L p 0 0 0 r
F P
0 g
s
.55381 .47712 m .55525 .47279 L .55473 .47295 L p 0 0 .073 r
F P
0 g
s
.55473 .47295 m .55267 .47913 L .55381 .47712 L p 0 0 .073 r
F P
0 g
s
.56065 .46644 m .55641 .47079 L .55473 .47295 L p 0 0 0 r
F P
0 g
s
.55473 .47295 m .56078 .46673 L .56065 .46644 L p 0 0 0 r
F P
0 g
s
.58161 .56793 m .58032 .56653 L .5789 .5644 L p .746 .278 0 r
F P
0 g
s
.44179 .59815 m .43709 .60949 L .43691 .61314 L p .976 .893 .676 r
F P
0 g
s
.57352 .55815 m .57704 .56178 L .5789 .5644 L p .787 .326 0 r
F P
0 g
s
.42837 .62995 m .43627 .61721 L .43691 .61314 L p .93 .853 .745 r
F P
0 g
s
.58287 .44963 m .57505 .45227 L .57487 .45284 L p 0 0 0 r
F P
0 g
s
.56882 .45834 m .57487 .45284 L .57505 .45227 L p 0 0 0 r
F P
0 g
s
.57505 .45227 m .56642 .46012 L .56882 .45834 L p 0 0 0 r
F P
0 g
s
.58346 .44916 m .57798 .45101 L .57505 .45227 L p 0 0 0 r
F P
0 g
s
.57505 .45227 m .58287 .44963 L .58346 .44916 L p 0 0 0 r
F P
0 g
s
.55036 .51323 m .55062 .51671 L .55031 .51624 L p .799 .498 0 r
F P
0 g
s
.56834 .5494 m .57352 .55815 L .57387 .55921 L p .784 .332 0 r
F P
0 g
s
.57387 .55921 m .56647 .54671 L .56834 .5494 L p .784 .332 0 r
F P
0 g
s
.5789 .5644 m .57387 .55921 L .57352 .55815 L p .787 .326 0 r
F P
0 g
s
.58477 .57419 m .57933 .5655 L .5789 .5644 L p .76 .288 0 r
F P
0 g
s
.5789 .5644 m .58668 .5768 L .58477 .57419 L p .76 .288 0 r
F P
0 g
s
.57387 .55921 m .5789 .5644 L .57933 .5655 L p .759 .29 0 r
F P
0 g
s
.58668 .5768 m .5789 .5644 L .58032 .56653 L p .747 .279 0 r
F P
0 g
s
.4164 .65784 m .41165 .65016 L .40797 .65168 L p .902 .859 .79 r
F P
0 g
s
.69712 .45736 m .718 .45415 L .72455 .45559 L p .573 .729 .948 r
F P
0 g
s
.59281 .58343 m .58957 .57949 L .58989 .58035 L p .728 .269 0 r
F P
0 g
s
.58989 .58035 m .59452 .58597 L .59281 .58343 L p .728 .269 0 r
F P
0 g
s
.56066 .54102 m .56477 .54445 L .56647 .54671 L p .85 .425 0 r
F P
0 g
s
.56647 .54671 m .5606 .54183 L .56066 .54102 L p .85 .425 0 r
F P
0 g
s
.57178 .55652 m .5666 .54777 L .56647 .54671 L p .813 .358 0 r
F P
0 g
s
.56647 .54671 m .57387 .55921 L .57178 .55652 L p .813 .358 0 r
F P
0 g
s
.5606 .54183 m .56647 .54671 L .5666 .54777 L p .816 .373 0 r
F P
0 g
s
.39776 .50507 m .40108 .5036 L .40451 .50481 L p .243 .591 .948 r
F P
0 g
s
.54282 .14184 m .53968 .20108 L .54749 .21324 L p .691 .674 .829 r
F P
0 g
s
.54749 .21324 m .55217 .12858 L .54282 .14184 L p .691 .674 .829 r
F P
0 g
s
.59604 .20582 m .55782 .20185 L .54749 .21324 L p .707 .688 .829 r
F P
0 g
s
.55217 .12858 m .54749 .21324 L .55782 .20185 L p .707 .688 .829 r
F P
0 g
s
.46376 .20812 m .44465 .15054 L .43364 .13909 L p .678 .665 .83 r
F P
0 g
s
.34794 .49117 m .3515 .48734 L .35698 .48803 L p .53 .742 .973 r
F P
0 g
s
.63274 .44368 m .64277 .44237 L .64715 .44264 L p .343 .761 .978 r
F P
0 g
s
.54977 .51036 m .54914 .50194 L .54904 .49926 L p .785 .61 .046 r
F P
0 g
s
.26337 .48464 m .22388 .47735 L .2155 .47556 L p .628 .762 .943 r
F P
0 g
s
.60299 .59757 m .5968 .58916 L .59452 .58597 L p 0 0 .441 r
F P
0 g
s
.59452 .58597 m .60336 .598 L .60299 .59757 L p 0 0 .441 r
F P
0 g
s
.59194 .58303 m .59518 .58696 L .59452 .58597 L p .617 .15 0 r
F P
0 g
s
.59452 .58597 m .58989 .58035 L .59194 .58303 L p .617 .15 0 r
F P
0 g
s
.60336 .598 m .59452 .58597 L .59518 .58696 L p .616 .15 0 r
F P
0 g
s
.43168 .60395 m .43691 .61314 L .43709 .60949 L p .977 .893 .673 r
F P
0 g
s
.43691 .61314 m .42561 .63135 L .42837 .62995 L p .93 .853 .745 r
F P
0 g
s
.43082 .60793 m .43449 .61435 L .43691 .61314 L p .95 .908 .743 r
F P
0 g
s
.43691 .61314 m .43168 .60395 L .43082 .60793 L p .95 .908 .743 r
F P
0 g
s
.42561 .63135 m .43691 .61314 L .43449 .61435 L p .95 .91 .744 r
F P
0 g
s
.58032 .56653 m .58576 .57521 L .58668 .5768 L p .747 .279 0 r
F P
0 g
s
.66209 .44865 m .67661 .44639 L .68195 .44725 L p .498 .748 .984 r
F P
0 g
s
.55525 .47279 m .55948 .46844 L .56078 .46673 L p 0 0 0 r
F P
0 g
s
.37664 .49703 m .3599 .49017 L .35698 .48803 L p .465 .707 .974 r
F P
0 g
s
.35698 .48803 m .38092 .49784 L .37664 .49703 L p .465 .707 .974 r
F P
0 g
s
.55195 .48068 m .55197 .48206 L .55271 .48109 L p 0 0 .344 r
F P
0 g
s
.55271 .48109 m .55267 .47913 L .55195 .48068 L p 0 0 .344 r
F P
0 g
s
.82501 .46338 m .78614 .46992 L .77667 .46775 L p .635 .728 .915 r
F P
0 g
s
.40984 .66451 m .39164 .68167 L .38881 .68712 L p .867 .857 .829 r
F P
0 g
s
.36606 .17466 m .3523 .18097 L .34189 .17104 L p .649 .65 .838 r
F P
0 g
s
.77546 .75507 m .83407 .7813 L .84401 .7918 L p .539 .648 .905 r
F P
0 g
s
.84401 .7918 m .76056 .75446 L .77546 .75507 L p .539 .648 .905 r
F P
0 g
s
.86483 .7537 m .84401 .7918 L .83407 .7813 L p .539 .648 .905 r
F P
0 g
s
.66902 .6797 m .65058 .66704 L .64728 .66158 L p .39 .483 .834 r
F P
0 g
s
.70061 .71704 m .70649 .70093 L .71358 .70094 L p .453 .55 .865 r
F P
0 g
s
.26384 .48359 m .26531 .4802 L .27403 .48114 L p .625 .762 .945 r
F P
0 g
s
.36162 .48869 m .37839 .49557 L .38092 .49784 L p .493 .712 .968 r
F P
0 g
s
.38092 .49784 m .35698 .48803 L .36162 .48869 L p .493 .712 .968 r
F P
0 g
s
.3872 .49358 m .38092 .49784 L .37839 .49557 L p .433 .685 .97 r
F P
0 g
s
.38897 .49575 m .38457 .49872 L .38092 .49784 L p .419 .651 .955 r
F P
0 g
s
.38092 .49784 m .3872 .49358 L .38897 .49575 L p .419 .651 .955 r
F P
0 g
s
.57487 .45284 m .58035 .451 L .58287 .44963 L p 0 0 0 r
F P
0 g
s
.43762 .54331 m .43484 .53714 L .43388 .53602 L p .903 .527 .079 r
F P
0 g
s
.35765 .71262 m .38435 .69289 L .38881 .68712 L p .825 .821 .845 r
F P
0 g
s
.44021 .55059 m .43878 .54578 L .43786 .54485 L p .964 .648 .257 r
F P
0 g
s
.57933 .5655 m .57581 .56188 L .57387 .55921 L p .759 .29 0 r
F P
0 g
s
.43388 .53602 m .43786 .54485 L .43762 .54331 L p .903 .527 .079 r
F P
0 g
s
.43709 .60949 m .43344 .60305 L .43168 .60395 L p .977 .893 .673 r
F P
0 g
s
.43293 .53431 m .42831 .52731 L .42727 .52601 L p .722 .279 0 r
F P
0 g
s
.42727 .52601 m .43388 .53602 L .43293 .53431 L p .722 .279 0 r
F P
0 g
s
.43786 .54485 m .43991 .55173 L .44021 .55059 L p .964 .648 .257 r
F P
0 g
s
.55762 .47084 m .55267 .47913 L .55339 .47813 L p 0 0 .202 r
F P
0 g
s
.55341 .47951 m .55339 .47813 L .55267 .47913 L p 0 0 .337 r
F P
0 g
s
.55267 .47913 m .55271 .48109 L .55341 .47951 L p 0 0 .337 r
F P
0 g
s
.55381 .47712 m .55267 .47913 L p .55606 .47338 L 0 0 0 r
F P
0 g
s
.55615 .47319 m .55381 .47712 L p .55606 .47338 L 0 0 0 r
F P
0 g
s
.55762 .47084 m .55727 .47131 L p .55606 .47338 L 0 0 0 r
F P
0 g
s
.55267 .47913 m .55579 .47391 L p .55606 .47338 L 0 0 0 r
F P
0 g
s
.55579 .47391 m .55762 .47084 L p .55606 .47338 L 0 0 0 r
F P
0 g
s
.55339 .47813 m .55685 .47233 L .55762 .47084 L p 0 0 .202 r
F P
0 g
s
.55192 .48247 m .55595 .47291 L .55539 .47407 L p 0 0 .125 r
F P
0 g
s
.555 .47503 m .55595 .47291 L p .55398 .47752 L .714 .826 .374 r
F P
0 g
s
.55539 .47407 m .55257 .48076 L .55192 .48247 L p 0 0 .125 r
F P
0 g
s
.55243 .48113 m .55381 .47787 L p .5539 .47767 L .714 .826 .374 r
F P
0 g
s
.55398 .47752 m .55243 .48113 L .5539 .47767 L .714 .826 .374 r
F
.55218 .48172 m .55243 .48113 L p .55398 .47752 L F P
0 g
s
.55381 .47787 m .555 .47503 L p .55398 .47752 L .714 .826 .374 r
F P
0 g
s
.55192 .48247 m .55218 .48172 L p .55398 .47752 L .714 .826 .374 r
F P
0 g
s
.55595 .47291 m .55417 .47714 L p .55398 .47752 L .714 .826 .374 r
F P
0 g
s
.55417 .47714 m .55192 .48247 L p .55398 .47752 L .714 .826 .374 r
F P
0 g
s
.55727 .47131 m .55615 .47319 L p .55606 .47338 L 0 0 0 r
F P
0 g
s
.4414 .55544 m .44079 .5524 L .43991 .55173 L p .984 .705 .345 r
F P
0 g
s
.71494 .72462 m .75386 .74605 L .76056 .75446 L p .502 .604 .888 r
F P
0 g
s
.77366 .72546 m .76056 .75446 L .75386 .74605 L p .502 .605 .888 r
F P
0 g
s
.78481 .73483 m .77546 .75507 L .76056 .75446 L p .539 .648 .905 r
F P
0 g
s
.76056 .75446 m .77366 .72546 L .78481 .73483 L p .539 .648 .905 r
F P
0 g
s
.5666 .54777 m .56249 .54436 L .5606 .54183 L p .816 .373 0 r
F P
0 g
s
.8323 .45836 m .77667 .46775 L .78293 .46293 L p .633 .736 .922 r
F P
0 g
s
.77433 .44828 m .78293 .46293 L .77667 .46775 L p .633 .735 .922 r
F P
0 g
s
.77667 .46775 m .7643 .44688 L .77433 .44828 L p .633 .735 .922 r
F P
0 g
s
.77667 .46775 m .8323 .45836 L .82501 .46338 L p .635 .728 .915 r
F P
0 g
s
.7643 .44688 m .77667 .46775 L .76871 .4657 L p .614 .726 .925 r
F P
0 g
s
.43991 .55173 m .44078 .55607 L .4414 .55544 L p .984 .705 .345 r
F P
0 g
s
.59171 .44598 m .58346 .44916 L .58287 .44963 L p 0 0 0 r
F P
0 g
s
.58287 .44963 m .59466 .44509 L .59171 .44598 L p 0 0 0 r
F P
0 g
s
.64516 .64606 m .64728 .66158 L .64431 .65702 L p .176 .361 .809 r
F P
0 g
s
.64728 .66158 m .67367 .67969 L .66902 .6797 L p .39 .483 .834 r
F P
0 g
s
.64949 .65097 m .65096 .66183 L .64728 .66158 L p .302 .47 .86 r
F P
0 g
s
.64728 .66158 m .64516 .64606 L .64949 .65097 L p .302 .47 .86 r
F P
0 g
s
.67367 .67969 m .64728 .66158 L .65096 .66183 L p .302 .47 .86 r
F P
0 g
s
.44178 .55742 m .44163 .55639 L .44078 .55607 L p .99 .728 .382 r
F P
0 g
s
.44078 .55607 m .44101 .55754 L .44178 .55742 L p .99 .728 .382 r
F P
0 g
s
.44197 .55873 m .44186 .55787 L .44101 .55754 L p .992 .739 .399 r
F P
0 g
s
.42554 .52437 m .41881 .51706 L .41765 .51556 L p 0 .105 .631 r
F P
0 g
s
.41765 .51556 m .42727 .52601 L .42554 .52437 L p 0 .105 .631 r
F P
0 g
s
.44101 .55754 m .44117 .55877 L .44197 .55873 L p .992 .739 .399 r
F P
0 g
s
.55022 .48851 m .5493 .49662 L .54904 .49926 L p 0 0 0 r
F P
0 g
s
.55131 .48487 m .55022 .48851 L .55035 .48768 L p .756 .763 .255 r
F P
0 g
s
.54904 .49926 m .55035 .48768 L .55022 .48851 L p 0 0 0 r
F P
0 g
s
.55035 .48768 m .54904 .49926 L .54894 .49853 L p .839 .779 .274 r
F P
0 g
s
.54834 .50328 m .54894 .49853 L .54904 .49926 L p .796 .675 .127 r
F P
0 g
s
.54904 .49926 m .54818 .50606 L .54834 .50328 L p .796 .675 .127 r
F P
0 g
s
.54818 .50606 m .54904 .49926 L .54914 .50194 L p .901 .688 .179 r
F P
0 g
s
.2225 .48154 m .22273 .48028 L .21426 .47855 L p .637 .76 .937 r
F P
0 g
s
.21426 .47855 m .21394 .48035 L .2225 .48154 L p .637 .76 .937 r
F P
0 g
s
.44232 .56217 m .44208 .55955 L .44117 .55877 L p .995 .756 .424 r
F P
0 g
s
.59518 .58696 m .60137 .59538 L .60336 .598 L p .616 .15 0 r
F P
0 g
s
.60434 .44214 m .59466 .44509 L .59427 .44515 L p .225 .739 .713 r
F P
0 g
s
.58602 .44833 m .59427 .44515 L .59466 .44509 L p .327 .8 .715 r
F P
0 g
s
.59466 .44509 m .58287 .44963 L .58602 .44833 L p .327 .8 .715 r
F P
0 g
s
.60496 .44239 m .59819 .44445 L .59466 .44509 L p .317 .803 .875 r
F P
0 g
s
.59466 .44509 m .60434 .44214 L .60496 .44239 L p .317 .803 .875 r
F P
0 g
s
.38138 .67424 m .38881 .68712 L .39164 .68167 L p .868 .858 .829 r
F P
0 g
s
.38881 .68712 m .35062 .71533 L .35765 .71262 L p .825 .821 .845 r
F P
0 g
s
.37665 .68019 m .38189 .68919 L .38881 .68712 L p .831 .85 .86 r
F P
0 g
s
.38881 .68712 m .38138 .67424 L .37665 .68019 L p .831 .85 .86 r
F P
0 g
s
.35062 .71533 m .38881 .68712 L .38189 .68919 L p .831 .848 .859 r
F P
0 g
s
.64431 .65702 m .64281 .64616 L .64516 .64606 L p .176 .361 .809 r
F P
0 g
s
.55137 .48202 m .55132 .48356 L .55192 .48247 L p 0 0 .302 r
F P
0 g
s
.55192 .48247 m .552 .48027 L .55137 .48202 L p 0 0 .302 r
F P
0 g
s
.44117 .55877 m .4415 .56251 L .44232 .56217 L p .995 .756 .424 r
F P
0 g
s
.44249 .56831 m .44243 .56385 L .4415 .56251 L p .998 .785 .469 r
F P
0 g
s
.43449 .61435 m .42657 .62711 L .42561 .63135 L p .95 .91 .744 r
F P
0 g
s
.56459 .46181 m .56065 .46644 L .56078 .46673 L p 0 0 0 r
F P
0 g
s
.56078 .46673 m .56642 .46012 L .56459 .46181 L p 0 0 0 r
F P
0 g
s
.60718 .60374 m .60299 .59757 L .60336 .598 L p 0 0 .439 r
F P
0 g
s
.60336 .598 m .60934 .60681 L .60718 .60374 L p 0 0 .439 r
F P
0 g
s
.76871 .4657 m .76001 .45111 L .7643 .44688 L p .614 .726 .925 r
F P
0 g
s
.55657 .47325 m .55341 .47951 L .55271 .48109 L p 0 0 .171 r
F P
0 g
s
.55271 .48109 m .55722 .47215 L .55657 .47325 L p 0 0 .171 r
F P
0 g
s
.42864 .52731 m .43327 .53432 L .43388 .53602 L p 0 .148 .692 r
F P
0 g
s
.43388 .53602 m .42727 .52601 L .42864 .52731 L p 0 .148 .692 r
F P
0 g
s
.43561 .53467 m .43388 .53602 L .43327 .53432 L p 0 .031 .602 r
F P
0 g
s
.43586 .53617 m .43464 .5371 L .43388 .53602 L p 0 0 .502 r
F P
0 g
s
.43388 .53602 m .43561 .53467 L .43586 .53617 L p 0 0 .502 r
F P
0 g
s
.43786 .54485 m .43388 .53602 L .43464 .5371 L p 0 0 .491 r
F P
0 g
s
.22448 .78378 m .2835 .75652 L .29402 .74818 L p .76 .809 .892 r
F P
0 g
s
.29402 .74818 m .20956 .78721 L .22448 .78378 L p .76 .809 .892 r
F P
0 g
s
.54914 .50194 m .54854 .5067 L .54818 .50606 L p .901 .688 .179 r
F P
0 g
s
.43464 .5371 m .43744 .54329 L .43786 .54485 L p 0 0 .491 r
F P
0 g
s
.43839 .54299 m .43786 .54485 L .43744 .54329 L p 0 0 .401 r
F P
0 g
s
.43856 .54426 m .43819 .54555 L .43786 .54485 L p 0 0 .294 r
F P
0 g
s
.43786 .54485 m .43839 .54299 L .43856 .54426 L p 0 0 .294 r
F P
0 g
s
.43991 .55173 m .43786 .54485 L .43819 .54555 L p 0 0 .297 r
F P
0 g
s
.62064 .61945 m .61205 .61054 L .60934 .60681 L p 0 .148 .692 r
F P
0 g
s
.60934 .60681 m .62162 .61955 L .62064 .61945 L p 0 .148 .692 r
F P
0 g
s
.60611 .60124 m .6103 .60741 L .60934 .60681 L p 0 .084 .628 r
F P
0 g
s
.60934 .60681 m .60336 .598 L .60611 .60124 L p 0 .084 .628 r
F P
0 g
s
.62162 .61955 m .60934 .60681 L .6103 .60741 L p 0 .083 .628 r
F P
0 g
s
.4415 .56251 m .44159 .56889 L .44249 .56831 L p .998 .785 .469 r
F P
0 g
s
.37839 .49557 m .38277 .49257 L .3872 .49358 L p .433 .685 .97 r
F P
0 g
s
.41974 .51687 m .42648 .5242 L .42727 .52601 L p .083 .374 .838 r
F P
0 g
s
.42727 .52601 m .41765 .51556 L .41974 .51687 L p .083 .374 .838 r
F P
0 g
s
.43067 .52469 m .42727 .52601 L .42648 .5242 L p 0 .272 .777 r
F P
0 g
s
.43103 .52639 m .42864 .52731 L .42727 .52601 L p 0 .171 .704 r
F P
0 g
s
.42727 .52601 m .43067 .52469 L .43103 .52639 L p 0 .171 .704 r
F P
0 g
s
.43819 .54555 m .43963 .55037 L .43991 .55173 L p 0 0 .297 r
F P
0 g
s
.43971 .54921 m .43991 .55173 L .43963 .55037 L p 0 0 .228 r
F P
0 g
s
.43984 .5502 m .43998 .55197 L .43991 .55173 L p 0 0 .142 r
F P
0 g
s
.43991 .55173 m .43971 .54921 L .43984 .5502 L p 0 0 .142 r
F P
0 g
s
.44078 .55607 m .43991 .55173 L .43998 .55197 L p 0 0 .159 r
F P
0 g
s
.57378 .45458 m .56882 .45834 L .56642 .46012 L p .445 .829 .599 r
F P
0 g
s
.56642 .46012 m .57349 .45474 L .57378 .45458 L p .445 .829 .599 r
F P
0 g
s
.57349 .45474 m .56642 .46012 L .56655 .46013 L p 0 0 0 r
F P
0 g
s
.56261 .46476 m .56655 .46013 L .56642 .46012 L p 0 0 0 r
F P
0 g
s
.56642 .46012 m .56078 .46673 L .56261 .46476 L p 0 0 0 r
F P
0 g
s
.5565 .47132 m .552 .48027 L .55262 .47922 L p 0 0 .17 r
F P
0 g
s
.55257 .48076 m .55262 .47922 L .552 .48027 L p 0 0 .313 r
F P
0 g
s
.552 .48027 m .55192 .48247 L .55257 .48076 L p 0 0 .313 r
F P
0 g
s
.58853 .57828 m .58741 .57701 L .58828 .57855 L p .74 .274 0 r
F P
0 g
s
.58828 .57855 m .58989 .58035 L .58853 .57828 L p .74 .274 0 r
F P
0 g
s
.41509 .51411 m .40591 .5066 L .40451 .50481 L p .072 .434 .874 r
F P
0 g
s
.40451 .50481 m .41765 .51556 L .41509 .51411 L p .072 .434 .874 r
F P
0 g
s
.44176 .57724 m .44239 .57088 L .44159 .56889 L p .999 .822 .529 r
F P
0 g
s
.41165 .65016 m .42399 .63594 L .42561 .63135 L p .902 .858 .789 r
F P
0 g
s
.39164 .68167 m .38647 .67264 L .38138 .67424 L p .868 .858 .829 r
F P
0 g
s
.43998 .55197 m .44059 .555 L .44078 .55607 L p 0 0 .159 r
F P
0 g
s
.4402 .55303 m .44078 .55607 L .44059 .555 L p .707 .481 0 r
F P
0 g
s
.44031 .55369 m .44072 .55582 L .44078 .55607 L p .728 .525 0 r
F P
0 g
s
.44078 .55607 m .4402 .55303 L .44031 .55369 L p .728 .525 0 r
F P
0 g
s
.44101 .55754 m .44078 .55607 L .44072 .55582 L p .718 .498 0 r
F P
0 g
s
.27818 .47334 m .31991 .48449 L .31309 .48384 L p .605 .754 .95 r
F P
0 g
s
.28545 .47367 m .31468 .48148 L .31991 .48449 L p .607 .754 .948 r
F P
0 g
s
.31991 .48449 m .27818 .47334 L .28545 .47367 L p .607 .754 .948 r
F P
0 g
s
.32597 .47676 m .31991 .48449 L .31468 .48148 L p .588 .751 .955 r
F P
0 g
s
.32981 .47946 m .32555 .48485 L .31991 .48449 L p .583 .742 .952 r
F P
0 g
s
.31991 .48449 m .32597 .47676 L .32981 .47946 L p .583 .742 .952 r
F P
0 g
s
.44072 .55582 m .44088 .55685 L .44101 .55754 L p .718 .498 0 r
F P
0 g
s
.4403 .55431 m .44101 .55754 L .44088 .55685 L p .74 .534 0 r
F P
0 g
s
.44042 .55497 m .44092 .55723 L .44101 .55754 L p .749 .552 0 r
F P
0 g
s
.44101 .55754 m .4403 .55431 L .44042 .55497 L p .749 .552 0 r
F P
0 g
s
.44117 .55877 m .44101 .55754 L .44092 .55723 L p .74 .53 0 r
F P
0 g
s
.31309 .48384 m .2839 .47605 L .27818 .47334 L p .605 .754 .95 r
F P
0 g
s
.50584 .20245 m .49667 .14328 L .48601 .13066 L p .691 .674 .829 r
F P
0 g
s
.55035 .48768 m .55192 .48247 L .55131 .48487 L p .756 .763 .255 r
F P
0 g
s
.44092 .55723 m .44103 .55809 L .44117 .55877 L p .74 .53 0 r
F P
0 g
s
.44037 .55537 m .44117 .55877 L .44103 .55809 L p .756 .558 0 r
F P
0 g
s
.44053 .55641 m .44108 .55879 L .44117 .55877 L p .77 .588 .018 r
F P
0 g
s
.44117 .55877 m .44037 .55537 L .44053 .55641 L p .77 .588 .018 r
F P
0 g
s
.4415 .56251 m .44117 .55877 L .44108 .55879 L p .769 .574 .002 r
F P
0 g
s
.34189 .17104 m .36158 .16196 L .36606 .17466 L p .649 .65 .838 r
F P
0 g
s
.2179 .46926 m .27403 .48114 L .26531 .4802 L p .632 .758 .938 r
F P
0 g
s
.22702 .4697 m .26635 .47803 L .27403 .48114 L p .632 .758 .938 r
F P
0 g
s
.27403 .48114 m .2179 .46926 L .22702 .4697 L p .632 .758 .938 r
F P
0 g
s
.27818 .47334 m .27403 .48114 L .26635 .47803 L p .622 .758 .944 r
F P
0 g
s
.2839 .47605 m .28097 .4815 L .27403 .48114 L p .62 .755 .943 r
F P
0 g
s
.27403 .48114 m .27818 .47334 L .2839 .47605 L p .62 .755 .943 r
F P
0 g
s
.30416 .74514 m .34373 .72217 L .35062 .71533 L p .792 .816 .871 r
F P
0 g
s
.64281 .64616 m .63016 .636 L .62707 .63155 L p .176 .361 .809 r
F P
0 g
s
.55782 .20185 m .56125 .14264 L .55217 .12858 L p .707 .688 .829 r
F P
0 g
s
.54894 .49853 m .54986 .49042 L .55035 .48768 L p .839 .779 .274 r
F P
0 g
s
.62446 .62785 m .62064 .61945 L .62162 .61955 L p 0 .146 .69 r
F P
0 g
s
.62162 .61955 m .62707 .63155 L .62446 .62785 L p 0 .146 .69 r
F P
0 g
s
.62707 .63155 m .64516 .64606 L .64281 .64616 L p .176 .361 .809 r
F P
0 g
s
.62516 .62348 m .62897 .63187 L .62707 .63155 L p .038 .323 .807 r
F P
0 g
s
.62707 .63155 m .62162 .61955 L .62516 .62348 L p .038 .323 .807 r
F P
0 g
s
.64516 .64606 m .62707 .63155 L .62897 .63187 L p .039 .322 .807 r
F P
0 g
s
.44108 .55879 m .44132 .56141 L .4415 .56251 L p .769 .574 .002 r
F P
0 g
s
.44049 .55862 m .4415 .56251 L .44132 .56141 L p .788 .601 .037 r
F P
0 g
s
.44064 .56009 m .44135 .56281 L .4415 .56251 L p .817 .664 .116 r
F P
0 g
s
.4415 .56251 m .44049 .55862 L .44064 .56009 L p .817 .664 .116 r
F P
0 g
s
.44159 .56889 m .4415 .56251 L .44135 .56281 L p .82 .656 .107 r
F P
0 g
s
.55108 .48536 m .55218 .48172 L .55192 .48247 L p 0 0 0 r
F P
0 g
s
.55192 .48247 m .55035 .48768 L .55108 .48536 L p 0 0 0 r
F P
0 g
s
.42094 .62024 m .42561 .63135 L .42657 .62711 L p .951 .911 .742 r
F P
0 g
s
.42561 .63135 m .40797 .65168 L .41165 .65016 L p .902 .858 .789 r
F P
0 g
s
.41902 .6248 m .42231 .63256 L .42561 .63135 L p .916 .912 .801 r
F P
0 g
s
.42561 .63135 m .42094 .62024 L .41902 .6248 L p .916 .912 .801 r
F P
0 g
s
.40797 .65168 m .42561 .63135 L .42231 .63256 L p .916 .912 .801 r
F P
0 g
s
.59427 .44515 m .60104 .44309 L .60434 .44214 L p .225 .739 .713 r
F P
0 g
s
.40741 .50601 m .41661 .51354 L .41765 .51556 L p .285 .536 .915 r
F P
0 g
s
.41765 .51556 m .40451 .50481 L .40741 .50601 L p .285 .536 .915 r
F P
0 g
s
.42291 .51351 m .41765 .51556 L .41661 .51354 L p .189 .467 .887 r
F P
0 g
s
.42343 .51545 m .41974 .51687 L .41765 .51556 L p .163 .388 .835 r
F P
0 g
s
.41765 .51556 m .42291 .51351 L .42343 .51545 L p .163 .388 .835 r
F P
0 g
s
.59845 .59179 m .59194 .58303 L .58989 .58035 L p .612 .146 0 r
F P
0 g
s
.58989 .58035 m .59919 .59288 L .59845 .59179 L p .612 .146 0 r
F P
0 g
s
.58992 .5807 m .59105 .58196 L .58989 .58035 L p .644 .166 0 r
F P
0 g
s
.58989 .58035 m .58828 .57855 L .58992 .5807 L p .644 .166 0 r
F P
0 g
s
.59919 .59288 m .58989 .58035 L .59105 .58196 L p .645 .166 0 r
F P
0 g
s
.44159 .56889 m .44069 .57798 L .44176 .57724 L p .999 .822 .529 r
F P
0 g
s
.61487 .4422 m .60496 .44239 L .60434 .44214 L p .232 .746 .861 r
F P
0 g
s
.60434 .44214 m .61849 .44187 L .61487 .4422 L p .232 .746 .861 r
F P
0 g
s
.26531 .4802 m .22603 .47189 L .2179 .46926 L p .632 .758 .938 r
F P
0 g
s
.43327 .53432 m .43448 .53337 L .43561 .53467 L p 0 .031 .602 r
F P
0 g
s
.43744 .54329 m .4378 .54198 L .43839 .54299 L p 0 0 .401 r
F P
0 g
s
.55262 .47922 m .55577 .47296 L .5565 .47132 L p 0 0 .17 r
F P
0 g
s
.63178 .4379 m .61849 .44187 L .61826 .44115 L p .409 .828 .969 r
F P
0 g
s
.60835 .44134 m .61826 .44115 L .61849 .44187 L p .462 .864 .965 r
F P
0 g
s
.61849 .44187 m .60434 .44214 L .60835 .44134 L p .462 .864 .965 r
F P
0 g
s
.63202 .43906 m .62271 .44183 L .61849 .44187 L p .451 .804 .997 r
F P
0 g
s
.61849 .44187 m .63178 .4379 L .63202 .43906 L p .451 .804 .997 r
F P
0 g
s
.35062 .71533 m .29402 .74818 L .30416 .74514 L p .792 .816 .871 r
F P
0 g
s
.22388 .47735 m .22329 .47855 L .21466 .47728 L p .637 .76 .937 r
F P
0 g
s
.75386 .74605 m .76291 .72571 L .77366 .72546 L p .502 .605 .888 r
F P
0 g
s
.43963 .55037 m .43948 .5486 L .43971 .54921 L p 0 0 .228 r
F P
0 g
s
.38189 .68919 m .35512 .70896 L .35062 .71533 L p .831 .848 .859 r
F P
0 g
s
.42648 .5242 m .42885 .52327 L .43067 .52469 L p 0 .272 .777 r
F P
0 g
s
.58576 .57521 m .58689 .57644 L .58828 .57855 L p .748 .279 0 r
F P
0 g
s
.43913 .58891 m .44116 .58068 L .44069 .57798 L p .993 .86 .598 r
F P
0 g
s
.56674 .5523 m .57178 .55652 L .57387 .55921 L p .852 .409 0 r
F P
0 g
s
.57387 .55921 m .56666 .55318 L .56674 .5523 L p .852 .409 0 r
F P
0 g
s
.57959 .56918 m .57396 .5602 L .57387 .55921 L p .803 .33 0 r
F P
0 g
s
.57387 .55921 m .58192 .57204 L .57959 .56918 L p .803 .33 0 r
F P
0 g
s
.56666 .55318 m .57387 .55921 L .57396 .5602 L p .805 .339 0 r
F P
0 g
s
.58192 .57204 m .57387 .55921 L .57581 .56188 L p .771 .303 0 r
F P
0 g
s
.27926 .75056 m .22 .77794 L .20956 .78721 L p .761 .825 .902 r
F P
0 g
s
.20956 .78721 m .29402 .74818 L .27926 .75056 L p .761 .825 .902 r
F P
0 g
s
.19229 .76078 m .20956 .78721 L .22 .77794 L p .761 .825 .902 r
F P
0 g
s
.44135 .56281 m .44141 .56728 L .44159 .56889 L p .82 .656 .107 r
F P
0 g
s
.44033 .56409 m .44159 .56889 L .44141 .56728 L p .837 .678 .139 r
F P
0 g
s
.44037 .56608 m .44126 .56943 L .44159 .56889 L p .873 .762 .256 r
F P
0 g
s
.44159 .56889 m .44033 .56409 L .44037 .56608 L p .873 .762 .256 r
F P
0 g
s
.44069 .57798 m .44159 .56889 L .44126 .56943 L p .877 .758 .253 r
F P
0 g
s
.56655 .46013 m .5715 .45637 L .57349 .45474 L p 0 0 0 r
F P
0 g
s
.44059 .555 m .44018 .55287 L .4402 .55303 L p .707 .481 0 r
F P
0 g
s
.65096 .66183 m .66945 .67451 L .67367 .67969 L p .302 .47 .86 r
F P
0 g
s
.57581 .56188 m .58144 .57085 L .58192 .57204 L p .771 .303 0 r
F P
0 g
s
.44088 .55685 m .44038 .55459 L .4403 .55431 L p .74 .534 0 r
F P
0 g
s
.34158 .69945 m .35062 .71533 L .35512 .70896 L p .831 .847 .859 r
F P
0 g
s
.33422 .70647 m .34062 .71756 L .35062 .71533 L p .795 .836 .883 r
F P
0 g
s
.35062 .71533 m .34158 .69945 L .33422 .70647 L p .795 .836 .883 r
F P
0 g
s
.29402 .74818 m .35062 .71533 L .34062 .71756 L p .795 .836 .883 r
F P
0 g
s
.44103 .55809 m .44047 .55571 L .44037 .55537 L p .756 .558 0 r
F P
0 g
s
.42657 .62711 m .42331 .61932 L .42094 .62024 L p .951 .911 .742 r
F P
0 g
s
.6103 .60741 m .6189 .61632 L .62162 .61955 L p 0 .083 .628 r
F P
0 g
s
.3515 .48734 m .32981 .47946 L .32597 .47676 L p .555 .735 .959 r
F P
0 g
s
.32597 .47676 m .35698 .48803 L .3515 .48734 L p .555 .735 .959 r
F P
0 g
s
.76001 .45111 m .73222 .45718 L .72455 .45559 L p .613 .724 .925 r
F P
0 g
s
.83407 .7813 m .8484 .75455 L .86483 .7537 L p .539 .648 .905 r
F P
0 g
s
.40108 .5036 m .38897 .49575 L .3872 .49358 L p .335 .604 .946 r
F P
0 g
s
.3872 .49358 m .40451 .50481 L .40108 .5036 L p .335 .604 .946 r
F P
0 g
s
.21466 .47728 m .2155 .47556 L .22388 .47735 L p .637 .76 .937 r
F P
0 g
s
.44132 .56141 m .44061 .55868 L .44049 .55862 L p .788 .601 .037 r
F P
0 g
s
.55948 .46844 m .55727 .47131 L .55762 .47084 L p .57 .816 .438 r
F P
0 g
s
.55762 .47084 m .56078 .46673 L .55948 .46844 L p .57 .816 .438 r
F P
0 g
s
.3319 .47726 m .35363 .48516 L .35698 .48803 L p .566 .735 .955 r
F P
0 g
s
.35698 .48803 m .32597 .47676 L .3319 .47726 L p .566 .735 .955 r
F P
0 g
s
.36472 .4814 m .35698 .48803 L .35363 .48516 L p .534 .723 .961 r
F P
0 g
s
.36705 .48406 m .36162 .48869 L .35698 .48803 L p .523 .702 .951 r
F P
0 g
s
.35698 .48803 m .36472 .4814 L .36705 .48406 L p .523 .702 .951 r
F P
0 g
s
.58828 .57855 m .58668 .5768 L .58576 .57521 L p .748 .279 0 r
F P
0 g
s
.59605 .58905 m .58946 .58018 L .58828 .57855 L p .656 .174 0 r
F P
0 g
s
.58828 .57855 m .59771 .59122 L .59605 .58905 L p .656 .174 0 r
F P
0 g
s
.58668 .5768 m .58828 .57855 L .58946 .58018 L p .656 .174 0 r
F P
0 g
s
.59652 .58957 m .58992 .5807 L .58828 .57855 L p .645 .166 0 r
F P
0 g
s
.58828 .57855 m .59771 .59122 L .59652 .58957 L p .645 .166 0 r
F P
0 g
s
.59105 .58196 m .59755 .59073 L .59919 .59288 L p .645 .166 0 r
F P
0 g
s
.7643 .44688 m .72455 .45559 L .72807 .45173 L p .61 .739 .937 r
F P
0 g
s
.71773 .44081 m .72807 .45173 L .72455 .45559 L p .611 .741 .938 r
F P
0 g
s
.72455 .45559 m .70975 .44003 L .71773 .44081 L p .611 .741 .938 r
F P
0 g
s
.72455 .45559 m .7643 .44688 L .76001 .45111 L p .613 .724 .925 r
F P
0 g
s
.70975 .44003 m .72455 .45559 L .718 .45415 L p .576 .728 .946 r
F P
0 g
s
.41661 .51354 m .42029 .5121 L .42291 .51351 L p .189 .467 .887 r
F P
0 g
s
.78293 .46293 m .82193 .45632 L .8323 .45836 L p .633 .736 .922 r
F P
0 g
s
.31468 .48148 m .3189 .47606 L .32597 .47676 L p .588 .751 .955 r
F P
0 g
s
.37439 .17112 m .36956 .1731 L .36158 .16196 L p .653 .652 .836 r
F P
0 g
s
.64277 .44237 m .63202 .43906 L .63178 .4379 L p .415 .776 .995 r
F P
0 g
s
.63178 .4379 m .64715 .44264 L .64277 .44237 L p .415 .776 .995 r
F P
0 g
s
.44126 .56943 m .44062 .5758 L .44069 .57798 L p .877 .758 .253 r
F P
0 g
s
.43929 .57185 m .44069 .57798 L .44062 .5758 L p .887 .772 .274 r
F P
0 g
s
.44069 .57798 m .43779 .58975 L .43913 .58891 L p .993 .86 .598 r
F P
0 g
s
.43907 .57442 m .44005 .5787 L .44069 .57798 L p .918 .858 .417 r
F P
0 g
s
.44069 .57798 m .43929 .57185 L .43907 .57442 L p .918 .858 .417 r
F P
0 g
s
.43779 .58975 m .44069 .57798 L .44005 .5787 L p .92 .856 .415 r
F P
0 g
s
.55351 .52544 m .55402 .52676 L .55395 .52712 L p .787 .439 0 r
F P
0 g
s
.55395 .52712 m .55323 .52523 L .55351 .52544 L p .787 .439 0 r
F P
0 g
s
.55261 .52305 m .55319 .52465 L .55323 .52523 L p .776 .44 0 r
F P
0 g
s
.55323 .52523 m .5524 .52294 L .55261 .52305 L p .776 .44 0 r
F P
0 g
s
.718 .45415 m .70763 .44328 L .70975 .44003 L p .576 .728 .946 r
F P
0 g
s
.26635 .47803 m .26923 .47256 L .27818 .47334 L p .622 .758 .944 r
F P
0 g
s
.55468 .52816 m .55634 .53212 L .55632 .53279 L p .819 .449 0 r
F P
0 g
s
.55632 .53279 m .55395 .52712 L .55468 .52816 L p .819 .449 0 r
F P
0 g
s
.66631 .43715 m .64715 .44264 L .64756 .44094 L p .515 .794 .996 r
F P
0 g
s
.6368 .43762 m .64756 .44094 L .64715 .44264 L p .535 .813 .997 r
F P
0 g
s
.64715 .44264 m .63178 .4379 L .6368 .43762 L p .535 .813 .997 r
F P
0 g
s
.66566 .43933 m .65225 .44317 L .64715 .44264 L p .528 .758 .981 r
F P
0 g
s
.64715 .44264 m .66631 .43715 L .66566 .43933 L p .528 .758 .981 r
F P
0 g
s
.44141 .56728 m .44052 .56392 L .44033 .56409 L p .837 .678 .139 r
F P
0 g
s
.391 .49461 m .40313 .50248 L .40451 .50481 L p .427 .633 .941 r
F P
0 g
s
.40451 .50481 m .3872 .49358 L .391 .49461 L p .427 .633 .941 r
F P
0 g
s
.41166 .50137 m .40451 .50481 L .40313 .50248 L p .362 .593 .934 r
F P
0 g
s
.41242 .50361 m .40741 .50601 L .40451 .50481 L p .343 .536 .899 r
F P
0 g
s
.40451 .50481 m .41166 .50137 L .41242 .50361 L p .343 .536 .899 r
F P
0 g
s
.55062 .51671 m .55208 .5214 L .5524 .52294 L p .788 .477 0 r
F P
0 g
s
.58035 .451 m .57378 .45458 L .57349 .45474 L p 0 0 0 r
F P
0 g
s
.57349 .45474 m .58287 .44963 L .58035 .451 L p 0 0 0 r
F P
0 g
s
.56678 .45902 m .56078 .46673 L .56114 .46609 L p .662 .927 .636 r
F P
0 g
s
.55893 .46897 m .56114 .46609 L .56078 .46673 L p .649 .867 .495 r
F P
0 g
s
.56078 .46673 m .55762 .47084 L .55893 .46897 L p .649 .867 .495 r
F P
0 g
s
.56681 .45936 m .56261 .46476 L .56078 .46673 L p .682 .948 .683 r
F P
0 g
s
.56078 .46673 m .56678 .45902 L .56681 .45936 L p .682 .948 .683 r
F P
0 g
s
.34062 .71756 m .30093 .74059 L .29402 .74818 L p .795 .836 .883 r
F P
0 g
s
.28207 .72804 m .29402 .74818 L .30093 .74059 L p .795 .837 .883 r
F P
0 g
s
.27077 .73651 m .27926 .75056 L .29402 .74818 L p .761 .825 .902 r
F P
0 g
s
.29402 .74818 m .28207 .72804 L .27077 .73651 L p .761 .825 .902 r
F P
0 g
s
.5524 .52294 m .55031 .51624 L .55062 .51671 L p .788 .477 0 r
F P
0 g
s
.22603 .47189 m .22433 .4763 L .2155 .47556 L p .639 .757 .934 r
F P
0 g
s
.42231 .63256 m .40994 .64681 L .40797 .65168 L p .916 .912 .801 r
F P
0 g
s
.58144 .57085 m .58477 .57419 L .58668 .5768 L p .773 .302 0 r
F P
0 g
s
.35512 .70896 m .34883 .69782 L .34158 .69945 L p .831 .847 .859 r
F P
0 g
s
.62897 .63187 m .64164 .64204 L .64516 .64606 L p .039 .322 .807 r
F P
0 g
s
.61826 .44115 m .62756 .43837 L .63178 .4379 L p .409 .828 .969 r
F P
0 g
s
.55767 .5347 m .56066 .54102 L .5606 .54183 L p .855 .455 0 r
F P
0 g
s
.5606 .54183 m .55632 .53279 L .55767 .5347 L p .855 .455 0 r
F P
0 g
s
.70763 .44328 m .68818 .44831 L .68195 .44725 L p .578 .73 .947 r
F P
0 g
s
.67661 .44639 m .66566 .43933 L .66631 .43715 L p .517 .746 .978 r
F P
0 g
s
.66631 .43715 m .68195 .44725 L .67661 .44639 L p .517 .746 .978 r
F P
0 g
s
.59162 .44425 m .58287 .44963 L .58269 .44942 L p .469 .889 .804 r
F P
0 g
s
.57612 .453 m .58269 .44942 L .58287 .44963 L p .546 .919 .768 r
F P
0 g
s
.58287 .44963 m .57349 .45474 L .57612 .453 L p .546 .919 .768 r
F P
0 g
s
.59215 .44456 m .58602 .44833 L .58287 .44963 L p .509 .911 .892 r
F P
0 g
s
.58287 .44963 m .59162 .44425 L .59215 .44456 L p .509 .911 .892 r
F P
0 g
s
.57396 .5602 m .56892 .55598 L .56666 .55318 L p .805 .339 0 r
F P
0 g
s
.70975 .44003 m .68195 .44725 L .68358 .44447 L p .573 .756 .965 r
F P
0 g
s
.67263 .43738 m .68358 .44447 L .68195 .44725 L p .58 .765 .967 r
F P
0 g
s
.68195 .44725 m .66631 .43715 L .67263 .43738 L p .58 .765 .967 r
F P
0 g
s
.68195 .44725 m .70975 .44003 L .70763 .44328 L p .578 .73 .947 r
F P
0 g
s
.43344 .60305 m .4377 .59312 L .43779 .58975 L p .977 .891 .671 r
F P
0 g
s
.2155 .47556 m .2179 .46926 L .22603 .47189 L p .639 .757 .934 r
F P
0 g
s
.58668 .5768 m .58192 .57204 L .58144 .57085 L p .773 .302 0 r
F P
0 g
s
.59406 .58695 m .5874 .57801 L .58668 .5768 L p .685 .194 0 r
F P
0 g
s
.58668 .5768 m .5962 .58957 L .59406 .58695 L p .685 .194 0 r
F P
0 g
s
.58192 .57204 m .58668 .5768 L .5874 .57801 L p .684 .194 0 r
F P
0 g
s
.58946 .58018 m .58833 .57896 L .58668 .5768 L p .656 .174 0 r
F P
0 g
s
.5962 .58957 m .58668 .5768 L .58833 .57896 L p .656 .174 0 r
F P
0 g
s
.54854 .5067 m .55003 .51382 L .55031 .51624 L p .86 .6 .066 r
F P
0 g
s
.36158 .16196 m .3685 .15909 L .37439 .17112 L p .653 .652 .836 r
F P
0 g
s
.55296 .47667 m .55035 .48768 L .55014 .48692 L p .917 .939 .58 r
F P
0 g
s
.54799 .4915 m .55014 .48692 L .55035 .48768 L p .917 .877 .451 r
F P
0 g
s
.55035 .48768 m .54729 .49422 L .54799 .4915 L p .917 .877 .451 r
F P
0 g
s
.55291 .47765 m .55108 .48536 L .55035 .48768 L p .883 .902 .489 r
F P
0 g
s
.55035 .48768 m .55296 .47667 L .55291 .47765 L p .883 .902 .489 r
F P
0 g
s
.54729 .49422 m .55035 .48768 L .54986 .49042 L p .977 .868 .486 r
F P
0 g
s
.54986 .49042 m .54772 .495 L .54729 .49422 L p .977 .868 .486 r
F P
0 g
s
.44062 .5758 m .43964 .57151 L .43929 .57185 L p .887 .772 .274 r
F P
0 g
s
.55685 .47233 m .55657 .47325 L .55722 .47215 L p 0 0 0 r
F P
0 g
s
.55722 .47215 m .55762 .47084 L .55685 .47233 L p 0 0 0 r
F P
0 g
s
.37622 .17039 m .38114 .16848 L .37553 .15634 L p .655 .653 .836 r
F P
0 g
s
.37553 .15634 m .3685 .15909 L .37622 .17039 L p .655 .653 .836 r
F P
0 g
s
.56114 .46609 m .56534 .46069 L .56678 .45902 L p .662 .927 .636 r
F P
0 g
s
.5524 .52294 m .55323 .52523 L .55227 .52504 L p .97 .652 .326 r
F P
0 g
s
.54826 .52559 m .55227 .52504 L .55323 .52523 L p .969 .649 .322 r
F P
0 g
s
.55323 .52523 m .5475 .52601 L .54826 .52559 L p .969 .649 .322 r
F P
0 g
s
.55298 .52692 m .55247 .52559 L .55323 .52523 L p .965 .636 .309 r
F P
0 g
s
.55323 .52523 m .55395 .52712 L .55298 .52692 L p .965 .636 .309 r
F P
0 g
s
.5475 .52601 m .55323 .52523 L .55247 .52559 L p .964 .635 .308 r
F P
0 g
s
.55031 .51624 m .5524 .52294 L .5513 .52225 L p .982 .693 .371 r
F P
0 g
s
.54745 .52318 m .5513 .52225 L .5524 .52294 L p .979 .681 .354 r
F P
0 g
s
.5524 .52294 m .5469 .52427 L .54745 .52318 L p .979 .681 .354 r
F P
0 g
s
.55227 .52504 m .55169 .52344 L .5524 .52294 L p .97 .652 .326 r
F P
0 g
s
.5469 .52427 m .5524 .52294 L .55169 .52344 L p .969 .649 .323 r
F P
0 g
s
.54882 .52714 m .55298 .52692 L .55395 .52712 L p .964 .634 .307 r
F P
0 g
s
.55395 .52712 m .54801 .52744 L .54882 .52714 L p .964 .634 .307 r
F P
0 g
s
.55503 .53189 m .55337 .52792 L .55395 .52712 L p .953 .605 .278 r
F P
0 g
s
.55395 .52712 m .55632 .53279 L .55503 .53189 L p .953 .605 .278 r
F P
0 g
s
.54801 .52744 m .55395 .52712 L .55337 .52792 L p .955 .608 .28 r
F P
0 g
s
.38647 .67264 m .40505 .65686 L .40797 .65168 L p .868 .857 .828 r
F P
0 g
s
.35363 .48516 m .35903 .48051 L .36472 .4814 L p .534 .723 .961 r
F P
0 g
s
.63314 .15293 m .68546 .16911 L .70206 .16083 L p .723 .705 .833 r
F P
0 g
s
.44005 .5787 m .43802 .58695 L .43779 .58975 L p .92 .856 .415 r
F P
0 g
s
.40313 .50248 m .40813 .50006 L .41166 .50137 L p .362 .593 .934 r
F P
0 g
s
.58833 .57896 m .59499 .5879 L .5962 .58957 L p .656 .174 0 r
F P
0 g
s
.22 .77794 m .20808 .75938 L .19229 .76078 L p .761 .825 .902 r
F P
0 g
s
.43652 .58189 m .43779 .58975 L .43802 .58695 L p .924 .861 .425 r
F P
0 g
s
.43779 .58975 m .43168 .60395 L .43344 .60305 L p .977 .891 .671 r
F P
0 g
s
.43583 .58506 m .43672 .59055 L .43779 .58975 L p .939 .931 .573 r
F P
0 g
s
.43779 .58975 m .43652 .58189 L .43583 .58506 L p .939 .931 .573 r
F P
0 g
s
.43168 .60395 m .43779 .58975 L .43672 .59055 L p .94 .93 .573 r
F P
0 g
s
.55031 .51624 m .54818 .50606 L .54854 .5067 L p .86 .6 .066 r
F P
0 g
s
.54818 .50606 m .55031 .51624 L .54924 .51528 L p .996 .766 .46 r
F P
0 g
s
.54571 .51727 m .54924 .51528 L .55031 .51624 L p .993 .741 .417 r
F P
0 g
s
.55031 .51624 m .54528 .5191 L .54571 .51727 L p .993 .741 .417 r
F P
0 g
s
.5513 .52225 m .54984 .51755 L .55031 .51624 L p .982 .693 .371 r
F P
0 g
s
.54528 .5191 m .55031 .51624 L .54984 .51755 L p .979 .685 .37 r
F P
0 g
s
.55036 .53116 m .55503 .53189 L .55632 .53279 L p .955 .609 .284 r
F P
0 g
s
.55632 .53279 m .54965 .53176 L .55036 .53116 L p .955 .609 .284 r
F P
0 g
s
.55887 .54018 m .55587 .53384 L .55632 .53279 L p .932 .552 .227 r
F P
0 g
s
.55632 .53279 m .5606 .54183 L .55887 .54018 L p .932 .552 .227 r
F P
0 g
s
.54965 .53176 m .55632 .53279 L .55587 .53384 L p .935 .56 .23 r
F P
0 g
s
.60137 .59538 m .59845 .59179 L .59919 .59288 L p .611 .146 0 r
F P
0 g
s
.59919 .59288 m .60336 .598 L .60137 .59538 L p .611 .146 0 r
F P
0 g
s
.55762 .47084 m .56276 .46171 L .56253 .46257 L p .799 .985 .723 r
F P
0 g
s
.56253 .46257 m .55893 .46897 L .55762 .47084 L p .799 .985 .723 r
F P
0 g
s
.55802 .47056 m .55722 .47215 L p .55967 .46728 L .64 .785 .332 r
F P
0 g
s
.5614 .46385 m .55971 .46721 L p .55967 .46728 L .64 .785 .332 r
F P
0 g
s
.55971 .46721 m .55802 .47056 L p .55967 .46728 L .64 .785 .332 r
F P
0 g
s
.55762 .47084 m .5583 .46964 L p .56014 .46638 L 0 0 0 r
F P
0 g
s
.56276 .46171 m .56019 .46629 L p .56014 .46638 L 0 0 0 r
F P
0 g
s
.56019 .46629 m .55762 .47084 L p .56014 .46638 L 0 0 0 r
F P
0 g
s
.55802 .47056 m .5583 .46964 L .55762 .47084 L p 0 0 0 r
F P
0 g
s
.55762 .47084 m .55722 .47215 L .55802 .47056 L p 0 0 0 r
F P
0 g
s
.30093 .74059 m .29265 .72646 L .28207 .72804 L p .795 .837 .883 r
F P
0 g
s
.70649 .70093 m .67861 .68607 L .67367 .67969 L p .453 .55 .865 r
F P
0 g
s
.58269 .44942 m .58881 .44566 L .59162 .44425 L p .469 .889 .804 r
F P
0 g
s
.40364 .63833 m .40797 .65168 L .40994 .64681 L p .916 .912 .801 r
F P
0 g
s
.40797 .65168 m .38138 .67424 L .38647 .67264 L p .868 .857 .828 r
F P
0 g
s
.4003 .64352 m .40336 .65284 L .40797 .65168 L p .875 .902 .846 r
F P
0 g
s
.40797 .65168 m .40364 .63833 L .4003 .64352 L p .875 .902 .846 r
F P
0 g
s
.38138 .67424 m .40797 .65168 L .40336 .65284 L p .875 .902 .846 r
F P
0 g
s
.56249 .54436 m .56674 .5523 L .56666 .55318 L p .859 .428 0 r
F P
0 g
s
.56666 .55318 m .5606 .54183 L .56249 .54436 L p .859 .428 0 r
F P
0 g
s
.55014 .48692 m .55196 .47921 L .55296 .47667 L p .917 .939 .58 r
F P
0 g
s
.64756 .44094 m .66097 .43709 L .66631 .43715 L p .515 .794 .996 r
F P
0 g
s
.5874 .57801 m .58406 .57467 L .58192 .57204 L p .684 .194 0 r
F P
0 g
s
.38277 .49257 m .36705 .48406 L .36472 .4814 L p .478 .68 .954 r
F P
0 g
s
.36472 .4814 m .3872 .49358 L .38277 .49257 L p .478 .68 .954 r
F P
0 g
s
.61494 .6103 m .60611 .60124 L .60336 .598 L p 0 .087 .632 r
F P
0 g
s
.60336 .598 m .61597 .61094 L .61494 .6103 L p 0 .087 .632 r
F P
0 g
s
.6017 .59558 m .60462 .59917 L .60336 .598 L p 0 .039 .57 r
F P
0 g
s
.60336 .598 m .59919 .59288 L .6017 .59558 L p 0 .039 .57 r
F P
0 g
s
.61597 .61094 m .60336 .598 L .60462 .59917 L p 0 .039 .57 r
F P
0 g
s
.55577 .47296 m .55539 .47407 L .55595 .47291 L p 0 0 0 r
F P
0 g
s
.55595 .47291 m .5565 .47132 L .55577 .47296 L p 0 0 0 r
F P
0 g
s
.54772 .495 m .54834 .50328 L .54818 .50606 L p .96 .785 .341 r
F P
0 g
s
.56191 .46325 m .56276 .46171 L p .56014 .46638 L 0 0 0 r
F P
0 g
s
.5583 .46964 m .5601 .46645 L p .56014 .46638 L 0 0 0 r
F P
0 g
s
.5601 .46645 m .56191 .46325 L p .56014 .46638 L 0 0 0 r
F P
0 g
s
.56204 .46257 m .5614 .46385 L p .55967 .46728 L .64 .785 .332 r
F P
0 g
s
.55722 .47215 m .55962 .46737 L p .55967 .46728 L .64 .785 .332 r
F P
0 g
s
.55962 .46737 m .56204 .46257 L p .55967 .46728 L .64 .785 .332 r
F P
0 g
s
.55169 .52344 m .54784 .52437 L .5469 .52427 L p .969 .649 .323 r
F P
0 g
s
.55247 .52559 m .54846 .52614 L .5475 .52601 L p .964 .635 .308 r
F P
0 g
s
.72807 .45173 m .75592 .44561 L .7643 .44688 L p .61 .739 .937 r
F P
0 g
s
.55337 .52792 m .54921 .52814 L .54801 .52744 L p .955 .608 .28 r
F P
0 g
s
.43802 .58695 m .43714 .58144 L .43652 .58189 L p .924 .861 .425 r
F P
0 g
s
.36959 .48225 m .38534 .49079 L .3872 .49358 L p .518 .687 .944 r
F P
0 g
s
.3872 .49358 m .36472 .4814 L .36959 .48225 L p .518 .687 .944 r
F P
0 g
s
.39625 .48821 m .3872 .49358 L .38534 .49079 L p .478 .666 .945 r
F P
0 g
s
.39735 .49086 m .391 .49461 L .3872 .49358 L p .463 .626 .923 r
F P
0 g
s
.3872 .49358 m .39625 .48821 L .39735 .49086 L p .463 .626 .923 r
F P
0 g
s
.54984 .51755 m .54632 .51956 L .54528 .5191 L p .979 .685 .37 r
F P
0 g
s
.55331 .53808 m .55887 .54018 L .5606 .54183 L p .937 .564 .247 r
F P
0 g
s
.5606 .54183 m .55266 .53884 L .55331 .53808 L p .937 .564 .247 r
F P
0 g
s
.56446 .55089 m .56021 .54294 L .5606 .54183 L p .901 .487 .163 r
F P
0 g
s
.5606 .54183 m .56666 .55318 L .56446 .55089 L p .901 .487 .163 r
F P
0 g
s
.55266 .53884 m .5606 .54183 L .56021 .54294 L p .907 .497 .166 r
F P
0 g
s
.54729 .49422 m .54818 .50606 L .54722 .50507 L p .995 .846 .578 r
F P
0 g
s
.54368 .50834 m .54722 .50507 L .54818 .50606 L p .999 .814 .513 r
F P
0 g
s
.54818 .50606 m .54313 .51075 L .54368 .50834 L p .999 .814 .513 r
F P
0 g
s
.54818 .50606 m .54729 .49422 L .54772 .495 L p .96 .785 .341 r
F P
0 g
s
.54924 .51528 m .54775 .50815 L .54818 .50606 L p .996 .766 .46 r
F P
0 g
s
.54313 .51075 m .54818 .50606 L .54775 .50815 L p .99 .749 .471 r
F P
0 g
s
.38485 .16716 m .39981 .162 L .39695 .14892 L p .659 .654 .834 r
F P
0 g
s
.39695 .14892 m .37553 .15634 L .38485 .16716 L p .659 .654 .834 r
F P
0 g
s
.70206 .16083 m .62714 .13751 L .63314 .15293 L p .723 .705 .833 r
F P
0 g
s
.40994 .64681 m .40693 .63745 L .40364 .63833 L p .916 .912 .801 r
F P
0 g
s
.60104 .44309 m .59215 .44456 L .59162 .44425 L p .422 .865 .899 r
F P
0 g
s
.59162 .44425 m .60434 .44214 L .60104 .44309 L p .422 .865 .899 r
F P
0 g
s
.55673 .47121 m .55595 .47291 L p .55826 .46779 L .701 .825 .379 r
F P
0 g
s
.55988 .46419 m .5583 .46771 L p .55826 .46779 L .701 .825 .379 r
F P
0 g
s
.5583 .46771 m .55673 .47121 L p .55826 .46779 L .701 .825 .379 r
F P
0 g
s
.5565 .47132 m .55711 .4701 L p .55884 .46666 L .641 .786 .333 r
F P
0 g
s
.56132 .46173 m .5589 .46654 L p .55884 .46666 L .641 .786 .333 r
F P
0 g
s
.5589 .46654 m .5565 .47132 L p .55884 .46666 L .641 .786 .333 r
F P
0 g
s
.55673 .47121 m .55711 .4701 L .5565 .47132 L p 0 0 0 r
F P
0 g
s
.5565 .47132 m .55595 .47291 L .55673 .47121 L p 0 0 0 r
F P
0 g
s
.67244 .66231 m .67367 .67969 L .66945 .67451 L p .302 .47 .86 r
F P
0 g
s
.67367 .67969 m .71358 .70094 L .70649 .70093 L p .453 .55 .865 r
F P
0 g
s
.67868 .66784 m .6795 .68 L .67367 .67969 L p .393 .55 .892 r
F P
0 g
s
.67367 .67969 m .67244 .66231 L .67868 .66784 L p .393 .55 .892 r
F P
0 g
s
.71358 .70094 m .67367 .67969 L .6795 .68 L p .394 .549 .891 r
F P
0 g
s
.555 .47503 m .55291 .47765 L .55296 .47667 L p .898 .97 .659 r
F P
0 g
s
.55296 .47667 m .55595 .47291 L .555 .47503 L p .898 .97 .659 r
F P
0 g
s
.55587 .53384 m .5512 .53313 L .54965 .53176 L p .935 .56 .23 r
F P
0 g
s
.68358 .44447 m .70304 .4394 L .70975 .44003 L p .573 .756 .965 r
F P
0 g
s
.5715 .45637 m .56681 .45936 L .56678 .45902 L p .624 .949 .764 r
F P
0 g
s
.56678 .45902 m .57349 .45474 L .5715 .45637 L p .624 .949 .764 r
F P
0 g
s
.42331 .61932 m .43082 .60793 L .43168 .60395 L p .951 .909 .741 r
F P
0 g
s
.43672 .59055 m .43244 .6005 L .43168 .60395 L p .94 .93 .573 r
F P
0 g
s
.61631 .43586 m .60434 .44214 L .60411 .44135 L p .524 .893 .97 r
F P
0 g
s
.59521 .44283 m .60411 .44135 L .60434 .44214 L p .578 .925 .956 r
F P
0 g
s
.60434 .44214 m .59162 .44425 L .59521 .44283 L p .578 .925 .956 r
F P
0 g
s
.61674 .43694 m .60835 .44134 L .60434 .44214 L p .538 .87 .993 r
F P
0 g
s
.60434 .44214 m .61631 .43586 L .61674 .43694 L p .538 .87 .993 r
F P
0 g
s
.56049 .46338 m .56132 .46173 L p .55884 .46666 L .641 .786 .333 r
F P
0 g
s
.55711 .4701 m .5588 .46674 L p .55884 .46666 L .641 .786 .333 r
F P
0 g
s
.5588 .46674 m .56049 .46338 L p .55884 .46666 L .641 .786 .333 r
F P
0 g
s
.56045 .46288 m .55988 .46419 L p .55826 .46779 L .701 .825 .379 r
F P
0 g
s
.55595 .47291 m .5582 .46791 L p .55826 .46779 L .701 .825 .379 r
F P
0 g
s
.5582 .46791 m .56045 .46288 L p .55826 .46779 L .701 .825 .379 r
F P
0 g
s
.56045 .46288 m .55595 .47291 L .5561 .47189 L p .859 .994 .753 r
F P
0 g
s
.55401 .47452 m .5561 .47189 L .55595 .47291 L p .866 .966 .641 r
F P
0 g
s
.55595 .47291 m .55296 .47667 L .55401 .47452 L p .866 .966 .641 r
F P
0 g
s
.66945 .67451 m .66856 .66234 L .67244 .66231 L p .302 .47 .86 r
F P
0 g
s
.58111 .44704 m .57349 .45474 L .57354 .4541 L p .669 .975 .873 r
F P
0 g
s
.56885 .45709 m .57354 .4541 L .57349 .45474 L p .714 .985 .813 r
F P
0 g
s
.57349 .45474 m .56678 .45902 L .56885 .45709 L p .714 .985 .813 r
F P
0 g
s
.58146 .4476 m .57612 .453 L .57349 .45474 L p .676 .973 .904 r
F P
0 g
s
.57349 .45474 m .58111 .44704 L .58146 .4476 L p .676 .973 .904 r
F P
0 g
s
.22276 .45905 m .27818 .47334 L .26923 .47256 L p .629 .754 .937 r
F P
0 g
s
.23226 .45941 m .2711 .46944 L .27818 .47334 L p .63 .754 .937 r
F P
0 g
s
.27818 .47334 m .22276 .45905 L .23226 .45941 L p .63 .754 .937 r
F P
0 g
s
.28534 .46298 m .27818 .47334 L .2711 .46944 L p .62 .753 .941 r
F P
0 g
s
.29048 .46643 m .28545 .47367 L .27818 .47334 L p .616 .747 .94 r
F P
0 g
s
.27818 .47334 m .28534 .46298 L .29048 .46643 L p .616 .747 .94 r
F P
0 g
s
.54775 .50815 m .54421 .51144 L .54313 .51075 L p .99 .749 .471 r
F P
0 g
s
.43448 .53337 m .43103 .52639 L .43067 .52469 L p 0 .058 .622 r
F P
0 g
s
.43067 .52469 m .43561 .53467 L .43448 .53337 L p 0 .058 .622 r
F P
0 g
s
.4378 .54198 m .43586 .53617 L .43561 .53467 L p 0 0 .411 r
F P
0 g
s
.60462 .59917 m .61345 .60823 L .61597 .61094 L p 0 .039 .57 r
F P
0 g
s
.26923 .47256 m .23046 .46257 L .22276 .45905 L p .629 .754 .937 r
F P
0 g
s
.42885 .52327 m .42343 .51545 L .42291 .51351 L p .056 .298 .786 r
F P
0 g
s
.42291 .51351 m .43067 .52469 L .42885 .52327 L p .056 .298 .786 r
F P
0 g
s
.4309 .59403 m .43168 .60395 L .43244 .6005 L p .941 .931 .576 r
F P
0 g
s
.43168 .60395 m .42094 .62024 L .42331 .61932 L p .951 .909 .741 r
F P
0 g
s
.42946 .59781 m .43002 .60474 L .43168 .60395 L p .933 .969 .704 r
F P
0 g
s
.43168 .60395 m .4309 .59403 L .42946 .59781 L p .933 .969 .704 r
F P
0 g
s
.42094 .62024 m .43168 .60395 L .43002 .60474 L p .933 .969 .704 r
F P
0 g
s
.43561 .53467 m .43839 .54299 L .4378 .54198 L p 0 0 .411 r
F P
0 g
s
.57421 .5647 m .57959 .56918 L .58192 .57204 L p .823 .356 0 r
F P
0 g
s
.58192 .57204 m .57422 .56564 L .57421 .5647 L p .823 .356 0 r
F P
0 g
s
.58895 .58207 m .58219 .573 L .58192 .57204 L p .737 .236 0 r
F P
0 g
s
.58192 .57204 m .59158 .58499 L .58895 .58207 L p .737 .236 0 r
F P
0 g
s
.57422 .56564 m .58192 .57204 L .58219 .573 L p .738 .24 0 r
F P
0 g
s
.59158 .58499 m .58192 .57204 L .58406 .57467 L p .688 .198 0 r
F P
0 g
s
.54722 .50507 m .5466 .49677 L .54729 .49422 L p .995 .846 .578 r
F P
0 g
s
.43948 .5486 m .43856 .54426 L .43839 .54299 L p 0 0 .219 r
F P
0 g
s
.40336 .65284 m .38472 .66865 L .38138 .67424 L p .875 .902 .846 r
F P
0 g
s
.38534 .49079 m .39167 .48702 L .39625 .48821 L p .478 .666 .945 r
F P
0 g
s
.3189 .47606 m .29048 .46643 L .28534 .46298 L p .601 .744 .945 r
F P
0 g
s
.28534 .46298 m .32597 .47676 L .3189 .47606 L p .601 .744 .945 r
F P
0 g
s
.56021 .54294 m .55466 .54085 L .55266 .53884 L p .907 .497 .166 r
F P
0 g
s
.59755 .59073 m .59652 .58957 L .59771 .59122 L p .645 .166 0 r
F P
0 g
s
.59903 .59267 m .59755 .59073 L p .59771 .59122 L .645 .166 0 r
F P
0 g
s
.59771 .59122 m .59939 .59291 L p .59646 .58985 L 0 .011 .525 r
F P
0 g
s
.59771 .59122 m .5962 .58957 L .59499 .5879 L p .656 .174 0 r
F P
0 g
s
.5962 .58957 m .59771 .59122 L p .59646 .58985 L 0 .011 .525 r
F P
0 g
s
.59771 .59122 m .59919 .59288 L .59903 .59267 L p .645 .166 0 r
F P
0 g
s
.29297 .46342 m .32144 .47308 L .32597 .47676 L p .606 .744 .942 r
F P
0 g
s
.32597 .47676 m .28534 .46298 L .29297 .46342 L p .606 .744 .942 r
F P
0 g
s
.33527 .46739 m .32597 .47676 L .32144 .47308 L p .589 .739 .947 r
F P
0 g
s
.33843 .47071 m .3319 .47726 L .32597 .47676 L p .581 .726 .942 r
F P
0 g
s
.32597 .47676 m .33527 .46739 L .33843 .47071 L p .581 .726 .942 r
F P
0 g
s
.43839 .54299 m .43971 .54921 L .43948 .5486 L p 0 0 .219 r
F P
0 g
s
.6189 .61632 m .61494 .6103 L .61597 .61094 L p 0 .087 .631 r
F P
0 g
s
.61597 .61094 m .62162 .61955 L .6189 .61632 L p 0 .087 .631 r
F P
0 g
s
.44018 .55287 m .43984 .5502 L .43971 .54921 L p .706 .502 0 r
F P
0 g
s
.58406 .57467 m .59083 .58374 L .59158 .58499 L p .688 .198 0 r
F P
0 g
s
.5561 .47189 m .55925 .46487 L .56045 .46288 L p .859 .994 .753 r
F P
0 g
s
.23046 .46257 m .22702 .4697 L .2179 .46926 L p .637 .754 .933 r
F P
0 g
s
.42029 .5121 m .41242 .50361 L .41166 .50137 L p .266 .478 .878 r
F P
0 g
s
.41166 .50137 m .42291 .51351 L .42029 .5121 L p .266 .478 .878 r
F P
0 g
s
.43971 .54921 m .4402 .55303 L .44018 .55287 L p .706 .502 0 r
F P
0 g
s
.2179 .46926 m .22276 .45905 L .23046 .46257 L p .637 .754 .933 r
F P
0 g
s
.81785 .43282 m .8323 .45836 L .82193 .45632 L p .632 .737 .923 r
F P
0 g
s
.44038 .55459 m .44031 .55369 L .4402 .55303 L p .751 .565 0 r
F P
0 g
s
.63802 .63321 m .62516 .62348 L .62162 .61955 L p .042 .325 .809 r
F P
0 g
s
.62162 .61955 m .64 .63345 L .63802 .63321 L p .042 .325 .809 r
F P
0 g
s
.61956 .61427 m .62351 .6203 L .62162 .61955 L p 0 .287 .786 r
F P
0 g
s
.62162 .61955 m .61597 .61094 L .61956 .61427 L p 0 .287 .786 r
F P
0 g
s
.64 .63345 m .62162 .61955 L .62351 .6203 L p 0 .287 .786 r
F P
0 g
s
.43239 .52566 m .43585 .53265 L .43561 .53467 L p .242 .339 .763 r
F P
0 g
s
.43561 .53467 m .43067 .52469 L .43239 .52566 L p .242 .339 .763 r
F P
0 g
s
.44156 .53104 m .43561 .53467 L .43585 .53265 L p .195 .293 .738 r
F P
0 g
s
.44103 .53281 m .43686 .53534 L .43561 .53467 L p .156 .21 .668 r
F P
0 g
s
.43561 .53467 m .44156 .53104 L .44103 .53281 L p .156 .21 .668 r
F P
0 g
s
.43839 .54299 m .43561 .53467 L .43686 .53534 L p .14 .216 .681 r
F P
0 g
s
.4402 .55303 m .4403 .55431 L .44038 .55459 L p .751 .565 0 r
F P
0 g
s
.42524 .51464 m .43068 .52248 L .43067 .52469 L p .34 .452 .829 r
F P
0 g
s
.43067 .52469 m .42291 .51351 L .42524 .51464 L p .34 .452 .829 r
F P
0 g
s
.43776 .52124 m .43067 .52469 L .43068 .52248 L p .296 .413 .812 r
F P
0 g
s
.43735 .52325 m .43239 .52566 L .43067 .52469 L p .265 .335 .749 r
F P
0 g
s
.43067 .52469 m .43776 .52124 L .43735 .52325 L p .265 .335 .749 r
F P
0 g
s
.44047 .55571 m .44042 .55497 L .4403 .55431 L p .766 .583 .012 r
F P
0 g
s
.57354 .4541 m .57887 .4487 L .58111 .44704 L p .669 .975 .873 r
F P
0 g
s
.43244 .6005 m .4319 .59355 L .4309 .59403 L p .941 .931 .576 r
F P
0 g
s
.4403 .55431 m .44037 .55537 L .44047 .55571 L p .766 .583 .012 r
F P
0 g
s
.60411 .44135 m .61249 .43695 L .61631 .43586 L p .524 .893 .97 r
F P
0 g
s
.44061 .55868 m .44053 .55641 L .44037 .55537 L p .79 .618 .056 r
F P
0 g
s
.56892 .55598 m .57421 .5647 L .57422 .56564 L p .827 .365 0 r
F P
0 g
s
.57422 .56564 m .56666 .55318 L .56892 .55598 L p .827 .365 0 r
F P
0 g
s
.34883 .69782 m .37665 .68019 L .38138 .67424 L p .83 .848 .86 r
F P
0 g
s
.54845 .48294 m .54799 .4915 L .54729 .49422 L p .985 .904 .609 r
F P
0 g
s
.54794 .482 m .54729 .49422 L .54637 .49323 L p .967 .899 .702 r
F P
0 g
s
.54216 .49723 m .54637 .49323 L .54729 .49422 L p .986 .874 .635 r
F P
0 g
s
.54729 .49422 m .54127 .49994 L .54216 .49723 L p .986 .874 .635 r
F P
0 g
s
.54729 .49422 m .54794 .482 L .54845 .48294 L p .985 .904 .609 r
F P
0 g
s
.54127 .49994 m .54729 .49422 L .5466 .49677 L p .981 .814 .603 r
F P
0 g
s
.61063 .60473 m .6017 .59558 L .59919 .59288 L p 0 .04 .571 r
F P
0 g
s
.59919 .59288 m .61193 .60594 L .61063 .60473 L p 0 .04 .571 r
F P
0 g
s
.59984 .59341 m .60087 .59457 L .59919 .59288 L p 0 .019 .537 r
F P
0 g
s
.59919 .59288 m .59771 .59122 L .59984 .59341 L p 0 .019 .537 r
F P
0 g
s
.61193 .60594 m .59919 .59288 L .60087 .59457 L p 0 .028 .554 r
F P
0 g
s
.43686 .53534 m .43881 .54117 L .43839 .54299 L p .14 .216 .681 r
F P
0 g
s
.44361 .53892 m .43839 .54299 L .43881 .54117 L p .099 .171 .652 r
F P
0 g
s
.44299 .54043 m .43934 .54328 L .43839 .54299 L p .056 .093 .583 r
F P
0 g
s
.43839 .54299 m .44361 .53892 L .44299 .54043 L p .056 .093 .583 r
F P
0 g
s
.43971 .54921 m .43839 .54299 L .43934 .54328 L p .051 .102 .596 r
F P
0 g
s
.55196 .47921 m .54845 .48294 L .54794 .482 L p .961 .937 .711 r
F P
0 g
s
.54794 .482 m .55296 .47667 L .55196 .47921 L p .961 .937 .711 r
F P
0 g
s
.44037 .55537 m .44049 .55862 L .44061 .55868 L p .79 .618 .056 r
F P
0 g
s
.56534 .46069 m .56253 .46257 L .56276 .46171 L p .779 .998 .825 r
F P
0 g
s
.56276 .46171 m .56678 .45902 L .56534 .46069 L p .779 .998 .825 r
F P
0 g
s
.55787 .54748 m .56446 .55089 L .56666 .55318 L p .909 .505 .196 r
F P
0 g
s
.56666 .55318 m .55726 .54831 L .55787 .54748 L p .909 .505 .196 r
F P
0 g
s
.57159 .56294 m .5663 .55421 L .56666 .55318 L p .862 .411 .084 r
F P
0 g
s
.56666 .55318 m .57422 .56564 L .57159 .56294 L p .862 .411 .084 r
F P
0 g
s
.55726 .54831 m .56666 .55318 L .5663 .55421 L p .867 .421 .087 r
F P
0 g
s
.55646 .4655 m .55296 .47667 L .55261 .4757 L p .909 .977 .789 r
F P
0 g
s
.5491 .47942 m .55261 .4757 L .55296 .47667 L p .941 .964 .711 r
F P
0 g
s
.55296 .47667 m .54794 .482 L .5491 .47942 L p .941 .964 .711 r
F P
0 g
s
.55646 .4667 m .55401 .47452 L .55296 .47667 L p .912 .98 .769 r
F P
0 g
s
.55296 .47667 m .55646 .4655 L .55646 .4667 L p .912 .98 .769 r
F P
0 g
s
.66856 .66234 m .64949 .65097 L .64516 .64606 L p .302 .47 .86 r
F P
0 g
s
.59499 .5879 m .59605 .58905 L .59771 .59122 L p .656 .174 0 r
F P
0 g
s
.44052 .56392 m .44064 .56009 L .44049 .55862 L p .835 .688 .151 r
F P
0 g
s
.82193 .45632 m .81175 .43848 L .81785 .43282 L p .632 .737 .923 r
F P
0 g
s
.41476 .50254 m .42264 .51106 L .42291 .51351 L p .427 .548 .875 r
F P
0 g
s
.42291 .51351 m .41166 .50137 L .41476 .50254 L p .427 .548 .875 r
F P
0 g
s
.43144 .50969 m .42291 .51351 L .42264 .51106 L p .386 .515 .865 r
F P
0 g
s
.43121 .51198 m .42524 .51464 L .42291 .51351 L p .364 .448 .814 r
F P
0 g
s
.42291 .51351 m .43144 .50969 L .43121 .51198 L p .364 .448 .814 r
F P
0 g
s
.62756 .43837 m .61674 .43694 L .61631 .43586 L p .492 .839 .996 r
F P
0 g
s
.61631 .43586 m .63178 .4379 L .62756 .43837 L p .492 .839 .996 r
F P
0 g
s
.64164 .64204 m .63802 .63321 L .64 .63345 L p .043 .324 .808 r
F P
0 g
s
.64 .63345 m .64516 .64606 L .64164 .64204 L p .043 .324 .808 r
F P
0 g
s
.64516 .64606 m .67244 .66231 L .66856 .66234 L p .302 .47 .86 r
F P
0 g
s
.64486 .63765 m .64845 .64648 L .64516 .64606 L p .214 .458 .876 r
F P
0 g
s
.64516 .64606 m .64 .63345 L .64486 .63765 L p .214 .458 .876 r
F P
0 g
s
.67244 .66231 m .64516 .64606 L .64845 .64648 L p .215 .457 .875 r
F P
0 g
s
.43934 .54328 m .44026 .54764 L .43971 .54921 L p .051 .102 .596 r
F P
0 g
s
.44455 .54468 m .43971 .54921 L .44026 .54764 L p .02 .067 .57 r
F P
0 g
s
.44388 .54591 m .44049 .54908 L .43971 .54921 L p 0 0 .507 r
F P
0 g
s
.43971 .54921 m .44455 .54468 L .44388 .54591 L p 0 0 .507 r
F P
0 g
s
.4402 .55303 m .43971 .54921 L .44049 .54908 L p 0 .014 .526 r
F P
0 g
s
.5466 .49677 m .54239 .50078 L .54127 .49994 L p .981 .814 .603 r
F P
0 g
s
.58219 .573 m .5768 .56852 L .57422 .56564 L p .738 .24 0 r
F P
0 g
s
.6795 .68 m .70748 .69489 L .71358 .70094 L p .394 .549 .891 r
F P
0 g
s
.64893 .43004 m .63178 .4379 L .63188 .43625 L p .559 .835 .997 r
F P
0 g
s
.62104 .43481 m .63188 .43625 L .63178 .4379 L p .587 .859 .995 r
F P
0 g
s
.63178 .4379 m .61631 .43586 L .62104 .43481 L p .587 .859 .995 r
F P
0 g
s
.64881 .43213 m .6368 .43762 L .63178 .4379 L p .562 .804 .99 r
F P
0 g
s
.63178 .4379 m .64893 .43004 L .64881 .43213 L p .562 .804 .99 r
F P
0 g
s
.43002 .60474 m .42249 .61615 L .42094 .62024 L p .933 .969 .704 r
F P
0 g
s
.43585 .53265 m .44001 .5301 L .44156 .53104 L p .195 .293 .738 r
F P
0 g
s
.44049 .55862 m .44033 .56409 L .44052 .56392 L p .835 .688 .151 r
F P
0 g
s
.57331 .44948 m .56678 .45902 L .5671 .45792 L p .775 .989 .892 r
F P
0 g
s
.56428 .4598 m .5671 .45792 L .56678 .45902 L p .802 .999 .833 r
F P
0 g
s
.56678 .45902 m .56276 .46171 L .56428 .4598 L p .802 .999 .833 r
F P
0 g
s
.57342 .45041 m .56885 .45709 L .56678 .45902 L p .774 .985 .901 r
F P
0 g
s
.56678 .45902 m .57331 .44948 L .57342 .45041 L p .774 .985 .901 r
F P
0 g
s
.377 .65801 m .38138 .67424 L .38472 .66865 L p .875 .901 .846 r
F P
0 g
s
.38138 .67424 m .34158 .69945 L .34883 .69782 L p .83 .848 .86 r
F P
0 g
s
.37164 .66396 m .37476 .6753 L .38138 .67424 L p .833 .884 .879 r
F P
0 g
s
.38138 .67424 m .377 .65801 L .37164 .66396 L p .833 .884 .879 r
F P
0 g
s
.34158 .69945 m .38138 .67424 L .37476 .6753 L p .833 .885 .88 r
F P
0 g
s
.2711 .46944 m .27607 .46217 L .28534 .46298 L p .62 .753 .941 r
F P
0 g
s
.44049 .54908 m .44083 .55176 L .4402 .55303 L p 0 .014 .526 r
F P
0 g
s
.44484 .54815 m .4402 .55303 L .44083 .55176 L p 0 0 .496 r
F P
0 g
s
.44415 .54907 m .4409 .55248 L .4402 .55303 L p 0 0 .461 r
F P
0 g
s
.4402 .55303 m .44484 .54815 L .44415 .54907 L p 0 0 .461 r
F P
0 g
s
.4403 .55431 m .4402 .55303 L .4409 .55248 L p 0 0 .475 r
F P
0 g
s
.43068 .52248 m .43563 .52006 L .43776 .52124 L p .296 .413 .812 r
F P
0 g
s
.4409 .55248 m .44097 .55338 L .4403 .55431 L p 0 0 .475 r
F P
0 g
s
.44491 .54931 m .4403 .55431 L .44097 .55338 L p 0 0 .459 r
F P
0 g
s
.44422 .55022 m .44099 .55371 L .4403 .55431 L p 0 0 .444 r
F P
0 g
s
.4403 .55431 m .44491 .54931 L .44422 .55022 L p 0 0 .444 r
F P
0 g
s
.44037 .55537 m .4403 .55431 L .44099 .55371 L p 0 0 .465 r
F P
0 g
s
.35903 .48051 m .33843 .47071 L .33527 .46739 L p .556 .716 .947 r
F P
0 g
s
.33527 .46739 m .36472 .4814 L .35903 .48051 L p .556 .716 .947 r
F P
0 g
s
.43964 .57151 m .44037 .56608 L .44033 .56409 L p .884 .777 .281 r
F P
0 g
s
.59771 .59122 m .61053 .60419 L .60881 .60248 L p 0 .037 .562 r
F P
0 g
s
.60726 .60091 m .60895 .60264 L p .60269 .59622 L 0 0 .498 r
F P
0 g
s
.59833 .59176 m .60278 .59632 L p .60269 .59622 L 0 0 .498 r
F P
0 g
s
.60278 .59632 m .60726 .60091 L p .60269 .59622 L 0 0 .498 r
F P
0 g
s
.59939 .59291 m .59771 .59122 L p .60396 .59754 L 0 .001 .507 r
F P
0 g
s
.60836 .60199 m .60386 .59744 L p .60396 .59754 L 0 .001 .507 r
F P
0 g
s
.60386 .59744 m .59939 .59291 L p .60396 .59754 L 0 .001 .507 r
F P
0 g
s
.59771 .59122 m .61053 .60419 L .60836 .60199 L p 0 .001 .507 r
F P
0 g
s
.60881 .60248 m .59984 .59341 L .59771 .59122 L p 0 .037 .562 r
F P
0 g
s
.43881 .54117 m .44246 .53832 L .44361 .53892 L p .099 .171 .652 r
F P
0 g
s
.44099 .55371 m .44104 .55446 L .44037 .55537 L p 0 0 .465 r
F P
0 g
s
.44494 .55026 m .44037 .55537 L .44104 .55446 L p 0 0 .441 r
F P
0 g
s
.44426 .5515 m .44106 .55507 L .44037 .55537 L p 0 0 .42 r
F P
0 g
s
.44037 .55537 m .44494 .55026 L .44426 .5515 L p 0 0 .42 r
F P
0 g
s
.44049 .55862 m .44037 .55537 L .44106 .55507 L p 0 0 .434 r
F P
0 g
s
.40813 .50006 m .39735 .49086 L .39625 .48821 L p .412 .591 .917 r
F P
0 g
s
.39625 .48821 m .41166 .50137 L .40813 .50006 L p .412 .591 .917 r
F P
0 g
s
.4074 .15976 m .43302 .15294 L .43364 .13909 L p .666 .658 .832 r
F P
0 g
s
.43364 .13909 m .39695 .14892 L .4074 .15976 L p .666 .658 .832 r
F P
0 g
s
.54637 .49323 m .54683 .48468 L .54794 .482 L p .967 .899 .702 r
F P
0 g
s
.34151 .46813 m .36214 .47796 L .36472 .4814 L p .575 .717 .939 r
F P
0 g
s
.36472 .4814 m .33527 .46739 L .34151 .46813 L p .575 .717 .939 r
F P
0 g
s
.37576 .47368 m .36472 .4814 L .36214 .47796 L p .55 .705 .942 r
F P
0 g
s
.37733 .47686 m .36959 .48225 L .36472 .4814 L p .539 .678 .928 r
F P
0 g
s
.36472 .4814 m .37576 .47368 L .37733 .47686 L p .539 .678 .928 r
F P
0 g
s
.60087 .59457 m .60979 .60371 L .61193 .60594 L p 0 .028 .554 r
F P
0 g
s
.32144 .47308 m .32793 .4665 L .33527 .46739 L p .589 .739 .947 r
F P
0 g
s
.55261 .4757 m .55506 .46787 L .55646 .4655 L p .909 .977 .789 r
F P
0 g
s
.58881 .44566 m .58146 .4476 L .58111 .44704 L p .608 .945 .934 r
F P
0 g
s
.58111 .44704 m .59162 .44425 L .58881 .44566 L p .608 .945 .934 r
F P
0 g
s
.44106 .55507 m .44115 .55735 L .44049 .55862 L p 0 0 .434 r
F P
0 g
s
.44499 .55319 m .44049 .55862 L .44115 .55735 L p 0 0 .413 r
F P
0 g
s
.44428 .55478 m .44113 .55858 L .44049 .55862 L p 0 0 .344 r
F P
0 g
s
.44049 .55862 m .44499 .55319 L .44428 .55478 L p 0 0 .344 r
F P
0 g
s
.44033 .56409 m .44049 .55862 L .44113 .55858 L p 0 0 .357 r
F P
0 g
s
.40693 .63745 m .41902 .6248 L .42094 .62024 L p .916 .912 .801 r
F P
0 g
s
.44026 .54764 m .44365 .54446 L .44455 .54468 L p .02 .067 .57 r
F P
0 g
s
.42264 .51106 m .4286 .50837 L .43144 .50969 L p .386 .515 .865 r
F P
0 g
s
.56191 .46325 m .5614 .46385 L .56204 .46257 L p .759 .931 .579 r
F P
0 g
s
.56204 .46257 m .56276 .46171 L .56191 .46325 L p .759 .931 .579 r
F P
0 g
s
.59083 .58374 m .59406 .58695 L .5962 .58957 L p .689 .198 0 r
F P
0 g
s
.62351 .6203 m .63638 .63003 L .64 .63345 L p 0 .287 .786 r
F P
0 g
s
.38472 .66865 m .38169 .65728 L .377 .65801 L p .875 .901 .846 r
F P
0 g
s
.40027 .48936 m .41106 .49858 L .41166 .50137 L p .499 .619 .902 r
F P
0 g
s
.41166 .50137 m .39625 .48821 L .40027 .48936 L p .499 .619 .902 r
F P
0 g
s
.42199 .49658 m .41166 .50137 L .41106 .49858 L p .467 .595 .897 r
F P
0 g
s
.42199 .4992 m .41476 .50254 L .41166 .50137 L p .45 .542 .859 r
F P
0 g
s
.41166 .50137 m .42199 .49658 L .42199 .4992 L p .45 .542 .859 r
F P
0 g
s
.44033 .56409 m .43929 .57185 L .43964 .57151 L p .884 .777 .281 r
F P
0 g
s
.5663 .55421 m .55972 .55081 L .55726 .54831 L p .867 .421 .087 r
F P
0 g
s
.44083 .55176 m .44408 .54834 L .44484 .54815 L p 0 0 .496 r
F P
0 g
s
.60213 .43568 m .59162 .44425 L .5915 .44325 L p .637 .931 .97 r
F P
0 g
s
.58414 .44519 m .5915 .44325 L .59162 .44425 L p .683 .957 .948 r
F P
0 g
s
.59162 .44425 m .58111 .44704 L .58414 .44519 L p .683 .957 .948 r
F P
0 g
s
.60257 .43683 m .59521 .44283 L .59162 .44425 L p .635 .913 .981 r
F P
0 g
s
.59162 .44425 m .60213 .43568 L .60257 .43683 L p .635 .913 .981 r
F P
0 g
s
.5671 .45792 m .57167 .45125 L .57331 .44948 L p .775 .989 .892 r
F P
0 g
s
.44097 .55338 m .4442 .54988 L .44491 .54931 L p 0 0 .459 r
F P
0 g
s
.5962 .58957 m .59158 .58499 L .59083 .58374 L p .689 .198 0 r
F P
0 g
s
.60633 .59997 m .5974 .59082 L .5962 .58957 L p .521 .019 0 r
F P
0 g
s
.60895 .60264 m .5962 .58957 L .59833 .59176 L p 0 0 .498 r
F P
0 g
s
.5962 .58957 m .60895 .60264 L .60633 .59997 L p .521 .019 0 r
F P
0 g
s
.59158 .58499 m .5962 .58957 L .5974 .59082 L p .521 .019 0 r
F P
0 g
s
.59939 .59291 m .59833 .59176 L .5962 .58957 L p 0 .011 .525 r
F P
0 g
s
.44113 .55858 m .44102 .56242 L .44033 .56409 L p 0 0 .357 r
F P
0 g
s
.44474 .55803 m .44033 .56409 L .44102 .56242 L p 0 0 .329 r
F P
0 g
s
.44391 .56004 m .44083 .56427 L .44033 .56409 L p 0 0 .213 r
F P
0 g
s
.44033 .56409 m .44474 .55803 L .44391 .56004 L p 0 0 .213 r
F P
0 g
s
.43929 .57185 m .44033 .56409 L .44083 .56427 L p 0 0 .223 r
F P
0 g
s
.42092 .60806 m .42094 .62024 L .42249 .61615 L p .933 .969 .703 r
F P
0 g
s
.42094 .62024 m .40364 .63833 L .40693 .63745 L p .916 .912 .801 r
F P
0 g
s
.4184 .61241 m .41843 .62092 L .42094 .62024 L p .905 .975 .801 r
F P
0 g
s
.42094 .62024 m .42092 .60806 L .4184 .61241 L p .905 .975 .801 r
F P
0 g
s
.40364 .63833 m .42094 .62024 L .41843 .62092 L p .905 .975 .801 r
F P
0 g
s
.44104 .55446 m .44424 .55088 L .44494 .55026 L p 0 0 .441 r
F P
0 g
s
.43714 .58144 m .43907 .57442 L .43929 .57185 L p .923 .863 .428 r
F P
0 g
s
.56853 .45114 m .56276 .46171 L .5635 .46023 L p .814 .992 .745 r
F P
0 g
s
.56299 .46083 m .5635 .46023 L .56276 .46171 L p .766 .934 .582 r
F P
0 g
s
.56276 .46171 m .56204 .46257 L .56299 .46083 L p .766 .934 .582 r
F P
0 g
s
.56832 .45241 m .56428 .4598 L .56276 .46171 L p .816 .978 .893 r
F P
0 g
s
.56276 .46171 m .56853 .45114 L .56832 .45241 L p .816 .978 .893 r
F P
0 g
s
.44115 .55735 m .4443 .55354 L .44499 .55319 L p 0 0 .413 r
F P
0 g
s
.66097 .43709 m .64881 .43213 L .64893 .43004 L p .542 .787 .989 r
F P
0 g
s
.64893 .43004 m .66631 .43715 L .66097 .43709 L p .542 .787 .989 r
F P
0 g
s
.56049 .46338 m .55988 .46419 L .56045 .46288 L p .803 .95 .608 r
F P
0 g
s
.56045 .46288 m .56132 .46173 L .56049 .46338 L p .803 .95 .608 r
F P
0 g
s
.76291 .72571 m .72097 .70857 L .71358 .70094 L p .502 .605 .888 r
F P
0 g
s
.63188 .43625 m .64387 .43074 L .64893 .43004 L p .559 .835 .997 r
F P
0 g
s
.69168 .42713 m .66631 .43715 L .66729 .4344 L p .587 .785 .974 r
F P
0 g
s
.65512 .42941 m .66729 .4344 L .66631 .43715 L p .6 .798 .976 r
F P
0 g
s
.66631 .43715 m .64893 .43004 L .65512 .42941 L p .6 .798 .976 r
F P
0 g
s
.69039 .43039 m .67263 .43738 L .66631 .43715 L p .588 .76 .961 r
F P
0 g
s
.66631 .43715 m .69168 .42713 L .69039 .43039 L p .588 .76 .961 r
F P
0 g
s
.81175 .43848 m .77433 .44828 L .7643 .44688 L p .632 .736 .923 r
F P
0 g
s
.56686 .45316 m .56299 .46083 L .56204 .46257 L p .835 .994 .752 r
F P
0 g
s
.56204 .46257 m .56756 .45161 L .56686 .45316 L p .835 .994 .752 r
F P
0 g
s
.64845 .64648 m .66757 .65785 L .67244 .66231 L p .215 .457 .875 r
F P
0 g
s
.54632 .51956 m .54745 .52318 L .5469 .52427 L p .975 .67 .351 r
F P
0 g
s
.5469 .52427 m .54528 .5191 L .54632 .51956 L p .975 .67 .351 r
F P
0 g
s
.54784 .52437 m .54826 .52559 L .5475 .52601 L p .968 .645 .319 r
F P
0 g
s
.5475 .52601 m .5469 .52427 L .54784 .52437 L p .968 .645 .319 r
F P
0 g
s
.42249 .61615 m .42249 .60762 L .42092 .60806 L p .933 .969 .703 r
F P
0 g
s
.54421 .51144 m .54571 .51727 L .54528 .5191 L p .986 .72 .425 r
F P
0 g
s
.54846 .52614 m .54882 .52714 L .54801 .52744 L p .963 .632 .305 r
F P
0 g
s
.54801 .52744 m .5475 .52601 L .54846 .52614 L p .963 .632 .305 r
F P
0 g
s
.55925 .46487 m .55646 .4667 L .55646 .4655 L p .878 .974 .842 r
F P
0 g
s
.55646 .4655 m .56045 .46288 L .55925 .46487 L p .878 .974 .842 r
F P
0 g
s
.81785 .43282 m .7643 .44688 L .76943 .44162 L p .631 .744 .93 r
F P
0 g
s
.75737 .42818 m .76943 .44162 L .7643 .44688 L p .631 .746 .93 r
F P
0 g
s
.7643 .44688 m .74701 .42774 L .75737 .42818 L p .631 .746 .93 r
F P
0 g
s
.7643 .44688 m .81785 .43282 L .81175 .43848 L p .632 .736 .923 r
F P
0 g
s
.74701 .42774 m .7643 .44688 L .75592 .44561 L p .611 .738 .936 r
F P
0 g
s
.44102 .56242 m .4441 .55817 L .44474 .55803 L p 0 0 .329 r
F P
0 g
s
.54921 .52814 m .55036 .53116 L .54965 .53176 L p .957 .614 .288 r
F P
0 g
s
.54965 .53176 m .54801 .52744 L .54921 .52814 L p .957 .614 .288 r
F P
0 g
s
.41106 .49858 m .41828 .49522 L .42199 .49658 L p .467 .595 .897 r
F P
0 g
s
.37476 .6753 m .34684 .69297 L .34158 .69945 L p .833 .885 .88 r
F P
0 g
s
.36214 .47796 m .36985 .47254 L .37576 .47368 L p .55 .705 .942 r
F P
0 g
s
.54528 .5191 m .54313 .51075 L .54421 .51144 L p .986 .72 .425 r
F P
0 g
s
.44083 .56427 m .4401 .56971 L .43929 .57185 L p 0 0 .223 r
F P
0 g
s
.44371 .56481 m .43929 .57185 L .4401 .56971 L p 0 0 .193 r
F P
0 g
s
.43929 .57185 m .43652 .58189 L .43714 .58144 L p .923 .863 .428 r
F P
0 g
s
.44265 .56727 m .43956 .5722 L .43929 .57185 L p 0 0 .019 r
F P
0 g
s
.43929 .57185 m .44371 .56481 L .44265 .56727 L p 0 0 .019 r
F P
0 g
s
.43652 .58189 m .43929 .57185 L .43956 .5722 L p 0 0 .024 r
F P
0 g
s
.5635 .46023 m .56753 .45283 L .56853 .45114 L p .814 .992 .745 r
F P
0 g
s
.56684 .45076 m .56132 .46173 L .56199 .46024 L p .835 .994 .752 r
F P
0 g
s
.56139 .46105 m .56199 .46024 L .56132 .46173 L p .797 .947 .603 r
F P
0 g
s
.56132 .46173 m .56045 .46288 L .56139 .46105 L p .797 .947 .603 r
F P
0 g
s
.75592 .44561 m .74379 .43224 L .74701 .42774 L p .611 .738 .936 r
F P
0 g
s
.54985 .46947 m .54794 .482 L .54696 .4809 L p .915 .908 .8 r
F P
0 g
s
.54163 .4848 m .54696 .4809 L .54794 .482 L p .945 .898 .75 r
F P
0 g
s
.54794 .482 m .54034 .48758 L .54163 .4848 L p .945 .898 .75 r
F P
0 g
s
.55043 .47066 m .5491 .47942 L .54794 .482 L p .936 .925 .772 r
F P
0 g
s
.54794 .482 m .54985 .46947 L .55043 .47066 L p .936 .925 .772 r
F P
0 g
s
.54034 .48758 m .54794 .482 L .54683 .48468 L p .943 .849 .721 r
F P
0 g
s
.5915 .44325 m .59885 .43724 L .60213 .43568 L p .637 .931 .97 r
F P
0 g
s
.29265 .72646 m .33422 .70647 L .34158 .69945 L p .795 .836 .883 r
F P
0 g
s
.54239 .50078 m .54368 .50834 L .54313 .51075 L p .987 .781 .54 r
F P
0 g
s
.5974 .59082 m .59416 .58762 L .59158 .58499 L p .521 .019 0 r
F P
0 g
s
.54683 .48468 m .5415 .48859 L .54034 .48758 L p .943 .849 .721 r
F P
0 g
s
.5512 .53313 m .55331 .53808 L .55266 .53884 L p .941 .575 .253 r
F P
0 g
s
.55266 .53884 m .54965 .53176 L .5512 .53313 L p .941 .575 .253 r
F P
0 g
s
.56567 .45163 m .56045 .46288 L .56057 .46153 L p .836 .966 .888 r
F P
0 g
s
.55777 .46335 m .56057 .46153 L .56045 .46288 L p .869 .982 .844 r
F P
0 g
s
.56045 .46288 m .55646 .4655 L .55777 .46335 L p .869 .982 .844 r
F P
0 g
s
.56504 .45317 m .56139 .46105 L .56045 .46288 L p .854 .996 .764 r
F P
0 g
s
.56045 .46288 m .56567 .45163 L .56504 .45317 L p .854 .996 .764 r
F P
0 g
s
.70304 .4394 m .69039 .43039 L .69168 .42713 L p .581 .753 .959 r
F P
0 g
s
.69168 .42713 m .70975 .44003 L .70304 .4394 L p .581 .753 .959 r
F P
0 g
s
.74701 .42774 m .70975 .44003 L .71234 .43604 L p .611 .756 .947 r
F P
0 g
s
.69971 .42698 m .71234 .43604 L .70975 .44003 L p .616 .762 .949 r
F P
0 g
s
.70975 .44003 m .69168 .42713 L .69971 .42698 L p .616 .762 .949 r
F P
0 g
s
.74379 .43224 m .71773 .44081 L .70975 .44003 L p .612 .74 .936 r
F P
0 g
s
.70975 .44003 m .74701 .42774 L .74379 .43224 L p .612 .74 .936 r
F P
0 g
s
.61345 .60823 m .61063 .60473 L .61193 .60594 L p 0 .04 .571 r
F P
0 g
s
.61193 .60594 m .61597 .61094 L .61345 .60823 L p 0 .04 .571 r
F P
0 g
s
.39167 .48702 m .37733 .47686 L .37576 .47368 L p .507 .659 .929 r
F P
0 g
s
.37576 .47368 m .39625 .48821 L .39167 .48702 L p .507 .659 .929 r
F P
0 g
s
.54313 .51075 m .54528 .5191 L .54349 .51823 L p .932 .712 .583 r
F P
0 g
s
.53657 .51957 m .54349 .51823 L .54528 .5191 L p .933 .7 .561 r
F P
0 g
s
.54528 .5191 m .53539 .52101 L .53657 .51957 L p .933 .7 .561 r
F P
0 g
s
.54516 .52371 m .54402 .52009 L .54528 .5191 L p .929 .676 .534 r
F P
0 g
s
.54528 .5191 m .5469 .52427 L .54516 .52371 L p .929 .676 .534 r
F P
0 g
s
.53539 .52101 m .54528 .5191 L .54402 .52009 L p .925 .665 .526 r
F P
0 g
s
.53804 .52442 m .54516 .52371 L .5469 .52427 L p .929 .666 .519 r
F P
0 g
s
.5469 .52427 m .53673 .52528 L .53804 .52442 L p .929 .666 .519 r
F P
0 g
s
.54588 .52587 m .54546 .52466 L .5469 .52427 L p .927 .657 .508 r
F P
0 g
s
.5469 .52427 m .5475 .52601 L .54588 .52587 L p .927 .657 .508 r
F P
0 g
s
.53673 .52528 m .5469 .52427 L .54546 .52466 L p .924 .649 .5 r
F P
0 g
s
.4319 .59355 m .43583 .58506 L .43652 .58189 L p .94 .932 .577 r
F P
0 g
s
.4401 .56971 m .4432 .56478 L .44371 .56481 L p 0 0 .193 r
F P
0 g
s
.56416 .55857 m .57159 .56294 L .57422 .56564 L p .87 .428 .114 r
F P
0 g
s
.57422 .56564 m .5636 .55941 L .56416 .55857 L p .87 .428 .114 r
F P
0 g
s
.58051 .57548 m .57396 .56654 L .57422 .56564 L p .798 .305 0 r
F P
0 g
s
.57422 .56564 m .58358 .5784 L .58051 .57548 L p .798 .305 0 r
F P
0 g
s
.5636 .55941 m .57422 .56564 L .57396 .56654 L p .802 .31 0 r
F P
0 g
s
.58358 .5784 m .57422 .56564 L .5768 .56852 L p .75 .253 0 r
F P
0 g
s
.53867 .52636 m .54588 .52587 L .5475 .52601 L p .925 .649 .498 r
F P
0 g
s
.5475 .52601 m .5372 .5267 L .53867 .52636 L p .925 .649 .498 r
F P
0 g
s
.54639 .52731 m .54603 .52631 L .5475 .52601 L p .925 .647 .495 r
F P
0 g
s
.5475 .52601 m .54801 .52744 L .54639 .52731 L p .925 .647 .495 r
F P
0 g
s
.5372 .5267 m .5475 .52601 L .54603 .52631 L p .922 .639 .487 r
F P
0 g
s
.56199 .46024 m .56585 .45257 L .56684 .45076 L p .835 .994 .752 r
F P
0 g
s
.71348 .67999 m .71358 .70094 L .70748 .69489 L p .396 .55 .891 r
F P
0 g
s
.71358 .70094 m .77366 .72546 L .76291 .72571 L p .502 .605 .888 r
F P
0 g
s
.72262 .68642 m .72261 .70107 L .71358 .70094 L p .463 .609 .91 r
F P
0 g
s
.71358 .70094 m .71348 .67999 L .72262 .68642 L p .463 .609 .91 r
F P
0 g
s
.77366 .72546 m .71358 .70094 L .72261 .70107 L p .463 .61 .91 r
F P
0 g
s
.41843 .62092 m .4063 .6336 L .40364 .63833 L p .905 .975 .801 r
F P
0 g
s
.57887 .4487 m .57342 .45041 L .57331 .44948 L p .726 .964 .939 r
F P
0 g
s
.57331 .44948 m .58111 .44704 L .57887 .4487 L p .726 .964 .939 r
F P
0 g
s
.5768 .56852 m .58335 .57745 L .58358 .5784 L p .75 .253 0 r
F P
0 g
s
.5391 .52762 m .54639 .52731 L .54801 .52744 L p .923 .639 .486 r
F P
0 g
s
.54801 .52744 m .5376 .52788 L .5391 .52762 L p .923 .639 .486 r
F P
0 g
s
.54782 .53112 m .54668 .52809 L .54801 .52744 L p .921 .63 .474 r
F P
0 g
s
.54801 .52744 m .54965 .53176 L .54782 .53112 L p .921 .63 .474 r
F P
0 g
s
.5376 .52788 m .54801 .52744 L .54668 .52809 L p .919 .624 .469 r
F P
0 g
s
.54127 .49994 m .54313 .51075 L .54139 .5097 L p .928 .757 .65 r
F P
0 g
s
.5346 .51194 m .54139 .5097 L .54313 .51075 L p .934 .742 .62 r
F P
0 g
s
.54313 .51075 m .53344 .51396 L .5346 .51194 L p .934 .742 .62 r
F P
0 g
s
.54313 .51075 m .54127 .49994 L .54239 .50078 L p .987 .781 .54 r
F P
0 g
s
.54349 .51823 m .54199 .51238 L .54313 .51075 L p .932 .712 .583 r
F P
0 g
s
.53344 .51396 m .54313 .51075 L .54199 .51238 L p .923 .695 .577 r
F P
0 g
s
.38087 .47476 m .39523 .48495 L .39625 .48821 L p .553 .669 .915 r
F P
0 g
s
.39625 .48821 m .37576 .47368 L .38087 .47476 L p .553 .669 .915 r
F P
0 g
s
.40871 .48192 m .39625 .48821 L .39523 .48495 L p .53 .654 .914 r
F P
0 g
s
.40899 .48497 m .40027 .48936 L .39625 .48821 L p .517 .612 .886 r
F P
0 g
s
.39625 .48821 m .40871 .48192 L .40899 .48497 L p .517 .612 .886 r
F P
0 g
s
.63242 .62369 m .61956 .61427 L .61597 .61094 L p 0 .29 .788 r
F P
0 g
s
.61597 .61094 m .63435 .62439 L .63242 .62369 L p 0 .29 .788 r
F P
0 g
s
.61526 .60866 m .61809 .61217 L .61597 .61094 L p 0 .257 .756 r
F P
0 g
s
.61597 .61094 m .61193 .60594 L .61526 .60866 L p 0 .257 .756 r
F P
0 g
s
.63435 .62439 m .61597 .61094 L .61809 .61217 L p 0 .257 .757 r
F P
0 g
s
.54696 .4809 m .54829 .47212 L .54985 .46947 L p .915 .908 .8 r
F P
0 g
s
.54027 .53086 m .54782 .53112 L .54965 .53176 L p .92 .624 .465 r
F P
0 g
s
.54965 .53176 m .53887 .53139 L .54027 .53086 L p .92 .624 .465 r
F P
0 g
s
.55054 .53763 m .54844 .53267 L .54965 .53176 L p .912 .595 .43 r
F P
0 g
s
.54965 .53176 m .55266 .53884 L .55054 .53763 L p .912 .595 .43 r
F P
0 g
s
.53887 .53139 m .54965 .53176 L .54844 .53267 L p .911 .592 .428 r
F P
0 g
s
.43956 .5722 m .43762 .57924 L .43652 .58189 L p 0 0 .024 r
F P
0 g
s
.55466 .54085 m .55787 .54748 L .55726 .54831 L p .916 .519 .203 r
F P
0 g
s
.55726 .54831 m .55266 .53884 L .55466 .54085 L p .916 .519 .203 r
F P
0 g
s
.56057 .46153 m .56422 .45365 L .56567 .45163 L p .836 .966 .888 r
F P
0 g
s
.33652 .67943 m .34158 .69945 L .34684 .69297 L p .833 .886 .88 r
F P
0 g
s
.34158 .69945 m .28207 .72804 L .29265 .72646 L p .795 .836 .883 r
F P
0 g
s
.32824 .68632 m .33186 .7003 L .34158 .69945 L p .793 .866 .902 r
F P
0 g
s
.34158 .69945 m .33652 .67943 L .32824 .68632 L p .793 .866 .902 r
F P
0 g
s
.28207 .72804 m .34158 .69945 L .33186 .7003 L p .794 .866 .902 r
F P
0 g
s
.55506 .46787 m .55043 .47066 L .54985 .46947 L p .898 .926 .829 r
F P
0 g
s
.54985 .46947 m .55646 .4655 L .55506 .46787 L p .898 .926 .829 r
F P
0 g
s
.58335 .57745 m .58895 .58207 L .59158 .58499 L p .749 .249 0 r
F P
0 g
s
.5901 .4365 m .58111 .44704 L .5812 .44572 L p .715 .936 .96 r
F P
0 g
s
.57573 .44743 m .5812 .44572 L .58111 .44704 L p .752 .959 .938 r
F P
0 g
s
.58111 .44704 m .57331 .44948 L .57573 .44743 L p .752 .959 .938 r
F P
0 g
s
.59044 .43782 m .58414 .44519 L .58111 .44704 L p .711 .926 .963 r
F P
0 g
s
.58111 .44704 m .5901 .4365 L .59044 .43782 L p .711 .926 .963 r
F P
0 g
s
.61249 .43695 m .60257 .43683 L .60213 .43568 L p .588 .885 .991 r
F P
0 g
s
.60213 .43568 m .61631 .43586 L .61249 .43695 L p .588 .885 .991 r
F P
0 g
s
.59158 .58499 m .58358 .5784 L .58335 .57745 L p .749 .249 0 r
F P
0 g
s
.60107 .59498 m .59223 .58591 L .59158 .58499 L p .596 .069 0 r
F P
0 g
s
.59158 .58499 m .60421 .59795 L .60107 .59498 L p .596 .069 0 r
F P
0 g
s
.58358 .5784 m .59158 .58499 L .59223 .58591 L p .596 .07 0 r
F P
0 g
s
.60421 .59795 m .59158 .58499 L .59416 .58762 L p .522 .02 0 r
F P
0 g
s
.5415 .48859 m .54216 .49723 L .54127 .49994 L p .963 .828 .662 r
F P
0 g
s
.70748 .69489 m .70736 .68022 L .71348 .67999 L p .396 .55 .891 r
F P
0 g
s
.44126 .57348 m .43652 .58189 L .43762 .57924 L p 0 0 .001 r
F P
0 g
s
.43652 .58189 m .4309 .59403 L .4319 .59355 L p .94 .932 .577 r
F P
0 g
s
.43976 .57645 m .43644 .58233 L .43652 .58189 L p 0 0 0 r
F P
0 g
s
.43652 .58189 m .44126 .57348 L .43976 .57645 L p 0 0 0 r
F P
0 g
s
.4309 .59403 m .43652 .58189 L .43644 .58233 L p 0 0 0 r
F P
0 g
s
.54402 .52009 m .5371 .52143 L .53539 .52101 L p .925 .665 .526 r
F P
0 g
s
.66729 .4344 m .68505 .42737 L .69168 .42713 L p .587 .785 .974 r
F P
0 g
s
.56087 .4533 m .55646 .4655 L .55602 .46418 L p .851 .938 .88 r
F P
0 g
s
.55139 .46696 m .55602 .46418 L .55646 .4655 L p .889 .948 .841 r
F P
0 g
s
.55646 .4655 m .54985 .46947 L .55139 .46696 L p .889 .948 .841 r
F P
0 g
s
.56086 .45481 m .55777 .46335 L .55646 .4655 L p .856 .944 .876 r
F P
0 g
s
.55646 .4655 m .56087 .4533 L .56086 .45481 L p .856 .944 .876 r
F P
0 g
s
.54546 .52466 m .53834 .52537 L .53673 .52528 L p .924 .649 .5 r
F P
0 g
s
.54199 .51238 m .53521 .51464 L .53344 .51396 L p .923 .695 .577 r
F P
0 g
s
.54603 .52631 m .53882 .5268 L .5372 .5267 L p .922 .639 .487 r
F P
0 g
s
.54139 .5097 m .54009 .50212 L .54127 .49994 L p .928 .757 .65 r
F P
0 g
s
.54034 .48758 m .54127 .49994 L .53958 .49879 L p .91 .795 .721 r
F P
0 g
s
.53261 .50186 m .53958 .49879 L .54127 .49994 L p .923 .782 .687 r
F P
0 g
s
.54127 .49994 m .53132 .50434 L .53261 .50186 L p .923 .782 .687 r
F P
0 g
s
.54127 .49994 m .54034 .48758 L .5415 .48859 L p .963 .828 .662 r
F P
0 g
s
.53132 .50434 m .54127 .49994 L .54009 .50212 L p .912 .731 .644 r
F P
0 g
s
.54668 .52809 m .53939 .5284 L .5376 .52788 L p .919 .624 .469 r
F P
0 g
s
.44001 .5301 m .43735 .52325 L .43776 .52124 L p .22 .289 .723 r
F P
0 g
s
.43563 .52006 m .43121 .51198 L .43144 .50969 L p .324 .41 .796 r
F P
0 g
s
.43144 .50969 m .43776 .52124 L .43563 .52006 L p .324 .41 .796 r
F P
0 g
s
.63142 .42558 m .61631 .43586 L .61629 .43414 L p .617 .864 .99 r
F P
0 g
s
.60636 .43401 m .61629 .43414 L .61631 .43586 L p .648 .887 .984 r
F P
0 g
s
.61631 .43586 m .60213 .43568 L .60636 .43401 L p .648 .887 .984 r
F P
0 g
s
.63162 .42763 m .62104 .43481 L .61631 .43586 L p .613 .841 .987 r
F P
0 g
s
.61631 .43586 m .63142 .42558 L .63162 .42763 L p .613 .841 .987 r
F P
0 g
s
.43776 .52124 m .44156 .53104 L .44001 .5301 L p .22 .289 .723 r
F P
0 g
s
.54248 .53647 m .55054 .53763 L .55266 .53884 L p .912 .592 .426 r
F P
0 g
s
.55266 .53884 m .54114 .53719 L .54248 .53647 L p .912 .592 .426 r
F P
0 g
s
.55477 .54652 m .55154 .53989 L .55266 .53884 L p .896 .542 .365 r
F P
0 g
s
.55266 .53884 m .55726 .54831 L .55477 .54652 L p .896 .542 .365 r
F P
0 g
s
.54114 .53719 m .55266 .53884 L .55154 .53989 L p .896 .542 .365 r
F P
0 g
s
.44465 .15054 m .48119 .1447 L .48601 .13066 L p .678 .665 .83 r
F P
0 g
s
.48601 .13066 m .43364 .13909 L .44465 .15054 L p .678 .665 .83 r
F P
0 g
s
.38169 .65728 m .4003 .64352 L .40364 .63833 L p .875 .902 .846 r
F P
0 g
s
.23104 .44547 m .28534 .46298 L .27607 .46217 L p .626 .748 .935 r
F P
0 g
s
.24103 .44596 m .27908 .45825 L .28534 .46298 L p .629 .748 .933 r
F P
0 g
s
.28534 .46298 m .23104 .44547 L .24103 .44596 L p .629 .748 .933 r
F P
0 g
s
.29637 .45046 m .28534 .46298 L .27908 .45825 L p .619 .746 .937 r
F P
0 g
s
.30072 .45468 m .29297 .46342 L .28534 .46298 L p .614 .738 .934 r
F P
0 g
s
.28534 .46298 m .29637 .45046 L .30072 .45468 L p .614 .738 .934 r
F P
0 g
s
.44246 .53832 m .44103 .53281 L .44156 .53104 L p .114 .164 .637 r
F P
0 g
s
.59416 .58762 m .603 .59669 L .60421 .59795 L p .522 .02 0 r
F P
0 g
s
.27607 .46217 m .2381 .44994 L .23104 .44547 L p .626 .748 .935 r
F P
0 g
s
.54844 .53267 m .54089 .53242 L .53887 .53139 L p .911 .592 .428 r
F P
0 g
s
.34684 .69297 m .34337 .67894 L .33652 .67943 L p .833 .886 .88 r
F P
0 g
s
.2381 .44994 m .23226 .45941 L .22276 .45905 L p .634 .75 .931 r
F P
0 g
s
.22276 .45905 m .23104 .44547 L .2381 .44994 L p .634 .75 .931 r
F P
0 g
s
.43762 .57924 m .44094 .57334 L .44126 .57348 L p 0 0 .001 r
F P
0 g
s
.44156 .53104 m .44361 .53892 L .44246 .53832 L p .114 .164 .637 r
F P
0 g
s
.57396 .56654 m .56652 .56219 L .5636 .55941 L p .802 .31 0 r
F P
0 g
s
.39523 .48495 m .40394 .48053 L .40871 .48192 L p .53 .654 .914 r
F P
0 g
s
.4286 .50837 m .42199 .4992 L .42199 .49658 L p .415 .511 .848 r
F P
0 g
s
.42199 .49658 m .43144 .50969 L .4286 .50837 L p .415 .511 .848 r
F P
0 g
s
.54009 .50212 m .53312 .50521 L .53132 .50434 L p .912 .731 .644 r
F P
0 g
s
.44365 .54446 m .44299 .54043 L .44361 .53892 L p .025 .056 .555 r
F P
0 g
s
.61809 .61217 m .63096 .62158 L .63435 .62439 L p 0 .257 .757 r
F P
0 g
s
.56125 .14264 m .61356 .14883 L .62714 .13751 L p .707 .688 .829 r
F P
0 g
s
.5812 .44572 m .58748 .43834 L .5901 .4365 L p .715 .936 .96 r
F P
0 g
s
.57167 .45125 m .56832 .45241 L .56853 .45114 L p .781 .955 .928 r
F P
0 g
s
.56853 .45114 m .57331 .44948 L .57167 .45125 L p .781 .955 .928 r
F P
0 g
s
.40457 .62343 m .40364 .63833 L .4063 .6336 L p .905 .975 .801 r
F P
0 g
s
.40364 .63833 m .377 .65801 L .38169 .65728 L p .875 .902 .846 r
F P
0 g
s
.40052 .62838 m .39989 .63879 L .40364 .63833 L p .865 .957 .865 r
F P
0 g
s
.40364 .63833 m .40457 .62343 L .40052 .62838 L p .865 .957 .865 r
F P
0 g
s
.377 .65801 m .40364 .63833 L .39989 .63879 L p .865 .957 .865 r
F P
0 g
s
.55602 .46418 m .55911 .45564 L .56087 .4533 L p .851 .938 .88 r
F P
0 g
s
.43413 .51068 m .43856 .51878 L .43776 .52124 L p .487 .496 .792 r
F P
0 g
s
.43776 .52124 m .43144 .50969 L .43413 .51068 L p .487 .496 .792 r
F P
0 g
s
.44887 .5164 m .43776 .52124 L .43856 .51878 L p .471 .479 .785 r
F P
0 g
s
.44772 .5186 m .43994 .52198 L .43776 .52124 L p .45 .422 .735 r
F P
0 g
s
.43776 .52124 m .44887 .5164 L .44772 .5186 L p .45 .422 .735 r
F P
0 g
s
.44156 .53104 m .43776 .52124 L .43994 .52198 L p .445 .426 .743 r
F P
0 g
s
.76943 .44162 m .80696 .43173 L .81785 .43282 L p .631 .744 .93 r
F P
0 g
s
.53958 .49879 m .53892 .49014 L .54034 .48758 L p .91 .795 .721 r
F P
0 g
s
.60979 .60371 m .60881 .60248 L .61053 .60419 L p 0 .046 .577 r
F P
0 g
s
.61053 .60419 m .61193 .60594 L .60979 .60371 L p 0 .046 .577 r
F P
0 g
s
.44361 .53892 m .44455 .54468 L .44365 .54446 L p .025 .056 .555 r
F P
0 g
s
.32793 .4665 m .30072 .45468 L .29637 .45046 L p .6 .733 .938 r
F P
0 g
s
.29637 .45046 m .33527 .46739 L .32793 .4665 L p .6 .733 .938 r
F P
0 g
s
.43994 .52198 m .44261 .52885 L .44156 .53104 L p .445 .426 .743 r
F P
0 g
s
.45206 .52614 m .44156 .53104 L .44261 .52885 L p .433 .412 .735 r
F P
0 g
s
.45076 .52804 m .44341 .53147 L .44156 .53104 L p .409 .354 .685 r
F P
0 g
s
.44156 .53104 m .45206 .52614 L .45076 .52804 L p .409 .354 .685 r
F P
0 g
s
.44361 .53892 m .44156 .53104 L .44341 .53147 L p .406 .36 .694 r
F P
0 g
s
.30439 .45119 m .33165 .46306 L .33527 .46739 L p .609 .733 .933 r
F P
0 g
s
.33527 .46739 m .29637 .45046 L .30439 .45119 L p .609 .733 .933 r
F P
0 g
s
.34853 .45689 m .33527 .46739 L .33165 .46306 L p .595 .727 .936 r
F P
0 g
s
.35081 .46081 m .34151 .46813 L .33527 .46739 L p .587 .709 .928 r
F P
0 g
s
.33527 .46739 m .34853 .45689 L .35081 .46081 L p .587 .709 .928 r
F P
0 g
s
.44408 .54834 m .44388 .54591 L .44455 .54468 L p 0 0 .475 r
F P
0 g
s
.71234 .43604 m .73844 .42741 L .74701 .42774 L p .611 .756 .947 r
F P
0 g
s
.43644 .58233 m .4325 .59083 L .4309 .59403 L p 0 0 0 r
F P
0 g
s
.20808 .75938 m .27077 .73651 L .28207 .72804 L p .761 .825 .902 r
F P
0 g
s
.59223 .58591 m .58663 .5813 L .58358 .5784 L p .596 .07 0 r
F P
0 g
s
.42536 .49774 m .43198 .50692 L .43144 .50969 L p .527 .56 .832 r
F P
0 g
s
.43144 .50969 m .42199 .49658 L .42536 .49774 L p .527 .56 .832 r
F P
0 g
s
.44368 .50463 m .43144 .50969 L .43198 .50692 L p .512 .545 .827 r
F P
0 g
s
.4427 .50714 m .43413 .51068 L .43144 .50969 L p .494 .491 .783 r
F P
0 g
s
.43144 .50969 m .44368 .50463 L .4427 .50714 L p .494 .491 .783 r
F P
0 g
s
.55154 .53989 m .54348 .53874 L .54114 .53719 L p .896 .542 .365 r
F P
0 g
s
.55972 .55081 m .56416 .55857 L .5636 .55941 L p .877 .439 .12 r
F P
0 g
s
.5636 .55941 m .55726 .54831 L .55972 .55081 L p .877 .439 .12 r
F P
0 g
s
.42249 .60762 m .42946 .59781 L .4309 .59403 L p .933 .969 .703 r
F P
0 g
s
.44455 .54468 m .44484 .54815 L .44408 .54834 L p 0 0 .475 r
F P
0 g
s
.4442 .54988 m .44415 .54907 L .44484 .54815 L p 0 0 .443 r
F P
0 g
s
.58111 .43746 m .57331 .44948 L .57369 .44787 L p .757 .926 .944 r
F P
0 g
s
.57035 .44904 m .57369 .44787 L .57331 .44948 L p .787 .952 .925 r
F P
0 g
s
.57331 .44948 m .56853 .45114 L .57035 .44904 L p .787 .952 .925 r
F P
0 g
s
.5812 .43902 m .57573 .44743 L .57331 .44948 L p .754 .922 .946 r
F P
0 g
s
.57331 .44948 m .58111 .43746 L .5812 .43902 L p .754 .922 .946 r
F P
0 g
s
.44341 .53147 m .44484 .53699 L .44361 .53892 L p .406 .36 .694 r
F P
0 g
s
.45375 .53373 m .44361 .53892 L .44484 .53699 L p .394 .344 .683 r
F P
0 g
s
.45235 .53535 m .44525 .53898 L .44361 .53892 L p .371 .295 .64 r
F P
0 g
s
.44361 .53892 m .45375 .53373 L .45235 .53535 L p .371 .295 .64 r
F P
0 g
s
.44455 .54468 m .44361 .53892 L .44525 .53898 L p .371 .303 .65 r
F P
0 g
s
.44484 .54815 m .44491 .54931 L .4442 .54988 L p 0 0 .443 r
F P
0 g
s
.44424 .55088 m .44422 .55022 L .44491 .54931 L p 0 0 .417 r
F P
0 g
s
.63638 .63003 m .63242 .62369 L .63435 .62439 L p 0 .289 .788 r
F P
0 g
s
.63435 .62439 m .64 .63345 L .63638 .63003 L p 0 .289 .788 r
F P
0 g
s
.4063 .6336 m .40698 .62316 L .40457 .62343 L p .905 .975 .801 r
F P
0 g
s
.44491 .54931 m .44494 .55026 L .44424 .55088 L p 0 0 .417 r
F P
0 g
s
.43856 .51878 m .44633 .51538 L .44887 .5164 L p .471 .479 .785 r
F P
0 g
s
.4443 .55354 m .44426 .5515 L .44494 .55026 L p 0 0 .397 r
F P
0 g
s
.61629 .43414 m .62686 .42694 L .63142 .42558 L p .617 .864 .99 r
F P
0 g
s
.72261 .70107 m .76476 .71826 L .77366 .72546 L p .463 .61 .91 r
F P
0 g
s
.44261 .52885 m .44995 .52541 L .45206 .52614 L p .433 .412 .735 r
F P
0 g
s
.628 .61783 m .61526 .60866 L .61193 .60594 L p 0 .26 .759 r
F P
0 g
s
.61193 .60594 m .63013 .61903 L .628 .61783 L p 0 .26 .759 r
F P
0 g
s
.61343 .6064 m .61442 .60762 L .61193 .60594 L p 0 .257 .757 r
F P
0 g
s
.61193 .60594 m .61053 .60419 L .61343 .6064 L p 0 .257 .757 r
F P
0 g
s
.63013 .61903 m .61193 .60594 L .61442 .60762 L p 0 .249 .747 r
F P
0 g
s
.54593 .54424 m .55477 .54652 L .55726 .54831 L p .896 .542 .365 r
F P
0 g
s
.55726 .54831 m .54463 .54506 L .54593 .54424 L p .896 .542 .365 r
F P
0 g
s
.56066 .55714 m .55622 .54936 L .55726 .54831 L p .868 .468 .272 r
F P
0 g
s
.55726 .54831 m .5636 .55941 L .56066 .55714 L p .868 .468 .272 r
F P
0 g
s
.54463 .54506 m .55726 .54831 L .55622 .54936 L p .87 .47 .274 r
F P
0 g
s
.60726 .60091 m .60836 .60199 L .61053 .60419 L p .52 .017 0 r
F P
0 g
s
.54175 .47543 m .54163 .4848 L .54034 .48758 L p .916 .846 .76 r
F P
0 g
s
.56753 .45283 m .56686 .45316 L .56756 .45161 L p .833 .994 .854 r
F P
0 g
s
.56756 .45161 m .56853 .45114 L .56753 .45283 L p .833 .994 .854 r
F P
0 g
s
.5405 .47419 m .54034 .48758 L .53863 .48632 L p .878 .818 .785 r
F P
0 g
s
.53102 .48979 m .53863 .48632 L .54034 .48758 L p .897 .809 .753 r
F P
0 g
s
.54034 .48758 m .52946 .49255 L .53102 .48979 L p .897 .809 .753 r
F P
0 g
s
.54034 .48758 m .5405 .47419 L .54175 .47543 L p .916 .846 .76 r
F P
0 g
s
.52946 .49255 m .54034 .48758 L .53892 .49014 L p .889 .761 .714 r
F P
0 g
s
.54829 .47212 m .54175 .47543 L .5405 .47419 L p .888 .854 .803 r
F P
0 g
s
.5405 .47419 m .54985 .46947 L .54829 .47212 L p .888 .854 .803 r
F P
0 g
s
.33186 .7003 m .29011 .72036 L .28207 .72804 L p .794 .866 .902 r
F P
0 g
s
.66399 .64787 m .64486 .63765 L .64 .63345 L p .218 .459 .876 r
F P
0 g
s
.64 .63345 m .66736 .64804 L .66399 .64787 L p .218 .459 .876 r
F P
0 g
s
.63924 .62784 m .64319 .63419 L .64 .63345 L p .138 .446 .88 r
F P
0 g
s
.64 .63345 m .63435 .62439 L .63924 .62784 L p .138 .446 .88 r
F P
0 g
s
.66736 .64804 m .64 .63345 L .64319 .63419 L p .137 .446 .88 r
F P
0 g
s
.55283 .45605 m .54985 .46947 L .54876 .46809 L p .854 .887 .861 r
F P
0 g
s
.54222 .47139 m .54876 .46809 L .54985 .46947 L p .886 .889 .828 r
F P
0 g
s
.54985 .46947 m .5405 .47419 L .54222 .47139 L p .886 .889 .828 r
F P
0 g
s
.55348 .45757 m .55139 .46696 L .54985 .46947 L p .867 .9 .854 r
F P
0 g
s
.54985 .46947 m .55283 .45605 L .55348 .45757 L p .867 .9 .854 r
F P
0 g
s
.44494 .55026 m .44499 .55319 L .4443 .55354 L p 0 0 .397 r
F P
0 g
s
.44525 .53898 m .44591 .54302 L .44455 .54468 L p .371 .303 .65 r
F P
0 g
s
.45454 .53917 m .44455 .54468 L .44591 .54302 L p .359 .287 .638 r
F P
0 g
s
.45308 .5405 m .44609 .54436 L .44455 .54468 L p .339 .246 .601 r
F P
0 g
s
.44455 .54468 m .45454 .53917 L .45308 .5405 L p .339 .246 .601 r
F P
0 g
s
.44484 .54815 m .44455 .54468 L .44609 .54436 L p .34 .25 .606 r
F P
0 g
s
.41828 .49522 m .40899 .48497 L .40871 .48192 L p .49 .59 .882 r
F P
0 g
s
.40871 .48192 m .42199 .49658 L .41828 .49522 L p .49 .59 .882 r
F P
0 g
s
.43637 .58394 m .4309 .59403 L .4325 .59083 L p 0 0 0 r
F P
0 g
s
.4309 .59403 m .42092 .60806 L .42249 .60762 L p .933 .969 .703 r
F P
0 g
s
.43414 .5874 m .43032 .59445 L .4309 .59403 L p .699 .889 .511 r
F P
0 g
s
.4325 .59083 m .43634 .58377 L .43637 .58394 L p 0 0 0 r
F P
0 g
s
.4309 .59403 m .43637 .58394 L .43414 .5874 L p .699 .889 .511 r
F P
0 g
s
.42092 .60806 m .4309 .59403 L .43032 .59445 L p .702 .889 .51 r
F P
0 g
s
.4441 .55817 m .44428 .55478 L .44499 .55319 L p 0 0 .313 r
F P
0 g
s
.70736 .68022 m .67868 .66784 L .67244 .66231 L p .396 .551 .891 r
F P
0 g
s
.44484 .53699 m .45194 .53335 L .45375 .53373 L p .394 .344 .683 r
F P
0 g
s
.43198 .50692 m .44054 .50337 L .44368 .50463 L p .512 .545 .827 r
F P
0 g
s
.53892 .49014 m .53131 .49362 L .52946 .49255 L p .889 .761 .714 r
F P
0 g
s
.44609 .54436 m .44629 .54679 L .44484 .54815 L p .34 .25 .606 r
F P
0 g
s
.45486 .54244 m .44484 .54815 L .44629 .54679 L p .336 .244 .601 r
F P
0 g
s
.45336 .54347 m .44635 .54747 L .44484 .54815 L p .324 .221 .58 r
F P
0 g
s
.44484 .54815 m .45486 .54244 L .45336 .54347 L p .324 .221 .58 r
F P
0 g
s
.44491 .54931 m .44484 .54815 L .44635 .54747 L p .329 .231 .59 r
F P
0 g
s
.8484 .75455 m .78481 .73483 L .77366 .72546 L p .539 .648 .905 r
F P
0 g
s
.61053 .60419 m .60895 .60264 L .60726 .60091 L p .52 .017 0 r
F P
0 g
s
.36985 .47254 m .35081 .46081 L .34853 .45689 L p .567 .699 .93 r
F P
0 g
s
.34853 .45689 m .37576 .47368 L .36985 .47254 L p .567 .699 .93 r
F P
0 g
s
.44635 .54747 m .44639 .54828 L .44491 .54931 L p .329 .231 .59 r
F P
0 g
s
.45492 .54352 m .44491 .54931 L .44639 .54828 L p .322 .219 .58 r
F P
0 g
s
.45342 .54453 m .44641 .54858 L .44491 .54931 L p .31 .198 .56 r
F P
0 g
s
.44491 .54931 m .45492 .54352 L .45342 .54453 L p .31 .198 .56 r
F P
0 g
s
.44494 .55026 m .44491 .54931 L .44641 .54858 L p .318 .213 .575 r
F P
0 g
s
.41293 .48318 m .42223 .49345 L .42199 .49658 L p .562 .615 .864 r
F P
0 g
s
.42199 .49658 m .40871 .48192 L .41293 .48318 L p .562 .615 .864 r
F P
0 g
s
.43584 .49085 m .42199 .49658 L .42223 .49345 L p .548 .604 .861 r
F P
0 g
s
.43505 .49374 m .42536 .49774 L .42199 .49658 L p .535 .556 .823 r
F P
0 g
s
.42199 .49658 m .43584 .49085 L .43505 .49374 L p .535 .556 .823 r
F P
0 g
s
.27908 .45825 m .28676 .44945 L .29637 .45046 L p .619 .746 .937 r
F P
0 g
s
.66757 .65785 m .66399 .64787 L .66736 .64804 L p .218 .458 .876 r
F P
0 g
s
.66736 .64804 m .67244 .66231 L .66757 .65785 L p .218 .458 .876 r
F P
0 g
s
.67244 .66231 m .71348 .67999 L .70736 .68022 L p .396 .551 .891 r
F P
0 g
s
.67423 .65263 m .67775 .66261 L .67244 .66231 L p .34 .551 .911 r
F P
0 g
s
.67244 .66231 m .66736 .64804 L .67423 .65263 L p .34 .551 .911 r
F P
0 g
s
.71348 .67999 m .67244 .66231 L .67775 .66261 L p .339 .552 .912 r
F P
0 g
s
.57369 .44787 m .57915 .43946 L .58111 .43746 L p .757 .926 .944 r
F P
0 g
s
.57548 .43826 m .56853 .45114 L .5694 .44927 L p .811 .964 .907 r
F P
0 g
s
.56872 .4496 m .5694 .44927 L .56853 .45114 L p .834 .993 .854 r
F P
0 g
s
.56853 .45114 m .56756 .45161 L .56872 .4496 L p .834 .993 .854 r
F P
0 g
s
.57522 .44002 m .57035 .44904 L .56853 .45114 L p .775 .914 .933 r
F P
0 g
s
.56853 .45114 m .57548 .43826 L .57522 .44002 L p .775 .914 .933 r
F P
0 g
s
.44641 .54858 m .44643 .54925 L .44494 .55026 L p .318 .213 .575 r
F P
0 g
s
.45494 .5444 m .44494 .55026 L .44643 .54925 L p .308 .196 .559 r
F P
0 g
s
.45344 .5457 m .44644 .54981 L .44494 .55026 L p .305 .191 .555 r
F P
0 g
s
.44494 .55026 m .45494 .5444 L .45344 .5457 L p .305 .191 .555 r
F P
0 g
s
.44499 .55319 m .44494 .55026 L .44644 .54981 L p .309 .203 .567 r
F P
0 g
s
.44499 .55319 m .44474 .55803 L .4441 .55817 L p 0 0 .313 r
F P
0 g
s
.62559 .61505 m .61297 .60589 L .61053 .60419 L p 0 .218 .711 r
F P
0 g
s
.61053 .60419 m .62855 .61728 L .62559 .61505 L p 0 .218 .711 r
F P
0 g
s
.60895 .60264 m .61053 .60419 L .61297 .60589 L p 0 .208 .695 r
F P
0 g
s
.62605 .61556 m .61343 .6064 L .61053 .60419 L p 0 .242 .741 r
F P
0 g
s
.61053 .60419 m .62855 .61728 L .62605 .61556 L p 0 .242 .741 r
F P
0 g
s
.44591 .54302 m .4529 .53916 L .45454 .53917 L p .359 .287 .638 r
F P
0 g
s
.35504 .45795 m .37411 .46973 L .37576 .47368 L p .591 .702 .92 r
F P
0 g
s
.37576 .47368 m .34853 .45689 L .35504 .45795 L p .591 .702 .92 r
F P
0 g
s
.39053 .46522 m .37576 .47368 L .37411 .46973 L p .575 .693 .921 r
F P
0 g
s
.39122 .46885 m .38087 .47476 L .37576 .47368 L p .565 .662 .903 r
F P
0 g
s
.37576 .47368 m .39053 .46522 L .39122 .46885 L p .565 .662 .903 r
F P
0 g
s
.56585 .45257 m .56504 .45317 L .56567 .45163 L p .846 .989 .855 r
F P
0 g
s
.56567 .45163 m .56684 .45076 L .56585 .45257 L p .846 .989 .855 r
F P
0 g
s
.64387 .43074 m .63162 .42763 L .63142 .42558 L p .586 .821 .989 r
F P
0 g
s
.63142 .42558 m .64893 .43004 L .64387 .43074 L p .586 .821 .989 r
F P
0 g
s
.27527 .70215 m .28207 .72804 L .29011 .72036 L p .794 .865 .902 r
F P
0 g
s
.28207 .72804 m .19229 .76078 L .20808 .75938 L p .761 .825 .902 r
F P
0 g
s
.26254 .71036 m .26747 .72845 L .28207 .72804 L p .758 .846 .917 r
F P
0 g
s
.28207 .72804 m .27527 .70215 L .26254 .71036 L p .758 .846 .917 r
F P
0 g
s
.19229 .76078 m .28207 .72804 L .26747 .72845 L p .758 .846 .917 r
F P
0 g
s
.53863 .48632 m .53874 .47694 L .5405 .47419 L p .878 .818 .785 r
F P
0 g
s
.59885 .43724 m .59044 .43782 L .5901 .4365 L p .668 .902 .978 r
F P
0 g
s
.5901 .4365 m .60213 .43568 L .59885 .43724 L p .668 .902 .978 r
F P
0 g
s
.4432 .56478 m .44391 .56004 L .44474 .55803 L p 0 0 .18 r
F P
0 g
s
.603 .59669 m .60633 .59997 L .60895 .60264 L p .522 .02 0 r
F P
0 g
s
.44644 .54981 m .44647 .55186 L .44499 .55319 L p .309 .203 .567 r
F P
0 g
s
.455 .54707 m .44499 .55319 L .44647 .55186 L p .299 .186 .553 r
F P
0 g
s
.45346 .54869 m .44645 .55297 L .44499 .55319 L p .274 .142 .512 r
F P
0 g
s
.44499 .55319 m .455 .54707 L .45346 .54869 L p .274 .142 .512 r
F P
0 g
s
.44474 .55803 m .44499 .55319 L .44645 .55297 L p .276 .148 .52 r
F P
0 g
s
.39989 .63879 m .38121 .65258 L .377 .65801 L p .865 .957 .865 r
F P
0 g
s
.57334 .44042 m .56872 .4496 L .56756 .45161 L p .819 .96 .903 r
F P
0 g
s
.56756 .45161 m .57417 .43849 L .57334 .44042 L p .819 .96 .903 r
F P
0 g
s
.54876 .46809 m .55085 .4587 L .55283 .45605 L p .854 .887 .861 r
F P
0 g
s
.61442 .60762 m .62716 .61679 L .63013 .61903 L p 0 .249 .747 r
F P
0 g
s
.62714 .13751 m .55217 .12858 L .56125 .14264 L p .707 .688 .829 r
F P
0 g
s
.56422 .45365 m .56086 .45481 L .56087 .4533 L p .82 .922 .904 r
F P
0 g
s
.56087 .4533 m .56567 .45163 L .56422 .45365 L p .82 .922 .904 r
F P
0 g
s
.44629 .54679 m .4533 .54279 L .45486 .54244 L p .336 .244 .601 r
F P
0 g
s
.55622 .54936 m .54738 .54709 L .54463 .54506 L p .87 .47 .274 r
F P
0 g
s
.33165 .46306 m .34091 .45569 L .34853 .45689 L p .595 .727 .936 r
F P
0 g
s
.49667 .14328 m .54282 .14184 L .55217 .12858 L p .691 .674 .829 r
F P
0 g
s
.55217 .12858 m .48601 .13066 L .49667 .14328 L p .691 .674 .829 r
F P
0 g
s
.67156 .41724 m .64893 .43004 L .64947 .42729 L p .613 .808 .975 r
F P
0 g
s
.6372 .42416 m .64947 .42729 L .64893 .43004 L p .63 .824 .975 r
F P
0 g
s
.64893 .43004 m .63142 .42558 L .6372 .42416 L p .63 .824 .975 r
F P
0 g
s
.67097 .42047 m .65512 .42941 L .64893 .43004 L p .61 .788 .967 r
F P
0 g
s
.64893 .43004 m .67156 .41724 L .67097 .42047 L p .61 .788 .967 r
F P
0 g
s
.44639 .54828 m .4534 .54422 L .45492 .54352 L p .322 .219 .58 r
F P
0 g
s
.44643 .54925 m .45343 .54515 L .45494 .5444 L p .308 .196 .559 r
F P
0 g
s
.57345 .43763 m .56684 .45076 L .56763 .44891 L p .819 .96 .903 r
F P
0 g
s
.56681 .44952 m .56763 .44891 L .56684 .45076 L p .845 .99 .854 r
F P
0 g
s
.56684 .45076 m .56567 .45163 L .56681 .44952 L p .845 .99 .854 r
F P
0 g
s
.6152 .42321 m .60213 .43568 L .60213 .43381 L p .668 .875 .976 r
F P
0 g
s
.59371 .43438 m .60213 .43381 L .60213 .43568 L p .698 .897 .968 r
F P
0 g
s
.60213 .43568 m .5901 .4365 L .59371 .43438 L p .698 .897 .968 r
F P
0 g
s
.61552 .42529 m .60636 .43401 L .60213 .43568 L p .663 .861 .975 r
F P
0 g
s
.60213 .43568 m .6152 .42321 L .61552 .42529 L p .663 .861 .975 r
F P
0 g
s
.60421 .59795 m .603 .59669 L p .60531 .59899 L .522 .02 0 r
F P
0 g
s
.60421 .59795 m .6055 .59873 L p .60271 .59653 L 0 .168 .633 r
F P
0 g
s
.59516 .59013 m .60107 .59498 L .60421 .59795 L p .6 .073 0 r
F P
0 g
s
.60421 .59795 m .59577 .59102 L .59516 .59013 L p .6 .073 0 r
F P
0 g
s
.59577 .59102 m .60421 .59795 L p .60271 .59653 L 0 .168 .633 r
F P
0 g
s
.60895 .60264 m .60421 .59795 L p .60531 .59899 L .522 .02 0 r
F P
0 g
s
.6235 .61285 m .61089 .60383 L .60895 .60264 L p 0 .214 .701 r
F P
0 g
s
.60895 .60264 m .62696 .61552 L .6235 .61285 L p 0 .214 .701 r
F P
0 g
s
.60421 .59795 m .60895 .60264 L .61089 .60383 L p 0 .214 .702 r
F P
0 g
s
.61297 .60589 m .61187 .6048 L .60895 .60264 L p 0 .208 .695 r
F P
0 g
s
.62696 .61552 m .60895 .60264 L .61187 .6048 L p 0 .226 .717 r
F P
0 g
s
.53521 .51464 m .53657 .51957 L .53539 .52101 L p .923 .68 .552 r
F P
0 g
s
.53539 .52101 m .53344 .51396 L .53521 .51464 L p .923 .68 .552 r
F P
0 g
s
.5694 .44927 m .57426 .44026 L .57548 .43826 L p .811 .964 .907 r
F P
0 g
s
.42223 .49345 m .43192 .48943 L .43584 .49085 L p .548 .604 .861 r
F P
0 g
s
.57197 .43817 m .56567 .45163 L .56583 .44982 L p .785 .904 .924 r
F P
0 g
s
.56246 .45098 m .56583 .44982 L .56567 .45163 L p .816 .927 .908 r
F P
0 g
s
.56567 .45163 m .56087 .4533 L .56246 .45098 L p .816 .927 .908 r
F P
0 g
s
.57122 .4401 m .56681 .44952 L .56567 .45163 L p .824 .954 .901 r
F P
0 g
s
.56567 .45163 m .57197 .43817 L .57122 .4401 L p .824 .954 .901 r
F P
0 g
s
.53312 .50521 m .5346 .51194 L .53344 .51396 L p .918 .714 .612 r
F P
0 g
s
.44645 .55297 m .44628 .55636 L .44474 .55803 L p .276 .148 .52 r
F P
0 g
s
.45487 .55151 m .44474 .55803 L .44628 .55636 L p .267 .136 .51 r
F P
0 g
s
.44474 .55803 m .44371 .56481 L .4432 .56478 L p 0 0 .18 r
F P
0 g
s
.45322 .55346 m .44612 .55802 L .44474 .55803 L p .226 .065 .443 r
F P
0 g
s
.44474 .55803 m .45487 .55151 L .45322 .55346 L p .226 .065 .443 r
F P
0 g
s
.44371 .56481 m .44474 .55803 L .44612 .55802 L p .226 .068 .447 r
F P
0 g
s
.43032 .59445 m .42333 .60428 L .42092 .60806 L p .702 .889 .51 r
F P
0 g
s
.44647 .55186 m .45348 .54757 L .455 .54707 L p .299 .186 .553 r
F P
0 g
s
.5371 .52143 m .53804 .52442 L .53673 .52528 L p .923 .653 .509 r
F P
0 g
s
.53673 .52528 m .53539 .52101 L .5371 .52143 L p .923 .653 .509 r
F P
0 g
s
.57236 .57048 m .58051 .57548 L .58358 .5784 L p .806 .317 0 r
F P
0 g
s
.58358 .5784 m .57194 .57126 L .57236 .57048 L p .806 .317 0 r
F P
0 g
s
.5921 .58799 m .58357 .57915 L .58358 .5784 L p .679 .139 0 r
F P
0 g
s
.58358 .5784 m .59577 .59102 L .5921 .58799 L p .679 .139 0 r
F P
0 g
s
.57194 .57126 m .58358 .5784 L .58357 .57915 L p .681 .141 0 r
F P
0 g
s
.59577 .59102 m .58358 .5784 L .58663 .5813 L p .601 .074 0 r
F P
0 g
s
.53344 .51396 m .53132 .50434 L .53312 .50521 L p .918 .714 .612 r
F P
0 g
s
.64319 .63419 m .66235 .6444 L .66736 .64804 L p .137 .446 .88 r
F P
0 g
s
.53834 .52537 m .53867 .52636 L .5372 .5267 L p .922 .638 .488 r
F P
0 g
s
.5372 .5267 m .53673 .52528 L .53834 .52537 L p .922 .638 .488 r
F P
0 g
s
.53882 .5268 m .5391 .52762 L .5376 .52788 L p .92 .63 .477 r
F P
0 g
s
.5376 .52788 m .5372 .5267 L .53882 .5268 L p .92 .63 .477 r
F P
0 g
s
.58663 .5813 m .59516 .59013 L .59577 .59102 L p .601 .074 0 r
F P
0 g
s
.44094 .57334 m .44265 .56727 L .44371 .56481 L p 0 0 0 r
F P
0 g
s
.53131 .49362 m .53261 .50186 L .53132 .50434 L p .901 .746 .68 r
F P
0 g
s
.53939 .5284 m .54027 .53086 L .53887 .53139 L p .917 .616 .459 r
F P
0 g
s
.53887 .53139 m .5376 .52788 L .53939 .5284 L p .917 .616 .459 r
F P
0 g
s
.29011 .72036 m .28546 .7022 L .27527 .70215 L p .794 .865 .902 r
F P
0 g
s
.55911 .45564 m .55348 .45757 L .55283 .45605 L p .831 .888 .883 r
F P
0 g
s
.55283 .45605 m .56087 .4533 L .55911 .45564 L p .831 .888 .883 r
F P
0 g
s
.53132 .50434 m .53344 .51396 L .53107 .513 L p .851 .678 .667 r
F P
0 g
s
.52146 .5149 m .53107 .513 L .53344 .51396 L p .855 .668 .649 r
F P
0 g
s
.53344 .51396 m .51971 .51669 L .52146 .5149 L p .855 .668 .649 r
F P
0 g
s
.53302 .5203 m .53166 .51536 L .53344 .51396 L p .853 .647 .623 r
F P
0 g
s
.53344 .51396 m .53539 .52101 L .53302 .5203 L p .853 .647 .623 r
F P
0 g
s
.51971 .51669 m .53344 .51396 L .53166 .51536 L p .847 .634 .614 r
F P
0 g
s
.56763 .44891 m .57225 .43972 L .57345 .43763 L p .819 .96 .903 r
F P
0 g
s
.44628 .55636 m .45337 .55179 L .45487 .55151 L p .267 .136 .51 r
F P
0 g
s
.37411 .46973 m .38445 .46378 L .39053 .46522 L p .575 .693 .921 r
F P
0 g
s
.77536 .69898 m .77366 .72546 L .76476 .71826 L p .462 .61 .911 r
F P
0 g
s
.77366 .72546 m .86483 .7537 L .8484 .75455 L p .539 .648 .905 r
F P
0 g
s
.78901 .7066 m .78765 .72511 L .77366 .72546 L p .512 .655 .923 r
F P
0 g
s
.77366 .72546 m .77536 .69898 L .78901 .7066 L p .512 .655 .923 r
F P
0 g
s
.86483 .7537 m .77366 .72546 L .78765 .72511 L p .512 .655 .924 r
F P
0 g
s
.56652 .56219 m .57236 .57048 L .57194 .57126 L p .81 .323 0 r
F P
0 g
s
.57194 .57126 m .5636 .55941 L .56652 .56219 L p .81 .323 0 r
F P
0 g
s
.61187 .6048 m .62448 .61382 L .62696 .61552 L p 0 .226 .717 r
F P
0 g
s
.52323 .52161 m .53302 .5203 L .53539 .52101 L p .854 .638 .608 r
F P
0 g
s
.53539 .52101 m .5214 .52289 L .52323 .52161 L p .854 .638 .608 r
F P
0 g
s
.53442 .52488 m .53348 .52189 L .53539 .52101 L p .853 .623 .591 r
F P
0 g
s
.53539 .52101 m .53673 .52528 L .53442 .52488 L p .853 .623 .591 r
F P
0 g
s
.5214 .52289 m .53539 .52101 L .53348 .52189 L p .848 .613 .582 r
F P
0 g
s
.40394 .48053 m .39122 .46885 L .39053 .46522 L p .546 .648 .901 r
F P
0 g
s
.39053 .46522 m .40871 .48192 L .40394 .48053 L p .546 .648 .901 r
F P
0 g
s
.54089 .53242 m .54248 .53647 L .54114 .53719 L p .911 .589 .423 r
F P
0 g
s
.54114 .53719 m .53887 .53139 L .54089 .53242 L p .911 .589 .423 r
F P
0 g
s
.34337 .67894 m .37164 .66396 L .377 .65801 L p .834 .885 .879 r
F P
0 g
s
.52946 .49255 m .53132 .50434 L .52896 .50318 L p .843 .71 .717 r
F P
0 g
s
.51935 .50574 m .52896 .50318 L .53132 .50434 L p .85 .701 .697 r
F P
0 g
s
.53132 .50434 m .51759 .50801 L .51935 .50574 L p .85 .701 .697 r
F P
0 g
s
.53132 .50434 m .52946 .49255 L .53131 .49362 L p .901 .746 .68 r
F P
0 g
s
.53107 .513 m .52958 .50626 L .53132 .50434 L p .851 .678 .667 r
F P
0 g
s
.51759 .50801 m .53132 .50434 L .52958 .50626 L p .842 .661 .658 r
F P
0 g
s
.55086 .55375 m .56066 .55714 L .5636 .55941 L p .869 .471 .278 r
F P
0 g
s
.5636 .55941 m .5496 .55458 L .55086 .55375 L p .869 .471 .278 r
F P
0 g
s
.56847 .56865 m .56263 .56035 L .5636 .55941 L p .821 .364 .14 r
F P
0 g
s
.5636 .55941 m .57194 .57126 L .56847 .56865 L p .821 .364 .14 r
F P
0 g
s
.5496 .55458 m .5636 .55941 L .56263 .56035 L p .823 .367 .142 r
F P
0 g
s
.44612 .55802 m .44541 .56277 L .44371 .56481 L p .226 .068 .447 r
F P
0 g
s
.40698 .62316 m .4184 .61241 L .42092 .60806 L p .905 .975 .801 r
F P
0 g
s
.56583 .44982 m .57023 .4404 L .57197 .43817 L p .785 .904 .924 r
F P
0 g
s
.54172 .45965 m .5405 .47419 L .53871 .4727 L p .836 .821 .835 r
F P
0 g
s
.53011 .4761 m .53871 .4727 L .5405 .47419 L p .858 .818 .809 r
F P
0 g
s
.5405 .47419 m .52823 .47906 L .53011 .4761 L p .858 .818 .809 r
F P
0 g
s
.54308 .46121 m .54222 .47139 L .5405 .47419 L p .86 .842 .826 r
F P
0 g
s
.5405 .47419 m .54172 .45965 L .54308 .46121 L p .86 .842 .826 r
F P
0 g
s
.52823 .47906 m .5405 .47419 L .53874 .47694 L p .855 .779 .776 r
F P
0 g
s
.56628 .43906 m .56087 .4533 L .56037 .45151 L p .793 .886 .912 r
F P
0 g
s
.55474 .45344 m .56037 .45151 L .56087 .4533 L p .825 .901 .894 r
F P
0 g
s
.56087 .4533 m .55283 .45605 L .55474 .45344 L p .825 .901 .894 r
F P
0 g
s
.56625 .44102 m .56246 .45098 L .56087 .4533 L p .797 .89 .911 r
F P
0 g
s
.56087 .4533 m .56628 .43906 L .56625 .44102 L p .797 .89 .911 r
F P
0 g
s
.52445 .52578 m .53442 .52488 L .53673 .52528 L p .852 .615 .579 r
F P
0 g
s
.53673 .52528 m .52249 .52657 L .52445 .52578 L p .852 .615 .579 r
F P
0 g
s
.53499 .52667 m .53466 .52567 L .53673 .52528 L p .852 .611 .574 r
F P
0 g
s
.53673 .52528 m .5372 .5267 L .53499 .52667 L p .852 .611 .574 r
F P
0 g
s
.52249 .52657 m .53673 .52528 L .53466 .52567 L p .849 .6 .563 r
F P
0 g
s
.53874 .47694 m .53016 .48035 L .52823 .47906 L p .855 .779 .776 r
F P
0 g
s
.45422 .55763 m .44371 .56481 L .44541 .56277 L p .221 .061 .441 r
F P
0 g
s
.44371 .56481 m .44126 .57348 L .44094 .57334 L p 0 0 0 r
F P
0 g
s
.45232 .55994 m .44496 .56496 L .44371 .56481 L p .151 0 .331 r
F P
0 g
s
.44371 .56481 m .45422 .55763 L .45232 .55994 L p .151 0 .331 r
F P
0 g
s
.44126 .57348 m .44371 .56481 L .44496 .56496 L p .151 0 .336 r
F P
0 g
s
.67775 .66261 m .70652 .675 L .71348 .67999 L p .339 .552 .912 r
F P
0 g
s
.39585 .46656 m .40858 .47827 L .40871 .48192 L p .591 .661 .886 r
F P
0 g
s
.40871 .48192 m .39053 .46522 L .39585 .46656 L p .591 .661 .886 r
F P
0 g
s
.42464 .47496 m .40871 .48192 L .40858 .47827 L p .58 .651 .885 r
F P
0 g
s
.42408 .47832 m .41293 .48318 L .40871 .48192 L p .569 .611 .855 r
F P
0 g
s
.40871 .48192 m .42464 .47496 L .42408 .47832 L p .569 .611 .855 r
F P
0 g
s
.52495 .52743 m .53499 .52667 L .5372 .5267 L p .85 .601 .562 r
F P
0 g
s
.5372 .5267 m .52285 .52779 L .52495 .52743 L p .85 .601 .562 r
F P
0 g
s
.53539 .52785 m .53511 .52703 L .5372 .5267 L p .851 .604 .564 r
F P
0 g
s
.5372 .5267 m .5376 .52788 L .53539 .52785 L p .851 .604 .564 r
F P
0 g
s
.52285 .52779 m .5372 .5267 L .53511 .52703 L p .849 .595 .555 r
F P
0 g
s
.60213 .43381 m .61128 .42508 L .6152 .42321 L p .668 .875 .976 r
F P
0 g
s
.61089 .60383 m .60757 .60055 L .60421 .59795 L p 0 .214 .702 r
F P
0 g
s
.52529 .52849 m .53539 .52785 L .5376 .52788 L p .849 .595 .554 r
F P
0 g
s
.5376 .52788 m .52317 .52879 L .52529 .52849 L p .849 .595 .554 r
F P
0 g
s
.5365 .53097 m .53561 .52851 L .5376 .52788 L p .85 .593 .55 r
F P
0 g
s
.5376 .52788 m .53887 .53139 L .5365 .53097 L p .85 .593 .55 r
F P
0 g
s
.52317 .52879 m .5376 .52788 L .53561 .52851 L p .847 .585 .542 r
F P
0 g
s
.44995 .52541 m .44772 .5186 L .44887 .5164 L p .438 .408 .727 r
F P
0 g
s
.53166 .51536 m .52205 .51727 L .51971 .51669 L p .847 .634 .614 r
F P
0 g
s
.44633 .51538 m .4427 .50714 L .44368 .50463 L p .48 .475 .775 r
F P
0 g
s
.44368 .50463 m .44887 .5164 L .44633 .51538 L p .48 .475 .775 r
F P
0 g
s
.64947 .42729 m .66531 .41831 L .67156 .41724 L p .613 .808 .975 r
F P
0 g
s
.52958 .50626 m .51998 .50883 L .51759 .50801 L p .842 .661 .658 r
F P
0 g
s
.44887 .5164 m .45206 .52614 L .44995 .52541 L p .438 .408 .727 r
F P
0 g
s
.53348 .52189 m .52369 .5232 L .5214 .52289 L p .848 .613 .582 r
F P
0 g
s
.52896 .50318 m .52766 .49492 L .52946 .49255 L p .843 .71 .717 r
F P
0 g
s
.58748 .43834 m .5812 .43902 L .58111 .43746 L p .719 .899 .96 r
F P
0 g
s
.58111 .43746 m .5901 .4365 L .58748 .43834 L p .719 .899 .96 r
F P
0 g
s
.45194 .53335 m .45076 .52804 L .45206 .52614 L p .396 .337 .674 r
F P
0 g
s
.37893 .63964 m .377 .65801 L .38121 .65258 L p .865 .957 .865 r
F P
0 g
s
.377 .65801 m .33652 .67943 L .34337 .67894 L p .834 .885 .879 r
F P
0 g
s
.37267 .64526 m .37137 .65811 L .377 .65801 L p .823 .929 .903 r
F P
0 g
s
.377 .65801 m .37893 .63964 L .37267 .64526 L p .823 .929 .903 r
F P
0 g
s
.33652 .67943 m .377 .65801 L .37137 .65811 L p .823 .928 .903 r
F P
0 g
s
.42765 .59568 m .42092 .60806 L .42333 .60428 L p .709 .895 .519 r
F P
0 g
s
.42092 .60806 m .40457 .62343 L .40698 .62316 L p .905 .975 .801 r
F P
0 g
s
.42433 .59964 m .41963 .6083 L .42092 .60806 L p .779 .985 .733 r
F P
0 g
s
.42092 .60806 m .42765 .59568 L .42433 .59964 L p .779 .985 .733 r
F P
0 g
s
.40457 .62343 m .42092 .60806 L .41963 .6083 L p .78 .985 .733 r
F P
0 g
s
.52619 .53126 m .5365 .53097 L .53887 .53139 L p .849 .586 .54 r
F P
0 g
s
.53887 .53139 m .52414 .53182 L .52619 .53126 L p .849 .586 .54 r
F P
0 g
s
.53856 .53632 m .53697 .53226 L .53887 .53139 L p .846 .569 .519 r
F P
0 g
s
.53887 .53139 m .54114 .53719 L .53856 .53632 L p .846 .569 .519 r
F P
0 g
s
.52414 .53182 m .53887 .53139 L .53697 .53226 L p .843 .562 .513 r
F P
0 g
s
.68505 .42737 m .67097 .42047 L .67156 .41724 L p .598 .777 .966 r
F P
0 g
s
.67156 .41724 m .69168 .42713 L .68505 .42737 L p .598 .777 .966 r
F P
0 g
s
.53016 .48035 m .53102 .48979 L .52946 .49255 L p .872 .769 .745 r
F P
0 g
s
.58357 .57915 m .57542 .57415 L .57194 .57126 L p .681 .141 0 r
F P
0 g
s
.53466 .52567 m .5247 .52658 L .52249 .52657 L p .849 .6 .563 r
F P
0 g
s
.44541 .56277 m .45276 .55774 L .45422 .55763 L p .221 .061 .441 r
F P
0 g
s
.54348 .53874 m .54593 .54424 L .54463 .54506 L p .896 .543 .366 r
F P
0 g
s
.54463 .54506 m .54114 .53719 L .54348 .53874 L p .896 .543 .366 r
F P
0 g
s
.76476 .71826 m .76584 .69971 L .77536 .69898 L p .462 .61 .911 r
F P
0 g
s
.44054 .50337 m .43505 .49374 L .43584 .49085 L p .521 .541 .817 r
F P
0 g
s
.43584 .49085 m .44368 .50463 L .44054 .50337 L p .521 .541 .817 r
F P
0 g
s
.53511 .52703 m .52507 .52779 L .52285 .52779 L p .849 .595 .555 r
F P
0 g
s
.26747 .72845 m .20444 .75142 L .19229 .76078 L p .758 .846 .917 r
F P
0 g
s
.18165 .72622 m .19229 .76078 L .20444 .75142 L p .758 .845 .917 r
F P
0 g
s
.52823 .47906 m .52946 .49255 L .52708 .49122 L p .826 .737 .766 r
F P
0 g
s
.51717 .49431 m .52708 .49122 L .52946 .49255 L p .837 .73 .745 r
F P
0 g
s
.52946 .49255 m .5153 .49698 L .51717 .49431 L p .837 .73 .745 r
F P
0 g
s
.52946 .49255 m .52823 .47906 L .53016 .48035 L p .872 .769 .745 r
F P
0 g
s
.5153 .49698 m .52946 .49255 L .52766 .49492 L p .83 .688 .707 r
F P
0 g
s
.45206 .52614 m .45375 .53373 L .45194 .53335 L p .396 .337 .674 r
F P
0 g
s
.44673 .50558 m .45036 .51382 L .44887 .5164 L p .583 .531 .762 r
F P
0 g
s
.44887 .5164 m .44368 .50463 L .44673 .50558 L p .583 .531 .762 r
F P
0 g
s
.46362 .51107 m .44887 .5164 L .45036 .51382 L p .58 .527 .76 r
F P
0 g
s
.46185 .51334 m .45153 .51706 L .44887 .5164 L p .565 .482 .72 r
F P
0 g
s
.44887 .5164 m .46362 .51107 L .46185 .51334 L p .565 .482 .72 r
F P
0 g
s
.45206 .52614 m .44887 .5164 L .45153 .51706 L p .564 .484 .723 r
F P
0 g
s
.53871 .4727 m .53956 .46251 L .54172 .45965 L p .836 .821 .835 r
F P
0 g
s
.7256 .41132 m .69168 .42713 L .69345 .42307 L p .621 .772 .953 r
F P
0 g
s
.67936 .41613 m .69345 .42307 L .69168 .42713 L p .628 .781 .955 r
F P
0 g
s
.69168 .42713 m .67156 .41724 L .67936 .41613 L p .628 .781 .955 r
F P
0 g
s
.72344 .41594 m .69971 .42698 L .69168 .42713 L p .619 .758 .945 r
F P
0 g
s
.69168 .42713 m .7256 .41132 L .72344 .41594 L p .619 .758 .945 r
F P
0 g
s
.53561 .52851 m .52551 .52915 L .52317 .52879 L p .847 .585 .542 r
F P
0 g
s
.63096 .62158 m .628 .61783 L .63013 .61903 L p 0 .26 .759 r
F P
0 g
s
.63013 .61903 m .63435 .62439 L .63096 .62158 L p 0 .26 .759 r
F P
0 g
s
.4529 .53916 m .45235 .53535 L .45375 .53373 L p .359 .279 .628 r
F P
0 g
s
.56037 .45151 m .56415 .44154 L .56628 .43906 L p .793 .886 .912 r
F P
0 g
s
.45153 .51706 m .45376 .52389 L .45206 .52614 L p .564 .484 .723 r
F P
0 g
s
.46645 .52086 m .45206 .52614 L .45376 .52389 L p .562 .48 .72 r
F P
0 g
s
.46453 .52279 m .45446 .52648 L .45206 .52614 L p .545 .434 .678 r
F P
0 g
s
.45206 .52614 m .46645 .52086 L .46453 .52279 L p .545 .434 .678 r
F P
0 g
s
.45375 .53373 m .45206 .52614 L .45446 .52648 L p .545 .436 .681 r
F P
0 g
s
.60125 .42219 m .5901 .4365 L .5903 .43442 L p .705 .872 .96 r
F P
0 g
s
.584 .4351 m .5903 .43442 L .5901 .4365 L p .731 .893 .953 r
F P
0 g
s
.5901 .4365 m .58111 .43746 L .584 .4351 L p .731 .893 .953 r
F P
0 g
s
.60152 .42437 m .59371 .43438 L .5901 .4365 L p .701 .866 .96 r
F P
0 g
s
.5901 .4365 m .60125 .42219 L .60152 .42437 L p .701 .866 .96 r
F P
0 g
s
.61785 .60753 m .6055 .59873 L .60421 .59795 L p 0 .169 .633 r
F P
0 g
s
.60421 .59795 m .62185 .61052 L .61785 .60753 L p 0 .169 .633 r
F P
0 g
s
.62185 .61052 m .60421 .59795 L .60757 .60055 L p 0 .211 .699 r
F P
0 g
s
.44496 .56496 m .44325 .57104 L .44126 .57348 L p .151 0 .336 r
F P
0 g
s
.42333 .60428 m .42804 .59561 L .42765 .59568 L p .709 .895 .519 r
F P
0 g
s
.52766 .49492 m .51774 .49803 L .5153 .49698 L p .83 .688 .707 r
F P
0 g
s
.43634 .58377 m .43976 .57645 L .44126 .57348 L p 0 0 0 r
F P
0 g
s
.43945 .49205 m .44494 .50169 L .44368 .50463 L p .601 .579 .801 r
F P
0 g
s
.44368 .50463 m .43584 .49085 L .43945 .49205 L p .601 .579 .801 r
F P
0 g
s
.45926 .49907 m .44368 .50463 L .44494 .50169 L p .597 .575 .799 r
F P
0 g
s
.45763 .50169 m .44673 .50558 L .44368 .50463 L p .584 .529 .759 r
F P
0 g
s
.44368 .50463 m .45926 .49907 L .45763 .50169 L p .584 .529 .759 r
F P
0 g
s
.56263 .56035 m .55283 .55697 L .5496 .55458 L p .823 .367 .142 r
F P
0 g
s
.38121 .65258 m .3826 .63971 L .37893 .63964 L p .865 .957 .865 r
F P
0 g
s
.52785 .53603 m .53856 .53632 L .54114 .53719 L p .846 .563 .51 r
F P
0 g
s
.54114 .53719 m .52585 .53678 L .52785 .53603 L p .846 .563 .51 r
F P
0 g
s
.54176 .54373 m .53931 .53822 L .54114 .53719 L p .837 .529 .468 r
F P
0 g
s
.54114 .53719 m .54463 .54506 L .54176 .54373 L p .837 .529 .468 r
F P
0 g
s
.52585 .53678 m .54114 .53719 L .53931 .53822 L p .835 .524 .464 r
F P
0 g
s
.53697 .53226 m .52666 .53256 L .52414 .53182 L p .843 .562 .513 r
F P
0 g
s
.55085 .4587 m .54308 .46121 L .54172 .45965 L p .831 .84 .854 r
F P
0 g
s
.54172 .45965 m .55283 .45605 L .55085 .4587 L p .831 .84 .854 r
F P
0 g
s
.45375 .53373 m .45454 .53917 L .4529 .53916 L p .359 .279 .628 r
F P
0 g
s
.40858 .47827 m .41973 .47339 L .42464 .47496 L p .58 .651 .885 r
F P
0 g
s
.45036 .51382 m .46068 .51009 L .46362 .51107 L p .58 .527 .76 r
F P
0 g
s
.52708 .49122 m .52621 .48177 L .52823 .47906 L p .826 .737 .766 r
F P
0 g
s
.4533 .54279 m .45308 .5405 L .45454 .53917 L p .334 .239 .596 r
F P
0 g
s
.45376 .52389 m .46383 .52019 L .46645 .52086 L p .562 .48 .72 r
F P
0 g
s
.65804 .63727 m .63924 .62784 L .63435 .62439 L p .135 .445 .879 r
F P
0 g
s
.63435 .62439 m .66122 .63786 L .65804 .63727 L p .135 .445 .879 r
F P
0 g
s
.63473 .62179 m .63768 .62554 L .63435 .62439 L p .077 .433 .874 r
F P
0 g
s
.63435 .62439 m .63013 .61903 L .63473 .62179 L p .077 .433 .874 r
F P
0 g
s
.66122 .63786 m .63435 .62439 L .63768 .62554 L p .077 .433 .874 r
F P
0 g
s
.45446 .52648 m .45564 .53179 L .45375 .53373 L p .545 .436 .681 r
F P
0 g
s
.46808 .52835 m .45375 .53373 L .45564 .53179 L p .542 .432 .678 r
F P
0 g
s
.46605 .52996 m .45602 .53373 L .45375 .53373 L p .529 .398 .646 r
F P
0 g
s
.45375 .53373 m .46808 .52835 L .46605 .52996 L p .529 .398 .646 r
F P
0 g
s
.45454 .53917 m .45375 .53373 L .45602 .53373 L p .529 .399 .647 r
F P
0 g
s
.55683 .44076 m .55283 .45605 L .55162 .45422 L p .798 .855 .893 r
F P
0 g
s
.54384 .45674 m .55162 .45422 L .55283 .45605 L p .827 .863 .873 r
F P
0 g
s
.55283 .45605 m .54172 .45965 L .54384 .45674 L p .827 .863 .873 r
F P
0 g
s
.55754 .44273 m .55474 .45344 L .55283 .45605 L p .805 .863 .891 r
F P
0 g
s
.55283 .45605 m .55683 .44076 L .55754 .44273 L p .805 .863 .891 r
F P
0 g
s
.45454 .53917 m .45486 .54244 L .4533 .54279 L p .334 .239 .596 r
F P
0 g
s
.45243 .56539 m .44126 .57348 L .44325 .57104 L p .14 0 .326 r
F P
0 g
s
.44126 .57348 m .43637 .58394 L .43634 .58377 L p 0 0 0 r
F P
0 g
s
.4501 .56807 m .44228 .57373 L .44126 .57348 L p .026 0 .148 r
F P
0 g
s
.44126 .57348 m .45243 .56539 L .4501 .56807 L p .026 0 .148 r
F P
0 g
s
.43637 .58394 m .44126 .57348 L .44228 .57373 L p .025 0 .154 r
F P
0 g
s
.60757 .60055 m .61992 .60935 L .62185 .61052 L p 0 .211 .699 r
F P
0 g
s
.4534 .54422 m .45336 .54347 L .45486 .54244 L p .317 .208 .569 r
F P
0 g
s
.44494 .50169 m .45584 .4978 L .45926 .49907 L p .597 .575 .799 r
F P
0 g
s
.45486 .54244 m .45492 .54352 L .4534 .54422 L p .317 .208 .569 r
F P
0 g
s
.45343 .54515 m .45342 .54453 L .45492 .54352 L p .299 .179 .543 r
F P
0 g
s
.45564 .53179 m .46567 .52802 L .46808 .52835 L p .542 .432 .678 r
F P
0 g
s
.79736 .40888 m .81785 .43282 L .80696 .43173 L p .631 .744 .929 r
F P
0 g
s
.62686 .42694 m .61552 .42529 L .6152 .42321 L p .635 .842 .98 r
F P
0 g
s
.6152 .42321 m .63142 .42558 L .62686 .42694 L p .635 .842 .98 r
F P
0 g
s
.57915 .43946 m .57522 .44002 L .57548 .43826 L p .745 .889 .945 r
F P
0 g
s
.57548 .43826 m .58111 .43746 L .57915 .43946 L p .745 .889 .945 r
F P
0 g
s
.43192 .48943 m .42408 .47832 L .42464 .47496 L p .557 .6 .852 r
F P
0 g
s
.42464 .47496 m .43584 .49085 L .43192 .48943 L p .557 .6 .852 r
F P
0 g
s
.45492 .54352 m .45494 .5444 L .45343 .54515 L p .299 .179 .543 r
F P
0 g
s
.45602 .53373 m .45657 .53754 L .45454 .53917 L p .529 .399 .647 r
F P
0 g
s
.46898 .53367 m .45454 .53917 L .45657 .53754 L p .528 .397 .646 r
F P
0 g
s
.46686 .53497 m .45675 .53882 L .45454 .53917 L p .515 .367 .618 r
F P
0 g
s
.45454 .53917 m .46898 .53367 L .46686 .53497 L p .515 .367 .618 r
F P
0 g
s
.45486 .54244 m .45454 .53917 L .45675 .53882 L p .517 .373 .625 r
F P
0 g
s
.45348 .54757 m .45344 .5457 L .45494 .5444 L p .294 .174 .541 r
F P
0 g
s
.53931 .53822 m .52861 .53794 L .52585 .53678 L p .835 .524 .464 r
F P
0 g
s
.73844 .42741 m .72344 .41594 L .7256 .41132 L p .615 .753 .944 r
F P
0 g
s
.7256 .41132 m .74701 .42774 L .73844 .42741 L p .615 .753 .944 r
F P
0 g
s
.80696 .43173 m .79257 .41502 L .79736 .40888 L p .631 .744 .929 r
F P
0 g
s
.54738 .54709 m .55086 .55375 L .5496 .55458 L p .871 .474 .281 r
F P
0 g
s
.5496 .55458 m .54463 .54506 L .54738 .54709 L p .871 .474 .281 r
F P
0 g
s
.44325 .57104 m .45107 .56538 L .45243 .56539 L p .14 0 .326 r
F P
0 g
s
.41963 .6083 m .40817 .61907 L .40457 .62343 L p .78 .985 .733 r
F P
0 g
s
.79736 .40888 m .74701 .42774 L .75097 .42219 L p .632 .754 .936 r
F P
0 g
s
.736 .41064 m .75097 .42219 L .74701 .42774 L p .635 .758 .937 r
F P
0 g
s
.74701 .42774 m .7256 .41132 L .736 .41064 L p .635 .758 .937 r
F P
0 g
s
.79257 .41502 m .75737 .42818 L .74701 .42774 L p .632 .745 .929 r
F P
0 g
s
.74701 .42774 m .79736 .40888 L .79257 .41502 L p .632 .745 .929 r
F P
0 g
s
.42902 .47637 m .43686 .4875 L .43584 .49085 L p .616 .624 .835 r
F P
0 g
s
.43584 .49085 m .42464 .47496 L .42902 .47637 L p .616 .624 .835 r
F P
0 g
s
.45281 .48474 m .43584 .49085 L .43686 .4875 L p .613 .62 .834 r
F P
0 g
s
.45133 .48777 m .43945 .49205 L .43584 .49085 L p .602 .577 .798 r
F P
0 g
s
.43584 .49085 m .45281 .48474 L .45133 .48777 L p .602 .577 .798 r
F P
0 g
s
.5903 .43442 m .5981 .42441 L .60125 .42219 L p .705 .872 .96 r
F P
0 g
s
.45494 .5444 m .455 .54707 L .45348 .54757 L p .294 .174 .541 r
F P
0 g
s
.24419 .42911 m .29637 .45046 L .28676 .44945 L p .625 .742 .931 r
F P
0 g
s
.25467 .42995 m .29123 .44493 L .29637 .45046 L p .63 .742 .928 r
F P
0 g
s
.29637 .45046 m .24419 .42911 L .25467 .42995 L p .63 .742 .928 r
F P
0 g
s
.31221 .43659 m .29637 .45046 L .29123 .44493 L p .621 .739 .931 r
F P
0 g
s
.31551 .44151 m .30439 .45119 L .29637 .45046 L p .616 .728 .926 r
F P
0 g
s
.29637 .45046 m .31221 .43659 L .31551 .44151 L p .616 .728 .926 r
F P
0 g
s
.45675 .53882 m .45698 .54112 L .45486 .54244 L p .517 .373 .625 r
F P
0 g
s
.46936 .53678 m .45486 .54244 L .45698 .54112 L p .512 .365 .618 r
F P
0 g
s
.46719 .5378 m .45704 .54176 L .45486 .54244 L p .507 .353 .607 r
F P
0 g
s
.45486 .54244 m .46936 .53678 L .46719 .5378 L p .507 .353 .607 r
F P
0 g
s
.45492 .54352 m .45486 .54244 L .45704 .54176 L p .507 .351 .605 r
F P
0 g
s
.45657 .53754 m .46668 .53369 L .46898 .53367 L p .528 .397 .646 r
F P
0 g
s
.28676 .44945 m .25028 .43454 L .24419 .42911 L p .625 .742 .931 r
F P
0 g
s
.45337 .55179 m .45346 .54869 L .455 .54707 L p .265 .129 .502 r
F P
0 g
s
.65118 .4102 m .63142 .42558 L .63172 .42279 L p .643 .822 .969 r
F P
0 g
s
.62035 .42111 m .63172 .42279 L .63142 .42558 L p .663 .839 .968 r
F P
0 g
s
.63142 .42558 m .6152 .42321 L .62035 .42111 L p .663 .839 .968 r
F P
0 g
s
.65105 .41341 m .6372 .42416 L .63142 .42558 L p .639 .808 .965 r
F P
0 g
s
.63142 .42558 m .65118 .4102 L .65105 .41341 L p .639 .808 .965 r
F P
0 g
s
.52758 .46384 m .52823 .47906 L .52573 .47748 L p .802 .756 .81 r
F P
0 g
s
.51506 .48078 m .52573 .47748 L .52823 .47906 L p .816 .751 .791 r
F P
0 g
s
.52823 .47906 m .513 .48377 L .51506 .48078 L p .816 .751 .791 r
F P
0 g
s
.52967 .46545 m .53011 .4761 L .52823 .47906 L p .835 .781 .8 r
F P
0 g
s
.52823 .47906 m .52758 .46384 L .52967 .46545 L p .835 .781 .8 r
F P
0 g
s
.513 .48377 m .52823 .47906 L .52621 .48177 L p .811 .712 .756 r
F P
0 g
s
.45704 .54176 m .45709 .54251 L .45492 .54352 L p .507 .351 .605 r
F P
0 g
s
.46948 .53785 m .45492 .54352 L .45709 .54251 L p .507 .353 .607 r
F P
0 g
s
.4673 .53883 m .45711 .5428 L .45492 .54352 L p .499 .335 .589 r
F P
0 g
s
.45492 .54352 m .46948 .53785 L .4673 .53883 L p .499 .335 .589 r
F P
0 g
s
.45494 .5444 m .45492 .54352 L .45711 .5428 L p .498 .332 .586 r
F P
0 g
s
.25028 .43454 m .24103 .44596 L .23104 .44547 L p .633 .744 .928 r
F P
0 g
s
.23104 .44547 m .24419 .42911 L .25028 .43454 L p .633 .744 .928 r
F P
0 g
s
.55162 .45422 m .55441 .44351 L .55683 .44076 L p .798 .855 .893 r
F P
0 g
s
.53039 .54265 m .54176 .54373 L .54463 .54506 L p .837 .525 .461 r
F P
0 g
s
.54463 .54506 m .5284 .54352 L .53039 .54265 L p .837 .525 .461 r
F P
0 g
s
.54632 .55282 m .54285 .54615 L .54463 .54506 L p .821 .47 .392 r
F P
0 g
s
.54463 .54506 m .5496 .55458 L .54632 .55282 L p .821 .47 .392 r
F P
0 g
s
.5284 .54352 m .54463 .54506 L .54285 .54615 L p .82 .467 .39 r
F P
0 g
s
.20444 .75142 m .19722 .72719 L .18165 .72622 L p .758 .845 .917 r
F P
0 g
s
.6055 .59873 m .59959 .59389 L .59577 .59102 L p 0 .168 .633 r
F P
0 g
s
.78765 .72511 m .85166 .74492 L .86483 .7537 L p .512 .655 .924 r
F P
0 g
s
.51998 .50883 m .52146 .5149 L .51971 .51669 L p .845 .65 .639 r
F P
0 g
s
.51971 .51669 m .51759 .50801 L .51998 .50883 L p .845 .65 .639 r
F P
0 g
s
.59068 .42195 m .58111 .43746 L .58162 .43522 L p .725 .864 .947 r
F P
0 g
s
.57768 .43578 m .58162 .43522 L .58111 .43746 L p .749 .886 .941 r
F P
0 g
s
.58111 .43746 m .57548 .43826 L .57768 .43578 L p .749 .886 .941 r
F P
0 g
s
.59071 .42424 m .584 .4351 L .58111 .43746 L p .724 .862 .947 r
F P
0 g
s
.58111 .43746 m .59068 .42195 L .59071 .42424 L p .724 .862 .947 r
F P
0 g
s
.52621 .48177 m .51556 .48507 L .513 .48377 L p .811 .712 .756 r
F P
0 g
s
.45711 .5428 m .45712 .54342 L .45494 .5444 L p .498 .332 .586 r
F P
0 g
s
.46956 .5387 m .45494 .5444 L .45712 .54342 L p .5 .335 .589 r
F P
0 g
s
.46738 .53995 m .45715 .54394 L .45494 .5444 L p .496 .328 .582 r
F P
0 g
s
.45494 .5444 m .46956 .5387 L .46738 .53995 L p .496 .328 .582 r
F P
0 g
s
.455 .54707 m .45494 .5444 L .45715 .54394 L p .497 .331 .585 r
F P
0 g
s
.31221 .43659 m .34853 .45689 L .34091 .45569 L p .604 .722 .928 r
F P
0 g
s
.32058 .43774 m .34602 .45198 L .34853 .45689 L p .617 .723 .922 r
F P
0 g
s
.34853 .45689 m .31221 .43659 L .32058 .43774 L p .617 .723 .922 r
F P
0 g
s
.36617 .44576 m .34853 .45689 L .34602 .45198 L p .607 .718 .923 r
F P
0 g
s
.3674 .45018 m .35504 .45795 L .34853 .45689 L p .599 .697 .911 r
F P
0 g
s
.34853 .45689 m .36617 .44576 L .3674 .45018 L p .599 .697 .911 r
F P
0 g
s
.34091 .45569 m .31551 .44151 L .31221 .43659 L p .604 .722 .928 r
F P
0 g
s
.51774 .49803 m .51935 .50574 L .51759 .50801 L p .836 .678 .686 r
F P
0 g
s
.37137 .65811 m .34298 .67312 L .33652 .67943 L p .823 .928 .903 r
F P
0 g
s
.52205 .51727 m .52323 .52161 L .5214 .52289 L p .848 .623 .598 r
F P
0 g
s
.5214 .52289 m .51971 .51669 L .52205 .51727 L p .848 .623 .598 r
F P
0 g
s
.57426 .44026 m .57334 .44042 L .57417 .43849 L p .786 .923 .928 r
F P
0 g
s
.57417 .43849 m .57548 .43826 L .57426 .44026 L p .786 .923 .928 r
F P
0 g
s
.45698 .54112 m .46712 .53716 L .46936 .53678 L p .512 .365 .618 r
F P
0 g
s
.44228 .57373 m .43886 .58106 L .43637 .58394 L p .025 0 .154 r
F P
0 g
s
.455 .54707 m .45487 .55151 L .45337 .55179 L p .265 .129 .502 r
F P
0 g
s
.63768 .62554 m .65649 .63496 L .66122 .63786 L p .077 .433 .874 r
F P
0 g
s
.45709 .54251 m .46728 .53854 L .46948 .53785 L p .507 .353 .607 r
F P
0 g
s
.51759 .50801 m .5153 .49698 L .51774 .49803 L p .836 .678 .686 r
F P
0 g
s
.69345 .42307 m .71719 .41198 L .7256 .41132 L p .621 .772 .953 r
F P
0 g
s
.62716 .61679 m .62605 .61556 L .62855 .61728 L p 0 .234 .73 r
F P
0 g
s
.62855 .61728 m .63013 .61903 L .62716 .61679 L p 0 .234 .73 r
F P
0 g
s
.45715 .54394 m .45719 .54581 L .455 .54707 L p .497 .331 .585 r
F P
0 g
s
.46976 .54125 m .455 .54707 L .45719 .54581 L p .495 .327 .582 r
F P
0 g
s
.46754 .54277 m .45721 .54685 L .455 .54707 L p .485 .303 .559 r
F P
0 g
s
.455 .54707 m .46976 .54125 L .46754 .54277 L p .485 .303 .559 r
F P
0 g
s
.45487 .55151 m .455 .54707 L .45721 .54685 L p .485 .304 .56 r
F P
0 g
s
.52369 .5232 m .52445 .52578 L .52249 .52657 L p .847 .602 .568 r
F P
0 g
s
.52249 .52657 m .5214 .52289 L .52369 .5232 L p .847 .602 .568 r
F P
0 g
s
.43686 .4875 m .44874 .48321 L .45281 .48474 L p .613 .62 .834 r
F P
0 g
s
.5153 .49698 m .51759 .50801 L .51476 .50695 L p .78 .643 .711 r
F P
0 g
s
.50319 .50951 m .51476 .50695 L .51759 .50801 L p .784 .636 .698 r
F P
0 g
s
.51759 .50801 m .50107 .51167 L .50319 .50951 L p .784 .636 .698 r
F P
0 g
s
.5169 .51588 m .51542 .50981 L .51759 .50801 L p .783 .614 .671 r
F P
0 g
s
.51759 .50801 m .51971 .51669 L .5169 .51588 L p .783 .614 .671 r
F P
0 g
s
.50107 .51167 m .51759 .50801 L .51542 .50981 L p .776 .602 .663 r
F P
0 g
s
.45712 .54342 m .46735 .53942 L .46956 .5387 L p .5 .335 .589 r
F P
0 g
s
.45276 .55774 m .45322 .55346 L .45487 .55151 L p .22 .058 .437 r
F P
0 g
s
.50522 .51797 m .5169 .51588 L .51971 .51669 L p .785 .607 .66 r
F P
0 g
s
.51971 .51669 m .50302 .51967 L .50522 .51797 L p .785 .607 .66 r
F P
0 g
s
.51862 .52236 m .51744 .51802 L .51971 .51669 L p .782 .587 .637 r
F P
0 g
s
.51971 .51669 m .5214 .52289 L .51862 .52236 L p .782 .587 .637 r
F P
0 g
s
.50302 .51967 m .51971 .51669 L .51744 .51802 L p .778 .578 .63 r
F P
0 g
s
.52573 .47748 m .52527 .46682 L .52758 .46384 L p .802 .756 .81 r
F P
0 g
s
.53956 .46251 m .52967 .46545 L .52758 .46384 L p .815 .785 .824 r
F P
0 g
s
.52758 .46384 m .54172 .45965 L .53956 .46251 L p .815 .785 .824 r
F P
0 g
s
.51556 .48507 m .51717 .49431 L .5153 .49698 L p .821 .703 .735 r
F P
0 g
s
.5247 .52658 m .52495 .52743 L .52285 .52779 L p .846 .589 .549 r
F P
0 g
s
.52285 .52779 m .52249 .52657 L .5247 .52658 L p .846 .589 .549 r
F P
0 g
s
.46383 .52019 m .46185 .51334 L .46362 .51107 L p .563 .478 .718 r
F P
0 g
s
.46068 .51009 m .45763 .50169 L .45926 .49907 L p .581 .525 .757 r
F P
0 g
s
.45926 .49907 m .46362 .51107 L .46068 .51009 L p .581 .525 .757 r
F P
0 g
s
.38445 .46378 m .3674 .45018 L .36617 .44576 L p .586 .688 .912 r
F P
0 g
s
.36617 .44576 m .39053 .46522 L .38445 .46378 L p .586 .688 .912 r
F P
0 g
s
.57225 .43972 m .57122 .4401 L .57197 .43817 L p .791 .918 .924 r
F P
0 g
s
.57197 .43817 m .57345 .43763 L .57225 .43972 L p .791 .918 .924 r
F P
0 g
s
.51476 .50695 m .51316 .49923 L .5153 .49698 L p .78 .643 .711 r
F P
0 g
s
.51542 .50981 m .50386 .51237 L .50107 .51167 L p .776 .602 .663 r
F P
0 g
s
.54378 .44315 m .54172 .45965 L .53975 .45775 L p .791 .812 .869 r
F P
0 g
s
.52985 .46068 m .53975 .45775 L .54172 .45965 L p .814 .814 .85 r
F P
0 g
s
.54172 .45965 m .52758 .46384 L .52985 .46068 L p .814 .814 .85 r
F P
0 g
s
.54529 .44519 m .54384 .45674 L .54172 .45965 L p .807 .826 .866 r
F P
0 g
s
.54172 .45965 m .54378 .44315 L .54529 .44519 L p .807 .826 .866 r
F P
0 g
s
.45719 .54581 m .46752 .54173 L .46976 .54125 L p .495 .327 .582 r
F P
0 g
s
.513 .48377 m .5153 .49698 L .5124 .49568 L p .773 .673 .752 r
F P
0 g
s
.50071 .49871 m .5124 .49568 L .5153 .49698 L p .779 .667 .739 r
F P
0 g
s
.5153 .49698 m .4986 .50131 L .50071 .49871 L p .779 .667 .739 r
F P
0 g
s
.5153 .49698 m .513 .48377 L .51556 .48507 L p .821 .703 .735 r
F P
0 g
s
.4986 .50131 m .5153 .49698 L .51316 .49923 L p .771 .629 .703 r
F P
0 g
s
.52507 .52779 m .52529 .52849 L .52317 .52879 L p .846 .585 .544 r
F P
0 g
s
.52317 .52879 m .52285 .52779 L .52507 .52779 L p .846 .585 .544 r
F P
0 g
s
.37289 .44722 m .38995 .46086 L .39053 .46522 L p .614 .694 .901 r
F P
0 g
s
.39053 .46522 m .36617 .44576 L .37289 .44722 L p .614 .694 .901 r
F P
0 g
s
.40923 .45657 m .39053 .46522 L .38995 .46086 L p .605 .688 .901 r
F P
0 g
s
.40894 .46052 m .39585 .46656 L .39053 .46522 L p .598 .657 .879 r
F P
0 g
s
.39053 .46522 m .40923 .45657 L .40894 .46052 L p .598 .657 .879 r
F P
0 g
s
.54285 .54615 m .53148 .54508 L .5284 .54352 L p .82 .467 .39 r
F P
0 g
s
.58406 .422 m .57548 .43826 L .57654 .43586 L p .762 .892 .936 r
F P
0 g
s
.57562 .43602 m .57654 .43586 L .57548 .43826 L p .787 .922 .927 r
F P
0 g
s
.57548 .43826 m .57417 .43849 L .57562 .43602 L p .787 .922 .927 r
F P
0 g
s
.58369 .4244 m .57768 .43578 L .57548 .43826 L p .735 .857 .938 r
F P
0 g
s
.57548 .43826 m .58406 .422 L .58369 .4244 L p .735 .857 .938 r
F P
0 g
s
.46362 .51107 m .46645 .52086 L .46383 .52019 L p .563 .478 .718 r
F P
0 g
s
.42804 .59561 m .43414 .5874 L .43637 .58394 L p .707 .895 .521 r
F P
0 g
s
.50676 .52409 m .51862 .52236 L .5214 .52289 L p .782 .581 .628 r
F P
0 g
s
.5214 .52289 m .50444 .52535 L .50676 .52409 L p .782 .581 .628 r
F P
0 g
s
.51977 .52636 m .519 .52378 L .5214 .52289 L p .78 .567 .611 r
F P
0 g
s
.5214 .52289 m .52249 .52657 L .51977 .52636 L p .78 .567 .611 r
F P
0 g
s
.50444 .52535 m .5214 .52289 L .519 .52378 L p .777 .558 .603 r
F P
0 g
s
.45721 .54685 m .45712 .54996 L .45487 .55151 L p .485 .304 .56 r
F P
0 g
s
.51744 .51802 m .50576 .52011 L .50302 .51967 L p .778 .578 .63 r
F P
0 g
s
.52551 .52915 m .52619 .53126 L .52414 .53182 L p .846 .577 .532 r
F P
0 g
s
.52414 .53182 m .52317 .52879 L .52551 .52915 L p .846 .577 .532 r
F P
0 g
s
.55753 .56429 m .56847 .56865 L .57194 .57126 L p .823 .368 .148 r
F P
0 g
s
.57194 .57126 m .5563 .56504 L .55753 .56429 L p .823 .368 .148 r
F P
0 g
s
.57876 .58021 m .57109 .57198 L .57194 .57126 L p .731 .208 0 r
F P
0 g
s
.57194 .57126 m .58291 .583 L .57876 .58021 L p .731 .208 0 r
F P
0 g
s
.5563 .56504 m .57194 .57126 L .57109 .57198 L p .733 .211 0 r
F P
0 g
s
.58291 .583 m .57194 .57126 L .57542 .57415 L p .686 .147 0 r
F P
0 g
s
.46567 .52802 m .46453 .52279 L .46645 .52086 L p .542 .43 .676 r
F P
0 g
s
.51316 .49923 m .50147 .50226 L .4986 .50131 L p .771 .629 .703 r
F P
0 g
s
.57023 .4404 m .56625 .44102 L .56628 .43906 L p .767 .869 .923 r
F P
0 g
s
.56628 .43906 m .57197 .43817 L .57023 .4404 L p .767 .869 .923 r
F P
0 g
s
.57542 .57415 m .5831 .58237 L .58291 .583 L p .686 .147 0 r
F P
0 g
s
.46997 .54549 m .45487 .55151 L .45712 .54996 L p .484 .303 .559 r
F P
0 g
s
.45487 .55151 m .45422 .55763 L .45276 .55774 L p .22 .058 .437 r
F P
0 g
s
.46764 .54729 m .45707 .5515 L .45487 .55151 L p .461 .254 .511 r
F P
0 g
s
.45487 .55151 m .46997 .54549 L .46764 .54729 L p .461 .254 .511 r
F P
0 g
s
.45422 .55763 m .45487 .55151 L .45707 .5515 L p .461 .257 .516 r
F P
0 g
s
.58162 .43522 m .58832 .42435 L .59068 .42195 L p .725 .864 .947 r
F P
0 g
s
.62448 .61382 m .62559 .61505 L .62855 .61728 L p 0 .234 .73 r
F P
0 g
s
.46253 .50008 m .46558 .50848 L .46362 .51107 L p .654 .566 .743 r
F P
0 g
s
.46362 .51107 m .45926 .49907 L .46253 .50008 L p .654 .566 .743 r
F P
0 g
s
.48076 .50594 m .46362 .51107 L .46558 .50848 L p .657 .57 .745 r
F P
0 g
s
.4786 .5082 m .4666 .51179 L .46362 .51107 L p .646 .531 .709 r
F P
0 g
s
.46362 .51107 m .48076 .50594 L .4786 .5082 L p .646 .531 .709 r
F P
0 g
s
.46645 .52086 m .46362 .51107 L .4666 .51179 L p .647 .53 .706 r
F P
0 g
s
.58144 .42447 m .57562 .43602 L .57417 .43849 L p .765 .89 .933 r
F P
0 g
s
.57417 .43849 m .58248 .422 L .58144 .42447 L p .765 .89 .933 r
F P
0 g
s
.65324 .63073 m .63473 .62179 L .63013 .61903 L p .077 .433 .874 r
F P
0 g
s
.63013 .61903 m .65658 .63181 L .65324 .63073 L p .077 .433 .874 r
F P
0 g
s
.6327 .61942 m .63381 .62065 L .63013 .61903 L p .037 .425 .866 r
F P
0 g
s
.63013 .61903 m .62855 .61728 L .6327 .61942 L p .037 .425 .866 r
F P
0 g
s
.65658 .63181 m .63013 .61903 L .63381 .62065 L p .037 .425 .866 r
F P
0 g
s
.5124 .49568 m .51079 .48644 L .513 .48377 L p .773 .673 .752 r
F P
0 g
s
.45584 .4978 m .45133 .48777 L .45281 .48474 L p .599 .574 .796 r
F P
0 g
s
.45281 .48474 m .45926 .49907 L .45584 .4978 L p .599 .574 .796 r
F P
0 g
s
.3826 .63971 m .40052 .62838 L .40457 .62343 L p .865 .957 .865 r
F P
0 g
s
.50772 .52784 m .51977 .52636 L .52249 .52657 L p .78 .559 .601 r
F P
0 g
s
.52249 .52657 m .50528 .52868 L .50772 .52784 L p .78 .559 .601 r
F P
0 g
s
.52022 .52791 m .51996 .52706 L .52249 .52657 L p .778 .553 .594 r
F P
0 g
s
.52249 .52657 m .52285 .52779 L .52022 .52791 L p .778 .553 .594 r
F P
0 g
s
.50528 .52868 m .52249 .52657 L .51996 .52706 L p .776 .547 .588 r
F P
0 g
s
.66235 .6444 m .65804 .63727 L .66122 .63786 L p .135 .445 .879 r
F P
0 g
s
.66122 .63786 m .66736 .64804 L .66235 .6444 L p .135 .445 .879 r
F P
0 g
s
.519 .52378 m .50713 .52551 L .50444 .52535 L p .777 .558 .603 r
F P
0 g
s
.46645 .52086 m .46808 .52835 L .46567 .52802 L p .542 .43 .676 r
F P
0 g
s
.4666 .51179 m .46858 .51864 L .46645 .52086 L p .647 .53 .706 r
F P
0 g
s
.4834 .51593 m .46645 .52086 L .46858 .51864 L p .649 .533 .708 r
F P
0 g
s
.48111 .5178 m .46924 .52125 L .46645 .52086 L p .637 .494 .671 r
F P
0 g
s
.46645 .52086 m .4834 .51593 L .48111 .5178 L p .637 .494 .671 r
F P
0 g
s
.46808 .52835 m .46645 .52086 L .46924 .52125 L p .638 .492 .669 r
F P
0 g
s
.44872 .57437 m .43637 .58394 L .43886 .58106 L p .009 0 .138 r
F P
0 g
s
.43637 .58394 m .42765 .59568 L .42804 .59561 L p .707 .895 .521 r
F P
0 g
s
.4457 .57743 m .43706 .58413 L .43637 .58394 L p 0 0 0 r
F P
0 g
s
.43637 .58394 m .44872 .57437 L .4457 .57743 L p 0 0 0 r
F P
0 g
s
.42765 .59568 m .43637 .58394 L .43706 .58413 L p 0 0 0 r
F P
0 g
s
.52666 .53256 m .52785 .53603 L .52585 .53678 L p .842 .555 .503 r
F P
0 g
s
.52585 .53678 m .52414 .53182 L .52666 .53256 L p .842 .555 .503 r
F P
0 g
s
.50811 .52932 m .52022 .52791 L .52285 .52779 L p .777 .548 .588 r
F P
0 g
s
.52285 .52779 m .50555 .52979 L .50811 .52932 L p .777 .548 .588 r
F P
0 g
s
.52053 .52893 m .52031 .52823 L .52285 .52779 L p .778 .55 .591 r
F P
0 g
s
.52285 .52779 m .52317 .52879 L .52053 .52893 L p .778 .55 .591 r
F P
0 g
s
.50555 .52979 m .52285 .52779 L .52031 .52823 L p .776 .543 .582 r
F P
0 g
s
.46558 .50848 m .47758 .50488 L .48076 .50594 L p .657 .57 .745 r
F P
0 g
s
.76584 .69971 m .72262 .68642 L .71348 .67999 L p .462 .609 .91 r
F P
0 g
s
.45712 .54996 m .46769 .54574 L .46997 .54549 L p .484 .303 .559 r
F P
0 g
s
.63172 .42279 m .64554 .41201 L .65118 .4102 L p .643 .822 .969 r
F P
0 g
s
.45654 .48604 m .46105 .49607 L .45926 .49907 L p .661 .605 .781 r
F P
0 g
s
.45926 .49907 m .45281 .48474 L .45654 .48604 L p .661 .605 .781 r
F P
0 g
s
.47705 .4936 m .45926 .49907 L .46105 .49607 L p .663 .608 .783 r
F P
0 g
s
.47498 .49625 m .46253 .50008 L .45926 .49907 L p .653 .568 .746 r
F P
0 g
s
.45926 .49907 m .47705 .4936 L .47498 .49625 L p .653 .568 .746 r
F P
0 g
s
.46668 .53369 m .46605 .52996 L .46808 .52835 L p .528 .396 .645 r
F P
0 g
s
.50835 .53026 m .52053 .52893 L .52317 .52879 L p .776 .543 .582 r
F P
0 g
s
.52317 .52879 m .50578 .53069 L .50835 .53026 L p .776 .543 .582 r
F P
0 g
s
.52137 .53163 m .52069 .52951 L .52317 .52879 L p .777 .542 .58 r
F P
0 g
s
.52317 .52879 m .52414 .53182 L .52137 .53163 L p .777 .542 .58 r
F P
0 g
s
.50578 .53069 m .52317 .52879 L .52069 .52951 L p .775 .536 .575 r
F P
0 g
s
.46858 .51864 m .48044 .51519 L .4834 .51593 L p .649 .533 .708 r
F P
0 g
s
.58175 .42112 m .57345 .43763 L .57444 .43524 L p .765 .89 .933 r
F P
0 g
s
.5734 .43562 m .57444 .43524 L .57345 .43763 L p .791 .919 .924 r
F P
0 g
s
.57345 .43763 m .57197 .43817 L .5734 .43562 L p .791 .919 .924 r
F P
0 g
s
.46924 .52125 m .47038 .52649 L .46808 .52835 L p .638 .492 .669 r
F P
0 g
s
.86997 .71863 m .86483 .7537 L .85166 .74492 L p .511 .655 .924 r
F P
0 g
s
.51996 .52706 m .50791 .52854 L .50528 .52868 L p .776 .547 .588 r
F P
0 g
s
.62855 .61728 m .62696 .61552 L .62448 .61382 L p 0 .234 .73 r
F P
0 g
s
.70273 .66312 m .67423 .65263 L .66736 .64804 L p .337 .55 .911 r
F P
0 g
s
.66736 .64804 m .70813 .66303 L .70273 .66312 L p .337 .55 .911 r
F P
0 g
s
.66815 .64145 m .67243 .64859 L .66736 .64804 L p .287 .552 .925 r
F P
0 g
s
.66736 .64804 m .66122 .63786 L .66815 .64145 L p .287 .552 .925 r
F P
0 g
s
.70813 .66303 m .66736 .64804 L .67243 .64859 L p .288 .551 .924 r
F P
0 g
s
.5831 .58237 m .5921 .58799 L .59577 .59102 L p .684 .145 0 r
F P
0 g
s
.41973 .47339 m .40894 .46052 L .40923 .45657 L p .588 .648 .877 r
F P
0 g
s
.40923 .45657 m .42464 .47496 L .41973 .47339 L p .588 .648 .877 r
F P
0 g
s
.28546 .7022 m .32824 .68632 L .33652 .67943 L p .793 .865 .902 r
F P
0 g
s
.58 .42144 m .57197 .43817 L .57224 .43577 L p .741 .852 .932 r
F P
0 g
s
.56825 .43639 m .57224 .43577 L .57197 .43817 L p .764 .872 .926 r
F P
0 g
s
.57197 .43817 m .56628 .43906 L .56825 .43639 L p .764 .872 .926 r
F P
0 g
s
.57903 .42391 m .5734 .43562 L .57197 .43817 L p .768 .886 .93 r
F P
0 g
s
.57197 .43817 m .58 .42144 L .57903 .42391 L p .768 .886 .93 r
F P
0 g
s
.53975 .45775 m .54118 .4462 L .54378 .44315 L p .791 .812 .869 r
F P
0 g
s
.41323 .60818 m .40457 .62343 L .40817 .61907 L p .781 .985 .734 r
F P
0 g
s
.40457 .62343 m .37893 .63964 L .3826 .63971 L p .865 .957 .865 r
F P
0 g
s
.40829 .61263 m .40225 .6233 L .40457 .62343 L p .794 .996 .862 r
F P
0 g
s
.40457 .62343 m .41323 .60818 L .40829 .61263 L p .794 .996 .862 r
F P
0 g
s
.37893 .63964 m .40457 .62343 L .40225 .6233 L p .793 .996 .863 r
F P
0 g
s
.45707 .5515 m .45662 .55578 L .45422 .55763 L p .461 .257 .516 r
F P
0 g
s
.52031 .52823 m .5082 .52963 L .50555 .52979 L p .776 .543 .582 r
F P
0 g
s
.45107 .56538 m .45232 .55994 L .45422 .55763 L p .14 0 .32 r
F P
0 g
s
.43886 .58106 m .4475 .57435 L .44872 .57437 L p .009 0 .138 r
F P
0 g
s
.59577 .59102 m .58291 .583 L .5831 .58237 L p .684 .145 0 r
F P
0 g
s
.61244 .60292 m .59577 .59102 L .59959 .59389 L p 0 .164 .628 r
F P
0 g
s
.59959 .59389 m .61126 .60222 L .61244 .60292 L p 0 .164 .628 r
F P
0 g
s
.60787 .59985 m .5962 .59152 L .59577 .59102 L p .462 0 0 r
F P
0 g
s
.59577 .59102 m .61244 .60292 L .60787 .59985 L p .462 0 0 r
F P
0 g
s
.58291 .583 m .59577 .59102 L .5962 .59152 L p .462 0 0 r
F P
0 g
s
.41462 .45819 m .42541 .47108 L .42464 .47496 L p .629 .662 .863 r
F P
0 g
s
.42464 .47496 m .40923 .45657 L .41462 .45819 L p .629 .662 .863 r
F P
0 g
s
.44375 .46797 m .42464 .47496 L .42541 .47108 L p .626 .659 .862 r
F P
0 g
s
.4424 .47148 m .42902 .47637 L .42464 .47496 L p .619 .622 .832 r
F P
0 g
s
.42464 .47496 m .44375 .46797 L .4424 .47148 L p .619 .622 .832 r
F P
0 g
s
.48516 .52354 m .46808 .52835 L .47038 .52649 L p .639 .495 .671 r
F P
0 g
s
.46808 .52835 m .46898 .53367 L .46668 .53369 L p .528 .396 .645 r
F P
0 g
s
.48274 .52507 m .47079 .52843 L .46808 .52835 L p .63 .467 .643 r
F P
0 g
s
.46808 .52835 m .48516 .52354 L .48274 .52507 L p .63 .467 .643 r
F P
0 g
s
.46898 .53367 m .46808 .52835 L .47079 .52843 L p .63 .466 .642 r
F P
0 g
s
.50903 .53276 m .52137 .53163 L .52414 .53182 L p .776 .537 .574 r
F P
0 g
s
.52414 .53182 m .5065 .53343 L .50903 .53276 L p .776 .537 .574 r
F P
0 g
s
.52291 .53624 m .52172 .53276 L .52414 .53182 L p .773 .522 .556 r
F P
0 g
s
.52414 .53182 m .52585 .53678 L .52291 .53624 L p .773 .522 .556 r
F P
0 g
s
.5065 .53343 m .52414 .53182 L .52172 .53276 L p .77 .515 .549 r
F P
0 g
s
.29123 .44493 m .30229 .43518 L .31221 .43659 L p .621 .739 .931 r
F P
0 g
s
.57654 .43586 m .58255 .42448 L .58406 .422 L p .762 .892 .936 r
F P
0 g
s
.34602 .45198 m .35836 .44416 L .36617 .44576 L p .607 .718 .923 r
F P
0 g
s
.52069 .52951 m .50852 .53084 L .50578 .53069 L p .775 .536 .575 r
F P
0 g
s
.46105 .49607 m .47351 .49224 L .47705 .4936 L p .663 .608 .783 r
F P
0 g
s
.55283 .55697 m .55753 .56429 L .5563 .56504 L p .825 .372 .151 r
F P
0 g
s
.5563 .56504 m .5496 .55458 L .55283 .55697 L p .825 .372 .151 r
F P
0 g
s
.70813 .66303 m .71348 .67999 L .70652 .675 L p .336 .551 .912 r
F P
0 g
s
.71348 .67999 m .77536 .69898 L .76584 .69971 L p .462 .609 .91 r
F P
0 g
s
.71814 .66807 m .72183 .67995 L .71348 .67999 L p .425 .617 .931 r
F P
0 g
s
.71348 .67999 m .70813 .66303 L .71814 .66807 L p .425 .617 .931 r
F P
0 g
s
.77536 .69898 m .71348 .67999 L .72183 .67995 L p .425 .617 .931 r
F P
0 g
s
.65057 .62762 m .6322 .61886 L .62855 .61728 L p .037 .425 .866 r
F P
0 g
s
.62855 .61728 m .6548 .6298 L .65057 .62762 L p .037 .425 .866 r
F P
0 g
s
.62696 .61552 m .62855 .61728 L .6322 .61886 L p .037 .425 .866 r
F P
0 g
s
.65108 .62819 m .6327 .61942 L .62855 .61728 L p .037 .425 .866 r
F P
0 g
s
.62855 .61728 m .6548 .6298 L .65108 .62819 L p .037 .425 .866 r
F P
0 g
s
.47038 .52649 m .48233 .52313 L .48516 .52354 L p .639 .495 .671 r
F P
0 g
s
.46712 .53716 m .46686 .53497 L .46898 .53367 L p .51 .358 .61 r
F P
0 g
s
.51067 .46838 m .513 .48377 L .50993 .4822 L p .761 .699 .793 r
F P
0 g
s
.49768 .48552 m .50993 .4822 L .513 .48377 L p .769 .694 .78 r
F P
0 g
s
.513 .48377 m .49551 .48853 L .49768 .48552 L p .769 .694 .78 r
F P
0 g
s
.51344 .47 m .51506 .48078 L .513 .48377 L p .799 .725 .782 r
F P
0 g
s
.513 .48377 m .51067 .46838 L .51344 .47 L p .799 .725 .782 r
F P
0 g
s
.49551 .48853 m .513 .48377 L .51079 .48644 L p .763 .657 .745 r
F P
0 g
s
.56415 .44154 m .55754 .44273 L .55683 .44076 L p .776 .849 .906 r
F P
0 g
s
.55683 .44076 m .56628 .43906 L .56415 .44154 L p .776 .849 .906 r
F P
0 g
s
.70652 .675 m .70273 .66312 L .70813 .66303 L p .336 .551 .912 r
F P
0 g
s
.51079 .48644 m .49855 .48976 L .49551 .48853 L p .763 .657 .745 r
F P
0 g
s
.61992 .60935 m .6235 .61285 L .62696 .61552 L p 0 .211 .698 r
F P
0 g
s
.50147 .50226 m .50319 .50951 L .50107 .51167 L p .775 .621 .689 r
F P
0 g
s
.50386 .51237 m .50522 .51797 L .50302 .51967 L p .778 .594 .651 r
F P
0 g
s
.50302 .51967 m .50107 .51167 L .50386 .51237 L p .778 .594 .651 r
F P
0 g
s
.53397 .55081 m .54632 .55282 L .5496 .55458 L p .821 .468 .387 r
F P
0 g
s
.5496 .55458 m .53195 .55172 L .53397 .55081 L p .821 .468 .387 r
F P
0 g
s
.55251 .56293 m .54782 .55561 L .5496 .55458 L p .79 .382 .277 r
F P
0 g
s
.5496 .55458 m .5563 .56504 L .55251 .56293 L p .79 .382 .277 r
F P
0 g
s
.53195 .55172 m .5496 .55458 L .54782 .55561 L p .789 .38 .276 r
F P
0 g
s
.47079 .52843 m .47142 .53215 L .46898 .53367 L p .63 .466 .642 r
F P
0 g
s
.50107 .51167 m .4986 .50131 L .50147 .50226 L p .775 .621 .689 r
F P
0 g
s
.75097 .42219 m .78624 .40893 L .79736 .40888 L p .632 .754 .936 r
F P
0 g
s
.61128 .42508 m .60152 .42437 L .60125 .42219 L p .674 .847 .966 r
F P
0 g
s
.60125 .42219 m .6152 .42321 L .61128 .42508 L p .674 .847 .966 r
F P
0 g
s
.52861 .53794 m .53039 .54265 L .5284 .54352 L p .835 .519 .456 r
F P
0 g
s
.5284 .54352 m .52585 .53678 L .52861 .53794 L p .835 .519 .456 r
F P
0 g
s
.46987 .55124 m .45422 .55763 L .45662 .55578 L p .457 .25 .51 r
F P
0 g
s
.45422 .55763 m .45243 .56539 L .45107 .56538 L p .14 0 .32 r
F P
0 g
s
.46733 .55332 m .45637 .55779 L .45422 .55763 L p .419 .177 .437 r
F P
0 g
s
.45422 .55763 m .46987 .55124 L .46733 .55332 L p .419 .177 .437 r
F P
0 g
s
.45243 .56539 m .45422 .55763 L .45637 .55779 L p .419 .177 .437 r
F P
0 g
s
.40817 .61907 m .41425 .60839 L .41323 .60818 L p .781 .985 .734 r
F P
0 g
s
.46898 .53367 m .46936 .53678 L .46712 .53716 L p .51 .358 .61 r
F P
0 g
s
.49855 .48976 m .50071 .49871 L .4986 .50131 L p .769 .65 .731 r
F P
0 g
s
.38995 .46086 m .40303 .45479 L .40923 .45657 L p .605 .688 .901 r
F P
0 g
s
.52172 .53276 m .50937 .5339 L .5065 .53343 L p .77 .515 .549 r
F P
0 g
s
.46728 .53854 m .46719 .5378 L .46936 .53678 L p .508 .355 .608 r
F P
0 g
s
.4986 .50131 m .50107 .51167 L .49804 .51078 L p .717 .586 .707 r
F P
0 g
s
.48567 .51377 m .49804 .51078 L .50107 .51167 L p .719 .582 .701 r
F P
0 g
s
.50107 .51167 m .4834 .51593 L .48567 .51377 L p .719 .582 .701 r
F P
0 g
s
.50006 .51908 m .4987 .51348 L .50107 .51167 L p .714 .555 .672 r
F P
0 g
s
.50107 .51167 m .50302 .51967 L .50006 .51908 L p .714 .555 .672 r
F P
0 g
s
.4834 .51593 m .50107 .51167 L .4987 .51348 L p .71 .547 .667 r
F P
0 g
s
.48044 .51519 m .4786 .5082 L .48076 .50594 L p .648 .534 .711 r
F P
0 g
s
.48627 .52891 m .46898 .53367 L .47142 .53215 L p .631 .467 .643 r
F P
0 g
s
.48375 .5301 m .47165 .53343 L .46898 .53367 L p .622 .443 .619 r
F P
0 g
s
.46898 .53367 m .48627 .52891 L .48375 .5301 L p .622 .443 .619 r
F P
0 g
s
.46936 .53678 m .46898 .53367 L .47165 .53343 L p .621 .437 .612 r
F P
0 g
s
.49551 .48853 m .4986 .50131 L .49542 .50012 L p .718 .619 .747 r
F P
0 g
s
.48293 .50336 m .49542 .50012 L .4986 .50131 L p .721 .615 .739 r
F P
0 g
s
.4986 .50131 m .48076 .50594 L .48293 .50336 L p .721 .615 .739 r
F P
0 g
s
.4986 .50131 m .49551 .48853 L .49855 .48976 L p .769 .65 .731 r
F P
0 g
s
.49804 .51078 m .49631 .50353 L .4986 .50131 L p .717 .586 .707 r
F P
0 g
s
.48076 .50594 m .4986 .50131 L .49631 .50353 L p .712 .578 .703 r
F P
0 g
s
.57109 .57198 m .56014 .56764 L .5563 .56504 L p .733 .211 0 r
F P
0 g
s
.47758 .50488 m .47498 .49625 L .47705 .4936 L p .656 .571 .748 r
F P
0 g
s
.47705 .4936 m .48076 .50594 L .47758 .50488 L p .656 .571 .748 r
F P
0 g
s
.49631 .50353 m .48382 .50677 L .48076 .50594 L p .712 .578 .703 r
F P
0 g
s
.63381 .62065 m .65233 .62959 L .65658 .63181 L p .037 .425 .866 r
F P
0 g
s
.48076 .50594 m .4834 .51593 L .48044 .51519 L p .648 .534 .711 r
F P
0 g
s
.50576 .52011 m .50676 .52409 L .50444 .52535 L p .778 .571 .62 r
F P
0 g
s
.50444 .52535 m .50302 .51967 L .50576 .52011 L p .778 .571 .62 r
F P
0 g
s
.46936 .53678 m .46948 .53785 L .46728 .53854 L p .508 .355 .608 r
F P
0 g
s
.4987 .51348 m .48633 .51646 L .4834 .51593 L p .71 .547 .667 r
F P
0 g
s
.50993 .4822 m .50829 .47142 L .51067 .46838 L p .761 .699 .793 r
F P
0 g
s
.47142 .53215 m .48352 .52882 L .48627 .52891 L p .631 .467 .643 r
F P
0 g
s
.46735 .53942 m .4673 .53883 L .46948 .53785 L p .501 .338 .592 r
F P
0 g
s
.49542 .50012 m .49325 .49117 L .49551 .48853 L p .718 .619 .747 r
F P
0 g
s
.57444 .43524 m .58025 .42368 L .58175 .42112 L p .765 .89 .933 r
F P
0 g
s
.33962 .65607 m .33652 .67943 L .34298 .67312 L p .823 .928 .903 r
F P
0 g
s
.33652 .67943 m .27527 .70215 L .28546 .7022 L p .793 .865 .902 r
F P
0 g
s
.33005 .66249 m .32797 .67883 L .33652 .67943 L p .782 .896 .924 r
F P
0 g
s
.33652 .67943 m .33962 .65607 L .33005 .66249 L p .782 .896 .924 r
F P
0 g
s
.27527 .70215 m .33652 .67943 L .32797 .67883 L p .782 .896 .924 r
F P
0 g
s
.45662 .55578 m .46757 .55131 L .46987 .55124 L p .457 .25 .51 r
F P
0 g
s
.48382 .50677 m .48567 .51377 L .4834 .51593 L p .714 .574 .696 r
F P
0 g
s
.4834 .51593 m .48076 .50594 L .48382 .50677 L p .714 .574 .696 r
F P
0 g
s
.48233 .52313 m .48111 .5178 L .4834 .51593 L p .639 .497 .673 r
F P
0 g
s
.52527 .46682 m .51344 .47 L .51067 .46838 L p .787 .73 .8 r
F P
0 g
s
.51067 .46838 m .52758 .46384 L .52527 .46682 L p .787 .73 .8 r
F P
0 g
s
.57327 .42166 m .56628 .43906 L .56578 .43665 L p .747 .843 .923 r
F P
0 g
s
.55916 .43784 m .56578 .43665 L .56628 .43906 L p .772 .858 .914 r
F P
0 g
s
.56628 .43906 m .55683 .44076 L .55916 .43784 L p .772 .858 .914 r
F P
0 g
s
.57315 .42421 m .56825 .43639 L .56628 .43906 L p .748 .845 .923 r
F P
0 g
s
.56628 .43906 m .57327 .42166 L .57315 .42421 L p .748 .845 .923 r
F P
0 g
s
.48033 .49472 m .48293 .50336 L .48076 .50594 L p .715 .605 .733 r
F P
0 g
s
.48076 .50594 m .47705 .4936 L .48033 .49472 L p .715 .605 .733 r
F P
0 g
s
.46948 .53785 m .46956 .5387 L .46735 .53942 L p .501 .338 .592 r
F P
0 g
s
.44874 .48321 m .4424 .47148 L .44375 .46797 L p .615 .618 .831 r
F P
0 g
s
.44375 .46797 m .45281 .48474 L .44874 .48321 L p .615 .618 .831 r
F P
0 g
s
.51019 .53701 m .52291 .53624 L .52585 .53678 L p .773 .517 .548 r
F P
0 g
s
.52585 .53678 m .50767 .53788 L .51019 .53701 L p .773 .517 .548 r
F P
0 g
s
.52523 .54262 m .52344 .5379 L .52585 .53678 L p .766 .489 .514 r
F P
0 g
s
.52585 .53678 m .5284 .54352 L .52523 .54262 L p .766 .489 .514 r
F P
0 g
s
.50767 .53788 m .52585 .53678 L .52344 .5379 L p .763 .482 .508 r
F P
0 g
s
.47165 .53343 m .47191 .53561 L .46936 .53678 L p .621 .437 .612 r
F P
0 g
s
.46752 .54173 m .46738 .53995 L .46956 .5387 L p .494 .323 .578 r
F P
0 g
s
.4834 .51593 m .48516 .52354 L .48233 .52313 L p .639 .497 .673 r
F P
0 g
s
.48516 .52354 m .4834 .51593 L .48633 .51646 L p .71 .542 .659 r
F P
0 g
s
.48633 .51646 m .48756 .52179 L .48516 .52354 L p .71 .542 .659 r
F P
0 g
s
.52741 .44644 m .52758 .46384 L .52486 .46189 L p .772 .765 .847 r
F P
0 g
s
.51301 .46507 m .52486 .46189 L .52758 .46384 L p .788 .763 .831 r
F P
0 g
s
.52758 .46384 m .51067 .46838 L .51301 .46507 L p .788 .763 .831 r
F P
0 g
s
.52973 .4485 m .52985 .46068 L .52758 .46384 L p .795 .783 .842 r
F P
0 g
s
.52758 .46384 m .52741 .44644 L .52973 .4485 L p .795 .783 .842 r
F P
0 g
s
.43706 .58413 m .43095 .59235 L .42765 .59568 L p 0 0 0 r
F P
0 g
s
.48756 .52179 m .50006 .51908 L .50302 .51967 L p .715 .551 .665 r
F P
0 g
s
.50302 .51967 m .48516 .52354 L .48756 .52179 L p .715 .551 .665 r
F P
0 g
s
.50153 .52506 m .50053 .52108 L .50302 .51967 L p .711 .531 .644 r
F P
0 g
s
.50302 .51967 m .50444 .52535 L .50153 .52506 L p .711 .531 .644 r
F P
0 g
s
.48516 .52354 m .50302 .51967 L .50053 .52108 L p .707 .524 .638 r
F P
0 g
s
.44814 .46955 m .45447 .4813 L .45281 .48474 L p .664 .641 .817 r
F P
0 g
s
.45281 .48474 m .44375 .46797 L .44814 .46955 L p .664 .641 .817 r
F P
0 g
s
.47194 .47881 m .45281 .48474 L .45447 .4813 L p .667 .644 .818 r
F P
0 g
s
.46993 .48189 m .45654 .48604 L .45281 .48474 L p .659 .606 .784 r
F P
0 g
s
.45281 .48474 m .47194 .47881 L .46993 .48189 L p .659 .606 .784 r
F P
0 g
s
.62696 .61552 m .62185 .61052 L .61992 .60935 L p 0 .211 .698 r
F P
0 g
s
.64824 .62513 m .63001 .61654 L .62696 .61552 L p 0 .414 .854 r
F P
0 g
s
.62696 .61552 m .65301 .6278 L .64824 .62513 L p 0 .414 .854 r
F P
0 g
s
.62185 .61052 m .62696 .61552 L .63001 .61654 L p 0 .414 .854 r
F P
0 g
s
.6322 .61886 m .63109 .61762 L .62696 .61552 L p .037 .425 .866 r
F P
0 g
s
.65301 .6278 m .62696 .61552 L .63109 .61762 L p .037 .425 .866 r
F P
0 g
s
.48689 .53211 m .46936 .53678 L .47191 .53561 L p .624 .444 .619 r
F P
0 g
s
.48428 .53297 m .47201 .53624 L .46936 .53678 L p .621 .435 .609 r
F P
0 g
s
.46936 .53678 m .48689 .53211 L .48428 .53297 L p .621 .435 .609 r
F P
0 g
s
.46948 .53785 m .46936 .53678 L .47201 .53624 L p .621 .437 .611 r
F P
0 g
s
.57224 .43577 m .57785 .42405 L .58 .42144 L p .741 .852 .932 r
F P
0 g
s
.63201 .40562 m .6152 .42321 L .61544 .42032 L p .67 .827 .959 r
F P
0 g
s
.60566 .4196 m .61544 .42032 L .6152 .42321 L p .688 .843 .957 r
F P
0 g
s
.6152 .42321 m .60125 .42219 L .60566 .4196 L p .688 .843 .957 r
F P
0 g
s
.63213 .40881 m .62035 .42111 L .6152 .42321 L p .666 .819 .957 r
F P
0 g
s
.6152 .42321 m .63201 .40562 L .63213 .40881 L p .666 .819 .957 r
F P
0 g
s
.50053 .52108 m .48803 .52379 L .48516 .52354 L p .707 .524 .638 r
F P
0 g
s
.50713 .52551 m .50772 .52784 L .50528 .52868 L p .776 .549 .592 r
F P
0 g
s
.50528 .52868 m .50444 .52535 L .50713 .52551 L p .776 .549 .592 r
F P
0 g
s
.66531 .41831 m .65105 .41341 L .65118 .4102 L p .623 .795 .965 r
F P
0 g
s
.65118 .4102 m .67156 .41724 L .66531 .41831 L p .623 .795 .965 r
F P
0 g
s
.42541 .47108 m .4388 .46617 L .44375 .46797 L p .626 .659 .862 r
F P
0 g
s
.47191 .53561 m .48418 .53234 L .48689 .53211 L p .624 .444 .619 r
F P
0 g
s
.47201 .53624 m .47209 .53698 L .46948 .53785 L p .621 .437 .611 r
F P
0 g
s
.48708 .53315 m .46948 .53785 L .47209 .53698 L p .621 .435 .609 r
F P
0 g
s
.48445 .53398 m .47213 .53727 L .46948 .53785 L p .616 .42 .595 r
F P
0 g
s
.46948 .53785 m .48708 .53315 L .48445 .53398 L p .616 .42 .595 r
F P
0 g
s
.46956 .5387 m .46948 .53785 L .47213 .53727 L p .616 .423 .597 r
F P
0 g
s
.46956 .5387 m .46976 .54125 L .46752 .54173 L p .494 .323 .578 r
F P
0 g
s
.49325 .49117 m .48033 .49472 L .47705 .4936 L p .711 .609 .741 r
F P
0 g
s
.45637 .55779 m .45512 .56323 L .45243 .56539 L p .419 .177 .437 r
F P
0 g
s
.47351 .49224 m .46993 .48189 L .47194 .47881 L p .662 .609 .785 r
F P
0 g
s
.47194 .47881 m .47705 .4936 L .47351 .49224 L p .662 .609 .785 r
F P
0 g
s
.48352 .52882 m .48274 .52507 L .48516 .52354 L p .631 .468 .644 r
F P
0 g
s
.47557 .48024 m .47915 .4906 L .47705 .4936 L p .712 .637 .772 r
F P
0 g
s
.47705 .4936 m .47194 .47881 L .47557 .48024 L p .712 .637 .772 r
F P
0 g
s
.49551 .48853 m .47705 .4936 L .47915 .4906 L p .719 .647 .777 r
F P
0 g
s
.47705 .4936 m .49551 .48853 L .49325 .49117 L p .711 .609 .741 r
F P
0 g
s
.47213 .53727 m .47219 .53787 L .46956 .5387 L p .616 .423 .597 r
F P
0 g
s
.48722 .534 m .46956 .5387 L .47219 .53787 L p .615 .42 .595 r
F P
0 g
s
.48461 .53509 m .47225 .53838 L .46956 .5387 L p .613 .414 .589 r
F P
0 g
s
.46956 .5387 m .48722 .534 L .48461 .53509 L p .613 .414 .589 r
F P
0 g
s
.46976 .54125 m .46956 .5387 L .47225 .53838 L p .612 .411 .585 r
F P
0 g
s
.85166 .74492 m .85503 .72035 L .86997 .71863 L p .511 .655 .924 r
F P
0 g
s
.47209 .53698 m .48441 .5337 L .48708 .53315 L p .621 .435 .609 r
F P
0 g
s
.46769 .54574 m .46754 .54277 L .46976 .54125 L p .484 .303 .559 r
F P
0 g
s
.48516 .52354 m .48627 .52891 L .48352 .52882 L p .631 .468 .644 r
F P
0 g
s
.48627 .52891 m .48516 .52354 L .48803 .52379 L p .707 .518 .63 r
F P
0 g
s
.52344 .5379 m .51071 .53867 L .50767 .53788 L p .763 .482 .508 r
F P
0 g
s
.48803 .52379 m .48881 .52755 L .48627 .52891 L p .707 .518 .63 r
F P
0 g
s
.49171 .47334 m .49551 .48853 L .49208 .48704 L p .714 .65 .785 r
F P
0 g
s
.47915 .4906 m .49208 .48704 L .49551 .48853 L p .719 .647 .777 r
F P
0 g
s
.49502 .47489 m .49768 .48552 L .49551 .48853 L p .758 .677 .773 r
F P
0 g
s
.49551 .48853 m .49171 .47334 L .49502 .47489 L p .758 .677 .773 r
F P
0 g
s
.48881 .52755 m .50153 .52506 L .50444 .52535 L p .711 .526 .637 r
F P
0 g
s
.50444 .52535 m .48627 .52891 L .48881 .52755 L p .711 .526 .637 r
F P
0 g
s
.50241 .52871 m .50183 .52637 L .50444 .52535 L p .706 .507 .617 r
F P
0 g
s
.50444 .52535 m .50528 .52868 L .50241 .52871 L p .706 .507 .617 r
F P
0 g
s
.48627 .52891 m .50444 .52535 L .50183 .52637 L p .705 .504 .615 r
F P
0 g
s
.54782 .55561 m .53546 .55361 L .53195 .55172 L p .789 .38 .276 r
F P
0 g
s
.47219 .53787 m .48455 .53458 L .48722 .534 L p .615 .42 .595 r
F P
0 g
s
.50791 .52854 m .50811 .52932 L .50555 .52979 L p .775 .542 .582 r
F P
0 g
s
.50555 .52979 m .50528 .52868 L .50791 .52854 L p .775 .542 .582 r
F P
0 g
s
.34298 .67312 m .34521 .65675 L .33962 .65607 L p .823 .928 .903 r
F P
0 g
s
.50183 .52637 m .48911 .52887 L .48627 .52891 L p .705 .504 .615 r
F P
0 g
s
.47225 .53838 m .47239 .54016 L .46976 .54125 L p .612 .411 .585 r
F P
0 g
s
.55441 .44351 m .54529 .44519 L .54378 .44315 L p .781 .82 .883 r
F P
0 g
s
.54378 .44315 m .55683 .44076 L .55441 .44351 L p .781 .82 .883 r
F P
0 g
s
.45447 .4813 m .46787 .47714 L .47194 .47881 L p .667 .644 .818 r
F P
0 g
s
.5082 .52963 m .50835 .53026 L .50578 .53069 L p .774 .534 .573 r
F P
0 g
s
.50578 .53069 m .50555 .52979 L .5082 .52963 L p .774 .534 .573 r
F P
0 g
s
.49208 .48704 m .48941 .47641 L .49171 .47334 L p .714 .65 .785 r
F P
0 g
s
.70179 .39807 m .67156 .41724 L .67272 .41315 L p .636 .785 .953 r
F P
0 g
s
.65844 .4082 m .67272 .41315 L .67156 .41724 L p .646 .795 .954 r
F P
0 g
s
.67156 .41724 m .65118 .4102 L .65844 .4082 L p .646 .795 .954 r
F P
0 g
s
.70052 .40274 m .67936 .41613 L .67156 .41724 L p .633 .774 .948 r
F P
0 g
s
.67156 .41724 m .70179 .39807 L .70052 .40274 L p .633 .774 .948 r
F P
0 g
s
.5962 .59152 m .58719 .5859 L .58291 .583 L p .462 0 0 r
F P
0 g
s
.48764 .53657 m .46976 .54125 L .47239 .54016 L p .614 .415 .589 r
F P
0 g
s
.46976 .54125 m .46997 .54549 L .46769 .54574 L p .484 .303 .559 r
F P
0 g
s
.48502 .53791 m .4725 .54118 L .46976 .54125 L p .607 .396 .57 r
F P
0 g
s
.46976 .54125 m .48764 .53657 L .48502 .53791 L p .607 .396 .57 r
F P
0 g
s
.46997 .54549 m .46976 .54125 L .4725 .54118 L p .607 .396 .569 r
F P
0 g
s
.52486 .46189 m .52472 .44971 L .52741 .44644 L p .772 .765 .847 r
F P
0 g
s
.50852 .53084 m .50903 .53276 L .5065 .53343 L p .774 .531 .567 r
F P
0 g
s
.5065 .53343 m .50578 .53069 L .50852 .53084 L p .774 .531 .567 r
F P
0 g
s
.48418 .53234 m .48375 .5301 L .48627 .52891 L p .625 .45 .625 r
F P
0 g
s
.48954 .5311 m .50241 .52871 L .50528 .52868 L p .706 .505 .614 r
F P
0 g
s
.50528 .52868 m .48689 .53211 L .48954 .5311 L p .706 .505 .614 r
F P
0 g
s
.50275 .53013 m .50256 .52936 L .50528 .52868 L p .704 .499 .608 r
F P
0 g
s
.50528 .52868 m .50555 .52979 L .50275 .53013 L p .704 .499 .608 r
F P
0 g
s
.48689 .53211 m .50528 .52868 L .50256 .52936 L p .702 .493 .602 r
F P
0 g
s
.67243 .64859 m .70099 .65908 L .70813 .66303 L p .288 .551 .924 r
F P
0 g
s
.47239 .54016 m .48491 .53689 L .48764 .53657 L p .614 .415 .589 r
F P
0 g
s
.53148 .54508 m .53397 .55081 L .53195 .55172 L p .819 .464 .384 r
F P
0 g
s
.53195 .55172 m .5284 .54352 L .53148 .54508 L p .819 .464 .384 r
F P
0 g
s
.4475 .57435 m .4501 .56807 L .45243 .56539 L p .009 0 .13 r
F P
0 g
s
.50256 .52936 m .48968 .53176 L .48689 .53211 L p .702 .493 .602 r
F P
0 g
s
.48911 .52887 m .48954 .5311 L .48689 .53211 L p .705 .502 .612 r
F P
0 g
s
.48689 .53211 m .48627 .52891 L .48911 .52887 L p .705 .502 .612 r
F P
0 g
s
.56578 .43665 m .57067 .42447 L .57327 .42166 L p .747 .843 .923 r
F P
0 g
s
.48627 .52891 m .48689 .53211 L .48418 .53234 L p .625 .45 .625 r
F P
0 g
s
.48982 .53249 m .50275 .53013 L .50555 .52979 L p .703 .494 .602 r
F P
0 g
s
.50555 .52979 m .48708 .53315 L .48982 .53249 L p .703 .494 .602 r
F P
0 g
s
.50297 .53106 m .50281 .53043 L .50555 .52979 L p .703 .491 .599 r
F P
0 g
s
.50555 .52979 m .50578 .53069 L .50297 .53106 L p .703 .491 .599 r
F P
0 g
s
.48708 .53315 m .50555 .52979 L .50281 .53043 L p .7 .483 .59 r
F P
0 g
s
.40225 .6233 m .38428 .63465 L .37893 .63964 L p .793 .996 .863 r
F P
0 g
s
.63109 .61762 m .64932 .62622 L .65301 .6278 L p .037 .425 .866 r
F P
0 g
s
.4725 .54118 m .47265 .54415 L .46997 .54549 L p .607 .396 .569 r
F P
0 g
s
.56214 .42231 m .55683 .44076 L .55549 .43829 L p .752 .825 .909 r
F P
0 g
s
.54635 .43997 m .55549 .43829 L .55683 .44076 L p .775 .834 .897 r
F P
0 g
s
.55683 .44076 m .54378 .44315 L .54635 .43997 L p .775 .834 .897 r
F P
0 g
s
.56289 .42493 m .55916 .43784 L .55683 .44076 L p .756 .83 .908 r
F P
0 g
s
.55683 .44076 m .56214 .42231 L .56289 .42493 L p .756 .83 .908 r
F P
0 g
s
.50281 .53043 m .48988 .53278 L .48708 .53315 L p .7 .483 .59 r
F P
0 g
s
.48998 .53337 m .50297 .53106 L .50578 .53069 L p .7 .483 .59 r
F P
0 g
s
.50578 .53069 m .48722 .534 L .48998 .53337 L p .7 .483 .59 r
F P
0 g
s
.50359 .53351 m .50308 .53159 L .50578 .53069 L p .703 .489 .595 r
F P
0 g
s
.50578 .53069 m .5065 .53343 L .50359 .53351 L p .703 .489 .595 r
F P
0 g
s
.48722 .534 m .50578 .53069 L .50308 .53159 L p .7 .481 .588 r
F P
0 g
s
.51185 .54287 m .52523 .54262 L .5284 .54352 L p .766 .484 .506 r
F P
0 g
s
.5284 .54352 m .50928 .54389 L .51185 .54287 L p .766 .484 .506 r
F P
0 g
s
.52845 .55048 m .52597 .54473 L .5284 .54352 L p .753 .438 .451 r
F P
0 g
s
.5284 .54352 m .53195 .55172 L .52845 .55048 L p .753 .438 .451 r
F P
0 g
s
.50928 .54389 m .5284 .54352 L .52597 .54473 L p .75 .433 .447 r
F P
0 g
s
.48441 .5337 m .48428 .53297 L .48689 .53211 L p .62 .434 .608 r
F P
0 g
s
.46757 .55131 m .46764 .54729 L .46997 .54549 L p .456 .246 .505 r
F P
0 g
s
.50308 .53159 m .49009 .5339 L .48722 .534 L p .7 .481 .588 r
F P
0 g
s
.50937 .5339 m .51019 .53701 L .50767 .53788 L p .77 .509 .541 r
F P
0 g
s
.50767 .53788 m .5065 .53343 L .50937 .5339 L p .77 .509 .541 r
F P
0 g
s
.46917 .55841 m .45243 .56539 L .45512 .56323 L p .42 .177 .437 r
F P
0 g
s
.45243 .56539 m .44872 .57437 L .4475 .57435 L p .009 0 .13 r
F P
0 g
s
.46622 .56074 m .4545 .56563 L .45243 .56539 L p .351 .053 .312 r
F P
0 g
s
.45243 .56539 m .46917 .55841 L .46622 .56074 L p .351 .053 .312 r
F P
0 g
s
.44872 .57437 m .45243 .56539 L .4545 .56563 L p .351 .054 .313 r
F P
0 g
s
.48689 .53211 m .48708 .53315 L .48441 .5337 L p .62 .434 .608 r
F P
0 g
s
.48968 .53176 m .48982 .53249 L .48708 .53315 L p .701 .488 .596 r
F P
0 g
s
.48708 .53315 m .48689 .53211 L .48968 .53176 L p .701 .488 .596 r
F P
0 g
s
.50829 .47142 m .49502 .47489 L .49171 .47334 L p .75 .682 .786 r
F P
0 g
s
.49171 .47334 m .51067 .46838 L .50829 .47142 L p .75 .682 .786 r
F P
0 g
s
.48455 .53458 m .48445 .53398 L .48708 .53315 L p .615 .418 .592 r
F P
0 g
s
.48708 .53315 m .48722 .534 L .48455 .53458 L p .615 .418 .592 r
F P
0 g
s
.48988 .53278 m .48998 .53337 L .48722 .534 L p .697 .474 .581 r
F P
0 g
s
.48722 .534 m .48708 .53315 L .48988 .53278 L p .697 .474 .581 r
F P
0 g
s
.49039 .5357 m .50359 .53351 L .5065 .53343 L p .702 .482 .588 r
F P
0 g
s
.5065 .53343 m .48764 .53657 L .49039 .5357 L p .702 .482 .588 r
F P
0 g
s
.50463 .53766 m .50381 .53455 L .5065 .53343 L p .697 .466 .569 r
F P
0 g
s
.5065 .53343 m .50767 .53788 L .50463 .53766 L p .697 .466 .569 r
F P
0 g
s
.48764 .53657 m .5065 .53343 L .50381 .53455 L p .695 .461 .565 r
F P
0 g
s
.4883 .54078 m .46997 .54549 L .47265 .54415 L p .607 .396 .57 r
F P
0 g
s
.46997 .54549 m .46987 .55124 L .46757 .55131 L p .456 .246 .505 r
F P
0 g
s
.48559 .54235 m .47276 .54564 L .46997 .54549 L p .592 .358 .53 r
F P
0 g
s
.46997 .54549 m .4883 .54078 L .48559 .54235 L p .592 .358 .53 r
F P
0 g
s
.46987 .55124 m .46997 .54549 L .47276 .54564 L p .592 .354 .525 r
F P
0 g
s
.48491 .53689 m .48461 .53509 L .48722 .534 L p .615 .417 .591 r
F P
0 g
s
.45512 .56323 m .46683 .55834 L .46917 .55841 L p .42 .177 .437 r
F P
0 g
s
.63001 .61654 m .62643 .61303 L .62185 .61052 L p 0 .414 .854 r
F P
0 g
s
.50817 .45053 m .51067 .46838 L .50729 .46646 L p .743 .719 .83 r
F P
0 g
s
.49401 .46993 m .50729 .46646 L .51067 .46838 L p .753 .716 .818 r
F P
0 g
s
.51067 .46838 m .49171 .47334 L .49401 .46993 L p .753 .716 .818 r
F P
0 g
s
.51126 .45257 m .51301 .46507 L .51067 .46838 L p .773 .74 .823 r
F P
0 g
s
.51067 .46838 m .50817 .45053 L .51126 .45257 L p .773 .74 .823 r
F P
0 g
s
.5981 .42441 m .59071 .42424 L .59068 .42195 L p .7 .844 .952 r
F P
0 g
s
.59068 .42195 m .60125 .42219 L .5981 .42441 L p .7 .844 .952 r
F P
0 g
s
.41425 .60839 m .42433 .59964 L .42765 .59568 L p .78 .985 .734 r
F P
0 g
s
.47265 .54415 m .48548 .54086 L .4883 .54078 L p .607 .396 .57 r
F P
0 g
s
.48941 .47641 m .47557 .48024 L .47194 .47881 L p .707 .641 .78 r
F P
0 g
s
.72183 .67995 m .76522 .69324 L .77536 .69898 L p .425 .617 .931 r
F P
0 g
s
.61544 .42032 m .62719 .408 L .63201 .40562 L p .67 .827 .959 r
F P
0 g
s
.49009 .5339 m .49039 .5357 L .48764 .53657 L p .698 .474 .58 r
F P
0 g
s
.48764 .53657 m .48722 .534 L .49009 .5339 L p .698 .474 .58 r
F P
0 g
s
.48722 .534 m .48764 .53657 L .48491 .53689 L p .615 .417 .591 r
F P
0 g
s
.50381 .53455 m .49061 .53675 L .48764 .53657 L p .695 .461 .565 r
F P
0 g
s
.61126 .60222 m .61785 .60753 L .62185 .61052 L p 0 .165 .628 r
F P
0 g
s
.46497 .46136 m .47194 .47881 L .46787 .47714 L p .665 .645 .821 r
F P
0 g
s
.46916 .46314 m .47402 .47536 L .47194 .47881 L p .706 .667 .809 r
F P
0 g
s
.47194 .47881 m .46497 .46136 L .46916 .46314 L p .706 .667 .809 r
F P
0 g
s
.49171 .47334 m .47194 .47881 L .47402 .47536 L p .713 .676 .813 r
F P
0 g
s
.47194 .47881 m .49171 .47334 L .48941 .47641 L p .707 .641 .78 r
F P
0 g
s
.52597 .54473 m .51258 .545 L .50928 .54389 L p .75 .433 .447 r
F P
0 g
s
.47276 .54564 m .47269 .54967 L .46987 .55124 L p .592 .354 .525 r
F P
0 g
s
.46787 .47714 m .46299 .46493 L .46497 .46136 L p .665 .645 .821 r
F P
0 g
s
.44197 .58424 m .42765 .59568 L .43095 .59235 L p 0 0 0 r
F P
0 g
s
.42765 .59568 m .41323 .60818 L .41425 .60839 L p .78 .985 .734 r
F P
0 g
s
.43789 .58765 m .42786 .59565 L .42765 .59568 L p 0 0 0 r
F P
0 g
s
.42765 .59568 m .44197 .58424 L .43789 .58765 L p 0 0 0 r
F P
0 g
s
.41323 .60818 m .42765 .59568 L .42786 .59565 L p 0 0 0 r
F P
0 g
s
.48548 .54086 m .48502 .53791 L .48764 .53657 L p .607 .397 .57 r
F P
0 g
s
.48764 .53657 m .4883 .54078 L .48548 .54086 L p .607 .397 .57 r
F P
0 g
s
.4883 .54078 m .48764 .53657 L .49061 .53675 L p .694 .457 .559 r
F P
0 g
s
.49061 .53675 m .49107 .5397 L .4883 .54078 L p .694 .457 .559 r
F P
0 g
s
.51071 .53867 m .51185 .54287 L .50928 .54389 L p .763 .476 .5 r
F P
0 g
s
.50928 .54389 m .50767 .53788 L .51071 .53867 L p .763 .476 .5 r
F P
0 g
s
.50729 .46646 m .50553 .45397 L .50817 .45053 L p .743 .719 .83 r
F P
0 g
s
.54118 .4462 m .52973 .4485 L .52741 .44644 L p .775 .783 .859 r
F P
0 g
s
.52741 .44644 m .54378 .44315 L .54118 .4462 L p .775 .783 .859 r
F P
0 g
s
.55549 .43829 m .5592 .42538 L .56214 .42231 L p .752 .825 .909 r
F P
0 g
s
.4545 .56563 m .45191 .57192 L .44872 .57437 L p .351 .054 .313 r
F P
0 g
s
.62185 .61052 m .61244 .60292 L .61126 .60222 L p 0 .165 .628 r
F P
0 g
s
.64176 .61906 m .62408 .611 L .62185 .61052 L p 0 .396 .828 r
F P
0 g
s
.62185 .61052 m .6471 .62203 L .64176 .61906 L p 0 .396 .828 r
F P
0 g
s
.61244 .60292 m .62185 .61052 L .62408 .611 L p 0 .396 .828 r
F P
0 g
s
.6471 .62203 m .62185 .61052 L .62643 .61303 L p 0 .414 .854 r
F P
0 g
s
.48697 .45554 m .49171 .47334 L .48787 .47152 L p .707 .679 .82 r
F P
0 g
s
.47402 .47536 m .48787 .47152 L .49171 .47334 L p .713 .676 .813 r
F P
0 g
s
.4907 .45748 m .49401 .46993 L .49171 .47334 L p .742 .7 .811 r
F P
0 g
s
.49171 .47334 m .48697 .45554 L .4907 .45748 L p .742 .7 .811 r
F P
0 g
s
.49107 .5397 m .50463 .53766 L .50767 .53788 L p .697 .462 .564 r
F P
0 g
s
.50767 .53788 m .4883 .54078 L .49107 .5397 L p .697 .462 .564 r
F P
0 g
s
.50607 .5434 m .50494 .53919 L .50767 .53788 L p .687 .432 .53 r
F P
0 g
s
.50767 .53788 m .50928 .54389 L .50607 .5434 L p .687 .432 .53 r
F P
0 g
s
.4883 .54078 m .50767 .53788 L .50494 .53919 L p .686 .429 .528 r
F P
0 g
s
.61564 .4029 m .60125 .42219 L .60166 .41921 L p .688 .826 .949 r
F P
0 g
s
.59426 .41903 m .60166 .41921 L .60125 .42219 L p .706 .841 .947 r
F P
0 g
s
.60125 .42219 m .59068 .42195 L .59426 .41903 L p .706 .841 .947 r
F P
0 g
s
.61574 .40611 m .60566 .4196 L .60125 .42219 L p .686 .822 .948 r
F P
0 g
s
.60125 .42219 m .61564 .4029 L .61574 .40611 L p .686 .822 .948 r
F P
0 g
s
.43095 .59235 m .44098 .58434 L .44197 .58424 L p 0 0 0 r
F P
0 g
s
.46299 .46493 m .44814 .46955 L .44375 .46797 L p .662 .642 .82 r
F P
0 g
s
.43128 .44822 m .44375 .46797 L .4388 .46617 L p .628 .658 .86 r
F P
0 g
s
.43657 .45014 m .44529 .46397 L .44375 .46797 L p .664 .673 .848 r
F P
0 g
s
.44375 .46797 m .43128 .44822 L .43657 .45014 L p .664 .673 .848 r
F P
0 g
s
.46497 .46136 m .44375 .46797 L .44529 .46397 L p .667 .676 .849 r
F P
0 g
s
.44375 .46797 m .46497 .46136 L .46299 .46493 L p .662 .642 .82 r
F P
0 g
s
.32797 .67883 m .28498 .69476 L .27527 .70215 L p .782 .896 .924 r
F P
0 g
s
.4388 .46617 m .43006 .45236 L .43128 .44822 L p .628 .658 .86 r
F P
0 g
s
.46683 .55834 m .46733 .55332 L .46987 .55124 L p .42 .177 .438 r
F P
0 g
s
.50494 .53919 m .49138 .54123 L .4883 .54078 L p .686 .429 .528 r
F P
0 g
s
.54672 .42366 m .54378 .44315 L .54157 .44067 L p .751 .799 .891 r
F P
0 g
s
.5301 .44297 m .54157 .44067 L .54378 .44315 L p .771 .803 .879 r
F P
0 g
s
.54378 .44315 m .52741 .44644 L .5301 .44297 L p .771 .803 .879 r
F P
0 g
s
.54842 .42633 m .54635 .43997 L .54378 .44315 L p .76 .807 .89 r
F P
0 g
s
.54378 .44315 m .54672 .42366 L .54842 .42633 L p .76 .807 .89 r
F P
0 g
s
.48787 .47152 m .48455 .45907 L .48697 .45554 L p .707 .679 .82 r
F P
0 g
s
.65649 .63496 m .65324 .63073 L .65658 .63181 L p .077 .433 .874 r
F P
0 g
s
.65658 .63181 m .66122 .63786 L .65649 .63496 L p .077 .433 .874 r
F P
0 g
s
.43006 .45236 m .41462 .45819 L .40923 .45657 L p .631 .661 .861 r
F P
0 g
s
.67272 .41315 m .69387 .3997 L .70179 .39807 L p .636 .785 .953 r
F P
0 g
s
.38833 .43476 m .40923 .45657 L .40303 .45479 L p .611 .685 .895 r
F P
0 g
s
.39507 .43666 m .40969 .45194 L .40923 .45657 L p .639 .693 .885 r
F P
0 g
s
.40923 .45657 m .38833 .43476 L .39507 .43666 L p .639 .693 .885 r
F P
0 g
s
.43128 .44822 m .40923 .45657 L .40969 .45194 L p .636 .691 .884 r
F P
0 g
s
.40923 .45657 m .43128 .44822 L .43006 .45236 L p .631 .661 .861 r
F P
0 g
s
.48904 .54649 m .46987 .55124 L .47269 .54967 L p .595 .359 .53 r
F P
0 g
s
.46987 .55124 m .46917 .55841 L .46683 .55834 L p .42 .177 .438 r
F P
0 g
s
.48616 .54827 m .47273 .5516 L .46987 .55124 L p .571 .303 .471 r
F P
0 g
s
.46987 .55124 m .48904 .54649 L .48616 .54827 L p .571 .303 .471 r
F P
0 g
s
.46917 .55841 m .46987 .55124 L .47273 .5516 L p .571 .303 .471 r
F P
0 g
s
.53877 .55996 m .55251 .56293 L .5563 .56504 L p .79 .38 .275 r
F P
0 g
s
.5563 .56504 m .53667 .5608 L .53877 .55996 L p .79 .38 .275 r
F P
0 g
s
.56074 .57323 m .5545 .56587 L .5563 .56504 L p .726 .245 .101 r
F P
0 g
s
.5563 .56504 m .56523 .57554 L .56074 .57323 L p .726 .245 .101 r
F P
0 g
s
.53667 .5608 m .5563 .56504 L .5545 .56587 L p .727 .245 .101 r
F P
0 g
s
.56523 .57554 m .5563 .56504 L .56014 .56764 L p .736 .215 0 r
F P
0 g
s
.47269 .54967 m .48611 .54635 L .48904 .54649 L p .595 .359 .53 r
F P
0 g
s
.40303 .45479 m .3884 .43955 L .38833 .43476 L p .611 .685 .895 r
F P
0 g
s
.48611 .54635 m .48559 .54235 L .4883 .54078 L p .595 .363 .534 r
F P
0 g
s
.56014 .56764 m .56639 .57498 L .56523 .57554 L p .736 .215 0 r
F P
0 g
s
.4883 .54078 m .48904 .54649 L .48611 .54635 L p .595 .363 .534 r
F P
0 g
s
.48904 .54649 m .4883 .54078 L .49138 .54123 L p .686 .427 .525 r
F P
0 g
s
.58832 .42435 m .58369 .4244 L .58406 .422 L p .714 .838 .941 r
F P
0 g
s
.58406 .422 m .59068 .42195 L .58832 .42435 L p .714 .838 .941 r
F P
0 g
s
.49138 .54123 m .49191 .54522 L .48904 .54649 L p .686 .427 .525 r
F P
0 g
s
.3884 .43955 m .37289 .44722 L .36617 .44576 L p .618 .691 .895 r
F P
0 g
s
.33347 .42214 m .36617 .44576 L .35836 .44416 L p .614 .714 .917 r
F P
0 g
s
.34204 .42383 m .36494 .44039 L .36617 .44576 L p .63 .717 .91 r
F P
0 g
s
.36617 .44576 m .33347 .42214 L .34204 .42383 L p .63 .717 .91 r
F P
0 g
s
.38833 .43476 m .36617 .44576 L .36494 .44039 L p .624 .713 .91 r
F P
0 g
s
.36617 .44576 m .38833 .43476 L .3884 .43955 L p .618 .691 .895 r
F P
0 g
s
.62643 .61303 m .6441 .6211 L .6471 .62203 L p 0 .414 .854 r
F P
0 g
s
.35836 .44416 m .33548 .42766 L .33347 .42214 L p .614 .714 .917 r
F P
0 g
s
.56639 .57498 m .57876 .58021 L .58291 .583 L p .734 .212 0 r
F P
0 g
s
.53546 .55361 m .53877 .55996 L .53667 .5608 L p .789 .379 .273 r
F P
0 g
s
.53667 .5608 m .53195 .55172 L .53546 .55361 L p .789 .379 .273 r
F P
0 g
s
.47273 .5516 m .47224 .55661 L .46917 .55841 L p .571 .303 .471 r
F P
0 g
s
.58291 .583 m .56523 .57554 L .56639 .57498 L p .734 .212 0 r
F P
0 g
s
.59271 .591 m .58228 .5834 L .58291 .583 L p .556 0 0 r
F P
0 g
s
.58291 .583 m .59782 .59386 L .59271 .591 L p .556 0 0 r
F P
0 g
s
.56523 .57554 m .58291 .583 L .58228 .5834 L p .556 0 0 r
F P
0 g
s
.59782 .59386 m .58291 .583 L .58719 .5859 L p .467 0 0 r
F P
0 g
s
.51403 .55013 m .52845 .55048 L .53195 .55172 L p .753 .435 .445 r
F P
0 g
s
.53195 .55172 m .51135 .55122 L .51403 .55013 L p .753 .435 .445 r
F P
0 g
s
.53271 .5593 m .52942 .55294 L .53195 .55172 L p .727 .359 .354 r
F P
0 g
s
.53195 .55172 m .53667 .5608 L .53271 .5593 L p .727 .359 .354 r
F P
0 g
s
.51135 .55122 m .53195 .55172 L .52942 .55294 L p .725 .357 .352 r
F P
0 g
s
.69608 .65041 m .66815 .64145 L .66122 .63786 L p .289 .552 .924 r
F P
0 g
s
.66122 .63786 m .70115 .65065 L .69608 .65041 L p .289 .552 .924 r
F P
0 g
s
.66315 .63452 m .66638 .63875 L .66122 .63786 L p .254 .554 .931 r
F P
0 g
s
.66122 .63786 m .65658 .63181 L .66315 .63452 L p .254 .554 .931 r
F P
0 g
s
.70115 .65065 m .66122 .63786 L .66638 .63875 L p .254 .554 .93 r
F P
0 g
s
.44529 .46397 m .46016 .45933 L .46497 .46136 L p .667 .676 .849 r
F P
0 g
s
.71719 .41198 m .70052 .40274 L .70179 .39807 L p .626 .767 .947 r
F P
0 g
s
.70179 .39807 m .7256 .41132 L .71719 .41198 L p .626 .767 .947 r
F P
0 g
s
.33548 .42766 m .32058 .43774 L .31221 .43659 L p .622 .72 .916 r
F P
0 g
s
.49191 .54522 m .50607 .5434 L .50928 .54389 L p .687 .43 .528 r
F P
0 g
s
.26328 .41097 m .31221 .43659 L .30229 .43518 L p .627 .736 .926 r
F P
0 g
s
.27418 .41235 m .30845 .43034 L .31221 .43659 L p .634 .736 .922 r
F P
0 g
s
.31221 .43659 m .26328 .41097 L .27418 .41235 L p .634 .736 .922 r
F P
0 g
s
.33347 .42214 m .31221 .43659 L .30845 .43034 L p .627 .733 .923 r
F P
0 g
s
.31221 .43659 m .33347 .42214 L .33548 .42766 L p .622 .72 .916 r
F P
0 g
s
.34521 .65675 m .37267 .64526 L .37893 .63964 L p .823 .928 .903 r
F P
0 g
s
.51258 .545 m .51403 .55013 L .51135 .55122 L p .75 .429 .44 r
F P
0 g
s
.51135 .55122 m .50928 .54389 L .51258 .545 L p .75 .429 .44 r
F P
0 g
s
.42786 .59565 m .41776 .60441 L .41323 .60818 L p 0 0 0 r
F P
0 g
s
.50928 .54389 m .48904 .54649 L .49191 .54522 L p .687 .43 .528 r
F P
0 g
s
.50789 .55049 m .50645 .54535 L .50928 .54389 L p .671 .383 .475 r
F P
0 g
s
.50928 .54389 m .51135 .55122 L .50789 .55049 L p .671 .383 .475 r
F P
0 g
s
.48904 .54649 m .50928 .54389 L .50645 .54535 L p .669 .378 .471 r
F P
0 g
s
.52472 .44971 m .51126 .45257 L .50817 .45053 L p .759 .742 .837 r
F P
0 g
s
.50817 .45053 m .52741 .44644 L .52472 .44971 L p .759 .742 .837 r
F P
0 g
s
.58719 .5859 m .59764 .5935 L .59782 .59386 L p .467 0 0 r
F P
0 g
s
.44098 .58434 m .4457 .57743 L .44872 .57437 L p 0 0 0 r
F P
0 g
s
.58255 .42448 m .58144 .42447 L .58248 .422 L p .741 .862 .936 r
F P
0 g
s
.58248 .422 m .58406 .422 L .58255 .42448 L p .741 .862 .936 r
F P
0 g
s
.54157 .44067 m .54362 .42703 L .54672 .42366 L p .751 .799 .891 r
F P
0 g
s
.30229 .43518 m .26807 .41729 L .26328 .41097 L p .627 .736 .926 r
F P
0 g
s
.60166 .41921 m .61173 .4057 L .61564 .4029 L p .688 .826 .949 r
F P
0 g
s
.60314 .40149 m .59068 .42195 L .59145 .41886 L p .7 .821 .94 r
F P
0 g
s
.58681 .4189 m .59145 .41886 L .59068 .42195 L p .716 .837 .939 r
F P
0 g
s
.59068 .42195 m .58406 .422 L .58681 .4189 L p .716 .837 .939 r
F P
0 g
s
.60299 .40471 m .59426 .41903 L .59068 .42195 L p .699 .82 .94 r
F P
0 g
s
.59068 .42195 m .60314 .40149 L .60299 .40471 L p .699 .82 .94 r
F P
0 g
s
.7717 .38781 m .7256 .41132 L .7285 .40558 L p .638 .763 .939 r
F P
0 g
s
.71183 .39627 m .7285 .40558 L .7256 .41132 L p .642 .769 .94 r
F P
0 g
s
.7256 .41132 m .70179 .39807 L .71183 .39627 L p .642 .769 .94 r
F P
0 g
s
.76825 .39424 m .736 .41064 L .7256 .41132 L p .637 .755 .934 r
F P
0 g
s
.7256 .41132 m .7717 .38781 L .76825 .39424 L p .637 .755 .934 r
F P
0 g
s
.46719 .56654 m .44872 .57437 L .45191 .57192 L p .349 .051 .311 r
F P
0 g
s
.44872 .57437 m .44197 .58424 L .44098 .58434 L p 0 0 0 r
F P
0 g
s
.46361 .56909 m .45067 .57457 L .44872 .57437 L p .232 0 .109 r
F P
0 g
s
.44872 .57437 m .46719 .56654 L .46361 .56909 L p .232 0 .109 r
F P
0 g
s
.44197 .58424 m .44872 .57437 L .45067 .57457 L p .232 0 .111 r
F P
0 g
s
.62408 .611 m .6175 .60568 L .61244 .60292 L p 0 .396 .828 r
F P
0 g
s
.50645 .54535 m .49228 .54718 L .48904 .54649 L p .669 .378 .471 r
F P
0 g
s
.39027 .62062 m .37893 .63964 L .38428 .63465 L p .793 .996 .862 r
F P
0 g
s
.37893 .63964 m .33962 .65607 L .34521 .65675 L p .823 .928 .903 r
F P
0 g
s
.38295 .62555 m .37505 .63887 L .37893 .63964 L p .775 .967 .923 r
F P
0 g
s
.37893 .63964 m .39027 .62062 L .38295 .62555 L p .775 .967 .923 r
F P
0 g
s
.33962 .65607 m .37893 .63964 L .37505 .63887 L p .775 .967 .923 r
F P
0 g
s
.52761 .42601 m .52741 .44644 L .52433 .44397 L p .741 .767 .873 r
F P
0 g
s
.51085 .44683 m .52433 .44397 L .52741 .44644 L p .757 .767 .862 r
F P
0 g
s
.52741 .44644 m .50817 .45053 L .51085 .44683 L p .757 .767 .862 r
F P
0 g
s
.53025 .42868 m .5301 .44297 L .52741 .44644 L p .757 .779 .871 r
F P
0 g
s
.52741 .44644 m .52761 .42601 L .53025 .42868 L p .757 .779 .871 r
F P
0 g
s
.45191 .57192 m .46483 .56643 L .46719 .56654 L p .349 .051 .311 r
F P
0 g
s
.5545 .56587 m .54075 .56291 L .53667 .5608 L p .727 .245 .101 r
F P
0 g
s
.19722 .72719 m .26254 .71036 L .27527 .70215 L p .758 .845 .917 r
F P
0 g
s
.40969 .45194 m .42514 .44608 L .43128 .44822 L p .636 .691 .884 r
F P
0 g
s
.48657 .55321 m .48616 .54827 L .48904 .54649 L p .571 .303 .471 r
F P
0 g
s
.48904 .54649 m .48964 .55355 L .48657 .55321 L p .571 .303 .471 r
F P
0 g
s
.48964 .55355 m .48904 .54649 L .49228 .54718 L p .669 .375 .466 r
F P
0 g
s
.52942 .55294 m .51499 .55259 L .51135 .55122 L p .725 .357 .352 r
F P
0 g
s
.64554 .41201 m .63213 .40881 L .63201 .40562 L p .648 .806 .959 r
F P
0 g
s
.63201 .40562 m .65118 .4102 L .64554 .41201 L p .648 .806 .959 r
F P
0 g
s
.48455 .45907 m .46916 .46314 L .46497 .46136 L p .701 .67 .816 r
F P
0 g
s
.26807 .41729 m .25467 .42995 L .24419 .42911 L p .634 .739 .924 r
F P
0 g
s
.58025 .42368 m .57903 .42391 L .58 .42144 L p .744 .86 .934 r
F P
0 g
s
.58 .42144 m .58175 .42112 L .58025 .42368 L p .744 .86 .934 r
F P
0 g
s
.24419 .42911 m .26328 .41097 L .26807 .41729 L p .634 .739 .924 r
F P
0 g
s
.49228 .54718 m .4927 .55212 L .48964 .55355 L p .669 .375 .466 r
F P
0 g
s
.38428 .63465 m .39223 .62133 L .39027 .62062 L p .793 .996 .862 r
F P
0 g
s
.45562 .44071 m .46497 .46136 L .46016 .45933 L p .665 .677 .852 r
F P
0 g
s
.46057 .44291 m .4671 .45737 L .46497 .46136 L p .697 .693 .842 r
F P
0 g
s
.46497 .46136 m .45562 .44071 L .46057 .44291 L p .697 .693 .842 r
F P
0 g
s
.48697 .45554 m .46497 .46136 L .4671 .45737 L p .703 .701 .845 r
F P
0 g
s
.46497 .46136 m .48697 .45554 L .48455 .45907 L p .701 .67 .816 r
F P
0 g
s
.57785 .42405 m .57315 .42421 L .57327 .42166 L p .727 .828 .927 r
F P
0 g
s
.57327 .42166 m .58 .42144 L .57785 .42405 L p .727 .828 .927 r
F P
0 g
s
.59524 .40084 m .58406 .422 L .58545 .41884 L p .722 .838 .936 r
F P
0 g
s
.58434 .41884 m .58545 .41884 L .58406 .422 L p .742 .862 .936 r
F P
0 g
s
.58406 .422 m .58248 .422 L .58434 .41884 L p .742 .862 .936 r
F P
0 g
s
.59464 .40409 m .58681 .4189 L .58406 .422 L p .706 .817 .934 r
F P
0 g
s
.58406 .422 m .59524 .40084 L .59464 .40409 L p .706 .817 .934 r
F P
0 g
s
.46483 .56643 m .46622 .56074 L .46917 .55841 L p .349 .05 .309 r
F P
0 g
s
.47224 .55661 m .48657 .55321 L .48964 .55355 L p .571 .303 .471 r
F P
0 g
s
.48964 .55355 m .46917 .55841 L .47224 .55661 L p .571 .303 .471 r
F P
0 g
s
.50553 .45397 m .4907 .45748 L .48697 .45554 L p .733 .703 .823 r
F P
0 g
s
.48697 .45554 m .50817 .45053 L .50553 .45397 L p .733 .703 .823 r
F P
0 g
s
.46917 .55841 m .46719 .56654 L .46483 .56643 L p .349 .05 .309 r
F P
0 g
s
.48643 .55547 m .47209 .55887 L .46917 .55841 L p .528 .209 .371 r
F P
0 g
s
.46917 .55841 m .48964 .55355 L .48643 .55547 L p .528 .209 .371 r
F P
0 g
s
.46719 .56654 m .46917 .55841 L .47209 .55887 L p .528 .208 .369 r
F P
0 g
s
.46016 .45933 m .4536 .44489 L .45562 .44071 L p .665 .677 .852 r
F P
0 g
s
.67745 .38814 m .65118 .4102 L .65193 .40608 L p .652 .793 .95 r
F P
0 g
s
.6385 .40285 m .65193 .40608 L .65118 .4102 L p .663 .804 .95 r
F P
0 g
s
.65118 .4102 m .63201 .40562 L .6385 .40285 L p .663 .804 .95 r
F P
0 g
s
.67685 .39278 m .65844 .4082 L .65118 .4102 L p .648 .785 .947 r
F P
0 g
s
.65118 .4102 m .67745 .38814 L .67685 .39278 L p .648 .785 .947 r
F P
0 g
s
.59188 .40387 m .58434 .41884 L .58248 .422 L p .724 .837 .934 r
F P
0 g
s
.58248 .422 m .59324 .40062 L .59188 .40387 L p .724 .837 .934 r
F P
0 g
s
.36494 .44039 m .38045 .43266 L .38833 .43476 L p .624 .713 .91 r
F P
0 g
s
.58228 .5834 m .56989 .57817 L .56523 .57554 L p .556 0 0 r
F P
0 g
s
.65233 .62959 m .65108 .62819 L .6548 .6298 L p .037 .425 .866 r
F P
0 g
s
.6548 .6298 m .65658 .63181 L .65233 .62959 L p .037 .425 .866 r
F P
0 g
s
.52433 .44397 m .52446 .42967 L .52761 .42601 L p .741 .767 .873 r
F P
0 g
s
.66638 .63875 m .69435 .6477 L .70115 .65065 L p .254 .554 .93 r
F P
0 g
s
.45067 .57457 m .44596 .58148 L .44197 .58424 L p .232 0 .111 r
F P
0 g
s
.59145 .41886 m .60016 .40454 L .60314 .40149 L p .7 .821 .94 r
F P
0 g
s
.50527 .42955 m .50817 .45053 L .50432 .44814 L p .723 .733 .859 r
F P
0 g
s
.48947 .45165 m .50432 .44814 L .50817 .45053 L p .733 .732 .85 r
F P
0 g
s
.50817 .45053 m .48697 .45554 L .48947 .45165 L p .733 .732 .85 r
F P
0 g
s
.50884 .43214 m .51085 .44683 L .50817 .45053 L p .744 .748 .855 r
F P
0 g
s
.50817 .45053 m .50527 .42955 L .50884 .43214 L p .744 .748 .855 r
F P
0 g
s
.59251 .39972 m .58175 .42112 L .58306 .41797 L p .724 .837 .934 r
F P
0 g
s
.58183 .4182 m .58306 .41797 L .58175 .42112 L p .744 .86 .934 r
F P
0 g
s
.58175 .42112 m .58 .42144 L .58183 .4182 L p .744 .86 .934 r
F P
0 g
s
.27912 .67173 m .27527 .70215 L .28498 .69476 L p .782 .897 .925 r
F P
0 g
s
.27527 .70215 m .18165 .72622 L .19722 .72719 L p .758 .845 .917 r
F P
0 g
s
.26453 .67915 m .26202 .70045 L .27527 .70215 L p .746 .868 .936 r
F P
0 g
s
.27527 .70215 m .27912 .67173 L .26453 .67915 L p .746 .868 .936 r
F P
0 g
s
.18165 .72622 m .27527 .70215 L .26202 .70045 L p .746 .868 .936 r
F P
0 g
s
.4671 .45737 m .48252 .4533 L .48697 .45554 L p .703 .701 .845 r
F P
0 g
s
.59764 .5935 m .60787 .59985 L .61244 .60292 L p .466 0 0 r
F P
0 g
s
.48078 .4344 m .48697 .45554 L .48252 .4533 L p .697 .703 .852 r
F P
0 g
s
.48515 .43685 m .48947 .45165 L .48697 .45554 L p .724 .719 .845 r
F P
0 g
s
.48697 .45554 m .48078 .4344 L .48515 .43685 L p .724 .719 .845 r
F P
0 g
s
.59035 .39983 m .58 .42144 L .58043 .41822 L p .709 .815 .931 r
F P
0 g
s
.57571 .41837 m .58043 .41822 L .58 .42144 L p .726 .829 .929 r
F P
0 g
s
.58 .42144 m .57327 .42166 L .57571 .41837 L p .726 .829 .929 r
F P
0 g
s
.58908 .40307 m .58183 .4182 L .58 .42144 L p .725 .835 .932 r
F P
0 g
s
.58 .42144 m .59035 .39983 L .58908 .40307 L p .725 .835 .932 r
F P
0 g
s
.47209 .55887 m .47072 .56456 L .46719 .56654 L p .528 .208 .369 r
F P
0 g
s
.57067 .42447 m .56289 .42493 L .56214 .42231 L p .735 .817 .916 r
F P
0 g
s
.56214 .42231 m .57327 .42166 L .57067 .42447 L p .735 .817 .916 r
F P
0 g
s
.4927 .55212 m .50789 .55049 L .51135 .55122 L p .671 .38 .47 r
F P
0 g
s
.61244 .60292 m .59782 .59386 L .59764 .5935 L p .466 0 0 r
F P
0 g
s
.63021 .61016 m .61358 .60298 L .61244 .60292 L p 0 .365 .77 r
F P
0 g
s
.61244 .60292 m .63621 .61319 L .63021 .61016 L p 0 .365 .77 r
F P
0 g
s
.59782 .59386 m .61244 .60292 L .61358 .60298 L p 0 .363 .77 r
F P
0 g
s
.63621 .61319 m .61244 .60292 L .6175 .60568 L p 0 .398 .83 r
F P
0 g
s
.85503 .72035 m .78901 .7066 L .77536 .69898 L p .511 .655 .924 r
F P
0 g
s
.51135 .55122 m .48964 .55355 L .4927 .55212 L p .671 .38 .47 r
F P
0 g
s
.51005 .55855 m .5083 .55277 L .51135 .55122 L p .644 .307 .387 r
F P
0 g
s
.51135 .55122 m .51386 .55947 L .51005 .55855 L p .644 .307 .387 r
F P
0 g
s
.48964 .55355 m .51135 .55122 L .5083 .55277 L p .64 .301 .382 r
F P
0 g
s
.51386 .55947 m .51135 .55122 L .51499 .55259 L p .725 .355 .348 r
F P
0 g
s
.78624 .40893 m .76825 .39424 L .7717 .38781 L p .634 .752 .933 r
F P
0 g
s
.7717 .38781 m .79736 .40888 L .78624 .40893 L p .634 .752 .933 r
F P
0 g
s
.30845 .43034 m .32332 .42017 L .33347 .42214 L p .627 .733 .923 r
F P
0 g
s
.64932 .62622 m .65057 .62762 L .6548 .6298 L p .037 .425 .866 r
F P
0 g
s
.51499 .55259 m .51675 .55837 L .51386 .55947 L p .725 .355 .348 r
F P
0 g
s
.58545 .41884 m .59327 .40403 L .59524 .40084 L p .722 .838 .936 r
F P
0 g
s
.50432 .44814 m .50227 .43346 L .50527 .42955 L p .723 .733 .859 r
F P
0 g
s
.48252 .4533 m .47816 .43851 L .48078 .4344 L p .697 .703 .852 r
F P
0 g
s
.69053 .64256 m .66315 .63452 L .65658 .63181 L p .255 .554 .931 r
F P
0 g
s
.65658 .63181 m .69571 .64329 L .69053 .64256 L p .255 .554 .931 r
F P
0 g
s
.66084 .63177 m .66209 .63318 L .65658 .63181 L p .231 .554 .933 r
F P
0 g
s
.65658 .63181 m .6548 .6298 L .66084 .63177 L p .231 .554 .933 r
F P
0 g
s
.69571 .64329 m .65658 .63181 L .66209 .63318 L p .231 .554 .933 r
F P
0 g
s
.4536 .44489 m .43657 .45014 L .43128 .44822 L p .663 .674 .851 r
F P
0 g
s
.58228 .39943 m .57327 .42166 L .57279 .41839 L p .714 .81 .925 r
F P
0 g
s
.56499 .41884 m .57279 .41839 L .57327 .42166 L p .731 .821 .921 r
F P
0 g
s
.57327 .42166 m .56214 .42231 L .56499 .41884 L p .731 .821 .921 r
F P
0 g
s
.58203 .40281 m .57571 .41837 L .57327 .42166 L p .714 .81 .925 r
F P
0 g
s
.57327 .42166 m .58228 .39943 L .58203 .40281 L p .714 .81 .925 r
F P
0 g
s
.48655 .56093 m .48643 .55547 L .48964 .55355 L p .529 .212 .373 r
F P
0 g
s
.48964 .55355 m .48982 .56135 L .48655 .56093 L p .529 .212 .373 r
F P
0 g
s
.5083 .55277 m .4931 .5544 L .48964 .55355 L p .64 .301 .382 r
F P
0 g
s
.48982 .56135 m .48964 .55355 L .4931 .5544 L p .64 .297 .375 r
F P
0 g
s
.39223 .62133 m .40829 .61263 L .41323 .60818 L p .793 .996 .862 r
F P
0 g
s
.28498 .69476 m .28781 .67346 L .27912 .67173 L p .782 .897 .925 r
F P
0 g
s
.70099 .65908 m .69608 .65041 L .70115 .65065 L p .29 .552 .924 r
F P
0 g
s
.70115 .65065 m .70813 .66303 L .70099 .65908 L p .29 .552 .924 r
F P
0 g
s
.41431 .42452 m .43128 .44822 L .42514 .44608 L p .638 .69 .882 r
F P
0 g
s
.42084 .42688 m .43271 .44349 L .43128 .44822 L p .663 .7 .874 r
F P
0 g
s
.43128 .44822 m .41431 .42452 L .42084 .42688 L p .663 .7 .874 r
F P
0 g
s
.45562 .44071 m .43128 .44822 L .43271 .44349 L p .665 .702 .874 r
F P
0 g
s
.43128 .44822 m .45562 .44071 L .4536 .44489 L p .663 .674 .851 r
F P
0 g
s
.6175 .60568 m .63413 .61287 L .63621 .61319 L p 0 .398 .83 r
F P
0 g
s
.7285 .40558 m .76077 .38908 L .7717 .38781 L p .638 .763 .939 r
F P
0 g
s
.6548 .6298 m .65301 .6278 L .64932 .62622 L p .037 .425 .866 r
F P
0 g
s
.51675 .55837 m .53271 .5593 L .53667 .5608 L p .727 .357 .351 r
F P
0 g
s
.58306 .41797 m .59059 .40299 L .59251 .39972 L p .724 .837 .934 r
F P
0 g
s
.37505 .63887 m .34748 .65037 L .33962 .65607 L p .775 .967 .923 r
F P
0 g
s
.76976 .67731 m .77536 .69898 L .76522 .69324 L p .426 .617 .93 r
F P
0 g
s
.77536 .69898 m .86997 .71863 L .85503 .72035 L p .511 .655 .924 r
F P
0 g
s
.7847 .68296 m .78849 .69814 L .77536 .69898 L p .488 .664 .94 r
F P
0 g
s
.77536 .69898 m .76976 .67731 L .7847 .68296 L p .488 .664 .94 r
F P
0 g
s
.86997 .71863 m .77536 .69898 L .78849 .69814 L p .489 .664 .94 r
F P
0 g
s
.43061 .5942 m .41323 .60818 L .41776 .60441 L p 0 0 0 r
F P
0 g
s
.41323 .60818 m .39027 .62062 L .39223 .62133 L p .793 .996 .862 r
F P
0 g
s
.4249 .5979 m .41274 .60769 L .41323 .60818 L p .581 .936 .779 r
F P
0 g
s
.41776 .60441 m .42993 .59462 L .43061 .5942 L p 0 0 0 r
F P
0 g
s
.41323 .60818 m .43061 .5942 L .4249 .5979 L p .581 .936 .779 r
F P
0 g
s
.39027 .62062 m .41323 .60818 L .41274 .60769 L p .582 .936 .778 r
F P
0 g
s
.5592 .42538 m .54842 .42633 L .54672 .42366 L p .74 .8 .9 r
F P
0 g
s
.54672 .42366 m .56214 .42231 L .5592 .42538 L p .74 .8 .9 r
F P
0 g
s
.53667 .5608 m .51386 .55947 L .51675 .55837 L p .727 .357 .351 r
F P
0 g
s
.53822 .56836 m .53394 .5619 L .53667 .5608 L p .675 .237 .202 r
F P
0 g
s
.53667 .5608 m .54281 .57002 L .53822 .56836 L p .675 .237 .202 r
F P
0 g
s
.51386 .55947 m .53667 .5608 L .53394 .5619 L p .672 .233 .198 r
F P
0 g
s
.54281 .57002 m .53667 .5608 L .54075 .56291 L p .727 .246 .102 r
F P
0 g
s
.4931 .5544 m .49323 .55986 L .48982 .56135 L p .64 .297 .375 r
F P
0 g
s
.42514 .44608 m .41325 .42952 L .41431 .42452 L p .638 .69 .882 r
F P
0 g
s
.76121 .67808 m .71814 .66807 L .70813 .66303 L p .425 .617 .931 r
F P
0 g
s
.70813 .66303 m .76976 .67731 L .76121 .67808 L p .425 .617 .931 r
F P
0 g
s
.71126 .65437 m .71611 .66305 L .70813 .66303 L p .399 .624 .944 r
F P
0 g
s
.70813 .66303 m .70115 .65065 L .71126 .65437 L p .399 .624 .944 r
F P
0 g
s
.76976 .67731 m .70813 .66303 L .71611 .66305 L p .399 .624 .944 r
F P
0 g
s
.76522 .69324 m .76121 .67808 L .76976 .67731 L p .426 .617 .93 r
F P
0 g
s
.58043 .41822 m .58767 .40309 L .59035 .39983 L p .709 .815 .931 r
F P
0 g
s
.54075 .56291 m .54505 .56936 L .54281 .57002 L p .727 .246 .102 r
F P
0 g
s
.65193 .40608 m .67031 .39062 L .67745 .38814 L p .652 .793 .95 r
F P
0 g
s
.6874 .63884 m .66025 .63111 L .6548 .6298 L p .231 .554 .933 r
F P
0 g
s
.6548 .6298 m .69358 .64085 L .6874 .63884 L p .231 .554 .933 r
F P
0 g
s
.65301 .6278 m .6548 .6298 L .66025 .63111 L p .231 .554 .933 r
F P
0 g
s
.68799 .63951 m .66084 .63177 L .6548 .6298 L p .231 .554 .933 r
F P
0 g
s
.6548 .6298 m .69358 .64085 L .68799 .63951 L p .231 .554 .933 r
F P
0 g
s
.6441 .6211 m .64824 .62513 L .65301 .6278 L p 0 .414 .854 r
F P
0 g
s
.62719 .408 m .61574 .40611 L .61564 .4029 L p .669 .809 .95 r
F P
0 g
s
.61564 .4029 m .63201 .40562 L .62719 .408 L p .669 .809 .95 r
F P
0 g
s
.56907 .39918 m .56214 .42231 L .56066 .41901 L p .717 .8 .916 r
F P
0 g
s
.54985 .41995 m .56066 .41901 L .56214 .42231 L p .734 .808 .91 r
F P
0 g
s
.56214 .42231 m .54672 .42366 L .54985 .41995 L p .734 .808 .91 r
F P
0 g
s
.56985 .40265 m .56499 .41884 L .56214 .42231 L p .72 .803 .916 r
F P
0 g
s
.56214 .42231 m .56907 .39918 L .56985 .40265 L p .72 .803 .916 r
F P
0 g
s
.47072 .56456 m .48655 .56093 L .48982 .56135 L p .529 .21 .371 r
F P
0 g
s
.48982 .56135 m .46719 .56654 L .47072 .56456 L p .529 .21 .371 r
F P
0 g
s
.54505 .56936 m .56074 .57323 L .56523 .57554 L p .727 .245 .102 r
F P
0 g
s
.66209 .63318 m .68948 .64121 L .69571 .64329 L p .231 .554 .933 r
F P
0 g
s
.57279 .41839 m .57909 .40283 L .58228 .39943 L p .714 .81 .925 r
F P
0 g
s
.61358 .60298 m .60335 .59663 L .59782 .59386 L p 0 .363 .77 r
F P
0 g
s
.42993 .59462 m .43789 .58765 L .44197 .58424 L p 0 0 0 r
F P
0 g
s
.4608 .57502 m .46361 .56909 L .46719 .56654 L p .227 0 .103 r
F P
0 g
s
.46719 .56654 m .46319 .57501 L .4608 .57502 L p .227 0 .103 r
F P
0 g
s
.48608 .56336 m .47022 .56699 L .46719 .56654 L p .453 .065 .212 r
F P
0 g
s
.46719 .56654 m .48982 .56135 L .48608 .56336 L p .453 .065 .212 r
F P
0 g
s
.46319 .57501 m .46719 .56654 L .47022 .56699 L p .453 .063 .209 r
F P
0 g
s
.53394 .5619 m .51795 .56097 L .51386 .55947 L p .672 .233 .198 r
F P
0 g
s
.56523 .57554 m .54281 .57002 L .54505 .56936 L p .727 .245 .102 r
F P
0 g
s
.57177 .58262 m .56338 .57602 L .56523 .57554 L p .59 .027 0 r
F P
0 g
s
.56523 .57554 m .57724 .58497 L .57177 .58262 L p .59 .027 0 r
F P
0 g
s
.54281 .57002 m .56523 .57554 L .56338 .57602 L p .59 .027 0 r
F P
0 g
s
.57724 .58497 m .56523 .57554 L .56989 .57817 L p .557 0 0 r
F P
0 g
s
.43271 .44349 m .44976 .43821 L .45562 .44071 L p .665 .702 .874 r
F P
0 g
s
.65301 .6278 m .6471 .62203 L .6441 .6211 L p 0 .414 .854 r
F P
0 g
s
.68464 .63584 m .65773 .62842 L .65301 .6278 L p .207 .555 .933 r
F P
0 g
s
.65301 .6278 m .69145 .63841 L .68464 .63584 L p .207 .555 .933 r
F P
0 g
s
.6471 .62203 m .65301 .6278 L .65773 .62842 L p .208 .554 .933 r
F P
0 g
s
.66025 .63111 m .659 .6297 L .65301 .6278 L p .231 .554 .933 r
F P
0 g
s
.69145 .63841 m .65301 .6278 L .659 .6297 L p .231 .554 .933 r
F P
0 g
s
.46319 .57501 m .44197 .58424 L .44596 .58148 L p .228 0 .106 r
F P
0 g
s
.43061 .5942 m .43213 .59367 L p .43069 .59435 L 0 0 0 r
F P
0 g
s
.41202 .6041 m .4249 .5979 L .43061 .5942 L p .583 .937 .78 r
F P
0 g
s
.43061 .5942 m .41221 .60304 L .41202 .6041 L p .583 .937 .78 r
F P
0 g
s
.41221 .60304 m .43061 .5942 L p .43069 .59435 L 0 0 0 r
F P
0 g
s
.43061 .5942 m .42993 .59462 L p .43055 .59409 L 0 0 0 r
F P
0 g
s
.44197 .58424 m .43061 .5942 L p .43055 .59409 L 0 0 0 r
F P
0 g
s
.45862 .57775 m .44375 .58421 L .44197 .58424 L p .03 0 0 r
F P
0 g
s
.44197 .58424 m .46319 .57501 L .45862 .57775 L p .03 0 0 r
F P
0 g
s
.43061 .5942 m .44197 .58424 L .44375 .58421 L p .03 0 0 r
F P
0 g
s
.44596 .58148 m .4608 .57502 L .46319 .57501 L p .228 0 .106 r
F P
0 g
s
.54362 .42703 m .53025 .42868 L .52761 .42601 L p .74 .776 .882 r
F P
0 g
s
.52761 .42601 m .54672 .42366 L .54362 .42703 L p .74 .776 .882 r
F P
0 g
s
.41325 .42952 m .39507 .43666 L .38833 .43476 L p .64 .692 .883 r
F P
0 g
s
.56989 .57817 m .57832 .58478 L .57724 .58497 L p .557 0 0 r
F P
0 g
s
.65443 .3812 m .63201 .40562 L .63264 .40147 L p .666 .796 .944 r
F P
0 g
s
.62117 .39955 m .63264 .40147 L .63201 .40562 L p .677 .806 .944 r
F P
0 g
s
.63201 .40562 m .61564 .4029 L .62117 .39955 L p .677 .806 .944 r
F P
0 g
s
.65421 .38578 m .6385 .40285 L .63201 .40562 L p .663 .791 .943 r
F P
0 g
s
.63201 .40562 m .65443 .3812 L .65421 .38578 L p .663 .791 .943 r
F P
0 g
s
.36005 .40802 m .38833 .43476 L .38045 .43266 L p .628 .711 .906 r
F P
0 g
s
.36861 .41035 m .38839 .42909 L .38833 .43476 L p .645 .716 .899 r
F P
0 g
s
.38833 .43476 m .36005 .40802 L .36861 .41035 L p .645 .716 .899 r
F P
0 g
s
.41431 .42452 m .38833 .43476 L .38839 .42909 L p .643 .714 .899 r
F P
0 g
s
.38833 .43476 m .41431 .42452 L .41325 .42952 L p .64 .692 .883 r
F P
0 g
s
.47816 .43851 m .46057 .44291 L .45562 .44071 L p .691 .695 .848 r
F P
0 g
s
.38045 .43266 m .36065 .41398 L .36005 .40802 L p .628 .711 .906 r
F P
0 g
s
.49323 .55986 m .51005 .55855 L .51386 .55947 L p .643 .303 .381 r
F P
0 g
s
.55082 .39953 m .54672 .42366 L .5442 .42036 L p .719 .784 .904 r
F P
0 g
s
.5308 .42201 m .5442 .42036 L .54672 .42366 L p .734 .79 .897 r
F P
0 g
s
.54672 .42366 m .52761 .42601 L .5308 .42201 L p .734 .79 .897 r
F P
0 g
s
.55273 .40305 m .54985 .41995 L .54672 .42366 L p .724 .79 .904 r
F P
0 g
s
.54672 .42366 m .55082 .39953 L .55273 .40305 L p .724 .79 .904 r
F P
0 g
s
.47022 .56699 m .46744 .57292 L .46319 .57501 L p .453 .063 .209 r
F P
0 g
s
.41274 .60769 m .39666 .61639 L .39027 .62062 L p .582 .936 .778 r
F P
0 g
s
.26202 .70045 m .19627 .71732 L .18165 .72622 L p .746 .868 .936 r
F P
0 g
s
.56066 .41901 m .56549 .40281 L .56907 .39918 L p .717 .8 .916 r
F P
0 g
s
.51386 .55947 m .48982 .56135 L .49323 .55986 L p .643 .303 .381 r
F P
0 g
s
.44297 .41577 m .45562 .44071 L .44976 .43821 L p .664 .703 .876 r
F P
0 g
s
.449 .41855 m .45782 .43601 L .45562 .44071 L p .686 .714 .869 r
F P
0 g
s
.45562 .44071 m .44297 .41577 L .449 .41855 L p .686 .714 .869 r
F P
0 g
s
.48078 .4344 m .45562 .44071 L .45782 .43601 L p .691 .72 .871 r
F P
0 g
s
.45562 .44071 m .48078 .4344 L .47816 .43851 L p .691 .695 .848 r
F P
0 g
s
.51239 .56673 m .51043 .56097 L .51386 .55947 L p .587 .18 .237 r
F P
0 g
s
.51386 .55947 m .51669 .56771 L .51239 .56673 L p .587 .18 .237 r
F P
0 g
s
.48982 .56135 m .51386 .55947 L .51043 .56097 L p .585 .177 .234 r
F P
0 g
s
.51669 .56771 m .51386 .55947 L .51795 .56097 L p .671 .23 .193 r
F P
0 g
s
.52446 .42967 m .50884 .43214 L .50527 .42955 L p .731 .748 .866 r
F P
0 g
s
.50527 .42955 m .52761 .42601 L .52446 .42967 L p .731 .748 .866 r
F P
0 g
s
.659 .6297 m .68591 .63713 L .69145 .63841 L p .231 .554 .933 r
F P
0 g
s
.71611 .66305 m .7593 .67304 L .76976 .67731 L p .399 .624 .944 r
F P
0 g
s
.69387 .3997 m .67685 .39278 L .67745 .38814 L p .639 .777 .947 r
F P
0 g
s
.67745 .38814 m .70179 .39807 L .69387 .3997 L p .639 .777 .947 r
F P
0 g
s
.44375 .58421 m .43581 .59118 L .43061 .5942 L p .03 0 0 r
F P
0 g
s
.56338 .57602 m .54767 .57215 L .54281 .57002 L p .59 .027 0 r
F P
0 g
s
.51795 .56097 m .51995 .56674 L .51669 .56771 L p .671 .23 .193 r
F P
0 g
s
.48558 .56897 m .48608 .56336 L .48982 .56135 L p .456 .069 .216 r
F P
0 g
s
.48982 .56135 m .48913 .56937 L .48558 .56897 L p .456 .069 .216 r
F P
0 g
s
.51043 .56097 m .49358 .56228 L .48982 .56135 L p .585 .177 .234 r
F P
0 g
s
.48913 .56937 m .48982 .56135 L .49358 .56228 L p .585 .175 .231 r
F P
0 g
s
.61173 .4057 m .60299 .40471 L .60314 .40149 L p .683 .807 .941 r
F P
0 g
s
.60314 .40149 m .61564 .4029 L .61173 .4057 L p .683 .807 .941 r
F P
0 g
s
.44976 .43821 m .44089 .42078 L .44297 .41577 L p .664 .703 .876 r
F P
0 g
s
.50227 .43346 m .48515 .43685 L .48078 .4344 L p .715 .72 .854 r
F P
0 g
s
.78849 .69814 m .85487 .71189 L .86997 .71863 L p .489 .664 .94 r
F P
0 g
s
.63413 .61287 m .64176 .61906 L .6471 .62203 L p 0 .397 .83 r
F P
0 g
s
.65773 .62842 m .6536 .62438 L .6471 .62203 L p .208 .554 .933 r
F P
0 g
s
.48078 .4344 m .50527 .42955 L .50227 .43346 L p .715 .72 .854 r
F P
0 g
s
.57832 .58478 m .59271 .591 L .59782 .59386 L p .557 0 0 r
F P
0 g
s
.52797 .40096 m .52761 .42601 L .52402 .42278 L p .714 .764 .892 r
F P
0 g
s
.50836 .42526 m .52402 .42278 L .52761 .42601 L p .727 .766 .884 r
F P
0 g
s
.52761 .42601 m .50527 .42955 L .50836 .42526 L p .727 .766 .884 r
F P
0 g
s
.53108 .40447 m .5308 .42201 L .52761 .42601 L p .724 .773 .891 r
F P
0 g
s
.52761 .42601 m .52797 .40096 L .53108 .40447 L p .724 .773 .891 r
F P
0 g
s
.36065 .41398 m .34204 .42383 L .33347 .42214 L p .633 .715 .906 r
F P
0 g
s
.74273 .37039 m .70179 .39807 L .70383 .39226 L p .646 .771 .939 r
F P
0 g
s
.68677 .38527 m .70383 .39226 L .70179 .39807 L p .652 .777 .94 r
F P
0 g
s
.70179 .39807 m .67745 .38814 L .68677 .38527 L p .652 .777 .94 r
F P
0 g
s
.74049 .37695 m .71183 .39627 L .70179 .39807 L p .644 .764 .936 r
F P
0 g
s
.70179 .39807 m .74273 .37039 L .74049 .37695 L p .644 .764 .936 r
F P
0 g
s
.5442 .42036 m .54704 .40346 L .55082 .39953 L p .719 .784 .904 r
F P
0 g
s
.63264 .40147 m .64832 .38436 L .65443 .3812 L p .666 .796 .944 r
F P
0 g
s
.28781 .67346 m .33005 .66249 L .33962 .65607 L p .782 .897 .924 r
F P
0 g
s
.28901 .39209 m .33347 .42214 L .32332 .42017 L p .632 .731 .919 r
F P
0 g
s
.30015 .39423 m .33127 .41531 L .33347 .42214 L p .64 .732 .915 r
F P
0 g
s
.33347 .42214 m .28901 .39209 L .30015 .39423 L p .64 .732 .915 r
F P
0 g
s
.36005 .40802 m .33347 .42214 L .33127 .41531 L p .637 .73 .915 r
F P
0 g
s
.33347 .42214 m .36005 .40802 L .36065 .41398 L p .633 .715 .906 r
F P
0 g
s
.59782 .59386 m .57724 .58497 L .57832 .58478 L p .557 0 0 r
F P
0 g
s
.61221 .59981 m .59755 .59369 L .59782 .59386 L p 0 .316 .665 r
F P
0 g
s
.59782 .59386 m .61878 .6026 L .61221 .59981 L p 0 .316 .665 r
F P
0 g
s
.57724 .58497 m .59782 .59386 L .59755 .59369 L p 0 .316 .665 r
F P
0 g
s
.61878 .6026 m .59782 .59386 L .60335 .59663 L p 0 .359 .765 r
F P
0 g
s
.49358 .56228 m .49312 .56789 L .48913 .56937 L p .585 .175 .231 r
F P
0 g
s
.38839 .42909 m .40659 .4219 L .41431 .42452 L p .643 .714 .899 r
F P
0 g
s
.45782 .43601 m .47546 .43159 L .48078 .4344 L p .691 .72 .871 r
F P
0 g
s
.47261 .40884 m .48078 .4344 L .47546 .43159 L p .686 .721 .876 r
F P
0 g
s
.47786 .41198 m .48355 .42988 L .48078 .4344 L p .705 .732 .872 r
F P
0 g
s
.48078 .4344 m .47261 .40884 L .47786 .41198 L p .705 .732 .872 r
F P
0 g
s
.50527 .42955 m .48078 .4344 L .48355 .42988 L p .713 .742 .875 r
F P
0 g
s
.6471 .62203 m .63621 .61319 L .63413 .61287 L p 0 .397 .83 r
F P
0 g
s
.67687 .62851 m .6508 .62196 L .6471 .62203 L p .168 .554 .93 r
F P
0 g
s
.6471 .62203 m .68433 .6314 L .67687 .62851 L p .168 .554 .93 r
F P
0 g
s
.63621 .61319 m .6471 .62203 L .6508 .62196 L p .168 .553 .93 r
F P
0 g
s
.68433 .6314 m .6471 .62203 L .6536 .62438 L p .206 .554 .933 r
F P
0 g
s
.32332 .42017 m .29221 .3992 L .28901 .39209 L p .632 .731 .919 r
F P
0 g
s
.50152 .40398 m .50527 .42955 L .50072 .42647 L p .703 .742 .882 r
F P
0 g
s
.48355 .42988 m .50072 .42647 L .50527 .42955 L p .713 .742 .875 r
F P
0 g
s
.50576 .40736 m .50836 .42526 L .50527 .42955 L p .718 .752 .879 r
F P
0 g
s
.50527 .42955 m .50152 .40398 L .50576 .40736 L p .718 .752 .879 r
F P
0 g
s
.63473 .37669 m .61564 .4029 L .61641 .39872 L p .676 .795 .938 r
F P
0 g
s
.60764 .39772 m .61641 .39872 L .61564 .4029 L p .687 .806 .938 r
F P
0 g
s
.61564 .4029 m .60314 .40149 L .60764 .39772 L p .687 .806 .938 r
F P
0 g
s
.63455 .38122 m .62117 .39955 L .61564 .4029 L p .675 .793 .938 r
F P
0 g
s
.61564 .4029 m .63473 .37669 L .63455 .38122 L p .675 .793 .938 r
F P
0 g
s
.35447 .6317 m .33962 .65607 L .34748 .65037 L p .775 .967 .923 r
F P
0 g
s
.33962 .65607 m .27912 .67173 L .28781 .67346 L p .782 .897 .924 r
F P
0 g
s
.34356 .63713 m .33324 .65421 L .33962 .65607 L p .748 .926 .949 r
F P
0 g
s
.33962 .65607 m .35447 .6317 L .34356 .63713 L p .748 .926 .949 r
F P
0 g
s
.27912 .67173 m .33962 .65607 L .33324 .65421 L p .748 .926 .949 r
F P
0 g
s
.60335 .59663 m .61802 .60276 L .61878 .6026 L p 0 .359 .765 r
F P
0 g
s
.60016 .40454 m .59464 .40409 L .59524 .40084 L p .691 .804 .935 r
F P
0 g
s
.59524 .40084 m .60314 .40149 L .60016 .40454 L p .691 .804 .935 r
F P
0 g
s
.52402 .42278 m .52425 .40525 L .52797 .40096 L p .714 .764 .892 r
F P
0 g
s
.47546 .43159 m .46972 .41371 L .47261 .40884 L p .686 .721 .876 r
F P
0 g
s
.34748 .65037 m .35793 .63332 L .35447 .6317 L p .775 .967 .923 r
F P
0 g
s
.51995 .56674 m .53822 .56836 L .54281 .57002 L p .674 .234 .197 r
F P
0 g
s
.69435 .6477 m .69053 .64256 L .69571 .64329 L p .255 .554 .93 r
F P
0 g
s
.69571 .64329 m .70115 .65065 L .69435 .6477 L p .255 .554 .93 r
F P
0 g
s
.6536 .62438 m .67965 .63094 L .68433 .6314 L p .206 .554 .933 r
F P
0 g
s
.50072 .42647 m .49806 .40858 L .50152 .40398 L p .703 .742 .882 r
F P
0 g
s
.54281 .57002 m .51669 .56771 L .51995 .56674 L p .674 .234 .197 r
F P
0 g
s
.54531 .57645 m .53974 .57081 L .54281 .57002 L p .56 .032 0 r
F P
0 g
s
.54281 .57002 m .5508 .57808 L .54531 .57645 L p .56 .032 0 r
F P
0 g
s
.51669 .56771 m .54281 .57002 L .53974 .57081 L p .559 .03 0 r
F P
0 g
s
.5508 .57808 m .54281 .57002 L .54767 .57215 L p .59 .027 0 r
F P
0 g
s
.59327 .40403 m .59188 .40387 L .59324 .40062 L p .707 .817 .933 r
F P
0 g
s
.59324 .40062 m .59524 .40084 L .59327 .40403 L p .707 .817 .933 r
F P
0 g
s
.46744 .57292 m .48558 .56897 L .48913 .56937 L p .455 .067 .213 r
F P
0 g
s
.48913 .56937 m .46319 .57501 L .46744 .57292 L p .455 .067 .213 r
F P
0 g
s
.18527 .68489 m .18165 .72622 L .19627 .71732 L p .746 .867 .936 r
F P
0 g
s
.29221 .3992 m .27418 .41235 L .26328 .41097 L p .637 .734 .918 r
F P
0 g
s
.54767 .57215 m .55328 .5778 L .5508 .57808 L p .59 .027 0 r
F P
0 g
s
.61957 .37407 m .60314 .40149 L .60428 .39728 L p .682 .793 .933 r
F P
0 g
s
.59873 .39683 m .60428 .39728 L .60314 .40149 L p .693 .803 .934 r
F P
0 g
s
.60314 .40149 m .59524 .40084 L .59873 .39683 L p .693 .803 .934 r
F P
0 g
s
.61916 .37855 m .60764 .39772 L .60314 .40149 L p .682 .792 .933 r
F P
0 g
s
.60314 .40149 m .61957 .37407 L .61916 .37855 L p .682 .792 .933 r
F P
0 g
s
.44089 .42078 m .42084 .42688 L .41431 .42452 L p .662 .701 .875 r
F P
0 g
s
.4536 .58344 m .45862 .57775 L .46319 .57501 L p .031 0 0 r
F P
0 g
s
.46319 .57501 m .45605 .58314 L .4536 .58344 L p .031 0 0 r
F P
0 g
s
.48456 .57135 m .46637 .5753 L .46319 .57501 L p .315 0 0 r
F P
0 g
s
.46319 .57501 m .48913 .56937 L .48456 .57135 L p .315 0 0 r
F P
0 g
s
.45605 .58314 m .46319 .57501 L .46637 .5753 L p .315 0 0 r
F P
0 g
s
.26328 .41097 m .28901 .39209 L .29221 .3992 L p .637 .734 .918 r
F P
0 g
s
.59755 .59369 m .58313 .58747 L .57724 .58497 L p 0 .316 .665 r
F P
0 g
s
.75352 .66196 m .71126 .65437 L .70115 .65065 L p .398 .624 .944 r
F P
0 g
s
.70115 .65065 m .76157 .66147 L .75352 .66196 L p .398 .624 .944 r
F P
0 g
s
.70538 .64584 m .70917 .651 L .70115 .65065 L p .378 .63 .953 r
F P
0 g
s
.70115 .65065 m .69571 .64329 L .70538 .64584 L p .378 .63 .953 r
F P
0 g
s
.76157 .66147 m .70115 .65065 L .70917 .651 L p .378 .63 .953 r
F P
0 g
s
.61641 .39872 m .62975 .38036 L .63473 .37669 L p .676 .795 .938 r
F P
0 g
s
.59059 .40299 m .58908 .40307 L .59035 .39983 L p .708 .815 .932 r
F P
0 g
s
.59035 .39983 m .59251 .39972 L .59059 .40299 L p .708 .815 .932 r
F P
0 g
s
.70383 .39226 m .73247 .37284 L .74273 .37039 L p .646 .771 .939 r
F P
0 g
s
.6508 .62196 m .64318 .61576 L .63621 .61319 L p .168 .553 .93 r
F P
0 g
s
.39134 .39531 m .41431 .42452 L .40659 .4219 L p .645 .714 .898 r
F P
0 g
s
.39955 .39828 m .4156 .41876 L .41431 .42452 L p .661 .72 .892 r
F P
0 g
s
.41431 .42452 m .39134 .39531 L .39955 .39828 L p .661 .72 .892 r
F P
0 g
s
.44297 .41577 m .41431 .42452 L .4156 .41876 L p .663 .721 .892 r
F P
0 g
s
.41431 .42452 m .44297 .41577 L .44089 .42078 L p .662 .701 .875 r
F P
0 g
s
.33127 .41531 m .34988 .40538 L .36005 .40802 L p .637 .73 .915 r
F P
0 g
s
.58767 .40309 m .58203 .40281 L .58228 .39943 L p .7 .798 .926 r
F P
0 g
s
.58228 .39943 m .59035 .39983 L .58767 .40309 L p .7 .798 .926 r
F P
0 g
s
.35793 .63332 m .38295 .62555 L .39027 .62062 L p .775 .967 .923 r
F P
0 g
s
.61006 .37274 m .59524 .40084 L .59709 .39663 L p .694 .801 .932 r
F P
0 g
s
.59569 .39647 m .59709 .39663 L .59524 .40084 L p .707 .817 .933 r
F P
0 g
s
.59524 .40084 m .59324 .40062 L .59569 .39647 L p .707 .817 .933 r
F P
0 g
s
.60912 .37716 m .59873 .39683 L .59524 .40084 L p .686 .791 .93 r
F P
0 g
s
.59524 .40084 m .61006 .37274 L .60912 .37716 L p .686 .791 .93 r
F P
0 g
s
.53974 .57081 m .52144 .56919 L .51669 .56771 L p .559 .03 0 r
F P
0 g
s
.41221 .60304 m .39027 .62062 L .39666 .61639 L p .583 .937 .78 r
F P
0 g
s
.39027 .62062 m .35447 .6317 L .35793 .63332 L p .775 .967 .923 r
F P
0 g
s
.40406 .60696 m .38871 .61928 L .39027 .62062 L p .66 .966 .919 r
F P
0 g
s
.39027 .62062 m .41221 .60304 L .40406 .60696 L p .66 .966 .919 r
F P
0 g
s
.35447 .6317 m .39027 .62062 L .38871 .61928 L p .661 .966 .918 r
F P
0 g
s
.40659 .4219 m .39049 .40149 L .39134 .39531 L p .645 .714 .898 r
F P
0 g
s
.39666 .61639 m .41202 .6041 L .41221 .60304 L p .583 .937 .78 r
F P
0 g
s
.60568 .37665 m .59569 .39647 L .59324 .40062 L p .695 .8 .93 r
F P
0 g
s
.59324 .40062 m .60751 .37229 L .60568 .37665 L p .695 .8 .93 r
F P
0 g
s
.43581 .59118 m .4536 .58344 L .45605 .58314 L p .03 0 0 r
F P
0 g
s
.45605 .58314 m .43061 .5942 L .43581 .59118 L p .03 0 0 r
F P
0 g
s
.49312 .56789 m .51239 .56673 L .51669 .56771 L p .587 .178 .234 r
F P
0 g
s
.44995 .58591 m .43213 .59367 L .43061 .5942 L p 0 0 0 r
F P
0 g
s
.43061 .5942 m .45605 .58314 L .44995 .58591 L p 0 0 0 r
F P
0 g
s
.19627 .71732 m .19907 .68839 L .18527 .68489 L p .746 .867 .936 r
F P
0 g
s
.46637 .5753 m .46139 .58099 L .45605 .58314 L p .315 0 0 r
F P
0 g
s
.57909 .40283 m .56985 .40265 L .56907 .39918 L p .705 .793 .919 r
F P
0 g
s
.56907 .39918 m .58228 .39943 L .57909 .40283 L p .705 .793 .919 r
F P
0 g
s
.51669 .56771 m .48913 .56937 L .49312 .56789 L p .587 .178 .234 r
F P
0 g
s
.60677 .37137 m .59251 .39972 L .59426 .39552 L p .695 .8 .93 r
F P
0 g
s
.59274 .3956 m .59426 .39552 L .59251 .39972 L p .708 .816 .932 r
F P
0 g
s
.59251 .39972 m .59035 .39983 L .59274 .3956 L p .708 .816 .932 r
F P
0 g
s
.61802 .60276 m .63021 .61016 L .63621 .61319 L p 0 .361 .766 r
F P
0 g
s
.60405 .37127 m .59035 .39983 L .59105 .3955 L p .688 .789 .928 r
F P
0 g
s
.58539 .39522 m .59105 .3955 L .59035 .39983 L p .698 .799 .927 r
F P
0 g
s
.59035 .39983 m .58228 .39943 L .58539 .39522 L p .698 .799 .927 r
F P
0 g
s
.60234 .37561 m .59274 .3956 L .59035 .39983 L p .696 .799 .929 r
F P
0 g
s
.59035 .39983 m .60405 .37127 L .60234 .37561 L p .696 .799 .929 r
F P
0 g
s
.60428 .39728 m .61576 .37809 L .61957 .37407 L p .682 .793 .933 r
F P
0 g
s
.67031 .39062 m .65421 .38578 L .65443 .3812 L p .653 .783 .943 r
F P
0 g
s
.65443 .3812 m .67745 .38814 L .67031 .39062 L p .653 .783 .943 r
F P
0 g
s
.33324 .65421 m .2908 .66516 L .27912 .67173 L p .748 .926 .949 r
F P
0 g
s
.51483 .57402 m .51265 .56902 L .51669 .56771 L p .472 0 0 r
F P
0 g
s
.51669 .56771 m .51985 .57486 L .51483 .57402 L p .472 0 0 r
F P
0 g
s
.48913 .56937 m .51669 .56771 L .51265 .56902 L p .471 0 0 r
F P
0 g
s
.51985 .57486 m .51669 .56771 L .52144 .56919 L p .558 .029 0 r
F P
0 g
s
.76077 .38908 m .74049 .37695 L .74273 .37039 L p .64 .76 .935 r
F P
0 g
s
.74273 .37039 m .7717 .38781 L .76077 .38908 L p .64 .76 .935 r
F P
0 g
s
.48305 .57633 m .48456 .57135 L .48913 .56937 L p .314 0 0 r
F P
0 g
s
.48913 .56937 m .48703 .57648 L .48305 .57633 L p .314 0 0 r
F P
0 g
s
.51265 .56902 m .49333 .57018 L .48913 .56937 L p .471 0 0 r
F P
0 g
s
.48703 .57648 m .48913 .56937 L .49333 .57018 L p .47 0 0 r
F P
0 g
s
.68948 .64121 m .68799 .63951 L .69358 .64085 L p .231 .554 .933 r
F P
0 g
s
.69358 .64085 m .69571 .64329 L .68948 .64121 L p .231 .554 .933 r
F P
0 g
s
.55328 .5778 m .57177 .58262 L .57724 .58497 L p .59 .027 0 r
F P
0 g
s
.63621 .61319 m .61878 .6026 L .61802 .60276 L p 0 .361 .766 r
F P
0 g
s
.66278 .61772 m .63845 .61252 L .63621 .61319 L p .11 .55 .916 r
F P
0 g
s
.63621 .61319 m .67098 .62064 L .66278 .61772 L p .11 .55 .916 r
F P
0 g
s
.61878 .6026 m .63621 .61319 L .63845 .61252 L p .111 .552 .916 r
F P
0 g
s
.67098 .62064 m .63621 .61319 L .64318 .61576 L p .165 .552 .929 r
F P
0 g
s
.4156 .41876 m .43569 .41261 L .44297 .41577 L p .663 .721 .892 r
F P
0 g
s
.70917 .651 m .75149 .65857 L .76157 .66147 L p .378 .63 .953 r
F P
0 g
s
.59432 .37027 m .58228 .39943 L .58188 .39501 L p .691 .787 .924 r
F P
0 g
s
.57261 .39483 m .58188 .39501 L .58228 .39943 L p .702 .795 .923 r
F P
0 g
s
.58228 .39943 m .56907 .39918 L .57261 .39483 L p .702 .795 .923 r
F P
0 g
s
.59383 .37481 m .58539 .39522 L .58228 .39943 L p .691 .787 .924 r
F P
0 g
s
.58228 .39943 m .59432 .37027 L .59383 .37481 L p .691 .787 .924 r
F P
0 g
s
.56549 .40281 m .55273 .40305 L .55082 .39953 L p .709 .783 .91 r
F P
0 g
s
.55082 .39953 m .56907 .39918 L .56549 .40281 L p .709 .783 .91 r
F P
0 g
s
.59709 .39663 m .60746 .37696 L .61006 .37274 L p .694 .801 .932 r
F P
0 g
s
.52144 .56919 m .52368 .57419 L .51985 .57486 L p .558 .029 0 r
F P
0 g
s
.57724 .58497 m .5508 .57808 L .55328 .5778 L p .59 .027 0 r
F P
0 g
s
.58697 .58964 m .57534 .58484 L .57724 .58497 L p .326 0 0 r
F P
0 g
s
.5939 .59183 m .57724 .58497 L .58313 .58747 L p 0 .318 .666 r
F P
0 g
s
.58313 .58747 m .59481 .59228 L .5939 .59183 L p 0 .318 .666 r
F P
0 g
s
.57724 .58497 m .5939 .59183 L .58697 .58964 L p .326 0 0 r
F P
0 g
s
.5508 .57808 m .57724 .58497 L .57534 .58484 L p .326 0 0 r
F P
0 g
s
.71302 .35688 m .67745 .38814 L .6789 .3823 L p .655 .775 .937 r
F P
0 g
s
.66276 .3774 m .6789 .3823 L .67745 .38814 L p .661 .781 .938 r
F P
0 g
s
.67745 .38814 m .65443 .3812 L .66276 .3774 L p .661 .781 .938 r
F P
0 g
s
.71169 .36343 m .68677 .38527 L .67745 .38814 L p .653 .77 .935 r
F P
0 g
s
.67745 .38814 m .71302 .35688 L .71169 .36343 L p .653 .77 .935 r
F P
0 g
s
.46972 .41371 m .449 .41855 L .44297 .41577 L p .681 .715 .874 r
F P
0 g
s
.49333 .57018 m .49189 .57516 L .48703 .57648 L p .47 0 0 r
F P
0 g
s
.59426 .39552 m .60424 .37568 L .60677 .37137 L p .695 .8 .93 r
F P
0 g
s
.68591 .63713 m .6874 .63884 L .69358 .64085 L p .231 .554 .933 r
F P
0 g
s
.64318 .61576 m .66752 .62099 L .67098 .62064 L p .165 .552 .929 r
F P
0 g
s
.43213 .59367 m .41926 .59985 L .41221 .60304 L p 0 0 0 r
F P
0 g
s
.86451 .68945 m .86997 .71863 L .85487 .71189 L p .489 .664 .939 r
F P
0 g
s
.59105 .3955 m .60063 .3755 L .60405 .37127 L p .688 .789 .928 r
F P
0 g
s
.74675 .65195 m .70538 .64584 L .69571 .64329 L p .377 .63 .953 r
F P
0 g
s
.69571 .64329 m .75484 .652 L .74675 .65195 L p .377 .63 .953 r
F P
0 g
s
.7026 .64245 m .70409 .64416 L .69571 .64329 L p .365 .634 .958 r
F P
0 g
s
.69571 .64329 m .69358 .64085 L .7026 .64245 L p .365 .634 .958 r
F P
0 g
s
.75484 .652 m .69571 .64329 L .70409 .64416 L p .365 .634 .958 r
F P
0 g
s
.57826 .3691 m .56907 .39918 L .56742 .39471 L p .693 .781 .919 r
F P
0 g
s
.55462 .39495 m .56742 .39471 L .56907 .39918 L p .705 .788 .916 r
F P
0 g
s
.56907 .39918 m .55082 .39953 L .55462 .39495 L p .705 .788 .916 r
F P
0 g
s
.57907 .37378 m .57261 .39483 L .56907 .39918 L p .695 .783 .919 r
F P
0 g
s
.56907 .39918 m .57826 .3691 L .57907 .37378 L p .695 .783 .919 r
F P
0 g
s
.42581 .38471 m .44297 .41577 L .43569 .41261 L p .661 .722 .894 r
F P
0 g
s
.43332 .38831 m .4453 .41007 L .44297 .41577 L p .676 .729 .889 r
F P
0 g
s
.44297 .41577 m .42581 .38471 L .43332 .38831 L p .676 .729 .889 r
F P
0 g
s
.47261 .40884 m .44297 .41577 L .4453 .41007 L p .68 .733 .89 r
F P
0 g
s
.44297 .41577 m .47261 .40884 L .46972 .41371 L p .681 .715 .874 r
F P
0 g
s
.39049 .40149 m .36861 .41035 L .36005 .40802 L p .646 .715 .898 r
F P
0 g
s
.54704 .40346 m .53108 .40447 L .52797 .40096 L p .71 .769 .898 r
F P
0 g
s
.52797 .40096 m .55082 .39953 L .54704 .40346 L p .71 .769 .898 r
F P
0 g
s
.38871 .61928 m .36364 .62703 L .35447 .6317 L p .661 .966 .918 r
F P
0 g
s
.85487 .71189 m .85087 .69148 L .86451 .68945 L p .489 .664 .939 r
F P
0 g
s
.7593 .67304 m .75352 .66196 L .76157 .66147 L p .398 .624 .944 r
F P
0 g
s
.76157 .66147 m .76976 .67731 L .7593 .67304 L p .398 .624 .944 r
F P
0 g
s
.69358 .64085 m .69145 .63841 L .68591 .63713 L p .231 .554 .933 r
F P
0 g
s
.32148 .37393 m .36005 .40802 L .34988 .40538 L p .639 .729 .913 r
F P
0 g
s
.33254 .37694 m .35952 .40086 L .36005 .40802 L p .649 .731 .909 r
F P
0 g
s
.36005 .40802 m .32148 .37393 L .33254 .37694 L p .649 .731 .909 r
F P
0 g
s
.39134 .39531 m .36005 .40802 L .35952 .40086 L p .648 .73 .909 r
F P
0 g
s
.36005 .40802 m .39134 .39531 L .39049 .40149 L p .646 .715 .898 r
F P
0 g
s
.58188 .39501 m .59029 .37459 L .59432 .37027 L p .691 .787 .924 r
F P
0 g
s
.85087 .69148 m .7847 .68296 L .76976 .67731 L p .489 .664 .94 r
F P
0 g
s
.76976 .67731 m .86451 .68945 L .85087 .69148 L p .489 .664 .94 r
F P
0 g
s
.77672 .66525 m .78237 .67636 L .76976 .67731 L p .472 .672 .951 r
F P
0 g
s
.76976 .67731 m .76157 .66147 L .77672 .66525 L p .472 .672 .951 r
F P
0 g
s
.86451 .68945 m .76976 .67731 L .78237 .67636 L p .472 .672 .952 r
F P
0 g
s
.49806 .40858 m .47786 .41198 L .47261 .40884 L p .697 .732 .878 r
F P
0 g
s
.43569 .41261 m .42364 .39089 L .42581 .38471 L p .661 .722 .894 r
F P
0 g
s
.74291 .64722 m .70188 .64162 L .69358 .64085 L p .365 .634 .958 r
F P
0 g
s
.69358 .64085 m .7522 .64886 L .74291 .64722 L p .365 .634 .958 r
F P
0 g
s
.69145 .63841 m .69358 .64085 L .70188 .64162 L p .365 .634 .958 r
F P
0 g
s
.74363 .64806 m .7026 .64245 L .69358 .64085 L p .365 .634 .958 r
F P
0 g
s
.69358 .64085 m .7522 .64886 L .74363 .64806 L p .365 .634 .958 r
F P
0 g
s
.67965 .63094 m .68464 .63584 L .69145 .63841 L p .206 .554 .933 r
F P
0 g
s
.52425 .40525 m .50576 .40736 L .50152 .40398 L p .707 .751 .887 r
F P
0 g
s
.50152 .40398 m .52797 .40096 L .52425 .40525 L p .707 .751 .887 r
F P
0 g
s
.57534 .58484 m .55681 .58001 L .5508 .57808 L p .326 0 0 r
F P
0 g
s
.55614 .36849 m .55082 .39953 L .54784 .39508 L p .695 .773 .912 r
F P
0 g
s
.53181 .39609 m .54784 .39508 L .55082 .39953 L p .706 .777 .907 r
F P
0 g
s
.55082 .39953 m .52797 .40096 L .53181 .39609 L p .706 .777 .907 r
F P
0 g
s
.55838 .37323 m .55462 .39495 L .55082 .39953 L p .698 .776 .912 r
F P
0 g
s
.55082 .39953 m .55614 .36849 L .55838 .37323 L p .698 .776 .912 r
F P
0 g
s
.63845 .61252 m .62624 .6051 L .61878 .6026 L p .111 .552 .916 r
F P
0 g
s
.34988 .40538 m .32287 .38158 L .32148 .37393 L p .639 .729 .913 r
F P
0 g
s
.47261 .40884 m .50152 .40398 L .49806 .40858 L p .697 .732 .878 r
F P
0 g
s
.64832 .38436 m .63455 .38122 L .63473 .37669 L p .664 .784 .938 r
F P
0 g
s
.63473 .37669 m .65443 .3812 L .64832 .38436 L p .664 .784 .938 r
F P
0 g
s
.6789 .3823 m .70377 .36038 L .71302 .35688 L p .655 .775 .937 r
F P
0 g
s
.4453 .41007 m .46608 .4052 L .47261 .40884 L p .68 .733 .89 r
F P
0 g
s
.56742 .39471 m .57382 .37365 L .57826 .3691 L p .693 .781 .919 r
F P
0 g
s
.4616 .37683 m .47261 .40884 L .46608 .4052 L p .676 .733 .893 r
F P
0 g
s
.46807 .38093 m .47573 .40335 L .47261 .40884 L p .688 .741 .891 r
F P
0 g
s
.47261 .40884 m .4616 .37683 L .46807 .38093 L p .688 .741 .891 r
F P
0 g
s
.50152 .40398 m .47261 .40884 L .47573 .40335 L p .694 .748 .893 r
F P
0 g
s
.70409 .64416 m .74548 .65026 L .75484 .652 L p .365 .634 .958 r
F P
0 g
s
.69145 .63841 m .68433 .6314 L .67965 .63094 L p .206 .554 .933 r
F P
0 g
s
.7395 .64339 m .69882 .63829 L .69145 .63841 L p .352 .639 .962 r
F P
0 g
s
.69145 .63841 m .74954 .64571 L .7395 .64339 L p .352 .639 .962 r
F P
0 g
s
.68433 .6314 m .69145 .63841 L .69882 .63829 L p .352 .639 .962 r
F P
0 g
s
.70188 .64162 m .70039 .63991 L .69145 .63841 L p .365 .634 .958 r
F P
0 g
s
.74954 .64571 m .69145 .63841 L .70039 .63991 L p .365 .634 .958 r
F P
0 g
s
.52847 .36907 m .52797 .40096 L .52369 .39666 L p .693 .761 .904 r
F P
0 g
s
.50513 .39877 m .52369 .39666 L .52797 .40096 L p .702 .763 .899 r
F P
0 g
s
.52797 .40096 m .50152 .40398 L .50513 .39877 L p .702 .763 .899 r
F P
0 g
s
.53221 .37377 m .53181 .39609 L .52797 .40096 L p .699 .766 .904 r
F P
0 g
s
.52797 .40096 m .52847 .36907 L .53221 .37377 L p .699 .766 .904 r
F P
0 g
s
.46139 .58099 m .48305 .57633 L .48703 .57648 L p .314 0 0 r
F P
0 g
s
.48703 .57648 m .45605 .58314 L .46139 .58099 L p .314 0 0 r
F P
0 g
s
.52368 .57419 m .54531 .57645 L .5508 .57808 L p .559 .03 0 r
F P
0 g
s
.49649 .37167 m .50152 .40398 L .49601 .39994 L p .687 .747 .897 r
F P
0 g
s
.47573 .40335 m .49601 .39994 L .50152 .40398 L p .694 .748 .893 r
F P
0 g
s
.50165 .37616 m .50513 .39877 L .50152 .40398 L p .696 .754 .896 r
F P
0 g
s
.50152 .40398 m .49649 .37167 L .50165 .37616 L p .696 .754 .896 r
F P
0 g
s
.44147 .5902 m .44995 .58591 L .45605 .58314 L p 0 0 0 r
F P
0 g
s
.45943 .58293 m .45102 .5872 L .44397 .58925 L p .057 0 0 r
F P
0 g
s
.44397 .58925 m .44764 .58809 L p .44681 .58819 L .247 .761 .796 r
F P
0 g
s
.45605 .58314 m .44397 .58925 L p .44169 .5901 L 0 0 0 r
F P
0 g
s
.44397 .58925 m .45605 .58314 L .45943 .58293 L p .057 0 0 r
F P
0 g
s
.42431 .59093 m .44397 .58925 L p .44681 .58819 L .247 .761 .796 r
F P
0 g
s
.44397 .58925 m .44147 .5902 L p .44169 .5901 L 0 0 0 r
F P
0 g
s
.48115 .57826 m .45943 .58293 L .45605 .58314 L p .057 0 0 r
F P
0 g
s
.45605 .58314 m .48703 .57648 L .48115 .57826 L p .057 0 0 r
F P
0 g
s
.68487 .3471 m .65443 .3812 L .65565 .37536 L p .662 .776 .934 r
F P
0 g
s
.64183 .37218 m .65565 .37536 L .65443 .3812 L p .669 .783 .934 r
F P
0 g
s
.65443 .3812 m .63473 .37669 L .64183 .37218 L p .669 .783 .934 r
F P
0 g
s
.6841 .35358 m .66276 .3774 L .65443 .3812 L p .661 .774 .933 r
F P
0 g
s
.65443 .3812 m .68487 .3471 L .6841 .35358 L p .661 .774 .933 r
F P
0 g
s
.54784 .39508 m .55153 .37336 L .55614 .36849 L p .695 .773 .912 r
F P
0 g
s
.59481 .59228 m .61221 .59981 L .61878 .6026 L p 0 .317 .666 r
F P
0 g
s
.5508 .57808 m .51985 .57486 L .52368 .57419 L p .559 .03 0 r
F P
0 g
s
.55472 .58195 m .54725 .57831 L .5508 .57808 L p .324 0 0 r
F P
0 g
s
.5508 .57808 m .56155 .58329 L .55472 .58195 L p .324 0 0 r
F P
0 g
s
.51985 .57486 m .5508 .57808 L .54725 .57831 L p .325 0 0 r
F P
0 g
s
.56155 .58329 m .5508 .57808 L .55681 .58001 L p .326 0 0 r
F P
0 g
s
.19907 .68839 m .26453 .67915 L .27912 .67173 L p .746 .867 .936 r
F P
0 g
s
.46608 .4052 m .45833 .38281 L .4616 .37683 L p .676 .733 .893 r
F P
0 g
s
.35952 .40086 m .38145 .39191 L .39134 .39531 L p .648 .73 .909 r
F P
0 g
s
.61878 .6026 m .5939 .59183 L .59481 .59228 L p 0 .317 .666 r
F P
0 g
s
.64052 .60483 m .61913 .60152 L .61878 .6026 L p .055 .552 .886 r
F P
0 g
s
.61878 .6026 m .64938 .60736 L .64052 .60483 L p .055 .552 .886 r
F P
0 g
s
.5939 .59183 m .61878 .6026 L .61913 .60152 L p .053 .55 .885 r
F P
0 g
s
.64938 .60736 m .61878 .6026 L .62624 .6051 L p .116 .554 .918 r
F P
0 g
s
.52369 .39666 m .52399 .37434 L .52847 .36907 L p .693 .761 .904 r
F P
0 g
s
.70039 .63991 m .74105 .64502 L .74954 .64571 L p .365 .634 .958 r
F P
0 g
s
.29872 .63931 m .27912 .67173 L .2908 .66516 L p .749 .925 .949 r
F P
0 g
s
.27912 .67173 m .18527 .68489 L .19907 .68839 L p .746 .867 .936 r
F P
0 g
s
.28224 .64529 m .26868 .66803 L .27912 .67173 L p .721 .887 .957 r
F P
0 g
s
.27912 .67173 m .29872 .63931 L .28224 .64529 L p .721 .887 .957 r
F P
0 g
s
.18527 .68489 m .27912 .67173 L .26868 .66803 L p .721 .887 .957 r
F P
0 g
s
.55681 .58001 m .56437 .58367 L .56155 .58329 L p .326 0 0 r
F P
0 g
s
.49601 .39994 m .49244 .37734 L .49649 .37167 L p .687 .747 .897 r
F P
0 g
s
.78237 .67636 m .84879 .68483 L .86451 .68945 L p .472 .672 .952 r
F P
0 g
s
.32287 .38158 m .30015 .39423 L .28901 .39209 L p .643 .731 .913 r
F P
0 g
s
.62975 .38036 m .61916 .37855 L .61957 .37407 L p .672 .784 .933 r
F P
0 g
s
.61957 .37407 m .63473 .37669 L .62975 .38036 L p .672 .784 .933 r
F P
0 g
s
.66752 .62099 m .67687 .62851 L .68433 .6314 L p .165 .553 .929 r
F P
0 g
s
.49189 .57516 m .51483 .57402 L .51985 .57486 L p .472 0 0 r
F P
0 g
s
.51985 .57486 m .48703 .57648 L .49189 .57516 L p .472 0 0 r
F P
0 g
s
.2908 .66516 m .30461 .6425 L .29872 .63931 L p .749 .925 .949 r
F P
0 g
s
.28901 .39209 m .32148 .37393 L .32287 .38158 L p .643 .731 .913 r
F P
0 g
s
.69882 .63829 m .69385 .63338 L .68433 .6314 L p .352 .639 .962 r
F P
0 g
s
.62624 .6051 m .64767 .60844 L .64938 .60736 L p .116 .554 .918 r
F P
0 g
s
.54725 .57831 m .52554 .57605 L .51985 .57486 L p .325 0 0 r
F P
0 g
s
.42364 .39089 m .39955 .39828 L .39134 .39531 L p .66 .72 .893 r
F P
0 g
s
.68433 .6314 m .67098 .62064 L .66752 .62099 L p .165 .553 .929 r
F P
0 g
s
.7298 .63397 m .69036 .63034 L .68433 .6314 L p .332 .646 .967 r
F P
0 g
s
.68433 .6314 m .74066 .63663 L .7298 .63397 L p .332 .646 .967 r
F P
0 g
s
.67098 .62064 m .68433 .6314 L .69036 .63034 L p .332 .646 .967 r
F P
0 g
s
.74066 .63663 m .68433 .6314 L .69385 .63338 L p .352 .639 .962 r
F P
0 g
s
.41926 .59985 m .44147 .5902 L .44397 .58925 L p 0 0 0 r
F P
0 g
s
.44397 .58925 m .41221 .60304 L .41926 .59985 L p 0 0 0 r
F P
0 g
s
.73247 .37284 m .71169 .36343 L .71302 .35688 L p .647 .765 .935 r
F P
0 g
s
.71302 .35688 m .74273 .37039 L .73247 .37284 L p .647 .765 .935 r
F P
0 g
s
.65565 .37536 m .67693 .35147 L .68487 .3471 L p .662 .776 .934 r
F P
0 g
s
.51721 .57878 m .51487 .57575 L .51985 .57486 L p .242 0 0 r
F P
0 g
s
.51985 .57486 m .52327 .57918 L .51721 .57878 L p .242 0 0 r
F P
0 g
s
.48703 .57648 m .51985 .57486 L .51487 .57575 L p .24 0 0 r
F P
0 g
s
.52327 .57918 m .51985 .57486 L .52554 .57605 L p .326 0 0 r
F P
0 g
s
.47797 .58143 m .48115 .57826 L .48703 .57648 L p .056 0 0 r
F P
0 g
s
.52327 .57918 m .48254 .58099 L .48876 .58004 L p .241 0 0 r
F P
0 g
s
.48254 .58099 m .48829 .58057 L p .48789 .58056 L .083 .643 .757 r
F P
0 g
s
.48703 .57648 m .48254 .58099 L p .47813 .58134 L .056 0 0 r
F P
0 g
s
.48254 .58099 m .48703 .57648 L .49185 .57689 L p .24 0 0 r
F P
0 g
s
.49185 .57689 m .48876 .58004 L .48254 .58099 L p .24 0 0 r
F P
0 g
s
.47434 .58022 m .48254 .58099 L p .48789 .58056 L .083 .643 .757 r
F P
0 g
s
.48254 .58099 m .47797 .58143 L p .47813 .58134 L .056 0 0 r
F P
0 g
s
.51487 .57575 m .49185 .57689 L .48703 .57648 L p .24 0 0 r
F P
0 g
s
.66062 .34061 m .63473 .37669 L .63603 .37088 L p .667 .776 .931 r
F P
0 g
s
.62539 .36903 m .63603 .37088 L .63473 .37669 L p .674 .783 .931 r
F P
0 g
s
.63473 .37669 m .61957 .37407 L .62539 .36903 L p .674 .783 .931 r
F P
0 g
s
.65999 .34695 m .64183 .37218 L .63473 .37669 L p .667 .775 .93 r
F P
0 g
s
.63473 .37669 m .66062 .34061 L .65999 .34695 L p .667 .775 .93 r
F P
0 g
s
.38362 .6111 m .40406 .60696 L .41221 .60304 L p .661 .966 .919 r
F P
0 g
s
.41221 .60304 m .38301 .60892 L .38362 .6111 L p .661 .966 .919 r
F P
0 g
s
.43557 .59188 m .4133 .60156 L .41221 .60304 L p .464 .89 .868 r
F P
0 g
s
.41221 .60304 m .44397 .58925 L .43557 .59188 L p .464 .89 .868 r
F P
0 g
s
.38301 .60892 m .41221 .60304 L .4133 .60156 L p .464 .89 .868 r
F P
0 g
s
.61576 .37809 m .60912 .37716 L .61006 .37274 L p .677 .782 .929 r
F P
0 g
s
.61006 .37274 m .61957 .37407 L .61576 .37809 L p .677 .782 .929 r
F P
0 g
s
.35986 .35777 m .39134 .39531 L .38145 .39191 L p .649 .73 .908 r
F P
0 g
s
.37041 .36169 m .39239 .38801 L .39134 .39531 L p .659 .733 .904 r
F P
0 g
s
.39134 .39531 m .35986 .35777 L .37041 .36169 L p .659 .733 .904 r
F P
0 g
s
.42581 .38471 m .39134 .39531 L .39239 .38801 L p .66 .734 .904 r
F P
0 g
s
.39134 .39531 m .42581 .38471 L .42364 .39089 L p .66 .72 .893 r
F P
0 g
s
.30461 .6425 m .34356 .63713 L .35447 .6317 L p .748 .925 .949 r
F P
0 g
s
.61913 .60152 m .60168 .59396 L .5939 .59183 L p .053 .55 .885 r
F P
0 g
s
.38301 .60892 m .35447 .6317 L .36364 .62703 L p .662 .966 .919 r
F P
0 g
s
.35447 .6317 m .29872 .63931 L .30461 .6425 L p .748 .925 .949 r
F P
0 g
s
.37114 .61291 m .35118 .62891 L .35447 .6317 L p .681 .937 .966 r
F P
0 g
s
.35447 .6317 m .38301 .60892 L .37114 .61291 L p .681 .937 .966 r
F P
0 g
s
.29872 .63931 m .35447 .6317 L .35118 .62891 L p .68 .936 .966 r
F P
0 g
s
.36364 .62703 m .38362 .6111 L .38301 .60892 L p .662 .966 .919 r
F P
0 g
s
.52554 .57605 m .52798 .57908 L .52327 .57918 L p .326 0 0 r
F P
0 g
s
.60746 .37696 m .60568 .37665 L .60751 .37229 L p .684 .788 .929 r
F P
0 g
s
.60751 .37229 m .61006 .37274 L .60746 .37696 L p .684 .788 .929 r
F P
0 g
s
.69385 .63338 m .73327 .63705 L .74066 .63663 L p .352 .639 .962 r
F P
0 g
s
.38145 .39191 m .35937 .36569 L .35986 .35777 L p .649 .73 .908 r
F P
0 g
s
.75149 .65857 m .74675 .65195 L .75484 .652 L p .377 .63 .953 r
F P
0 g
s
.75484 .652 m .76157 .66147 L .75149 .65857 L p .377 .63 .953 r
F P
0 g
s
.60424 .37568 m .60234 .37561 L .60405 .37127 L p .685 .787 .928 r
F P
0 g
s
.60405 .37127 m .60677 .37137 L .60424 .37568 L p .685 .787 .928 r
F P
0 g
s
.64191 .33658 m .61957 .37407 L .62128 .36829 L p .671 .775 .928 r
F P
0 g
s
.6146 .36735 m .62128 .36829 L .61957 .37407 L p .677 .782 .929 r
F P
0 g
s
.61957 .37407 m .61006 .37274 L .6146 .36735 L p .677 .782 .929 r
F P
0 g
s
.64106 .34281 m .62539 .36903 L .61957 .37407 L p .671 .775 .928 r
F P
0 g
s
.61957 .37407 m .64191 .33658 L .64106 .34281 L p .671 .775 .928 r
F P
0 g
s
.60063 .3755 m .59383 .37481 L .59432 .37027 L p .682 .779 .924 r
F P
0 g
s
.59432 .37027 m .60405 .37127 L .60063 .3755 L p .682 .779 .924 r
F P
0 g
s
.56437 .58367 m .58697 .58964 L .5939 .59183 L p .326 0 0 r
F P
0 g
s
.63603 .37088 m .65412 .34561 L .66062 .34061 L p .667 .776 .931 r
F P
0 g
s
.84181 .66992 m .77672 .66525 L .76157 .66147 L p .472 .672 .951 r
F P
0 g
s
.76157 .66147 m .8547 .6681 L .84181 .66992 L p .472 .672 .951 r
F P
0 g
s
.76946 .65415 m .77413 .66079 L .76157 .66147 L p .46 .679 .959 r
F P
0 g
s
.76157 .66147 m .75484 .652 L .76946 .65415 L p .46 .679 .959 r
F P
0 g
s
.8547 .6681 m .76157 .66147 L .77413 .66079 L p .46 .679 .959 r
F P
0 g
s
.69036 .63034 m .68102 .62278 L .67098 .62064 L p .332 .646 .967 r
F P
0 g
s
.26868 .66803 m .20278 .67721 L .18527 .68489 L p .721 .887 .957 r
F P
0 g
s
.63016 .33448 m .61006 .37274 L .61259 .36702 L p .677 .779 .927 r
F P
0 g
s
.6108 .3667 m .61259 .36702 L .61006 .37274 L p .684 .788 .929 r
F P
0 g
s
.61006 .37274 m .60751 .37229 L .6108 .3667 L p .684 .788 .929 r
F P
0 g
s
.6287 .34058 m .6146 .36735 L .61006 .37274 L p .673 .774 .926 r
F P
0 g
s
.61006 .37274 m .63016 .33448 L .6287 .34058 L p .673 .774 .926 r
F P
0 g
s
.39239 .38801 m .41657 .38055 L .42581 .38471 L p .66 .734 .904 r
F P
0 g
s
.4133 .60156 m .39289 .60565 L .38301 .60892 L p .464 .89 .868 r
F P
0 g
s
.59029 .37459 m .57907 .37378 L .57826 .3691 L p .685 .776 .92 r
F P
0 g
s
.57826 .3691 m .59432 .37027 L .59029 .37459 L p .685 .776 .92 r
F P
0 g
s
.45833 .38281 m .43332 .38831 L .42581 .38471 L p .673 .729 .892 r
F P
0 g
s
.62438 .33976 m .6108 .3667 L .60751 .37229 L p .677 .778 .926 r
F P
0 g
s
.60751 .37229 m .6269 .3338 L .62438 .33976 L p .677 .778 .926 r
F P
0 g
s
.5939 .59183 m .56155 .58329 L .56437 .58367 L p .326 0 0 r
F P
0 g
s
.60877 .59226 m .59198 .59072 L .5939 .59183 L p .002 .55 .829 r
F P
0 g
s
.5939 .59183 m .61797 .59405 L .60877 .59226 L p .002 .55 .829 r
F P
0 g
s
.56155 .58329 m .5939 .59183 L .59198 .59072 L p .003 .551 .829 r
F P
0 g
s
.61797 .59405 m .5939 .59183 L .60168 .59396 L p .048 .548 .883 r
F P
0 g
s
.62616 .33284 m .60677 .37137 L .60917 .36566 L p .677 .778 .926 r
F P
0 g
s
.60726 .36558 m .60917 .36566 L .60677 .37137 L p .685 .787 .928 r
F P
0 g
s
.60677 .37137 m .60405 .37127 L .60726 .36558 L p .685 .787 .928 r
F P
0 g
s
.62271 .33251 m .60405 .37127 L .60518 .36536 L p .674 .773 .925 r
F P
0 g
s
.59835 .36466 m .60518 .36536 L .60405 .37127 L p .681 .78 .925 r
F P
0 g
s
.60405 .37127 m .59432 .37027 L .59835 .36466 L p .681 .78 .925 r
F P
0 g
s
.62032 .33846 m .60726 .36558 L .60405 .37127 L p .678 .778 .926 r
F P
0 g
s
.60405 .37127 m .62271 .33251 L .62032 .33846 L p .678 .778 .926 r
F P
0 g
s
.64767 .60844 m .66278 .61772 L .67098 .62064 L p .115 .552 .917 r
F P
0 g
s
.57382 .37365 m .55838 .37323 L .55614 .36849 L p .688 .771 .915 r
F P
0 g
s
.55614 .36849 m .57826 .3691 L .57382 .37365 L p .688 .771 .915 r
F P
0 g
s
.62128 .36829 m .6369 .34204 L .64191 .33658 L p .671 .775 .928 r
F P
0 g
s
.40225 .34454 m .42581 .38471 L .41657 .38055 L p .659 .734 .905 r
F P
0 g
s
.41184 .34935 m .42826 .3775 L .42581 .38471 L p .668 .739 .903 r
F P
0 g
s
.42581 .38471 m .40225 .34454 L .41184 .34935 L p .668 .739 .903 r
F P
0 g
s
.4616 .37683 m .42581 .38471 L .42826 .3775 L p .671 .741 .903 r
F P
0 g
s
.42581 .38471 m .4616 .37683 L .45833 .38281 L p .673 .729 .892 r
F P
0 g
s
.61067 .33085 m .59432 .37027 L .59406 .36422 L p .676 .772 .923 r
F P
0 g
s
.58278 .36339 m .59406 .36422 L .59432 .37027 L p .683 .778 .922 r
F P
0 g
s
.59432 .37027 m .57826 .3691 L .58278 .36339 L p .683 .778 .922 r
F P
0 g
s
.60982 .33707 m .59835 .36466 L .59432 .37027 L p .676 .772 .923 r
F P
0 g
s
.59432 .37027 m .61067 .33085 L .60982 .33707 L p .676 .772 .923 r
F P
0 g
s
.60168 .59396 m .61856 .59554 L .61797 .59405 L p .048 .548 .883 r
F P
0 g
s
.35118 .62891 m .31212 .6342 L .29872 .63931 L p .68 .936 .966 r
F P
0 g
s
.67098 .62064 m .64938 .60736 L .64767 .60844 L p .115 .552 .917 r
F P
0 g
s
.71179 .62 m .67502 .61867 L .67098 .62064 L p .308 .657 .972 r
F P
0 g
s
.67098 .62064 m .72352 .62259 L .71179 .62 L p .308 .657 .972 r
F P
0 g
s
.64938 .60736 m .67098 .62064 L .67502 .61867 L p .307 .657 .971 r
F P
0 g
s
.72352 .62259 m .67098 .62064 L .68102 .62278 L p .332 .646 .967 r
F P
0 g
s
.61259 .36702 m .62666 .34024 L .63016 .33448 L p .677 .779 .927 r
F P
0 g
s
.74548 .65026 m .74363 .64806 L .7522 .64886 L p .365 .634 .958 r
F P
0 g
s
.7522 .64886 m .75484 .652 L .74548 .65026 L p .365 .634 .958 r
F P
0 g
s
.49244 .37734 m .46807 .38093 L .4616 .37683 L p .682 .74 .895 r
F P
0 g
s
.55153 .37336 m .53221 .37377 L .52847 .36907 L p .689 .763 .908 r
F P
0 g
s
.52847 .36907 m .55614 .36849 L .55153 .37336 L p .689 .763 .908 r
F P
0 g
s
.70377 .36038 m .6841 .35358 L .68487 .3471 L p .655 .768 .933 r
F P
0 g
s
.68487 .3471 m .71302 .35688 L .70377 .36038 L p .655 .768 .933 r
F P
0 g
s
.45102 .5872 m .47797 .58143 L .48254 .58099 L p .057 0 0 r
F P
0 g
s
.48254 .58099 m .44397 .58925 L .45102 .5872 L p .057 0 0 r
F P
0 g
s
.41657 .38055 m .40002 .35248 L .40225 .34454 L p .659 .734 .905 r
F P
0 g
s
.77413 .66079 m .83937 .66541 L .8547 .6681 L p .46 .679 .959 r
F P
0 g
s
.59073 .32876 m .57826 .3691 L .57642 .36299 L p .678 .769 .92 r
F P
0 g
s
.5609 .36255 m .57642 .36299 L .57826 .3691 L p .685 .774 .918 r
F P
0 g
s
.57826 .3691 m .55614 .36849 L .5609 .36255 L p .685 .774 .918 r
F P
0 g
s
.59155 .33516 m .58278 .36339 L .57826 .3691 L p .678 .77 .92 r
F P
0 g
s
.57826 .3691 m .59073 .32876 L .59155 .33516 L p .678 .77 .92 r
F P
0 g
s
.35937 .36569 m .33254 .37694 L .32148 .37393 L p .65 .731 .908 r
F P
0 g
s
.60917 .36566 m .62273 .33868 L .62616 .33284 L p .677 .778 .926 r
F P
0 g
s
.60518 .36536 m .61822 .33822 L .62271 .33251 L p .674 .773 .925 r
F P
0 g
s
.4616 .37683 m .49649 .37167 L .49244 .37734 L p .682 .74 .895 r
F P
0 g
s
.52399 .37434 m .50165 .37616 L .49649 .37167 L p .688 .752 .901 r
F P
0 g
s
.49649 .37167 m .52847 .36907 L .52399 .37434 L p .688 .752 .901 r
F P
0 g
s
.59198 .59072 m .56928 .58473 L .56155 .58329 L p .003 .551 .829 r
F P
0 g
s
.68102 .62278 m .71779 .62418 L .72352 .62259 L p .332 .646 .967 r
F P
0 g
s
.42176 .59309 m .43557 .59188 L .44397 .58925 L p .465 .891 .868 r
F P
0 g
s
.44397 .58925 m .42431 .59093 L .42176 .59309 L p .465 .891 .868 r
F P
0 g
s
.47471 .58229 m .44764 .58809 L .44397 .58925 L p .247 .761 .796 r
F P
0 g
s
.44397 .58925 m .48254 .58099 L .47471 .58229 L p .247 .761 .796 r
F P
0 g
s
.32148 .37393 m .35986 .35777 L .35937 .36569 L p .65 .731 .908 r
F P
0 g
s
.52798 .57908 m .55472 .58195 L .56155 .58329 L p .325 0 0 r
F P
0 g
s
.74105 .64502 m .74291 .64722 L .7522 .64886 L p .365 .634 .958 r
F P
0 g
s
.44637 .33503 m .4616 .37683 L .45339 .37195 L p .668 .741 .905 r
F P
0 g
s
.42826 .3775 m .45339 .37195 L .4616 .37683 L p .671 .741 .903 r
F P
0 g
s
.45457 .34059 m .46516 .36986 L .4616 .37683 L p .676 .746 .904 r
F P
0 g
s
.4616 .37683 m .44637 .33503 L .45457 .34059 L p .676 .746 .904 r
F P
0 g
s
.49649 .37167 m .4616 .37683 L .46516 .36986 L p .679 .75 .905 r
F P
0 g
s
.56341 .32709 m .55614 .36849 L .55261 .36242 L p .678 .764 .916 r
F P
0 g
s
.53319 .36283 m .55261 .36242 L .55614 .36849 L p .686 .768 .914 r
F P
0 g
s
.55614 .36849 m .52847 .36907 L .53319 .36283 L p .686 .768 .914 r
F P
0 g
s
.56604 .33358 m .5609 .36255 L .55614 .36849 L p .681 .766 .916 r
F P
0 g
s
.55614 .36849 m .56341 .32709 L .56604 .33358 L p .681 .766 .916 r
F P
0 g
s
.59406 .36422 m .60547 .33662 L .61067 .33085 L p .676 .772 .923 r
F P
0 g
s
.83342 .6564 m .76946 .65415 L .75484 .652 L p .46 .679 .959 r
F P
0 g
s
.75484 .652 m .84628 .65519 L .83342 .6564 L p .46 .679 .959 r
F P
0 g
s
.766 .64971 m .76783 .65192 L .75484 .652 L p .454 .684 .964 r
F P
0 g
s
.75484 .652 m .7522 .64886 L .766 .64971 L p .454 .684 .964 r
F P
0 g
s
.84628 .65519 m .75484 .652 L .76783 .65192 L p .455 .683 .963 r
F P
0 g
s
.84879 .68483 m .84181 .66992 L .8547 .6681 L p .471 .672 .952 r
F P
0 g
s
.8547 .6681 m .86451 .68945 L .84879 .68483 L p .471 .672 .952 r
F P
0 g
s
.7522 .64886 m .74954 .64571 L .74105 .64502 L p .365 .634 .958 r
F P
0 g
s
.5292 .32694 m .52847 .36907 L .52325 .36323 L p .678 .758 .911 r
F P
0 g
s
.50079 .36506 m .52325 .36323 L .52847 .36907 L p .684 .76 .909 r
F P
0 g
s
.52847 .36907 m .49649 .37167 L .50079 .36506 L p .684 .76 .909 r
F P
0 g
s
.53376 .33334 m .53319 .36283 L .52847 .36907 L p .681 .761 .911 r
F P
0 g
s
.52847 .36907 m .5292 .32694 L .53376 .33334 L p .681 .761 .911 r
F P
0 g
s
.56155 .58329 m .52327 .57918 L .52798 .57908 L p .325 0 0 r
F P
0 g
s
.56763 .58249 m .55725 .58258 L .56155 .58329 L p .005 .575 .774 r
F P
0 g
s
.56155 .58329 m .5765 .58318 L .56763 .58249 L p .005 .575 .774 r
F P
0 g
s
.52327 .57918 m .56155 .58329 L .55725 .58258 L p .005 .575 .774 r
F P
0 g
s
.5765 .58318 m .56155 .58329 L .56928 .58473 L p .004 .551 .83 r
F P
0 g
s
.48956 .32934 m .49649 .37167 L .48965 .36624 L p .674 .75 .907 r
F P
0 g
s
.46516 .36986 m .48965 .36624 L .49649 .37167 L p .679 .75 .905 r
F P
0 g
s
.49602 .33542 m .50079 .36506 L .49649 .37167 L p .68 .754 .907 r
F P
0 g
s
.49649 .37167 m .48956 .32934 L .49602 .33542 L p .68 .754 .907 r
F P
0 g
s
.67502 .61867 m .65989 .60934 L .64938 .60736 L p .307 .657 .971 r
F P
0 g
s
.57642 .36299 m .5851 .33474 L .59073 .32876 L p .678 .769 .92 r
F P
0 g
s
.73327 .63705 m .7395 .64339 L .74954 .64571 L p .352 .639 .962 r
F P
0 g
s
.82865 .65 m .76507 .6486 L .7522 .64886 L p .453 .684 .964 r
F P
0 g
s
.7522 .64886 m .84301 .65087 L .82865 .65 L p .453 .684 .964 r
F P
0 g
s
.74954 .64571 m .7522 .64886 L .76507 .6486 L p .454 .684 .964 r
F P
0 g
s
.82955 .65113 m .766 .64971 L .7522 .64886 L p .455 .683 .963 r
F P
0 g
s
.7522 .64886 m .84301 .65087 L .82955 .65113 L p .455 .683 .963 r
F P
0 g
s
.48876 .58004 m .51721 .57878 L .52327 .57918 L p .241 0 0 r
F P
0 g
s
.45339 .37195 m .44264 .34273 L .44637 .33503 L p .668 .741 .905 r
F P
0 g
s
.44764 .58809 m .43395 .58925 L .42431 .59093 L p .247 .761 .796 r
F P
0 g
s
.56928 .58473 m .57981 .58467 L .5765 .58318 L p .004 .551 .83 r
F P
0 g
s
.55261 .36242 m .55764 .33344 L .56341 .32709 L p .678 .764 .916 r
F P
0 g
s
.67693 .35147 m .65999 .34695 L .66062 .34061 L p .661 .77 .93 r
F P
0 g
s
.66062 .34061 m .68487 .3471 L .67693 .35147 L p .661 .77 .93 r
F P
0 g
s
.61856 .59554 m .64052 .60483 L .64938 .60736 L p .051 .55 .883 r
F P
0 g
s
.76783 .65192 m .83186 .65414 L .84628 .65519 L p .455 .683 .963 r
F P
0 g
s
.48965 .36624 m .48472 .33662 L .48956 .32934 L p .674 .75 .907 r
F P
0 g
s
.74954 .64571 m .74066 .63663 L .73327 .63705 L p .352 .639 .962 r
F P
0 g
s
.82424 .64483 m .76122 .64425 L .74954 .64571 L p .447 .688 .968 r
F P
0 g
s
.74954 .64571 m .83953 .64658 L .82424 .64483 L p .447 .688 .968 r
F P
0 g
s
.74066 .63663 m .74954 .64571 L .76122 .64425 L p .448 .688 .968 r
F P
0 g
s
.76507 .6486 m .76323 .64639 L .74954 .64571 L p .454 .684 .964 r
F P
0 g
s
.83953 .64658 m .74954 .64571 L .76323 .64639 L p .453 .684 .964 r
F P
0 g
s
.46888 .58177 m .47471 .58229 L .48254 .58099 L p .246 .76 .795 r
F P
0 g
s
.48254 .58099 m .47434 .58022 L .46888 .58177 L p .246 .76 .795 r
F P
0 g
s
.51688 .5793 m .48829 .58057 L .48254 .58099 L p .082 .642 .756 r
F P
0 g
s
.48254 .58099 m .52327 .57918 L .51688 .5793 L p .082 .642 .756 r
F P
0 g
s
.52325 .36323 m .52368 .33375 L .5292 .32694 L p .678 .758 .911 r
F P
0 g
s
.51947 .57842 m .51688 .5793 L .52327 .57918 L p .08 .641 .755 r
F P
0 g
s
.52327 .57918 m .52711 .57791 L .51947 .57842 L p .08 .641 .755 r
F P
0 g
s
.55725 .58258 m .53038 .57969 L .52327 .57918 L p .005 .575 .774 r
F P
0 g
s
.52711 .57791 m .52327 .57918 L .53038 .57969 L p .005 .575 .774 r
F P
0 g
s
.21078 .64012 m .18527 .68489 L .20278 .67721 L p .721 .887 .957 r
F P
0 g
s
.64938 .60736 m .61797 .59405 L .61856 .59554 L p .051 .55 .883 r
F P
0 g
s
.6829 .60326 m .65074 .60477 L .64938 .60736 L p .279 .675 .971 r
F P
0 g
s
.64938 .60736 m .69539 .60526 L .6829 .60326 L p .279 .675 .971 r
F P
0 g
s
.61797 .59405 m .64938 .60736 L .65074 .60477 L p .279 .675 .971 r
F P
0 g
s
.69539 .60526 m .64938 .60736 L .65989 .60934 L p .307 .657 .971 r
F P
0 g
s
.39289 .60565 m .42176 .59309 L .42431 .59093 L p .465 .891 .868 r
F P
0 g
s
.42431 .59093 m .38301 .60892 L .39289 .60565 L p .465 .891 .868 r
F P
0 g
s
.20278 .67721 m .22085 .64595 L .21078 .64012 L p .721 .887 .957 r
F P
0 g
s
.33884 .61286 m .37114 .61291 L .38301 .60892 L p .68 .937 .966 r
F P
0 g
s
.38301 .60892 m .33685 .60875 L .33884 .61286 L p .68 .937 .966 r
F P
0 g
s
.41234 .59314 m .38337 .60577 L .38301 .60892 L p .572 .915 .968 r
F P
0 g
s
.38301 .60892 m .42431 .59093 L .41234 .59314 L p .572 .915 .968 r
F P
0 g
s
.33685 .60875 m .38301 .60892 L .38337 .60577 L p .573 .915 .968 r
F P
0 g
s
.40002 .35248 m .37041 .36169 L .35986 .35777 L p .658 .733 .905 r
F P
0 g
s
.53038 .57969 m .53316 .57882 L .52711 .57791 L p .005 .575 .774 r
F P
0 g
s
.48829 .58057 m .48264 .58002 L .47434 .58022 L p .083 .643 .757 r
F P
0 g
s
.76323 .64639 m .8262 .64701 L .83953 .64658 L p .453 .684 .964 r
F P
0 g
s
.65989 .60934 m .69211 .60791 L .69539 .60526 L p .307 .657 .971 r
F P
0 g
s
.65412 .34561 m .64106 .34281 L .64191 .33658 L p .665 .769 .928 r
F P
0 g
s
.64191 .33658 m .66062 .34061 L .65412 .34561 L p .665 .769 .928 r
F P
0 g
s
.71779 .62418 m .7298 .63397 L .74066 .63663 L p .332 .646 .967 r
F P
0 g
s
.35986 .35777 m .40225 .34454 L .40002 .35248 L p .658 .733 .905 r
F P
0 g
s
.76122 .64425 m .75503 .63787 L .74066 .63663 L p .448 .688 .968 r
F P
0 g
s
.22085 .64595 m .28224 .64529 L .29872 .63931 L p .721 .887 .957 r
F P
0 g
s
.31212 .6342 m .33884 .61286 L .33685 .60875 L p .68 .937 .966 r
F P
0 g
s
.33685 .60875 m .29872 .63931 L .31212 .6342 L p .68 .937 .966 r
F P
0 g
s
.29872 .63931 m .21078 .64012 L .22085 .64595 L p .721 .887 .957 r
F P
0 g
s
.31912 .61259 m .29248 .63408 L .29872 .63931 L p .677 .897 .976 r
F P
0 g
s
.29872 .63931 m .33685 .60875 L .31912 .61259 L p .677 .897 .976 r
F P
0 g
s
.21078 .64012 m .29872 .63931 L .29248 .63408 L p .677 .897 .976 r
F P
0 g
s
.74066 .63663 m .72352 .62259 L .71779 .62418 L p .332 .646 .967 r
F P
0 g
s
.81166 .63201 m .75049 .6338 L .74066 .63663 L p .438 .697 .975 r
F P
0 g
s
.74066 .63663 m .82801 .63414 L .81166 .63201 L p .438 .697 .975 r
F P
0 g
s
.72352 .62259 m .74066 .63663 L .75049 .6338 L p .438 .697 .975 r
F P
0 g
s
.82801 .63414 m .74066 .63663 L .75503 .63787 L p .447 .688 .968 r
F P
0 g
s
.65074 .60477 m .62871 .59542 L .61797 .59405 L p .279 .675 .971 r
F P
0 g
s
.6369 .34204 m .6287 .34058 L .63016 .33448 L p .667 .768 .925 r
F P
0 g
s
.63016 .33448 m .64191 .33658 L .6369 .34204 L p .667 .768 .925 r
F P
0 g
s
.38337 .60577 m .35111 .60561 L .33685 .60875 L p .573 .915 .968 r
F P
0 g
s
.62666 .34024 m .62438 .33976 L .6269 .3338 L p .671 .771 .925 r
F P
0 g
s
.6269 .3338 m .63016 .33448 L .62666 .34024 L p .671 .771 .925 r
F P
0 g
s
.57981 .58467 m .60877 .59226 L .61797 .59405 L p .003 .551 .83 r
F P
0 g
s
.62273 .33868 m .62032 .33846 L .62271 .33251 L p .672 .771 .925 r
F P
0 g
s
.62271 .33251 m .62616 .33284 L .62273 .33868 L p .672 .771 .925 r
F P
0 g
s
.75503 .63787 m .81613 .63616 L .82801 .63414 L p .447 .688 .968 r
F P
0 g
s
.44264 .34273 m .41184 .34935 L .40225 .34454 L p .666 .739 .904 r
F P
0 g
s
.83937 .66541 m .83342 .6564 L .84628 .65519 L p .46 .679 .959 r
F P
0 g
s
.84628 .65519 m .8547 .6681 L .83937 .66541 L p .46 .679 .959 r
F P
0 g
s
.61822 .33822 m .60982 .33707 L .61067 .33085 L p .67 .767 .923 r
F P
0 g
s
.61067 .33085 m .62271 .33251 L .61822 .33822 L p .67 .767 .923 r
F P
0 g
s
.61797 .59405 m .5765 .58318 L .57981 .58467 L p .003 .551 .83 r
F P
0 g
s
.64106 .58671 m .61607 .59126 L .61797 .59405 L p .266 .7 .964 r
F P
0 g
s
.61797 .59405 m .65382 .58761 L .64106 .58671 L p .266 .7 .964 r
F P
0 g
s
.5765 .58318 m .61797 .59405 L .61607 .59126 L p .265 .7 .964 r
F P
0 g
s
.65382 .58761 m .61797 .59405 L .62871 .59542 L p .28 .675 .971 r
F P
0 g
s
.60547 .33662 m .59155 .33516 L .59073 .32876 L p .672 .765 .921 r
F P
0 g
s
.59073 .32876 m .61067 .33085 L .60547 .33662 L p .672 .765 .921 r
F P
0 g
s
.40225 .34454 m .44637 .33503 L .44264 .34273 L p .666 .739 .904 r
F P
0 g
s
.75049 .6338 m .73851 .62393 L .72352 .62259 L p .438 .697 .975 r
F P
0 g
s
.43395 .58925 m .46888 .58177 L .47434 .58022 L p .246 .76 .795 r
F P
0 g
s
.47434 .58022 m .42431 .59093 L .43395 .58925 L p .246 .76 .795 r
F P
0 g
s
.29248 .63408 m .23083 .63456 L .21078 .64012 L p .677 .897 .976 r
F P
0 g
s
.5851 .33474 m .56604 .33358 L .56341 .32709 L p .674 .763 .917 r
F P
0 g
s
.56341 .32709 m .59073 .32876 L .5851 .33474 L p .674 .763 .917 r
F P
0 g
s
.62871 .59542 m .65387 .59096 L .65382 .58761 L p .28 .675 .971 r
F P
0 g
s
.69211 .60791 m .71179 .62 L .72352 .62259 L p .307 .657 .972 r
F P
0 g
s
.48472 .33662 m .45457 .34059 L .44637 .33503 L p .671 .745 .906 r
F P
0 g
s
.38994 .58854 m .41234 .59314 L .42431 .59093 L p .573 .915 .969 r
F P
0 g
s
.42431 .59093 m .39244 .58428 L .38994 .58854 L p .573 .915 .969 r
F P
0 g
s
.46348 .58055 m .42833 .58809 L .42431 .59093 L p .447 .86 .957 r
F P
0 g
s
.42431 .59093 m .47434 .58022 L .46348 .58055 L p .447 .86 .957 r
F P
0 g
s
.39244 .58428 m .42431 .59093 L .42833 .58809 L p .446 .86 .958 r
F P
0 g
s
.55764 .33344 m .53376 .33334 L .5292 .32694 L p .675 .758 .913 r
F P
0 g
s
.5292 .32694 m .56341 .32709 L .55764 .33344 L p .675 .758 .913 r
F P
0 g
s
.44637 .33503 m .48956 .32934 L .48472 .33662 L p .671 .745 .906 r
F P
0 g
s
.53316 .57882 m .56763 .58249 L .5765 .58318 L p .005 .575 .774 r
F P
0 g
s
.72352 .62259 m .69539 .60526 L .69211 .60791 L p .307 .657 .972 r
F P
0 g
s
.78789 .6128 m .73058 .61841 L .72352 .62259 L p .427 .71 .983 r
F P
0 g
s
.72352 .62259 m .8054 .61468 L .78789 .6128 L p .427 .71 .983 r
F P
0 g
s
.69539 .60526 m .72352 .62259 L .73058 .61841 L p .427 .71 .982 r
F P
0 g
s
.8054 .61468 m .72352 .62259 L .73851 .62393 L p .438 .697 .975 r
F P
0 g
s
.52368 .33375 m .49602 .33542 L .48956 .32934 L p .674 .752 .909 r
F P
0 g
s
.48956 .32934 m .5292 .32694 L .52368 .33375 L p .674 .752 .909 r
F P
0 g
s
.61607 .59126 m .58694 .58361 L .5765 .58318 L p .265 .7 .964 r
F P
0 g
s
.83186 .65414 m .82955 .65113 L .84301 .65087 L p .455 .683 .963 r
F P
0 g
s
.84301 .65087 m .84628 .65519 L .83186 .65414 L p .455 .683 .963 r
F P
0 g
s
.48264 .58002 m .51947 .57842 L .52711 .57791 L p .081 .642 .756 r
F P
0 g
s
.52711 .57791 m .47434 .58022 L .48264 .58002 L p .081 .642 .756 r
F P
0 g
s
.5765 .58318 m .52711 .57791 L .53316 .57882 L p .005 .575 .774 r
F P
0 g
s
.58629 .57389 m .57113 .58082 L .5765 .58318 L p .279 .738 .952 r
F P
0 g
s
.5765 .58318 m .59839 .5733 L .58629 .57389 L p .279 .738 .952 r
F P
0 g
s
.52711 .57791 m .5765 .58318 L .57113 .58082 L p .28 .739 .952 r
F P
0 g
s
.59839 .5733 m .5765 .58318 L .58694 .58361 L p .263 .699 .963 r
F P
0 g
s
.73851 .62393 m .7958 .61845 L .8054 .61468 L p .438 .697 .975 r
F P
0 g
s
.42833 .58809 m .40616 .58339 L .39244 .58428 L p .446 .86 .958 r
F P
0 g
s
.8262 .64701 m .82865 .65 L .84301 .65087 L p .453 .685 .965 r
F P
0 g
s
.45343 .57319 m .46348 .58055 L .47434 .58022 L p .446 .859 .957 r
F P
0 g
s
.47434 .58022 m .46022 .56963 L .45343 .57319 L p .446 .859 .957 r
F P
0 g
s
.51857 .57663 m .48147 .57825 L .47434 .58022 L p .34 .793 .949 r
F P
0 g
s
.47434 .58022 m .52711 .57791 L .51857 .57663 L p .34 .793 .949 r
F P
0 g
s
.46022 .56963 m .47434 .58022 L .48147 .57825 L p .34 .793 .948 r
F P
0 g
s
.58694 .58361 m .60239 .57674 L .59839 .5733 L p .263 .699 .963 r
F P
0 g
s
.84301 .65087 m .83953 .64658 L .8262 .64701 L p .453 .685 .965 r
F P
0 g
s
.5216 .56849 m .51857 .57663 L .52711 .57791 L p .341 .794 .949 r
F P
0 g
s
.52711 .57791 m .53172 .56627 L .5216 .56849 L p .341 .794 .949 r
F P
0 g
s
.57113 .58082 m .53642 .57712 L .52711 .57791 L p .28 .739 .952 r
F P
0 g
s
.53172 .56627 m .52711 .57791 L .53642 .57712 L p .281 .739 .953 r
F P
0 g
s
.73058 .61841 m .71088 .60621 L .69539 .60526 L p .427 .71 .982 r
F P
0 g
s
.81613 .63616 m .82424 .64483 L .83953 .64658 L p .447 .688 .968 r
F P
0 g
s
.35111 .60561 m .38994 .58854 L .39244 .58428 L p .573 .915 .968 r
F P
0 g
s
.39244 .58428 m .33685 .60875 L .35111 .60561 L p .573 .915 .968 r
F P
0 g
s
.65387 .59096 m .6829 .60326 L .69539 .60526 L p .279 .675 .971 r
F P
0 g
s
.48147 .57825 m .47177 .57083 L .46022 .56963 L p .34 .793 .948 r
F P
0 g
s
.26726 .60466 m .31912 .61259 L .33685 .60875 L p .677 .897 .976 r
F P
0 g
s
.33685 .60875 m .26272 .5972 L .26726 .60466 L p .677 .897 .976 r
F P
0 g
s
.37482 .58551 m .33581 .60276 L .33685 .60875 L p .615 .89 .989 r
F P
0 g
s
.33685 .60875 m .39244 .58428 L .37482 .58551 L p .615 .89 .989 r
F P
0 g
s
.26272 .5972 m .33685 .60875 L .33581 .60276 L p .614 .889 .989 r
F P
0 g
s
.53642 .57712 m .53981 .569 L .53172 .56627 L p .281 .739 .953 r
F P
0 g
s
.83953 .64658 m .82801 .63414 L .81613 .63616 L p .447 .688 .968 r
F P
0 g
s
.69539 .60526 m .65382 .58761 L .65387 .59096 L p .279 .675 .971 r
F P
0 g
s
.74886 .58973 m .69859 .60005 L .69539 .60526 L p .417 .73 .99 r
F P
0 g
s
.69539 .60526 m .76733 .59066 L .74886 .58973 L p .417 .73 .99 r
F P
0 g
s
.65382 .58761 m .69539 .60526 L .69859 .60005 L p .417 .73 .99 r
F P
0 g
s
.76733 .59066 m .69539 .60526 L .71088 .60621 L p .426 .71 .983 r
F P
0 g
s
.71088 .60621 m .76125 .59609 L .76733 .59066 L p .426 .71 .983 r
F P
0 g
s
.23083 .63456 m .26726 .60466 L .26272 .5972 L p .677 .897 .976 r
F P
0 g
s
.26272 .5972 m .21078 .64012 L .23083 .63456 L p .677 .897 .976 r
F P
0 g
s
.7958 .61845 m .81166 .63201 L .82801 .63414 L p .438 .697 .974 r
F P
0 g
s
.33581 .60276 m .284 .59455 L .26272 .5972 L p .614 .889 .989 r
F P
0 g
s
.69859 .60005 m .6694 .58761 L .65382 .58761 L p .417 .73 .99 r
F P
0 g
s
.82801 .63414 m .8054 .61468 L .7958 .61845 L p .438 .697 .974 r
F P
0 g
s
.60239 .57674 m .64106 .58671 L .65382 .58761 L p .265 .7 .963 r
F P
0 g
s
.65382 .58761 m .59839 .5733 L .60239 .57674 L p .265 .7 .963 r
F P
0 g
s
.69132 .56667 m .6522 .58195 L .65382 .58761 L p .418 .756 .995 r
F P
0 g
s
.65382 .58761 m .71 .56591 L .69132 .56667 L p .418 .756 .995 r
F P
0 g
s
.59839 .5733 m .65382 .58761 L .6522 .58195 L p .418 .756 .995 r
F P
0 g
s
.71 .56591 m .65382 .58761 L .6694 .58761 L p .418 .73 .99 r
F P
0 g
s
.40616 .58339 m .45343 .57319 L .46022 .56963 L p .446 .859 .957 r
F P
0 g
s
.46022 .56963 m .39244 .58428 L .40616 .58339 L p .446 .859 .957 r
F P
0 g
s
.33817 .5703 m .37482 .58551 L .39244 .58428 L p .614 .89 .989 r
F P
0 g
s
.39244 .58428 m .34031 .56231 L .33817 .5703 L p .614 .89 .989 r
F P
0 g
s
.44456 .56814 m .39686 .57847 L .39244 .58428 L p .542 .864 .995 r
F P
0 g
s
.39244 .58428 m .46022 .56963 L .44456 .56814 L p .542 .864 .995 r
F P
0 g
s
.34031 .56231 m .39244 .58428 L .39686 .57847 L p .542 .864 .995 r
F P
0 g
s
.6694 .58761 m .70884 .57253 L .71 .56591 L p .418 .73 .99 r
F P
0 g
s
.53981 .569 m .58629 .57389 L .59839 .5733 L p .279 .738 .952 r
F P
0 g
s
.76125 .59609 m .78789 .6128 L .8054 .61468 L p .427 .71 .983 r
F P
0 g
s
.6522 .58195 m .61321 .57185 L .59839 .5733 L p .418 .756 .995 r
F P
0 g
s
.47177 .57083 m .5216 .56849 L .53172 .56627 L p .34 .794 .949 r
F P
0 g
s
.53172 .56627 m .46022 .56963 L .47177 .57083 L p .34 .794 .949 r
F P
0 g
s
.8054 .61468 m .76733 .59066 L .76125 .59609 L p .427 .71 .983 r
F P
0 g
s
.59839 .5733 m .53172 .56627 L .53981 .569 L p .279 .738 .952 r
F P
0 g
s
.61479 .5487 m .59146 .56807 L .59839 .5733 L p .436 .789 .997 r
F P
0 g
s
.59839 .5733 m .6322 .54568 L .61479 .5487 L p .436 .789 .997 r
F P
0 g
s
.53172 .56627 m .59839 .5733 L .59146 .56807 L p .436 .789 .997 r
F P
0 g
s
.6322 .54568 m .59839 .5733 L .61321 .57185 L p .418 .756 .995 r
F P
0 g
s
.39686 .57847 m .36065 .563 L .34031 .56231 L p .542 .864 .995 r
F P
0 g
s
.42739 .54821 m .44456 .56814 L .46022 .56963 L p .542 .864 .995 r
F P
0 g
s
.46022 .56963 m .43617 .541 L .42739 .54821 L p .542 .864 .995 r
F P
0 g
s
.51982 .5625 m .46947 .56487 L .46022 .56963 L p .478 .827 .997 r
F P
0 g
s
.46022 .56963 m .53172 .56627 L .51982 .5625 L p .478 .827 .997 r
F P
0 g
s
.43617 .541 m .46022 .56963 L .46947 .56487 L p .478 .827 .997 r
F P
0 g
s
.52367 .54125 m .51982 .5625 L .53172 .56627 L p .479 .827 .997 r
F P
0 g
s
.53172 .56627 m .53777 .53587 L .52367 .54125 L p .479 .827 .997 r
F P
0 g
s
.59146 .56807 m .54451 .56311 L .53172 .56627 L p .436 .789 .997 r
F P
0 g
s
.53777 .53587 m .53172 .56627 L .54451 .56311 L p .436 .789 .997 r
F P
0 g
s
.61321 .57185 m .63713 .55263 L .6322 .54568 L p .418 .756 .995 r
F P
0 g
s
.284 .59455 m .33817 .5703 L .34031 .56231 L p .614 .89 .989 r
F P
0 g
s
.34031 .56231 m .26272 .5972 L .284 .59455 L p .614 .89 .989 r
F P
0 g
s
.46947 .56487 m .45301 .5448 L .43617 .541 L p .478 .827 .997 r
F P
0 g
s
.54451 .56311 m .5491 .54189 L .53777 .53587 L p .436 .789 .997 r
F P
0 g
s
.70884 .57253 m .74886 .58973 L .76733 .59066 L p .417 .73 .99 r
F P
0 g
s
.76733 .59066 m .71 .56591 L .70884 .57253 L p .417 .73 .99 r
F P
0 g
s
.63713 .55263 m .69132 .56667 L .71 .56591 L p .418 .756 .995 r
F P
0 g
s
.36065 .563 m .42739 .54821 L .43617 .541 L p .542 .864 .995 r
F P
0 g
s
.43617 .541 m .34031 .56231 L .36065 .563 L p .542 .864 .995 r
F P
0 g
s
.71 .56591 m .6322 .54568 L .63713 .55263 L p .418 .756 .995 r
F P
0 g
s
.5491 .54189 m .61479 .5487 L .6322 .54568 L p .436 .789 .997 r
F P
0 g
s
.45301 .5448 m .52367 .54125 L .53777 .53587 L p .479 .827 .997 r
F P
0 g
s
.53777 .53587 m .43617 .541 L .45301 .5448 L p .479 .827 .997 r
F P
0 g
s
.6322 .54568 m .53777 .53587 L .5491 .54189 L p .436 .789 .997 r
F P
0 g
s
.25 Mabswid
.67926 0 m
.94495 .42182 L
s
.94495 .42182 m
1 .82462 L
s
1 .82462 m
.70489 .4415 L
s
.70489 .4415 m
.67926 0 L
s
.06678 .25008 m
0 .67149 L
s
0 .67149 m
.70489 .4415 L
s
.70489 .4415 m
.67926 0 L
s
.67926 0 m
.06678 .25008 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{582, 565.062},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000960002=B000`400?l00000o`00003ooooooon:
ooooo`;o0000^oooool00?ooooooQoooool3o`000003ooooool0003ooooo0;[ooooo003oooooohGo
oooo0_l00004ooooo`;o0000^_ooool00?ooooooP_ooool3o`0000Kooooo00?o0000ooooool00000
^Oooool00?ooooooP?ooool2o`0000Wooooo00?o0000ooooool00000^Oooool00?ooooooO_ooool2
o`0000_ooooo00Co0000oooooooooooo0000^?ooool00?ooooooNoooool3o`0000gooooo00Co0000
oooooooooooo0000^?ooool00?ooooooNOooool2o`00013ooooo00Go0000ooooooooooooooooo`00
002gooooo`00oooooomfooooo`?o00004_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0;Cooooo003oooooogCooooo0_l0000Eooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0]?ooool00?ooooooLOooool3o`0001Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2cooooo`00oooooom_ooooo`;o00006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0;;ooooo003oooooofgooooo0_l0000Mooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0/_ooool00?ooooooJ_ooool3o`0001oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`2aooooo`00oooooomXooooo`;o00008_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0;7ooooo003oooooofGooooo0ol0000Tooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/?ooool00?ooooooHoooool2o`0002Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2_ooooo`00oooooomPooooo`?o0000:Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0:oooooo003ooooooekooooo0_l0000/ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0[_ooool00?ooooooFoooool3o`0002kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`2]ooooo`00oooooomIooooo`;o0000<Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo0:gooooo003ooooooeOooooo0_l0000cooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0[?ooool00?ooooooE?ooool3o`0003Gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`2[ooooo`00oooooomBooooo`;o0000>?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:_ooooo003oooooodoooooo0ol0000joooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Z_ooool00?ooooooCOooool2o`0003go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2Zooooo`00oooooom:ooooo`?o0000
?oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0:Wooooo003oooooodSooooo0_l0
0013ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Z?ooool00?ooooooA_ooool2
o`0004Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Xooooo`00oooooom3oooo
o`?o0000Aoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Oooooo003ooooood7o
oooo0_l0001:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Y_ooool00?oooooo
?_ooool3o`0004cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Vooooo`00oooo
oollooooo`;o0000Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:Gooooo003o
ooooocWooooo0ol0001Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0YOooool0
0?oooooo=oooool2o`0005Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Toooo
o`00ooooooldooooo`?o0000E_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0:?o
oooo003ooooooc;ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
Xoooool00?oooooo<?ooool2o`0005_ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`2Rooooo`00ooooool]ooooo`?o0000GOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo0:7ooooo003oooooob_ooooo0_l0001Pooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0XOooool00?oooooo:?ooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`2Pooooo`00oooooolVooooo`;o0000IOooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo0:3ooooo003oooooob?ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0Woooool00?oooooo8Oooool2o`0006[ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`2Nooooo`00oooooolNooooo`?o0000KOooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo09kooooo003ooooooacooooo0_l0001`ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0WOooool00?oooooo6_ooool2o`0007;ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`2Looooo`00oooooolGooooo`?o0000M?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo09cooooo003ooooooaGooooo0_l0001gooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0Voooool00?oooooo4_ooool3o`0007Wooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`2Kooooo`00ooooool@ooooo`;o0000O?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo09[ooooo003oooooo`gooooo0ol0001nooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0VOooool00?oooooo2oooool2o`00087ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`2Iooooo`00ooooool9ooooo`;o0000Poooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo09Sooooo003oooooo`Kooooo0ol00025oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Uoooool00?oooooo1?ooool2o`0008So
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2Gooooo`00ooooool1ooooo`?o0000
R_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo09Kooooo003nooooo`;o0000SOoo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo09Gooooo003kooooo`?o0000Soooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo09Gooooo003iooooo`;o0000T_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo09Cooooo003fooooo`?o0000U?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo09Cooooo003dooooo`;o0000V?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo09?ooooo003booooo`;o0000V_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo09;ooooo003_ooooo`?o0000W?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo09;ooooo003]ooooo`;o0000Woooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo097ooooo003Zooooo`?o0000XOooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo093ooooo003Xooooo`;o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo093ooooo003Uooooo`?o0000Y_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo08oooooo003Sooooo`;o0000ZOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo08oooooo003Qooooo`;o0000Zoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
08kooooo003Nooooo`?o0000[Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo08go
oooo003Looooo`;o0000/?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo08gooooo
003Iooooo`?o0000/_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo08cooooo003G
ooooo`;o0000]Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08_ooooo003Doooo
o`?o0000]oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08_ooooo003Booooo`;o
0000FOoooolHo`0004Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2:ooooo`00
coooool3o`0004Gooooo5_l0000Cok2/e003o`000?nd/=Co];3D00;o];3D2Ol00010ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0R_ooool00<gooooo0_l00012ooooo`Ko00000on]
Z]@00ol0003o/:cDok2/e00Rok2/e003o`000?nd/=Co000000co];3D2Ol0000gooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0ROooool00<_ooooo0_l0000mooooo`Oo00002?n]Z]@0
0ol0003o/:cDo`00000Rok2/e005o`000?n`[=Co];3DokB`e?l000005?nd/=@9o`0002oooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`28ooooo`00b?ooool3o`0003Wooooo1_l0000?
ojfZe0;o000000?o/:cDo`000?n`[=@08?n`[=@00ol0003o/:cDokB`e002okB`e003o`000?nd/=Co
];3D01[o];3D2Ol0000Vooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0R?ooool0
0<Kooooo0_l0000fooooo`Ko00005On]Z]@01Ol0003o[J[Dok2/e?n`[=Co000001oo/:cD00?o0000
ok2/e?n`[=@00ond/=@00ol0003o];3DokB`e00SokB`e0Ko00008?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo08Oooooo0033ooooo`?o0000<oooool5o`0001[o[J[D00?o0000ojfZ
e?n]Z]@00_n`[=@00ol0003o/:cDok2/e00Mok2/e004o`000?n`[=Co/:cDo`0000?o];3D00?o0000
okB`e?nd/=@08ond/=@00ol0003o];3Do`000002okVde@?o00007Oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo08Kooooo0031ooooo`;o0000<oooool3o`0000;oZZSD0_l0000KojfZ
e003o`000?n]Z]Co[J[D00?o/:cD00?o0000ok2/e?n`[=@06on`[=@01Ol0003o/:cDok2/e?n`[=Co
000000Co];3D00?o0000okB`e?nd/=@08Ond/=@01Ol0003o];3DokB`e?ni]=Go000000Co^KCE0ol0
000Jooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Q_ooool00;kooooo0ol0000a
ooooo`Co00001OnZZ=@00ol0003o[J[Do`00000JojfZe004o`000?n]Z]Co[J[Do`0000?o/:cD00?o
0000ok2/e?n`[=@03?n`[=@>o`0000Co/:cD00?o0000okB`e?nd/=@00ond/=@00ol0003o];3DokB`
e00OokB`e006o`000?nd/=Co];3Do`000?ni]=Go00001oni]=D3o`0001Oooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`25ooooo`00_?ooool2o`00037ooooo0ol00009ojZXe004o`00
0?n]Z]Co[J[Do`0001Go[J[D1?l00003ojfZe003o`000?n`[=Co/:cD00;o/:cD00?o0000ok2/e?l0
00002ol0000=ooooo`Go/:cD00?o0000okB`e?nd/=@00ond/=@00ol0003oooooooooo`02ooooo`Oo
00005Ond/=@01ol0003o];3DokB`e?nd/=Co0000okVdeOl000002_ni]=D3o`0001Cooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`25ooooo`00^_ooool2o`0002oooooo1?l0000<ojZX
e0;o00000_n]Z]@00ol0003o[J[DojfZe00=ojfZe0Go00000oooool4ojfZe003o`000?n`[=Co/:cD
00;o/:cD00?o0000ooooooooool06?ooool5ok2/e003o`000?nd/=Co];3D00?o];3D00?o0000oooo
ooooool02Oooool8o`0000co];3D00?o0000okB`e?nd/=@00_nd/=@3okVde@03o`000?ni]=Go^KCE
00[o^KCE0ol0000Aooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Q?ooool00;Oo
oooo0ol0000^ooooo`?o00004?nZZ=@00ol0003oZZSDojfZe002ojfZe003o`000?n]Z]Co[J[D00Oo
[J[D1Ol00008ooooo`Go[J[D1?n`[=@00ol0003oooooooooo`0Hooooo`Go/:cD00?o0000okB`e?nd
/=@00ond/=@00ol0003oooooooooo`0Aooooo`Oo00001?nd/=@00ol0003o];3DokB`e002okB`e005
o`000?ni]=Go^KCEokVdeOl000003oni]=D3o`0000kooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`23ooooo`00]Oooool2o`0002kooooo0ol0000CojZXe003o`000?nZZ=Co[J[D00?o
[J[D00Co0000ojfZe?n]Z]Co[J[D1Ol0000=ooooo`03o`000?n]Z]Co[J[D00;o[J[D00Go0000ok2/
e?n`[=Co/:cDo`00000Jooooo`Go/:cD00?o0000okB`e?nd/=@00ond/=@00ol0003oooooooooo`0H
ooooo`Co00001Ond/=@01Ol0003o^KCEokVdeOni]=Go000001;o^KCE0ol0000;ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0Poooool00;;ooooo0ol0000]ooooo`?o000000?oZ:OE
o`000?l000004onZZ=@00ol0003oZZSDo`000004ojfZe0?o00004oooool4ojfZe003o`000?n`[=Co
/:cD00;o/:cD00?o0000ooooooooool05oooool4ok2/e003o`000?nd/=Co];3D00Co];3D00?o0000
ooooooooool06oooool6okB`e003o`000?ni]=Go^KCE00;o^KCE00?o0000okVdeOni]=D04_ni]=D3
o`0000Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`22ooooo`00/?ooool2o`00
02gooooo0ol00004ojRWe@03o`000?nZZ=Co0000013oZZSD0ol00002ojZXe0Co[J[D00?o0000oooo
ooooool04oooool4ojfZe003o`000?n`[=Co/:cD00;o/:cD00?o0000ooooooooool05oooool4ok2/
e003o`000?nd/=Co];3D00Co];3D00?o0000ooooooooool06oooool5okB`e003o`000?ni]=Go^KCE
00?o^KCE00?o0000okVdeOni]=D05Oni]=D3o`0000Gooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`21ooooo`00[Oooool3o`0002cooooo0ol00008ojRWe@03o`000?nZZ=Co000000_o
ZZSD1?l00002ooooo`?oZZSD00?o0000ojfZe?n]Z]@00_n]Z]@00ol0003oooooooooo`0Booooo`Co
[J[D00?o0000ok2/e?n`[=@00_n`[=@00ol0003oooooooooo`0Gooooo`Co/:cD00?o0000okB`e?nd
/=@01?nd/=@00ol0003oooooooooo`0Jooooo`03o`000?nd/=Co];3D00?o];3D00?o0000okVdeOni
]=D00oni]=D00ol0003oooooooooo`02o`0001Ko^KCE0ol00002ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0POooool00:_ooooo0_l0000/ooooo`?o00002onXYmD01?l0003oZZSD
ojZXe?l00007ojZXe0?o00001_ooool01?l0003oZZSDojZXe?l00004ojfZe003o`000?oooooooooo
01;ooooo00Go0000ojfZe?n]Z]Co[J[Do`000004ok2/e003o`000?oooooooooo01Oooooo00Go0000
ok2/e?n`[=Co/:cDo`000006okB`e003o`000?oooooooooo01[ooooo00?o0000okB`e?nd/=@00ond
/=@00ol0003o^KCEokVde@03okVde@03o`000?oooooooooo00?ooooo0ol0000EokVde@?o0000<ooo
ool00ol0003oooooooooo`20ooooo`00Z?ooool3o`0002cooooo0_l000000onWYmKo0000ojRWe@0;
ojRWe@05o`000?nZZ=CoZZSDojZXe?l000000_nZZ=@4o`0000[ooooo0onZZ=@01Ol0003o[J[DojfZ
e?n]Z]Co000001Cooooo00?o0000ojfZe?n]Z]@00_n]Z]@01Ol0003o/:cDok2/e?n`[=Co000001So
oooo00?o0000ok2/e?n`[=@00_n`[=@00ol0003o];3DokB`e004okB`e003o`000?oooooooooo01[o
oooo1Ond/=@00ol0003o^KCEokVde@03okVde@03o`000?oooooooooo00Oooooo0ol0000DokVde@Co
0000<Oooool00ol0003oooooooooo`1oooooo`00Y_ooool2o`0002gooooo0_l00004ojNWeP03o`00
0?nXYmGoZ:OE00WoZ:OE00?o0000ojRWeOnZZ=@00_nZZ=@2o`0000kooooo0onZZ=@00ol0003o[J[D
ojfZe002ojfZe003o`000?oooooooooo017ooooo00?o0000ojfZe?n]Z]@00_n]Z]@01Ol0003o/:cD
ok2/e?n`[=Co000001Sooooo00?o0000ok2/e?n`[=@00_n`[=@00ol0003o];3DokB`e003okB`e003
o`000?oooooooooo01[ooooo00?o0000okB`e?nd/=@00ond/=@00ol0003o^KCEokVde@03okVde@03
o`000?oooooooooo00[ooooo0ol0000AokVde@04o`000?ni]=Go^KCEokVde@?o0000;_ooool00ol0
003oooooooooo`1oooooo`00Y?ooool2o`0002gooooo0_l000000onWY]Ko0000ojNWeP03ojNWeP;o
00002onXYmD2o`0000;oZZSD00?o0000ooooooooool03Oooool01?l0003oZZSDojZXe?l00004ojfZ
e003o`000?oooooooooo01;ooooo00Go0000ojfZe?n]Z]Co[J[Do`000003ok2/e003o`000?oooooo
oooo01Kooooo00?o0000ok2/e?n`[=@00_n`[=@00ol0003o];3DokB`e003okB`e003o`000?oooooo
oooo01[ooooo00?o0000okB`e?nd/=@00ond/=@00ol0003o^KCEokVde@03okVde@03o`000?oooooo
oooo00gooooo0ol0000>okVde@03o`000?ni]=Go^KCE00Co^KCE0ol0000/ooooo`03o`000?oooooo
oooo07kooooo002Qooooo`?o0000;Oooool2o`0000CoYjKF00?o0000ojNWe_nWYmH00_nWYmH2o`00
00WoZ:OE0_l000001OnXYmGoZZSDojZXe?nZZ=Co000000oooooo0onZZ=@01Ol0003o[J[DojfZe?n]
Z]Co000001Cooooo00Go0000ojfZe?n]Z]Co[J[Do`000004ok2/e003o`000?oooooooooo01Gooooo
00?o0000ok2/e?n`[=@00_n`[=@00ol0003o];3DokB`e003okB`e003o`000?oooooooooo01[ooooo
00?o0000okB`e?nd/=@00_nd/=@00ol0003o^KCEokVde@03okVde@03o`000?oooooooooo017ooooo
0ol0000<okVde@04o`000?ni]=Go^KCEokVde@;o000000?o^KCEo`000?nm^]L00_l0000Zooooo`03
o`000?oooooooooo07kooooo002Oooooo`;o0000;Oooool3o`000003ojJVe_l0003oYjKF00?oYjKF
0_l00003ojNWeP;o00001_nXYmD3o`000004oooooonXYmGoZ:OEo`0000;oZZSD00?o0000oooooooo
ool03Oooool01?l0003oZZSDojZXe?l00004ojfZe003o`000?oooooooooo017ooooo00Go0000ojfZ
e?n]Z]Co[J[Do`000004ok2/e003o`000?oooooooooo01Gooooo00?o0000ok2/e?n`[=@00_n`[=@0
0ol0003o];3DokB`e003okB`e003o`000?oooooooooo01Wooooo00?o0000okB`e?nd/=@00ond/=@0
0ol0003o^KCEokVde@03okVde@03o`000?oooooooooo01Cooooo0ol00009okVde@04o`000?ni]=Go
0000o`0000;o^KCE0_l00003okfje`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0OOoo
ool009cooooo0ol0000]ooooo`;o00001?nVY]H2o`0000CoYjKF00Oo0000ojNWe_nWYmKoYjOFo`00
0?nXYmGo000000;oZ:OE0ol00005ooooo`;oZ:OE0onZZ=@00ol0003oooooooooo`0<ooooo`04o`00
0?nZZ=CoZZSDo`0000Co[J[D00?o0000ooooooooool04Oooool01Ol0003o[J[DojfZe?n]Z]Co0000
00Co/:cD00?o0000ooooooooool05Oooool00ol0003o/:cDok2/e002ok2/e003o`000?nd/=Co];3D
00?o];3D00?o0000ooooooooool06Oooool00ol0003o];3DokB`e003okB`e003o`000?ni]=Go^KCE
00?o^KCE00?o0000ooooooooool05oooool3o`0000Ko^KCE0_l00003okVde@03o`000?nm^]Oo0000
00Co_K[G0_l0000Yooooo`03o`000?oooooooooo07cooooo002Jooooo`;o0000;_ooool2o`0000Oo
YZKF0_l00003ojNVeP;o00000_nWYmH2o`000003ojRWeOl0003o000000Sooooo0_nXYmD01?l0003o
ZZSDojZXe?l0000?ooooo`?oZZSD00Go0000ojfZe?n]Z]Co[J[Do`00000Cooooo`03o`000?n]Z]Co
[J[D00;o[J[D00Go0000ok2/e?n`[=Co/:cDo`00000Gooooo`03o`000?n`[=Co/:cD00;o/:cD00?o
0000okB`e?nd/=@00ond/=@00ol0003oooooooooo`0Iooooo`03o`000?nd/=Co];3D00?o];3D00?o
0000okVdeOni]=D00_ni]=D00ol0003oooooooooo`0Kooooo`?o00000_ni]=D2o`0000Co^KCE00?o
0000okfjeol000001_nm^]L2o`0002Oooooo00?o0000ooooooooool0O?ooool009Oooooo0ol0000]
ooooo`?o00002OnVY]H2o`0000?oYjKF00So0000ojNWe_l0003o0000oooooonWYmKoZ:OEo`0000[o
oooo0_nXYmD3ojZXe003o`000?oooooooooo00cooooo00Co0000ojZXe?nZZ=Co00001?n]Z]@00ol0
003oooooooooo`0@ooooo`03o`000?n]Z]Co[J[D00;o[J[D00Go0000ok2/e?n`[=Co/:cDo`00000G
ooooo`03o`000?n`[=Co/:cD00;o/:cD00?o0000okB`e?nd/=@00ond/=@00ol0003oooooooooo`0I
ooooo`03o`000?nd/=Co];3D00;o];3D00?o0000okVdeOni]=D00oni]=D00ol0003oooooooooo`0N
ooooo`;o000000?o^KCEo`000?ni]=D00_ni]=D01Ol0003o_K[Gokfjeonm^]Oo000000Oo_K[G0_l0
000Vooooo`03o`000?oooooooooo07_ooooo002Eooooo`;o0000;_ooool2o`0000coYZKF00?o0000
ojJVe_l000000_nWY]H3o`0000?ooooo00?oYjOFojRWeOl000002Oooool2ojRWe@04o`000?nZZ=Co
ZZSDo`0000kooooo00Co0000ojZXe?nZZ=Co00001?n]Z]@00ol0003oooooooooo`0Aooooo`05o`00
0?n]Z]Co[J[DojfZe?l000000on`[=@00ol0003oooooooooo`0Eooooo`03o`000?n`[=Co/:cD00;o
/:cD00?o0000okB`e?nd/=@00ond/=@00ol0003oooooooooo`0Hooooo`03o`000?nd/=Co];3D00?o
];3D00?o0000okVdeOni]=D00oni]=D00ol0003oooooooooo`0Oooooo`;o^KCE00Go0000okVdeOni
]=Go^KCEo`000003okfje`03o`000?nm^]Oo_K[G00Oo_K[G00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1jooooo`00Toooool2o`0002kooooo0_l000000onTYMOo0000o`00000<ojJVePCo
000000Coooooo`000?nWYmKo00000_ooool00onWYmKo0000o`00000:ooooo`05ojRWeOl0003oZZSD
ojZXe?l000003oooool01?l0003oZZSDojZXe?l00003ojfZe003o`000?oooooooooo017ooooo00Go
0000ojfZe?n]Z]Co[J[Do`000003ok2/e003o`000?oooooooooo01Gooooo00?o0000ok2/e?n`[=@0
0_n`[=@00ol0003o];3DokB`e003okB`e003o`000?oooooooooo01Sooooo00?o0000okB`e?nd/=@0
0ond/=@00ol0003o^KCEokVde@03okVde@03o`000?oooooooooo01kooooo00Co0000okVdeOni]=Go
00000_ni]=D00ol0003o_K[Gokfje`02okfje`03o`000?nm^]Oo_K[G00So_K[G0_l0000Tooooo`03
o`000?oooooooooo07[ooooo002@ooooo`?o0000;_ooool2o`0000?oY:GG0ol0000;ojJVeP03o`00
0?nVY]Ko000000?ooooo0_l00003ooooo`03ojNWe_nXYmGo000000Wooooo0_nXYmD01?l0003oZZSD
ojZXe?l0000>ooooo`04o`000?nZZ=CoZZSDo`0000Co[J[D00?o0000ooooooooool04?ooool01Ol0
003o[J[DojfZe?n]Z]Co000000Co/:cD00?o0000ooooooooool05?ooool00ol0003o/:cDok2/e002
ok2/e003o`000?nd/=Co];3D00?o];3D00?o0000ooooooooool06?ooool00ol0003o];3DokB`e002
okB`e003o`000?ni]=Go^KCE00?o^KCE00?o0000ooooooooool07_ooool01ol0003o^KCEokVdeOni
]=Go0000okVdeOl000001Onm^]L00ol0003o_K[Gokfje`0:okfje`;o00008oooool00ol0003ooooo
ooooo`1iooooo`00S_ooool2o`0002oooooo0_l00006ojBUe`?o00001onVY]H2o`000005ooooool0
003oYZKFojJVe_l000000_ooool00ol0003oYjKFo`000002ooooo`?o00002_ooool01OnXYmGo0000
ojZXe?nZZ=Co000000kooooo00Co0000ojZXe?nZZ=Co00001?n]Z]@00ol0003oooooooooo`0@oooo
o`05o`000?n]Z]Co[J[DojfZe?l000001?n`[=@00ol0003oooooooooo`0Dooooo`03o`000?n`[=Co
/:cD00;o/:cD00?o0000okB`e?nd/=@00ond/=@00ol0003oooooooooo`0Gooooo`03o`000?nd/=Co
];3D00?o];3D00?o0000okVdeOni]=D00oni]=D00ol0003oooooooooo`0Nooooo`07o`000?ni]=Go
^KCEokVdeOl0003o^KCEo`000005okfje`03o`000?nm^]Oo_K[G00co_K[G00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`1iooooo`00Roooool3o`0002oooooo0_l00008ojBUe`04o`000?nT
YMOo0000o`0000CoYZKF0_l00004ooooo`04o`000?nVY]Ko0000o`0000;ooooo00?o0000ojNWe_l0
00000_ooool00onWYmKoZ:OEo`000009ooooo`;oZ:OE00Co0000ojZXe?nZZ=Co00003_ooool01?l0
003oZZSDojZXe?l00003ojfZe003o`000?oooooooooo013ooooo00Go0000ojfZe?n]Z]Co[J[Do`00
0004ok2/e003o`000?oooooooooo01Cooooo00?o0000ok2/e?n`[=@00_n`[=@00ol0003o];3DokB`
e003okB`e003o`000?oooooooooo01Oooooo00?o0000okB`e?nd/=@00ond/=@00ol0003o^KCEokVd
e@03okVde@03o`000?oooooooooo01gooooo00?o0000okVdeOni]=D00_ni]=D2o`0000Ko_K[G00?o
0000oooooonm^]L03Onm^]L2o`00027ooooo00?o0000ooooooooool0N?ooool008Wooooo0_l0000a
ooooo`03o`000?nTYMOoY:GG00SoY:GG00Ko0000ojBUeol0003oYZKFo`000?nVY]H2o`0000Oooooo
00?o0000ojJVe_l000000oooool2o`0000;ooooo00Co0000ojNWe_nXYmGo00002?ooool00ol0003o
Z:OEo`000002ojZXe003o`000?oooooooooo00cooooo00Co0000ojZXe?nZZ=Co00001?n]Z]@00ol0
003oooooooooo`0@ooooo`05o`000?n]Z]Co[J[DojfZe?l000000on`[=@00ol0003oooooooooo`0D
ooooo`03o`000?n`[=Co/:cD00;o/:cD00?o0000okB`e?nd/=@00ond/=@00ol0003oooooooooo`0G
ooooo`03o`000?nd/=Co];3D00;o];3D00?o0000okVdeOni]=D00oni]=D00ol0003oooooooooo`0N
ooooo`03o`000?ni]=Go^KCE00;o^KCE0_l00005okfje`03o`000?oooooooooo00;ooooo00?o0000
okfjeonm^]L02onm^]L2o`00023ooooo00?o0000ooooooooool0Moooool008Kooooo0ol0000aoooo
o`;o00002onTYML01_l0003oY:GGojBUeol0003oYZKFo`0000Wooooo00Co0000ojJVe_nVY]Ko0000
0_ooool00ol0003oYjOFo`000002ooooo`03ojNWe_nXYmGo000000Wooooo00?o0000ojRWeOl00000
0_nZZ=@00ol0003oooooooooo`0;ooooo`04o`000?nZZ=CoZZSDo`0000Co[J[D00?o0000oooooooo
ool04?ooool01Ol0003o[J[DojfZe?n]Z]Co000000?o/:cD00?o0000ooooooooool05?ooool00ol0
003o/:cDok2/e002ok2/e003o`000?nd/=Co];3D00?o];3D00?o0000ooooooooool05_ooool00ol0
003o];3DokB`e003okB`e003o`000?ni]=Go^KCE00?o^KCE00?o0000ooooooooool07Oooool00ol0
003o^KCEokVde@03okVde@03o`000?nm^]Oo_K[G00?o_K[G00?o0000ooooooooool01Oooool00ol0
003o_K[Gokfje`0;okfje`;o00007_ooool00ol0003oooooooooo`1gooooo`00Q?ooool2o`0003;o
oooo0_l0000>ojBUe`03o`000?nTYMOoY:GG00;o00002_ooool00ol0003oYZKFo`000003ooooo`;o
00000oooool00onWYmKoZ:OEo`000008ooooo`03o`000?nXYmGo000000;oZZSD00?o0000oooooooo
ool03?ooool01?l0003oZZSDojZXe?l00003ojfZe003o`000?oooooooooo013ooooo00Go0000ojfZ
e?n]Z]Co[J[Do`000003ok2/e003o`000?oooooooooo01Cooooo00?o0000ok2/e?n`[=@00_n`[=@0
0ol0003o];3DokB`e003okB`e003o`000?oooooooooo01Kooooo00?o0000okB`e?nd/=@00ond/=@0
0ol0003o^KCEokVde@03okVde@03o`000?oooooooooo01cooooo00?o0000okVdeOni]=D00oni]=D2
o`0000Go_K[G00?o0000ooooooooool01_ooool2o`0000go_K[G00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`1fooooo`00POooool3o`0003;ooooo0_l0000@ojBUe`06o`000?nTYMOoY:GG
o`000?nVY]Ko00002Oooool01?l0003oYZKFojJVe_l00002ooooo`03o`000?nWYmKo000000;ooooo
0ol00009ooooo`03o`000?nXYmGo000000;oZZSD00?o0000ooooooooool02oooool01?l0003oZZSD
ojZXe?l00004ojfZe003o`000?oooooooooo00oooooo00Go0000ojfZe?n]Z]Co[J[Do`000003ok2/
e003o`000?oooooooooo01Cooooo00?o0000ok2/e?n`[=@00_n`[=@00ol0003o];3DokB`e003okB`
e003o`000?oooooooooo01Kooooo00?o0000okB`e?nd/=@00_nd/=@00ol0003o^KCEokVde@03okVd
e@03o`000?oooooooooo01gooooo00?o0000okVdeOni]=D00oni]=D2o`0000Co_K[G00?o0000oooo
ooooool02Oooool2o`0000co_K[G0_l0000Mooooo`03o`000?oooooooooo07Gooooo001oooooo`;o
0000<oooool2o`0000ooY:GG0_l000000ooooooo0000ojBUe`02ojBUe`03o`000?nVY]Ko000000Wo
oooo00Co0000ojJVe_l0003o00000_ooool2o`0000?ooooo00?oYjOFojRWeOl000002?ooool00ol0
003oZ:OEo`000002ojZXe003o`000?oooooooooo00_ooooo00Co0000ojZXe?nZZ=Co00001?n]Z]@0
0ol0003oooooooooo`0?ooooo`05o`000?n]Z]Co[J[DojfZe?l000001?n`[=@00ol0003ooooooooo
o`0Booooo`03o`000?n`[=Co/:cD00?o/:cD00?o0000okB`e?nd/=@00ond/=@00ol0003ooooooooo
o`0Eooooo`03o`000?nd/=Co];3D00?o];3D00?o0000okVdeOni]=D00oni]=D00ol0003ooooooooo
o`0Looooo`03o`000?ni]=Go^KCE00?o^KCE00?o0000okfjeol000001?nm^]L00ol0003ooooooooo
o`0;ooooo`;o00003?nm^]L2o`0001_ooooo00?o0000ooooooooool0MOooool007gooooo0_l0000d
ooooo`05o`000?nQY=So0000ojBUeol000002onTYML2o`0000Cooooo00Oo0000ojBUeonTYMOoY:GG
o`000?nVY]Ko000000Wooooo00?o0000ojJVe_l000000oooool2o`0000;ooooo0ol00009ooooo`03
o`000?nXYmGo000000;oZZSD00?o0000ooooooooool02oooool01?l0003oZZSDojZXe?l00003ojfZ
e003o`000?oooooooooo00oooooo00Go0000ojfZe?n]Z]Co[J[Do`000004ok2/e003o`000?oooooo
oooo01;ooooo00?o0000ok2/e?n`[=@00on`[=@00ol0003o];3DokB`e002okB`e003o`000?oooooo
oooo01Kooooo00?o0000okB`e?nd/=@00ond/=@00ol0003o^KCEokVde@03okVde@03o`000?oooooo
oooo01_ooooo00?o0000okVdeOni]=D01?ni]=D00ol0003o_K[Go`000003okfje`03o`000?oooooo
oooo00kooooo0_l0000<okfje`;o00006_ooool00ol0003oooooooooo`1dooooo`00N_ooool3o`00
03Gooooo00Ko0000oj6Tf?nQY=SoXJCHo`000?nTYML2o`0000OoY:GG0_l00007ooooo`04o`000?nT
YMOoY:GGojBUe`;o00002Oooool01?l0003oYZKFojJVe_l00002ooooo`;o00000oooool00onWYmKo
Z:OEo`000008ooooo`03o`000?nXYmGo000000;oZZSD00?o0000ooooooooool02oooool01?l0003o
ZZSDojZXe?l00004ojfZe003o`000?oooooooooo00oooooo00Go0000ojfZe?n]Z]Co[J[Do`000003
ok2/e003o`000?oooooooooo01;ooooo00?o0000ok2/e?n`[=@00on`[=@00ol0003o];3DokB`e002
okB`e003o`000?oooooooooo01Kooooo00?o0000okB`e?nd/=@00_nd/=@00ol0003o^KCEokVde@03
okVde@03o`000?oooooooooo01cooooo00?o0000okVdeOni]=D00oni]=D01?l0003o_K[Gokfjeol0
0002okfje`03o`000?oooooooooo017ooooo00?o0000okfjeonm^]L02onm^]L00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo07Cooooo001hooooo`;o0000=_ooool2o`0000CoXJCH0_l00002
ojBUe`03o`000?nTYMOoY:GG00;oY:GG0_l0000:ooooo`06o`000?nTYMOoY:GGo`000?nVY]Ko0000
2Oooool00ol0003oYZKFo`000003ooooo`;o00000_ooool3o`0000Wooooo00Go0000ojRWeOl0003o
ZZSDo`00000=ooooo`04o`000?nZZ=CoZZSDo`0000Co[J[D00?o0000ooooooooool03oooool01Ol0
003o[J[DojfZe?n]Z]Co000000?o/:cD00?o0000ooooooooool04_ooool00ol0003o/:cDok2/e003
ok2/e003o`000?nd/=Co];3D00;o];3D00?o0000ooooooooool05_ooool00ol0003o];3DokB`e002
okB`e003o`000?ni]=Go^KCE00?o^KCE00?o0000ooooooooool06oooool00ol0003o^KCEokVde@03
okVde@03o`000?nm^]Oo_K[G00;o_K[G00?o0000okfjeol000005?ooool2o`0000co_K[G0_l0000H
ooooo`03o`000?oooooooooo07?ooooo001eooooo`?o0000=oooool00ol0003oXJCHoj6Tf004oj6T
f003o`000?nQY=So000000;oY:GG00Co0000ojBUeol0003o00003?ooool01ol0003oY:GGojBUeonT
YMOo0000ojJVe_l000002?ooool01?l0003oYZKFojJVe_l00002ooooo`03o`000?nWYmKo000000;o
oooo00?oYjOFojRWeOl000002?ooool00ol0003oZ:OEo`000002ojZXe003o`000?oooooooooo00_o
oooo00Co0000ojZXe?nZZ=Co00000on]Z]@00ol0003oooooooooo`0?ooooo`05o`000?n]Z]Co[J[D
ojfZe?l000000on`[=@00ol0003oooooooooo`0Booooo`03o`000?n`[=Co/:cD00;o/:cD00?o0000
okB`e?nd/=@00ond/=@00ol0003oooooooooo`0Eooooo`03o`000?nd/=Co];3D00?o];3D00?o0000
okVdeOni]=D00oni]=D00ol0003oooooooooo`0Jooooo`03o`000?ni]=Go^KCE00Co^KCE00?o0000
okfjeonm^]L00_nm^]L2o`0001Oooooo0_l0000<okfje`;o00005oooool00ol0003oooooooooo`1b
ooooo`00Loooool2o`0003Wooooo00?o0000oj6Tf?nQY=P01_nQY=P00ol0003oXJCHo`000002ojBU
e`03o`000?oooooooooo00gooooo00Co0000ojBUeonTYMOoY:GG0_l00009ooooo`04o`000?nVY]Ko
YZKFo`0000;ooooo0_l00002ooooo`04o`000?nWYmKoZ:OEo`0000Sooooo00Go0000ojRWeOl0003o
ZZSDo`00000=ooooo`04o`000?nZZ=CoZZSDo`0000Co[J[D00?o0000ooooooooool03_ooool01Ol0
003o[J[DojfZe?n]Z]Co000000?o/:cD00?o0000ooooooooool04_ooool00ol0003o/:cDok2/e002
ok2/e003o`000?nd/=Co];3D00?o];3D00?o0000ooooooooool05Oooool00ol0003o];3DokB`e003
okB`e003o`000?ni]=Go^KCE00?o^KCE00?o0000ooooooooool06_ooool00ol0003o^KCEokVde@03
okVde@03o`000?nm^]Oo_K[G00?o_K[G0_l0000Iooooo`;o00003?nm^]L00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo07;ooooo001`ooooo`?o0000>Oooool2o`0000WoXJCH00Ko0000oj6T
f?nQY=So0000ojBUeol0000@ooooo`06o`000?nTYMOoY:GGo`000?nVY]Ko00002Oooool00ol0003o
YZKFo`000002ooooo`03o`000?nWYmKo000000;ooooo0ol00008ooooo`03o`000?nXYmGo000000;o
ZZSD00?o0000ooooooooool02_ooool01?l0003oZZSDojZXe?l00004ojfZe003o`000?oooooooooo
00kooooo00Go0000ojfZe?n]Z]Co[J[Do`000003ok2/e003o`000?oooooooooo01;ooooo00?o0000
ok2/e?n`[=@00_n`[=@00ol0003o];3DokB`e003okB`e003o`000?oooooooooo01Gooooo00?o0000
okB`e?nd/=@00_nd/=@00ol0003o^KCEokVde@03okVde@03o`000?oooooooooo01[ooooo00?o0000
okVdeOni]=D01?ni]=D00ol0003o_K[Gokfje`03okfje`03o`000?oooooooooo01[ooooo0_l0000;
okfje`;o00005Oooool00ol0003oooooooooo`1aooooo`00K_ooool2o`0003_ooooo00?o0000oj6T
f?nQY=P02OnQY=P01ol0003oXJCHoj6Tf?nQY=So0000ojBUeol000003oooool01ol0003oY:GGojBU
eonTYMOo0000ojJVe_l000002?ooool01?l0003oYZKFojJVe_l00002ooooo`;o00000_ooool01?l0
003oYjOFojRWeOl00008ooooo`05o`000?nXYmGo0000ojZXe?l000003Oooool01?l0003oZZSDojZX
e?l00003ojfZe003o`000?oooooooooo00kooooo00Go0000ojfZe?n]Z]Co[J[Do`000004ok2/e003
o`000?oooooooooo017ooooo00?o0000ok2/e?n`[=@00_n`[=@00ol0003o];3DokB`e003okB`e003
o`000?oooooooooo01Cooooo00?o0000okB`e?nd/=@00ond/=@00ol0003o^KCEokVde@03okVde@03
o`000?oooooooooo01[ooooo00?o0000okVdeOni]=D00oni]=D00ol0003o_K[Gokfje`03okfje`;o
00007_ooool00ol0003o_K[Gokfje`08okfje`?o00005Oooool00ol0003oooooooooo`1`ooooo`00
Joooool3o`0003cooooo00?o0000oj6Tf?nQY=P02onQY=P01?l0003oXJCHoj6Tf?l00002ojBUe`03
o`000?oooooooooo00gooooo00Oo0000ojBUeonTYMOoY:GGo`000?nVY]Ko000000Sooooo00Co0000
ojJVe_nVY]Ko00000_ooool2o`0000;ooooo0ol00008ooooo`03o`000?nXYmGo000000;oZZSD00?o
0000ooooooooool02_ooool01?l0003oZZSDojZXe?l00004ojfZe003o`000?oooooooooo00kooooo
00Go0000ojfZe?n]Z]Co[J[Do`000003ok2/e003o`000?oooooooooo00Oooooo2ol00004ok2/e003
o`000?nd/=Co];3D00?o];3D00?o0000ooooooooool05?ooool00ol0003o];3DokB`e003okB`e003
o`000?ni]=Go^KCE00?o^KCE00?o0000ooooooooool06Oooool00ol0003o^KCEokVde@03okVde@03
o`000?nm^]Oo_K[G00Co_K[G0_l0000Oooooo`;o00000onm^]L5o`000003okfjeol0003o000001Go
oooo00?o0000ooooooooool0L?ooool006Wooooo0_l0000mooooo`;o00003?nQY=P00ol0003ooooo
o`000003oj6Tf004o`000?nTYMOoY:GGo`0000oooooo00Co0000ojBUeonTYMOoY:GG0_l00009oooo
o`03o`000?nVY]Ko000000;ooooo0_l00002ooooo`04o`000?nWYmKoZ:OEo`0000Sooooo00Go0000
ojRWeOl0003oZZSDo`00000<ooooo`04o`000?nZZ=CoZZSDo`0000Co[J[D00?o0000ooooooooool0
3_ooool01Ol0003o[J[DojfZe?n]Z]Co000000?o/:cD2_l0000:ok6/e003o`000?n`[=Co/:cD00;o
/:cD00?o0000okB`e?nd/=@00ond/=@7o`00013ooooo00?o0000okB`e?nd/=@00_nd/=@00ol0003o
^KCEokVde@03okVde@03o`000?oooooooooo01Wooooo00?o0000okVdeOni]=D01?ni]=D00ol0003o
_K[Gokfje`03okfje`03o`000?oooooo0000027ooooo0ol00005okfje`04o`000?o0`=[o0000o`00
01Gooooo00?o0000ooooooooool0Koooool006Oooooo0_l0000nooooo`03o`000?nQY=SoXJCH00_o
XJCH00Go0000ooooooooooooooooo`000003oj6Tf004o`000?nTYMOoY:GGo`0000oooooo00Ko0000
ojBUeonTYMOo0000ojJVe_l00008ooooo`04o`000?nVY]KoYZKFo`0000;ooooo0_l00002ooooo`?o
00002?ooool00ol0003oZ:OEo`000002ojZXe003o`000?oooooooooo00[ooooo00Co0000ojZXe?nZ
Z=Co00000on]Z]@00ol0003oooooooooo`0:ooooo`Go00000on]Z]@01Ol0003o/:cDok2/e?n`[=Co
000001Co/JcD00Go0000ok2/e?n`[=Co/:cDo`000004okB`e003o`000?nd/=Co];3D00Go];3D2ol0
0004ooooo`03o`000?nd/=Co];3D00?o];3D00?o0000okVdeOni]=D00oni]=D00ol0003ooooooooo
o`0Iooooo`03o`000?ni]=Go^KCE00?o^KCE00?o0000okfjeonm^]L01?nm^]L00ol0003oooooo`00
000Pooooo`03o`000?nm^]Oo_K[G00Go_K[G00?o0000ol30f_l000000_o0`=X00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo06oooooo001Tooooo`?o0000?oooool00ol0003oXJCHoj6Tf00;
oj6Tf003o`000?oooooooooo00?ooooo00Go0000oj6Tf?nQY=SoXJCHo`000002ojBUe`03o`000?oo
oooooooo00cooooo00Oo0000ojBUeonTYMOoY:GGo`000?nVY]Ko000000Sooooo00?o0000ojJVe_l0
00000_ooool01_l0003oYjOFo`000?oooooo0000ojNWeP;o00001oooool01_l0003oZ:OEojRWeOl0
003oZZSDo`0000cooooo00Co0000ojZXe?nZZ=Co00001?n]Z]@01?l0003oooooooooooooool8o`00
00Co[J[D00Go0000ojfZe?n]Z]Co[J[Do`000002ok2/e003o`000?na[=Co/JcD01Co/JcD00Co0000
ok2/e?n`[=Co00000ond/=@00ol0003o];3DokB`e00AokB`e0Go00001Ond/=@00ol0003o^KCEokVd
e@03okVde@03o`000?oooooooooo01Sooooo00?o0000okVdeOni]=D01?ni]=D00ol0003o_K[Gokfj
e`03okfje`04o`000?ooooooooooo`0001oooooo00?o0000okfjeonm^]L01Onm^]L01?l0003o`<3J
ol30f_l00003ol30fP03o`000?oooooooooo01;ooooo00?o0000ooooooooool0K_ooool006;ooooo
0_l00010ooooo`;o00003?nQY=P2o`0000Oooooo00Go0000oj6Tf?nQY=SoXJCHo`000002ojBUe`03
o`000?oooooooooo00cooooo00Oo0000ojBUeonTYMOoY:GGo`000?nVY]Ko000000Oooooo00Co0000
ojJVe_nVY]Ko00000_ooool2o`0000;ooooo0ol00008ooooo`03o`000?nXYmGo000000;oZZSD00?o
0000ooooooooool02Oooool01?l0003oZZSDojZXe?l00004ojfZe0Co00003On]Z]@01?l0003o[J[D
ojfZe?l00002ok2/e003o`000?na[=Co/JcD01Go/JcD00?o0000ok2/e?l000000_nd/=@00ol0003o
];3DokB`e00FokB`e003o`000?nd/=Co];3D00;o];3D00?o0000okVdeOni]=D00oni]=D00ol0003o
ooooooooo`0Hooooo`03o`000?ni]=Go^KCE00Co^KCE00?o0000okfjeonm^]L00onm^]L01Ol0003o
oooooooooooooooo000001kooooo00?o0000okfjeonm^]L01Onm^]L01Ol0003o`<3Jol30f_o0`=[o
000000Co`<3J00?o0000ooooooooool04_ooool00ol0003oooooooooo`1]ooooo`00Goooool3o`00
047ooooo00?o0000oj6Tf?nQY=P02onQY=P00ol0003oooooooooo`08ooooo`07o`000?nQY=SoXJCH
oj6Tf?l0003oY:GGo`00000?ooooo`06o`000?nTYMOoY:GGo`000?nVY]Ko00002?ooool02ol0003o
YZKFojJVe_l0003oooooo`000?nWY]Ko0000ooooool0003oYjOF00;o00001oooool01_l0003oZ:OE
ojRWeOl0003oZZSDo`0000cooooo00Co0000ojZXe?nZZ=Co00000on]Z]@00ol0003o[J[DojfZe00?
ojfZe005o`000?n]Z]Co0000ok2/e?l000006?na[=@01Ol0003o/:cDo`000?nd/=Co000001[o];3D
00Go0000okB`e?nd/=Co];3Do`000004okVde@Co00006?ooool00ol0003o^KCEokVde@03okVde@03
o`000?nm^]Oo_K[G00Co_K[G00Go0000ooooooooooooooooo`00000Mooooo`03o`000?nm^]Oo_K[G
00Go_K[G00?o0000ol30f_o0`=X00_o0`=X00ol0003o`<3Jol30fP03ol30fP03o`000?oooooooooo
017ooooo00?o0000ooooooooool0KOooool005gooooo0_l00013ooooo`03o`000?nQY=SoXJCH00_o
XJCH00?o0000ooooooooool02_ooool01?l0003oXJCHoj6Tf?l00002ojBUe`03o`000?oooooooooo
00gooooo00Ko0000ojBUeonTYMOo0000ojJVe_l00008ooooo`03o`000?nVY]Ko000000;ooooo0_l0
0002ooooo`03o`000?nWYmKo000000Sooooo00Go0000ojRWeOl0003oZZSDo`00000:ooooo`?o0000
0_nZZ=@01Ol0003o[J[DojfZe?n]Z]Co000001;o[J[D00Co0000ojfZe?l0003o00006Ona[=@3o`00
01_o];3D00Go0000okB`e?nd/=Co];3Do`000003okVde@03o`000?ni]=Go^KCE00;o^KCE0ol0000D
ooooo`03o`000?ni]=Go^KCE00Co^KCE00?o0000okfjeonm^]L00onm^]L00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01[ooooo00?o0000okfjeonm^]L01Onm^]L00ol0003o`<3Jol30fP03
ol30fP03o`000?o0`=[o`<3J00Co`<3J00?o0000ooooooooool04Oooool00ol0003oooooooooo`1/
ooooo`00F_ooool3o`0004Cooooo00?o0000oj6Tf?nQY=P02_nQY=P2o`0000kooooo00Co0000oj6T
f?nQY=So00000_nTYML00ol0003oooooooooo`0<ooooo`07o`000?nTYMOoY:GGojBUeol0003oYZKF
o`000007ooooo`04o`000?nVY]KoYZKFo`0000;ooooo0_l00002ooooo`?o00001oooool00ol0003o
Z:OEo`000002ojZXe003o`000?oooooooooo00?ooooo1?l00002ojZXe004o`000?nZZ=CoZZSDo`00
00;o[J[D00?o0000ojfZe?n]Z]@04_n]Z]@3o`0000co/JcD3ol00003okB`e003o`000?nd/=Co];3D
01Ko];3D00Co0000okB`e?nd/=Co00000oni]=D00ol0003o^KCEokVde@06okVde@?o00004?ooool0
0ol0003o^KCEokVde@04okVde@03o`000?nm^]Oo_K[G00Co_K[G00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?nm^]Oo_K[G00Go_K[G00?o0000ol30f_o0`=X00oo0`=X0
0ol0003o`<3Jol30fP06ol30fP03o`000?oooooooooo017ooooo00?o0000ooooooooool0Joooool0
05Sooooo0_l00017ooooo`;oW:CJ0_l00008oj6Tf003o`000?oooooooooo00kooooo00Go0000oj6T
f?nQY=SoXJCHo`000002ojBUe`03o`000?oooooooooo00cooooo00Co0000ojBUeonTYMOoY:GG0_l0
0008ooooo`05o`000?nVY]KoYZKFo`000?ooool00ol000001Ooooooo0000ojNWe_nXYmGo000000Oo
oooo00Go0000ojRWeOl0003oZZSDo`000002ooooo`?o00001onZZ=@01_l0003oZZSDojZXe?l0003o
[J[Do`0001;o[J[D4Ol0000>ok6WcP03o`000?ng[<ko]jc>00;o]jc>2?l0000AokB`e004o`000?nd
/=Co0000okVde@;o00003?ni]=D3o`0000gooooo00?o0000okVdeOni]=D01?ni]=D00ol0003o_K[G
okfje`03okfje`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?ooool00ol0003o_K[G
okfje`05okfje`03o`000?o0`=[o`<3J00Co`<3J00?o0000ol30f_o0`=X01oo0`=X00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo06_ooooo001Fooooo`;o0000B?ooool01?l0003oW:CJoibT
f_nLY=X4o`0000CoXJCH00?o0000ooooooooool04?ooool01Ol0003oXJCHoj6Tf?nQY=So000000;o
Y:GG00?o0000ooooooooool03?ooool01_l0003oY:GGojBUeol0003oYZKFo`0000Oooooo00Co0000
ojJVe_nVY]Ko00000_ooool2o`0000;ooooo0ol00007ooooo`03o`000?nXYmGo000000;oZZSD0_l0
000;ojZXe005o`000?nZZ=Co0000ojfZe?l000003?n]Z]@6o`0000?o[JC>00?o0000ok6Wc_naYlh0
6?naYlh00ol0003o]jc>o`00000;okN/cPOo00002_nd/=@01?l0003o];3Do`000?l0000AokVde@?o
00002Oooool00ol0003o^KCEokVde@04okVde@03o`000?nm^]Oo_K[G00?o_K[G00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?nm^]Oo_K[G00Go_K[G00?o0000ol30f_o0
`=X01?o0`=X2o`0000[o`<3J00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Zooooo`00
Doooool3o`0004Wooooo00Co0000oibTf_nLY=[o00000_nLY=X00ol0003oXJCHoj6Tf002o`000003
oj6Tf?l0003ooooo01?ooooo00Go0000oj6Tf?nQY=SoXJCHo`000002ojBUe`03o`000?oooooooooo
00_ooooo00Oo0000ojBUeonTYMOoY:GGo`000?nVY]Ko000000Oooooo00Go0000ojJVe_nVY]Ko0000
ooooo`03o`000003ooooool0003oYjOF00;o00001Oooool3o`000004ojRWeOl0003oZZSDo`0000go
ZZSD0_l000000on]Z]Co0000ojfZe006ojfZe0Go00002?n]Y<h00ol0003o/JO>o`00000Hok6WcP05
o`000?naYlko]jc>okN/c_l000004Ong[<h8o`0000;o];3D0ol0000EokVde@?o00001_ooool00ol0
003o^KCEokVde@03okVde@03o`000?nm^]Oo_K[G00Co_K[G00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Fooooo`03o`000?nm^]Oo_K[G00Go_K[G00?o0000ol30f_o0`=X01?o0`=X01?l0
003oooooooooool0000:ol30fP03o`000?oooooooooo013ooooo00?o0000ooooooooool0JOooool0
057ooooo0_l0001;ooooo`03o`000?nLY=[oW:CJ00;oW:CJ00Co0000oibTf_nLY=[o00000onQY=P2
o`0001Gooooo00Go0000oj6Tf?nQY=SoXJCHo`000002ojBUe`03o`000?oooooooooo00_ooooo00Oo
0000ojBUeonTYMOoY:GGo`000?nVY]Ko000000Oooooo00?o0000ojJVe_l000000_ooool2o`0000;o
oooo0ol00002ooooo`?o00000_nXYmD01Ol0003oZ:OEo`000?nZZ=Co000000ooZZSD00?o0000ojfZ
e?n]Z]@01_l0000=ojfTcP;o000000?o/JO>o`000?naYlh05_naYlh01Ol0003o/JO>okN/c_ng[<ko
000001Wo]jc>1?l0000IokVde@?o00000_ooool00ol0003o^KCEokVde@04okVde@03o`000?nm^]Oo
_K[G00?o_K[G00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?nm^]Oo
_K[G00Go_K[G00?o0000ol30f_o0`=X01?o0`=X00ol0003oooooooooo`02ooooo`03o`000?o0`=[o
`<3J00So`<3J00?o0000ooooooooool03oooool00ol0003oooooooooo`1Yooooo`00C_ooool3o`00
04cooooo00?o0000oibTf_nLY=X00onLY=X01Ol0003oW:CJoibTf_nLY=[o000000CoXJCH00?o0000
ooooooooool04oooool01ol0003oXJCHoj6Tf?nQY=So0000ojBUeol000003_ooool01_l0003oY:GG
ojBUeol0003oYZKFo`0000Oooooo00Co0000ojJVe_nVY]Ko00000_ooool2o`000003ooooool0003o
YjOF00?o00001_nXYmD01?l0003oZ:OEo`000?l0000=ojZXe0Go00004_n]Y<h01Ol0003o[JC>ojfT
c_naYlko000001Ko/JO>00?o0000ok6Wc_naYlh00ong[<h00ol0003o]jc>okN/cP0GokN/cP03o`00
0?ngZlko000000;o_;7?0ol0000GokVde@;o00001_ni]=D00ol0003o_K[Gokfje`04okfje`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04oooool00ol0003o_K[Gokfje`05okfje`03o`00
0?o0`=[o`<3J00Co`<3J00?o0000ooooooooool01?ooool00ol0003o`<3Jol30fP08ol30fP03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0J?ooool004cooooo0_l0001>ooooo`03o`000?nL
Y=[oW:CJ00CoW:CJ00?o0000oibTf_nLY=X00_nLY=X00ol0003oXJCHoj6Tf002oj6Tf003o`000?oo
oooooooo01?ooooo00Co0000oj6Tf?nQY=So00000_nTYML00ol0003oooooooooo`0<ooooo`06o`00
0?nTYMOoY:GGo`000?nVY]Ko00001oooool01Ol0003oYZKFojJVe_l0003ooooo00Oo00002?nXYmD2
o`000003ojZXe?l0003oZZSD00OoZZSD1?l00002ojVRc`;o00004on]Y<h00ol0003o[JC>ojfTcP02
ok6WcP03o`000?naYlko/JO>00So/JO>2ol00003ok6WcP05o`000?ng[<ko]jc>okN/c_l000005ong
[<h01Ol0003o]j_>okN[c_nl/Loo000000Co_;7?1?l0000DokVde@03o`000?ni]=Go^KCE00Co^KCE
00?o0000okfjeonm^]L00onm^]L00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo
00?o0000okfjeonm^]L01Onm^]L00ol0003o`<3Jol30fP04ol30fP03o`000?oooooooooo00Kooooo
00?o0000ol30f_o0`=X02?o0`=X00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Sooooo
0019ooooo`?o0000Coooool00ol0003oW:CJoibTfP06oibTfP03o`000?nLY=[oW:CJ00;oW:CJ00?o
0000oj6Tf?nQY=P00_nQY=P00ol0003oooooooooo`0Cooooo`04o`000?nQY=SoXJCHo`0000;oY:GG
00?o0000ooooooooool02oooool01ol0003oY:GGojBUeonTYMOo0000ojJVe_l000001_ooool01Ol0
003oYZKFojJVe_l0003ooooo00?o000000?oYjKFo`000?nWYmH00_l00008ojRWe@?o00001OnZZ=@3
o`0000KoZJ;?00?o0000ojfTc_l000003on]Y<h3o`0000?o[JC>0onaYlh00ol0003o/JO>o`000007
o`0000[ooooo1?naYlh01Ol0003o]jc>okN/c_ng[<ko000000Kooooo2ol00005okN/cP06o`000?ng
Zlko]j_>o`000?nl/Loo00002?nl/Ll3o`00017o^KCE00?o0000okVdeOni]=D00oni]=D00ol0003o
_K[Gokfje`03okfje`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003o
_K[Gokfje`05okfje`03o`000?o0`=[o`<3J00Co`<3J00?o0000ooooooooool02?ooool00ol0003o
`<3Jol30fP07ol30fP03o`000?oooooooooo00oooooo00?o0000ooooooooool0Ioooool004Oooooo
0_l0001Booooo`03o`000?nLY=[oW:CJ00KoW:CJ00?o0000oibTf_nLY=X00onLY=X00ol0003oXJCH
oj6Tf002oj6Tf003o`000?oooooooooo01;ooooo00Go0000oj6Tf?nQY=SoXJCHo`000002ojBUe`03
o`000?oooooooooo00_ooooo00Co0000ojBUeonTYMOoY:GG0_l00007ooooo`0<o`000?nVY]KoYZKF
o`000?nWY]Ko0000ojNVe_l0003oYjKFo`000?nWYmKo00002OnXYmD2o`000003ojZXe?l0003o0000
00;o00002OnYX/l01?l0003o[JC>ojfTc_l00009ojfTcPGo00000_ooool4ojfTcP04o`000?naYlko
/JO>o`0001?ooooo1?naYlh01Ol0003o]jc>okN/c_ng[<ko0000017ooooo1Ol00003okN[cP04o`00
0?nl/Loo_;7?o`0000[o_;7?1?l0000>okVde@05o`000?ni]=Go^KCEokVdeOl000001_nm^]L00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000okfjeonm^]L01Onm^]L00ol0
003o`<3Jol30fP04ol30fP03o`000?oooooooooo00[ooooo00?o0000ol30f_o0`=X01oo0`=X00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo06Kooooo0014ooooo`?o0000Doooool00ol0003o
W:CJoibTfP08oibTfP;o00001?nLY=X00ol0003oXJCHoj6Tf002oj6Tf003o`000?oooooooooo01;o
oooo00Go0000oj6Tf?nQY=SoXJCHo`000002ojBUe`03o`000?oooooooooo00_ooooo00Ko0000ojBU
eonTYMOo0000ojJVe_l00006ooooo`?o000000?oYZKFo`000?nWY]H00_l00002ojNVeP?o00002?nX
YmD3o`0000goZJ;?0_l00002ojfTcP04o`000?n]Y<ko[JC>ojfTcPGo00001oooool4ojfTcP04o`00
0?naYlko/JO>o`0001?ooooo1?naYlh01Ol0003o]jc>okN/c_ng[<ko000001Gooooo1?ngZlh01?l0
003o_;7?okbacol0000>okbac`Co00002_ni]=D01Ol0003o^KCEokVdeOni]=Go000000Co_K[G0ol0
000:ooooo`03o`000?oooooooooo00oooooo00?o0000okfjeonm^]L01Onm^]L00ol0003o`<3Jol30
fP04ol30fP03o`000?oooooooooo00cooooo00?o0000ol30f_o0`=X01oo0`=X00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo06Kooooo0012ooooo`;o0000EOooool00ol0003oW:CJoibTfP09
oibTfP03o`000?oooooo000000CoW:CJ00?o0000oj6Tf?nQY=P00_nQY=P00ol0003oooooooooo`0B
ooooo`05o`000?nQY=SoXJCHoj6Tf?l000000_nTYML00ol0003oooooooooo`0:ooooo`07o`000?nT
YMOoY:GGojBUeol0003oYZKFo`000002ooooo`?o00000onVY]H2o`0000;oYjKF0_l00002ojNVeP;o
00001OnXYmD3o`000003ojNQd?l0003oZJ;?00goZJ;?0_l00003ojfTcP?o00003?ooool01Ol0003o
[JC>ojfTc_n]Y<ko000000;o/JO>00?o0000ooooooooool04Oooool3ok6WcP03o`000?ng[<ko]jc>
00;o]jc>00?o0000ooooooooool04oooool4okN[cP05o`000?nl/Loo_;7?okbacol000004Onl/Ll3
o`0000Oo^KCE00Co0000okVdeOni]=Go00000onm^]L2o`0000?o_K[G0_l00008ooooo`03o`000?oo
oooooooo00kooooo00?o0000okfjeonm^]L01Onm^]L00ol0003o`<3Jol30fP04ol30fP03o`000?oo
oooooooo00kooooo00?o0000ol30f_o0`=X01oo0`=X00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo06Gooooo0010ooooo`;o0000E_ooool00ol0003oW:CJoibTfP09oibTfP05o`000?oooooo
ooooooooool000001?nLY=X00ol0003oXJCHoj6Tf002oj6Tf003o`000?oooooooooo01;ooooo00Go
0000oj6Tf?nQY=SoXJCHo`000002ojBUe`03o`000?oooooooooo00[ooooo00Ko0000ojBUeonTYMOo
Y:GGo`000?nVY]H2o`0000OoYZKF0_l00002ojNVeP;o00000_nWY]H00ol0003oZ:OEojRWe@03o`00
00CoYj7@0_l0000;ojVRc`?o000000GoZJ;?ojfTc_n]Y<ko[JC>o`00000?ooooo`?o[JC>00Go0000
ok6Wc_naYlko/JO>o`00000Booooo`?o/JO>00?o0000okN/c_ng[<h00_ng[<h00ol0003ooooooooo
o`0Booooo`05o`000?ngZlko]j_>okN[c_l000001?nl/Ll00ol0003oooooooooo`03o`0000oo_;7?
1?l00003okVde@03o`000?ni]=Go^KCE00Co00001onm^]L00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00gooooo00?o0000okfjeonm^]L01Onm^]L00ol0003o`<3Jol30fP04ol30fP03o`00
0?oooooooooo013ooooo00?o0000ol30f_o0`=X01oo0`=X00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo06Cooooo000mooooo`?o0000Eoooool00ol0003oW:CJoibTfP09oibTfP03o`000?oo
oooooooo00?ooooo00?o0000oibTf_nLY=X00_nLY=X2o`0000?oXJCH0_l0000Cooooo`07o`000?nQ
Y=SoXJCHoj6Tf?l0003oY:GGo`00000=ooooo`06o`000?nTYMOoY:GGo`000?nVY]Ko00002OnVY]H0
1Ol0003oYjKFojNVe_nWY]Ko000000;oYjKF0ol00008ojNQd0;o00001_nYX/l4o`0000;ooooo0_nY
X/l01?l0003o[JC>ojfTc_l0000?ooooo`Co[JC>00Co0000ok6Wc_naYlko00004_ooool3ok6WcP03
o`000?ng[<ko]jc>00;o]jc>00?o0000ooooooooool04_ooool01Ol0003o]j_>okN[c_ngZlko0000
00Co_;7?00?o0000ooooooooool01?ooool3o`0000oo_;7?0ol000001?ni]=Go0000o`000?l0000;
okfje`;o00001Oooool00ol0003oooooooooo`0<ooooo`03o`000?nm^]Oo_K[G00Go_K[G00?o0000
ol30f_o0`=X01?o0`=X00ol0003oooooooooo`0Aooooo`03o`000?o0`=[o`<3J00So`<3J00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1Tooooo`00>oooool2o`0005Wooooo00?o0000oibT
f_nLY=X02OnLY=X00ol0003oooooooooo`05ooooo`03o`000?nLY=[oW:CJ00?oW:CJ00?o0000oj6T
f?nQY=P00_nQY=P00ol0003oooooooooo`0Aooooo`04o`000?nQY=SoXJCHo`0000;oY:GG00?o0000
ooooooooool02_ooool3o`000004ojBUeol0003oYZKFo`0000WoYZKF00?o0000ojNVe_nWY]H00ol0
00000onUX=3o0000ojNQd008ojNQd003o`000?nYX/oo000000;oZJ;?0ol00006ooooo`03o`000?nY
X/oo000000?o[JC>00?o0000ooooooooool03?ooool01Ol0003o[JC>ojfTc_n]Y<ko000000;o/JO>
00?o0000ooooooooool04?ooool3ok6WcP03o`000?ng[<ko]jc>00;o]jc>00?o0000ooooooooool0
4_ooool01Ol0003o]j_>okN[c_ngZlko000000?o_;7?00?o0000ooooooooool02?ooool4o`0000ko
_;7?0_l0000?okfje`;o00000oooool00ol0003oooooooooo`0;ooooo`03o`000?nm^]Oo_K[G00Go
_K[G00?o0000ol30f_o0`=X01?o0`=X00ol0003oooooooooo`0Cooooo`03o`000?o0`=[o`<3J00So
`<3J00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Sooooo`00>?ooool3o`0005[ooooo
00?o0000oibTf_nLY=X02OnLY=X00ol0003oooooooooo`07ooooo`03o`000?nLY=[oW:CJ00?oW:CJ
00?o0000oj6Tf?nQY=P00_nQY=P00ol0003oooooooooo`0Aooooo`04o`000?nQY=SoXJCHo`0000;o
Y:GG00?o0000ooooooooool01oooool2o`0000?oXjGG00Co0000ojBUeol0003o00002_nVY]H2o`00
0003ojFPd?l0003oYJ3@00;oYJ3@00?o0000ojNQd?nWXM001OnWXM02o`0000;oZJ;?0_l0000:oooo
o`;oZJ;?00Co0000ojfTc_n]Y<ko00003_ooool01Ol0003o[JC>ojfTc_n]Y<ko000000;o/JO>00?o
0000ooooooooool04?ooool01?l0003o/JO>ok6Wc_l00004okN/cP03o`000?oooooooooo01;ooooo
00Go0000okN[c_ngZlko]j_>o`000003okbac`03o`000?oooooooooo00cooooo1?l00007okbac`?o
000000Co_;7?o`000?o1^=7o00003onm^]L2o`000003ooooool0003ooooo00_ooooo00?o0000okfj
eonm^]L01Onm^]L00ol0003o`<3Jol30fP04ol30fP03o`000?oooooooooo01Gooooo00?o0000ol30
f_o0`=X02?o0`=X00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06?ooooo000fooooo`;o
0000GOooool00ol0003oW:CJoibTfP08oibTfP03o`000?oooooooooo00Wooooo00?o0000oibTf_nL
Y=X00onLY=X00ol0003oXJCHoj6Tf002oj6Tf003o`000?oooooooooo013ooooo00Go0000oj6Tf?nQ
Y=SoXJCHo`000002ojBUe`03o`000?oooooooooo00Cooooo0_l00006oj>Ue`Co00001_nVY]H2o`00
0003ojBOdOl0003oYJ3@00;oYJ3@00?o0000ojFPd?nUX=000_l00003ojNQd0?o000000GoooooojNQ
d?l0003oZJ;?o`00000;ooooo`;oZJ;?00Co0000ojfTc_n]Y<ko00003_ooool01Ol0003o[JC>ojfT
c_n]Y<ko000000;o/JO>00?o0000ooooooooool04?ooool01?l0003o/JO>ok6Wc_l00004okN/cP03
o`000?oooooooooo017ooooo00Go0000okN[c_ngZlko]j_>o`000004okbac`03o`000?oooooooooo
013ooooo0ol00002okbac`;o00000onl/Ll2o`0000?o`KSA0_l0000>okfje`;o00002oooool00ol0
003o_K[Gokfje`05okfje`03o`000?o0`=[o`<3J00Co`<3J00?o0000ooooooooool05oooool00ol0
003o`<3Jol30fP08ol30fP03o`000?oooooooooo00cooooo00?o0000ooooooooool0H_ooool003?o
oooo0ol0001Nooooo`03o`000?nLY=[oW:CJ00SoW:CJ00?o0000ooooooooool02oooool00ol0003o
W:CJoibTfP03oibTfP03o`000?nQY=SoXJCH00;oXJCH00?o0000ooooooooool04?ooool01Ol0003o
XJCHoj6Tf?nQY=So000000;oY:GG00?o0000ooooooooool00_ooool00ol0003oXjGGoj>Ue`08oj>U
e`;o00000onVY]H3o`0000?oY9oA0_l00002ojFPd003o`000?nUX=3oYJ3@00;o00000_nWXM000ol0
003oooooooooo`03ooooo`04ojNQd?nYX/ooZJ;?o`0000[ooooo00?o0000ojVRcol000000on]Y<h0
0ol0003oooooooooo`0;ooooo`05o`000?n]Y<ko[JC>ojfTc_l000000_naYlh00ol0003ooooooooo
o`0@ooooo`04o`000?naYlko/JO>o`0000Co]jc>00?o0000ooooooooool04Oooool01Ol0003o]j_>
okN[c_ngZlko000000Co_;7?00?o0000ooooooooool04oooool2o`0000Go_;7?0_l00005ol6hd@;o
00003Onm^]L2o`0000Wooooo00?o0000okfjeonm^]L01Onm^]L00ol0003o`<3Jol30fP04ol30fP03
o`000?oooooooooo01Wooooo00?o0000ol30f_o0`=X02?o0`=X00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo067ooooo000aooooo`;o0000H?ooool00ol0003oW:CJoibTfP08oibTfP03o`00
0?oooooooooo00gooooo0_l00004oibTfP03o`000?nQY=SoXJCH00;oXJCH00?o0000ooooooooool0
4?ooool01Ol0003oXJCHoj6Tf?nQY=So000000;oY:GG00Co0000ooooool0003o00003?nSYML01?l0
003oYZKFo`000?l00006ojBOd@?o000000CoYJ3@o`000?nUX=3oYJ3@0ol00007ooooo`04ojNQd?l0
003oZJ;?o`0000_ooooo0_nYX/l01?l0003o[JC>ojfTc_l0000>ooooo`04o`000?n]Y<ko[JC>o`00
00?o/JO>00?o0000ooooooooool03oooool01?l0003o/JO>ok6Wc_l00004okN/cP03o`000?oooooo
oooo017ooooo00Go0000okN[c_ngZlko]j_>o`000003okbac`03o`000?oooooooooo01Gooooo1Onl
/Ll01?l0003o`KSAol6hdOl00006ol6hd@03o`000?nm^]Oo_K[G00[o_K[G00Co0000okfjeol0003o
00001_ooool00ol0003o_K[Gokfje`05okfje`03o`000?o0`=[o`<3J00Co`<3J00?o0000oooooooo
ool06oooool00ol0003o`<3Jol30fP08ol30fP03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0HOooool002oooooo0_l0001Qooooo`03o`000?nLY=[oW:CJ00SoW:CJ00?o0000ooooooooool0
4?ooool00ol0003oW:CJoibTfP02oibTfP03o`000?nQY=SoXJCH00;oXJCH00?o0000ooooooooool0
4?ooool01Ol0003oXJCHoj6Tf?nQY=So000000;oY:GG00?o0000oj>UeonSYML03OnSYML00ol0003o
Y9oAojBOd@07ojBOd@;o000000OoYJ3@o`000?l0003o0000oooooonUX=3o000000Oooooo00Go0000
ojNQd?nYX/ooZJ;?o`00000:ooooo`03o`000?nYX/oo000000;o[JC>00?o0000ooooooooool03?oo
ool01?l0003o[JC>ojfTc_l00003ok6WcP03o`000?oooooooooo00oooooo00Co0000ok6Wc_naYlko
00001?ng[<h00ol0003oooooooooo`0Aooooo`05o`000?ngZlko]j_>okN[c_l000000onl/Ll00ol0
003oooooooooo`0Dooooo`03o`000?nl/Loo_;7?00?o_;7?00Co0000ol6hdOo1^=7o00001oo1^=42
o`0000[o_K[G00Go0000okfjeonm^]Oo_K[Go`000004ooooo`03o`000?nm^]Oo_K[G00Go_K[G00?o
0000ol30f_o0`=X01?o0`=X00ol0003oooooooooo`0Mooooo`03o`000?o0`=[o`<3J00So`<3J00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Pooooo`00;?ooool3o`0006;ooooo00?o0000
oibTf_nLY=X02?nLY=X00ol0003oooooooooo`0Booooo`03o`000?nLY=[oW:CJ00;oW:CJ00?o0000
oj6Tf?nQY=P00_nQY=P00ol0003oooooooooo`0@ooooo`04o`000?nQY=SoXJCHo`0000;oY:GG00?o
0000oj>UeonSYML02_nSYML2o`000003oj6Nd_l0003o000000SoY9oA0ol000000ooooooo0000o`00
0002ooooo`03ojNQd?l0003ooooo00Kooooo00CoYj7@o`000?nYX/oo00002_ooool00ol0003oZJ;?
o`000003ojfTcP03o`000?oooooooooo00_ooooo00Go0000ojfTc_n]Y<ko[JC>o`000002ok6WcP03
o`000?oooooooooo00kooooo00Go0000ok6Wc_naYlko/JO>o`000003okN/cP03o`000?oooooooooo
017ooooo00Go0000okN[c_ngZlko]j_>o`000004okbac`03o`000?oooooooooo01Cooooo1Onl/Ll0
1Ol0003o`KSAol6hdOo1^=7o000000Wo`KSA0_l00008okfje`03o`000?nm^]Oo_K[G00;o_K[G0_l0
00000ooooooo0000okfje`06okfje`03o`000?o0`=[o`<3J00Co`<3J00?o0000ooooooooool07ooo
ool00ol0003o`<3Jol30fP08ol30fP03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Gooo
ool002[ooooo0_l0001Tooooo`03o`000?nLY=[oW:CJ00SoW:CJ00?o0000ooooooooool05?ooool0
0ol0003oW:CJoibTfP02oibTfP03o`000?nQY=SoXJCH00;oXJCH0_l0000Aooooo`04o`000?nQY=So
XJCHo`0000;oY:GG00?o0000oj>UeonSYML01onSYML2o`0000?oXIkB0ol00007ojBOd@03o`000?nT
Wm7o000000;ooooo00Go0000ooooooooooooYJ3@o`000007ooooo`;o000000?oZJ;?o`000?ooool0
2_ooool2ojVRc`04o`000?n]Y<ko[JC>o`0000gooooo00Go0000ojfTc_n]Y<ko[JC>o`000002ok6W
cP03o`000?oooooooooo00kooooo00Go0000ok6Wc_naYlko/JO>o`000003okN/cP03o`000?oooooo
oooo017ooooo00Go0000okN[c_ngZlko]j_>o`000004okbac`03o`000?oooooooooo01?ooooo00?o
0000okbaconl/Ll00onl/Ll01ol0003o`KSAol6hdOo1^=7o0000ooooool000002Oo1^=42o`0000Ko
_K[G00?o0000okfjeonm^]L01?nm^]L00ol0003o_K[Gokfje`05okfje`03o`000?o0`=[o`<3J00Co
`<3J00?o0000ooooooooool08Oooool00ol0003o`<3Jol30fP03ol30fPKo00003?ooool00ol0003o
ooooooooo`1Oooooo`009oooool3o`0006Gooooo0ol00008oibTfP03o`000?oooooooooo01Kooooo
00?o0000oibTf_nLY=X00_nLY=X00ol0003oXJCHoj6Tf003oj6Tf003o`000?oooooooooo00kooooo
0ol000001?nQY=So0000ojBUeol00007oj>Ue`;o00001OnQW]801?l0003oXIkBo`000?l00002ojBO
d@?o000000?oooooo`000?nTWm400_l000000ooooooo0000o`000002ooooo`03ojNQd?l0003ooooo
00Gooooo00Go0000ojNQd?l0003oZJ;?o`00000:ooooo`03o`000?nYX/oo000000;o[JC>00?o0000
ooooooooool02oooool01Ol0003o[JC>ojfTc_n]Y<ko000000;o/JO>00?o0000ooooooooool03_oo
ool01Ol0003o/JO>ok6Wc_naYlko000000?o]jc>00?o0000ooooooooool04Oooool01Ol0003o]j_>
okN[c_ngZlko000000?o_;7?00?o0000ooooooooool05?ooool00ol0003o_;7?okbac`02okbac`05
o`000?o1^=7o`KSAol6hdOl000001?ooool2o`0000So`KSA0_l00004okfje`03o`000?nm^]Oo_K[G
00Co_K[G00?o0000okfjeonm^]L01?nm^]L00ol0003o`<3Jol30fP04ol30fP03o`000?oooooooooo
02;ooooo1_l00003ol30fP03o`000?o2amko000000gooooo00?o0000ooooooooool0G_ooool002Ko
oooo0_l0001Wooooo`03o`000?nGXmgo000000Go00000_nLY=X00ol0003oooooooooo`0Hooooo`03
o`000?nLY=[oW:CJ00;oW:CJ00?o0000oj6Tf?nQY=P00onQY=P00ol0003oooooooooo`0<ooooo`04
o`000?nQY=SoXJCHoj6Tf0?o000000?oY:GGo`000?nSYML01?nSYML00ol0003oXIkBoj6NdP06oj6N
dP;o000000?oY9oAo`000?l000001Oooool00ol0003oY9oAo`000002ooooo`05o`000?oooooooooo
ojFPd?l000001oooool01?nWXM3o0000ojVRcol0000:ooooo`03o`000?nYX/oo000000?o[JC>00?o
0000ooooooooool02_ooool01Ol0003o[JC>ojfTc_n]Y<ko000000;o/JO>00?o0000ooooooooool0
3_ooool01Ol0003o/JO>ok6Wc_naYlko000000?o]jc>00?o0000ooooooooool04Oooool01Ol0003o
]j_>okN[c_ngZlko000000?o_;7?00?o0000ooooooooool04oooool00ol0003o_;7?okbac`02okba
c`03o`000?o1^=7o`KSA00;o`KSA00?o0000ooooooooool01?ooool00ol0003o`KSAol6hd@07ol6h
d@;o00000_nm^]L00ol0003o_K[Gokfje`04okfje`03o`000?nm^]Oo_K[G00?o_K[G00?o0000ol30
f_o0`=X01?o0`=X00ol0003oooooooooo`0Rooooo`03o`000?o0`=[o`<3J00Go`<3J0_l000001?o2
amko0000ol;7g_l0000<ooooo`03o`000?oooooooooo05kooooo000Vooooo`03o`000?oooooo0000
06Gooooo00Co0000oiNTgOl0003oUj?M0_l00003oibTfP?o00006oooool00ol0003oW:CJoibTfP02
oibTfP03o`000?nQY=SoXJCH00?oXJCH00?o0000ooooooooool02Oooool2o`0000KoXJCH0ol00003
oj>Ue`;o00002OnQW]801?l0003oXIkBo`000?l00006ooooo`05o`000?nTWm7oY9oAo`000?ooool0
0_l00002ooooo`03ojNQd?l0003ooooo00Gooooo00Go0000ojNQd?l0003oZJ;?o`00000:ooooo`03
o`000?nYX/oo000000;o[JC>00?o0000ooooooooool02oooool01?l0003o[JC>ojfTc_l00003ok6W
cP03o`000?oooooooooo00gooooo00Go0000ok6Wc_naYlko/JO>o`000003okN/cP03o`000?oooooo
oooo013ooooo00?o0000okN[c_ngZlh00_ngZlh01Ol0003o_;7?okbaconl/Loo000001Gooooo00?o
0000okbaconl/Ll00_nl/Ll01Ol0003o`KSAol6hdOo1^=7o000000Sooooo0_l00009ol6hd@;o0000
00?o_K[Go`000?nm^]L01?nm^]L00ol0003o_K[Gokfje`02okfje`03o`000?o0`=[o`<3J00Go`<3J
8oooool2o`0000Oo`<3J00Oo0000ol;7g_o2amko`/ONo`000?o2amko000000gooooo00?o0000oooo
ooooool0GOooool002Kooooo00Co0000oooooooooooo0000I?ooool00ol0003oUjCMo`000003oiNS
g@03o`000?nLY=[oW:CJ00?oW:CJ00?o0000ooooooooool06Oooool00ol0003oW:CJoibTfP02oibT
fP;o00001?nQY=P00ol0003oooooooooo`06ooooo`;o00002OnQY=P2o`000003oj>Ueol0003o0000
00_oXIkB00Go0000oj6Nd_l0003oY9oAo`000006ooooo`03o`000?nTWm7o000000;ooooo00Go0000
ooooooooooooYJ3@o`000007ooooo`04ojNQd?l0003oZJ;?o`0000[ooooo00?o0000ojVRcol00000
0_n]Y<h00ol0003oooooooooo`0;ooooo`04o`000?n]Y<ko[JC>o`0000?o/JO>00?o0000oooooooo
ool03Oooool01Ol0003o/JO>ok6Wc_naYlko000000?o]jc>00?o0000ooooooooool04?ooool01Ol0
003o]j_>okN[c_ngZlko000000?o_;7?00?o0000ooooooooool04oooool00ol0003o_;7?okbac`02
okbac`03o`000?o1^=7o`KSA00;o`KSA00?o0000ooooooooool02?ooool2o`0000Wo`KSA0_l00005
okfje`05o`000?nm^]Oo_K[Gokfjeol000001oo0`=XRooooo`;o00001oo0`=X2o`0000?o`/ON00Co
0000ol;7g_o2amko00003_ooool00ol0003oooooooooo`1Looooo`009_ooool01Ol0003ooooooooo
oooooooo000006;ooooo00Go0000oiNTgOnGY=goUjCMo`000003oiNSg@;o00001?nLY=X2o`0001[o
oooo00?o0000oibTf_nLY=X00onLY=X00ol0003oXJCHoj6Tf002oj6Tf003o`000?oooooooooo00Co
oooo00?o0000oj6Tf?nQY=P02onQY=P00ol0003oXIkBoj6NdP08oj6NdP;o000000Ooooooo`000?nQ
W];oXIkBo`000?nTWm7o000000Gooooo00Go0000ojBOdOnTWm7o0000ooooo`02o`0000;ooooo00?o
Yj7@o`000?ooool01Oooool01Ol0003oYj7@o`000?nYX/oo000000Wooooo00?o0000ojVRcol00000
0_n]Y<h00ol0003oooooooooo`0;ooooo`04o`000?n]Y<ko[JC>o`0000?o/JO>00?o0000oooooooo
ool03Oooool01Ol0003o/JO>ok6Wc_naYlko000000?o]jc>00?o0000ooooooooool04?ooool01Ol0
003o]j_>okN[c_ngZlko000000?o_;7?00?o0000ooooooooool04oooool00ol0003o_;7?okbac`02
okbac`05o`000?o1^=7o`KSAol6hdOl000003Oooool2o`0000So`KSA0_l00004okfje`04o`000?nm
^]Oo_K[Go`0000Oo`<3J8_ooool00ol0003o`<3Jol30fP06ol30fP03o`000?o2amko`/ON00;o`/ON
00?o0000ol;7g_o2amh00_o2amh00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05cooooo
000Uooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool01Ol0003oUjCMoiNT
gOnGY=go000000GoUj?M00?o0000oibTf_nLY=X00onLY=X00ol0003oooooooooo`0Iooooo`GoW:CJ
00?o0000oj6Tf?nQY=P00_nQY=P01?l0003oooooooooooooool2o`0000coXJCH00Co0000oifMdol0
003oXIkB0_l00004oj6NdP?o00001?ooool00ol0003oXIkBoj6NdP02o`0000Kooooo00Ko0000ojBO
dOl0003o0000ooooool00002ooooo`03ojFPd?l0003ooooo00Gooooo00Go0000ojNQd?l0003oZJ;?
o`000009ooooo`04o`000?nYX/ooZJ;?o`0000;o[JC>00?o0000ooooooooool02_ooool01Ol0003o
[JC>ojfTc_n]Y<ko000000;o/JO>00?o0000ooooooooool03Oooool01Ol0003o/JO>ok6Wc_naYlko
000000?o]jc>00?o0000ooooooooool04?ooool01Ol0003o]j_>okN[c_ngZlko000000?o_;7?00?o
0000ooooooooool04_ooool00ol0003o_;7?okbac`02okbac`03o`000?o1^=7o`KSA00;o`KSA00?o
0000ooooooooool03Oooool2o`0000Ko`KSA00Co0000ol6hdOl0003o00000_nm^]L00ol0003o_K[G
o`000004ol30fP?o00008Oooool2o`0000Oo`<3J0_l00005ol;7gP03o`000?o2amko`/ON00;o`/ON
00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Kooooo`009Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo05gooooo00?o0000oiNTgOnGY=d00onGY=d00ol0003oUj?MoiNS
g@03oiNSg@;o00001?nLY=X2o`0001[ooooo1OnLY=X00ol0003oXJCHoj6Tf002oj6Tf003o`000?oo
oooo000000goXJCH00?o0000oifMdonMWM<00_l00002oj6NdP04o`000?nQW];o0000o`0000Sooooo
00Go0000oj6Nd_l0003oY9oAo`000006ooooo`04o`000?nTWm7o0000ooooo`;o00000_ooool2o`00
00Kooooo0_l000000onYX/oo0000ooooo`09ooooo`03o`000?nYX/oo000000;o[JC>00?o0000oooo
ooooool02_ooool01Ol0003o[JC>ojfTc_n]Y<ko000000;o/JO>00?o0000ooooooooool03Oooool0
1?l0003o/JO>ok6Wc_l00004okN/cP03o`000?oooooooooo00oooooo00?o0000okN[c_ngZlh00_ng
Zlh01Ol0003o_;7?okbaconl/Loo000001?ooooo00?o0000okbaconl/Ll00onl/Ll01Ol0003o`KSA
ol6hdOo1^=7o000001;ooooo00?o0000ol6hdOo1^=400oo1^=401?l0003o`KSAol6hdOo1^=49o`00
00;o`<3J00?o0000ooooooooool07_ooool00ol0003o`<3Jol30fP06ol30fP03o`000?o2amko`/ON
00Co`/ON00?o0000ol;7g_o2amh01?o2amh00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
05[ooooo000Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00ol0003o
UjCMoiNTg@03oiNTg@03o`000?nGXmgoUj?M00GoUj?M00?o0000oibTf_nLY=X00onLY=X00ol0003o
ooooooooo`0Hooooo`GoW:CJ00?o0000oj6Tf?nQY=P00_nQY=P00ol0003oXJCHoj6Tf00:oj6Tf0;o
00000onMWM<00ol0003oWIgCo`000002oj6NdP03o`000?oooooooooo00Sooooo00Ko0000oj6Nd_nQ
W];o0000ojBOdOl00005ooooo`06o`000?nTWm7o0000o`000?oooooo00000_ooool00onUX=3o0000
ooooo`05ooooo`05o`000?nWXM3o0000ojVRcol000002Oooool00ol0003oZJ;?o`000002ojfTcP03
o`000?oooooooooo00[ooooo00Go0000ojfTc_n]Y<ko[JC>o`000002ok6WcP03o`000?oooooooooo
00gooooo00Co0000ok6Wc_naYlko00001?ng[<h00ol0003oooooooooo`0?ooooo`05o`000?ngZlko
]j_>okN[c_l000000onl/Ll00ol0003oooooooooo`0Booooo`03o`000?nl/Loo_;7?00;o_;7?00?o
0000ol6hdOo1^=400_o1^=400ol0003oooooooooo`0Aooooo`;o00000oo1^=401?l0003o`KSAol6h
dOo1^=44o`0000So`<3J00?o0000ooooooooool06oooool2o`0000Oo`<3J0_l00007ol;7gP03o`00
0?o2amko`/ON00Co`/ON00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Jooooo`009Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05[ooooo00?o0000oiNTgOnGY=d01OnG
Y=d2o`0000KoUj?M0_l00004oibTfP;o00006Oooool5oibTfP05o`000?nQY=SoXJCHoj6Tf?l00000
2onQY=P00ol0003oWIgCoifMd`04oifMd`05o`000?nMWM?o0000oj6Nd_l000002oooool01Ol0003o
XIkBo`000?nTWm7o000000Kooooo00Co0000ojBOdOl0003ooooo0_l00002ooooo`;o00001Oooool0
1Ol0003oYj7@o`000?nYX/oo000000Wooooo00Co0000ojVRconYX/oo00000_n]Y<h00ol0003ooooo
ooooo`0:ooooo`04o`000?n]Y<ko[JC>o`0000?o/JO>00?o0000ooooooooool03?ooool01?l0003o
/JO>ok6Wc_l00004okN/cP03o`000?oooooooooo00oooooo00Go0000okN[c_ngZlko]j_>o`000003
okbac`03o`000?oooooooooo017ooooo00?o0000okbaconl/Ll00onl/Ll01Ol0003o`KSAol6hdOo1
^=7o000001Kooooo0_l000000oo1^=7o0000o`000002o`0000;o`KSA0_l00009ol30fP03o`000?oo
oooooooo01Wooooo00?o0000ol30f_o0`=X01_o0`=X00ol0003o`/ONol;7gP05ol;7gP;o00001oo2
amh00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Wooooo000Uooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0FOooool00ol0003oUjCMoiNTg@05oiNTg@03o`000?oooooo
000000OoUj?M00?o0000oibTf_nLY=X00onLY=X00ol0003oooooooooo`0Gooooo`GoW:CJ00Go0000
oj6Tf?nQY=SoXJCHo`000008oj6Tf0;o00001onMWM<00ol0003oWIgCo`000002oj6NdP03o`000?oo
oooooooo00Wooooo00Go0000oj6Nd_l0003oY9oAo`000005ooooo`06o`000?nTWm7o0000o`000?oo
oooo00000_ooool00onUX=3o0000ooooo`05ooooo`05o`000?nWXM3o0000ojVRcol000002Oooool0
0ol0003oZJ;?o`000002ojfTcP03o`000?oooooooooo00[ooooo00Co0000ojfTc_n]Y<ko00000ona
Ylh00ol0003oooooooooo`05ooooo`So00000_naYlh00ol0003o]jc>okN/cP02okN/cPGo00003Ooo
ool01Ol0003o]j_>okN[c_ngZlko000000?o_;7?00?o0000ooooooooool04Oooool00ol0003o_;7?
okbac`02okbac`05o`000?o1^=7o`KSAol6hdOl000006Oooool2o`0000Co`KSA0_l000000oo6`MGo
0000ol30fP08ol30fP03o`000?oooooooooo01Kooooo0_l00007ol30fP;o00001oo2amh00ol0003o
oooool;7gP08ol;7gP03o`000?oooooooooo00cooooo00?o0000ooooooooool0FOooool002Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Gooooo`03o`000?nGY=goUjCM00KoUjCM
0oooool2o`0000KoUj?M0_l00004oibTfP;o00006?ooool5oibTfP04o`000?nQY=SoXJCHo`0000Oo
XJCH00?o0000oifMdonMWM<01onMWM<01?l0003oWIgCoifMdol00002oj6NdP03o`000?oooooooooo
00Sooooo00?o0000oj6Nd_nQW]800_l00006ooooo`04o`000?nTWm7o0000ooooo`;o000000Cooooo
o`000?l0003o00001Oooool01Ol0003oYj7@o`000?nYX/oo000000Wooooo00?o0000ojVRcol00000
0_n]Y<h00ol0003oooooooooo`07ooooo`Co00000_n]Y<h01?l0003o/JO>ok6Wc_naYlh8o`0000Oo
/JO>00Co0000ok6Wc_naYlko00000ong[<h00ol0003o]Z_>okJ[cP03okJ[cPWo00000oooool00ol0
003o]j_>okN[cP02okN[cP05o`000?nl/Loo_;7?okbacol000004_ooool00ol0003o_;7?okbac`03
okbac`05o`000?o1^=7o`KSAol6hdOl000006Oooool00oo1^=7o0000ol6hd@02ol6hd@03o`000?o6
`MGo000000;oa/7E00?o0000ol30f_o0`=X01oo0`=X00ol0003oooooooooo`0Cooooo`;o00002?o0
`=X00ol0003o`/ONol;7gP05ol;7gP;o00000oooool8ol;7gP03o`000?oooooooooo00gooooo00?o
0000ooooooooool0F?ooool002Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1F
ooooo`03o`000?nGY=goUjCM00GoUjCM00?o0000ooooooooool00oooool00ol0003oUj?MoiNSg@05
oiNSg@03o`000?nLY=[oW:CJ00?oW:CJ00?o0000ooooooooool05_ooool5oibTfP03o`000?nQY=So
000000KoXJCH00?o0000oifMdonMWM<01_nMWM<00ol0003oooooo`000003oifMd`04o`000?nQW];o
XIkBo`0000[ooooo00Go0000oj6Nd_l0003oY9oAo`000005ooooo`03o`000?nTWm7o000000?o0000
0_ooool2o`0000Kooooo00Go0000ojNQd?l0003oZJ;?o`000008ooooo`04o`000?nYX/ooZJ;?o`00
00;o[JC>00?o0000ooooooooool01_l00003ojfTcP04o`000?n]Y<ko[JC>o`0000?o/JO>00?o0000
ok6Wc_naYlh03OnaYlh00ol0003o/JO>o`000002okN/cP03o`000?nfZlko]Z_>00go]Z_>1?l00003
okN[cP05o`000?nl/Loo_;7?okbacol000004oooool00ol0003o_;7?okbac`02okbac`05o`000?o1
^=7o`KSAol6hdOl000006Oooool00ol0003o`KSAo`000002ol6hd@03o`000?o6`MGo000000Coa/7E
00?o0000ol30f_o0`=X01oo0`=X00ol0003oooooooooo`0Aooooo`03o`000?o0`=[o`<3J00Ko`<3J
0_l00007ol;7gP03o`000?oooooooooo00?ooooo00?o0000ol;7g_o2amh01_o2amh00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05Oooooo000Tooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0E?ooool00ol0003oUjCMoiNTg@05oiNTg@03o`000?oooooooooo00Gooooo0_l0
0006oiNSg@;o00001?nLY=X2o`0001Oooooo0_l00003oibTfP03o`000?nQY=So000000?oXJCH0_l0
0007oifMd`;o00000oooool01ol0003oWIgCoifMdonMWM?o0000oj6Nd_l000002oooool01Ol0003o
XIkBo`000?nTWm7o000000Gooooo00Co0000ojBOdOl0003ooooo0_l000001?oooooo0000o`000?l0
0005ooooo`05o`000?nWXM3o0000ojVRcol000002Oooool00ol0003oZJ;?o`000002ojfTcP?o0000
2_n]Y<h01_l0003o[JC>ojfTc_l0003o/JO>o`00017o/JO>0_l000000ong[<ko0000okJ[cP0BokJ[
cP05o`000?ngZlko]j_>okN[c_l000000_nl/Ll4o`00013ooooo00?o0000okbaconl/Ll00onl/Ll0
1Ol0003o`KSAol6hdOo1^=7o000001Sooooo00Ko0000ol6hdOo1^=7o0000ol6hdOl00002olK1e@03
o`000?o6`MGoa/7E00?oa/7E00?o0000ol30f_o0`=X01oo0`=X00ol0003oooooooooo`0>ooooo`;o
00002?o0`=X00ol0003o`/ONol;7gP05ol;7gP;o00001oooool00ol0003o`/ONol;7gP05ol;7gP03
o`000?oooooooooo00gooooo00?o0000ooooooooool0Eoooool002Cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`1Cooooo`03o`000?nGY=goUjCM00GoUjCM00?o0000ooooooooool0
1oooool00ol0003oUj?MoiNSg@05oiNSg@03o`000?nLY=[oW:CJ00?oW:CJ00?o0000ooooooooool0
4oooool00ol0003oW:CJoibTfP03o`000003oibTf_l0003o000000;oXJCH00?o0000oifMdonMWM<0
1_nMWM<00ol0003oooooooooo`04ooooo`04o`000?nMWM?oWIgCo`0000;oXIkB00?o0000oooooooo
ool02?ooool00ol0003oXIkBoj6NdP02o`0000Gooooo00?o0000ojBOdOl000000ol00002ooooo`;o
00001Oooool01Ol0003oYj7@o`000?nYX/oo000000Sooooo0_l000001OnYX/oo0000ojfTc_n]Y<ko
000000go[JC>00Co0000ojfTc_l0003o00004_naYlh3o`0001Go]Z_>00Ko0000okN[c_ngZlko0000
okbacol00004okbac`Co00003?ooool00ol0003o_;7?okbac`02okbac`05o`000?o1^=7o`KSAol6h
dOl000006?ooool01?l0003o`KSAol6hdOo1^=42o`0000?oa/7E00?o0000olK1eOo6`MD01?o6`MD0
0ol0003o`<3Jol30fP07ol30fP03o`000?oooooooooo00cooooo00?o0000ol30f_o0`=X01_o0`=X2
o`0000Oo`/ON00?o0000ooooooooool01oooool00ol0003o`/ONol;7gP05ol;7gP03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0E_ooool002Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1Aooooo`03o`000?nGY=goUjCM00GoUjCM00?o0000ooooooooool02Oooool2o`00
00KoUj?M0_l00004oibTfP;o00004_ooool00ol0003oW:CJoibTfP04oibTfP?o000000?oXJCHo`00
0?nMWM<01onMWM<00ol0003oooooooooo`06ooooo`04o`000?nMWM?oWIgCo`0000;oXIkB00?o0000
ooooooooool02?ooool01Ol0003oXIkBo`000?nTWm7o000000Gooooo00Co0000ojBOdOl0003ooooo
0_l000001?oooooo0000o`000?l00005ooooo`05o`000?nWXM3o0000ojVRcol000001?ooool3o`00
0007ojZRcol0003oZJ;?ojVRcol0003o[JC>o`00000>ojfTcP?o00002OnaYlh;o`0000?o]Z_>0ol0
000AokJ[cP04o`000?ngZlko0000o`0000Wo_;7?1Ol00006ooooo`03o`000?nl/Loo_;7?00?o_;7?
00Go0000ol6hdOo1^=7o`KSAo`00000Gooooo`03o`000?o1^=7o`KSA00;o`KSA00?o0000olK1eOo6
`MD00_o6`MD2o`0000Koa/7E00?o0000ol30f_o0`=X01oo0`=X00ol0003oooooooooo`09ooooo`;o
00002?o0`=X00ol0003o`/ONol;7gP05ol;7gP;o00002_ooool00ol0003o`/ONol;7gP06ol;7gP03
o`000?oooooooooo00kooooo00?o0000ooooooooool0EOooool002Cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1@ooooo`03o`000?nGY=goUjCM00GoUjCM00?o0000ooooooooool0
2oooool00ol0003oUj?MoiNSg@05oiNSg@03o`000?nLY=[oW:CJ00?oW:CJ00?o0000ooooooooool0
3_ooool00ol0003oW:CJoibTfP08oibTfP03o`000?nMWM?o000000GoWIgC0_l0000:ooooo`04o`00
0?nMWM?oWIgCo`0000;oXIkB00?o0000ooooooooool02?ooool01Ol0003oXIkBo`000?nTWm7o0000
00Cooooo00?o0000ojBOdOl000001?l000000ooooooo0000o`000005ooooo`06o`000?nWXM3o0000
ojVRcol0003ooooo0ol00005ojZRc`05o`000?nYX/oo0000ojfTc_l000003?n]Y<h>o`0000[o/Z;7
0_l00005okRVa`go00001?nfZlh3o`0000oo_;7?1?l00002ooooo`03o`000?nl/Loo_;7?00;o_;7?
00Go0000ol6hdOo1^=7o`KSAo`00000Gooooo`03o`000?o1^=7o`KSA00;o`KSA0_l00003olK1e@04
o`000?ooooooooooo`0000Koa/7E00?o0000ol30f_o0`=X01oo0`=X00ol0003oooooooooo`07oooo
o`03o`000?o0`=[o`<3J00Ko`<3J0_l00007ol;7gP03o`000?oooooooooo00_ooooo00?o0000ol;7
g_o2amh01Oo2amh00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Gooooo000Tooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool00ol0003oUjCMoiNTg@05oiNTg@03
o`000?oooooooooo00gooooo0_l00006oiNSg@03o`000?nLY=[oW:CJ00?oW:CJ0_l0000=ooooo`03
o`000?nLY=[oW:CJ00SoW:CJ0_l00002oifMd`?o000000?oWIgCo`000?ooool02oooool01ol0003o
WIgCoifMdonMWM?o0000oj6Nd_l000002_ooool01Ol0003oXIkBo`000?nTWm7o000000Gooooo00?o
0000ojBOdOl000000ol000001?oooooo0000o`000?l00004ooooo`06o`000?nWXM3oYj7@o`000?nY
X/oo00002OnZX/l3o`0000Oo[JC>1_l00003ojfNb003o`000?nbX/Oo/Z;7017o/Z;700Co0000okRV
aonhY/Oo00004OnhY/L6o`0001Co_;7?0_l00004okbac`03o`000?o1^=7o`KSA00;o`KSA00?o0000
ooooooooool05?ooool00ol0003o`KSAol6hd@02ol6hd@03o`000?o6`MGo000000;oa/7E00?o0000
ooooooooool00_ooool00ol0003oa/7EolK1e@04olK1e@03o`000?o0`=[o`<3J00Oo`<3J00?o0000
ooooooooool01?ooool2o`0000So`<3J00?o0000ol;7g_o2amh01Oo2amh2o`0000kooooo00?o0000
ol;7g_o2amh01_o2amh00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Cooooo000Toooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0COooool00ol0003oUjCMoiNTg@05oiNT
g@03o`000?oooooooooo00oooooo00?o0000oiNSgOnGXmd01?nGXmd2o`0000GoW:CJ00?o0000oooo
ooooool02Oooool00ol0003oW:CJoibTfP08oibTfP04o`000?nGVmKoUi_Fo`0000CoWIgC00?o0000
ooooooooool03?ooool01?l0003oWIgCoifMdol00002oj6NdP03o`000?oooooooooo00Sooooo00Go
0000oj6Nd_l0003oY9oAo`000005ooooo`Ko000000?oooooo`000?l000000oooool3o`000004ojNQ
d?l0003oZJ;?o`0000[oZZ;?00CoZJ;?o`000?n]Y<ko[JC>1Ol00008ojfNb003o`000?nbX/Oo0000
017o/Z;700?o0000ok:QaonhY/L00_nhY/L00ol0003o^:K7okRVa`0AokRVa`03o`000?nhY/Oo0000
00;o_jg81?l0000?okbac`03o`000?nl/Loo_;7?00;o_;7?00Go0000ol6hdOo1^=7o`KSAo`00000F
ooooo`03o`000?o1^=7o`KSA00?o`KSA00Go0000olK1eOl0003oa/7Eo`000006ooooo`03o`000?o6
`MGoa/7E00Coa/7E00?o0000ol30f_o0`=X01oo0`=X01?l0003oooooooooooooool2o`0000So`<3J
0_l00006ol;7gP;o00004Oooool00ol0003o`/ONol;7gP05ol;7gP03o`000?oooooooooo00oooooo
00?o0000ooooooooool0Doooool002?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1;ooooo`03o`000?nGY=goUjCM00GoUjCM00?o0000ooooooooool04Oooool2o`0000KoUj?M00?o
0000oibTf_nLY=X00onLY=X2o`0000Sooooo00?o0000oibTf_nLY=X02?nLY=X01?l0003oUi_FoiNK
e_nGVmH2o`0000?oWIgC00?o0000ooooooooool03Oooool01?l0003oWIgCoifMdol00002oj6NdP03
o`000?oooooooooo00Sooooo00Go0000oj6Nd_l0003oY9oAo`000004ooooo`03o`000?nTWm7o0000
00?o000000?oooooo`000?l000000ol00003ojNQd004o`000?nWXM3o0000o`0000WoZZ;?1Ol0000=
ojfNb0;o000000?o/Z;7o`000?nbX/L01onbX/L8o`0000;o/Z7700Go0000okRVaonhY/Oo^:K7o`00
0004okRVa`Go00002?nhY/L01Ol0003o^:K7okRVaono[LSo000000Go_jg81?l0000<okbac`04o`00
0?nl/Loo_;7?o`0000Co`KSA00?o0000ooooooooool04oooool00ol0003o`KSAol6hd@03ol6hd@03
o`000?o6`MGoa/7E00;o00002?ooool00ol0003oa/7EolK1e@04olK1e@03o`000?o0`=[o`<3J00Oo
`<3J00?o0000ooooool000002Oo0`=X00ol0003o`/ONol;7gP05ol;7gP03o`000?oooooooooo017o
oooo00?o0000ol;7g_o2amh01_o2amh00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?o
oooo000Sooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003oUjCM
oiNTg@05oiNTg@03o`000?oooooooooo01?ooooo00?o0000oiNSgOnGXmd01?nGXmd2o`0000GoW:CJ
00?o0000ooooooooool01?ooool00ol0003oW:CJoibTfP08oibTfP03o`000?nGVmKoUi_F00;oUi_F
00?o0000oiNKe_l000000onMWM<00ol0003oooooooooo`0=ooooo`04o`000?nMWM?oWIgCo`0000;o
XIkB00?o0000ooooooooool01oooool01Ol0003oXIkBo`000?nTWm7o000000Gooooo00?o0000ojBO
dOl000001_l00006ojNQd0?o00001OnZX/l4o`0000;oZ9_80_l0000:ojfNb0Co00000_n]W/P2ok:R
a`03o`000?nbX/Oo000000Go00001oooool3ok:Qa`05o`000?nhY/Oo^:K7okRVaol000002Oooool8
o`0000;o^:K700?o0000okn]b?l000002Ono[LP4o`0000So_;7?00Co0000okbaconl/Loo00000_o1
^=43o`0001Gooooo00?o0000ol6hdOo1^=400_o1^=401?l0003oa/7EolK1eOo6`MD2o`0000Wooooo
00?o0000olK1eOo6`MD01?o6`MD00ol0003o`<3Jol30fP07ol30fP03o`000?o0`=[o`<3J00Ko`<3J
0_l00006ol;7gP;o00005Oooool00ol0003o`/ONol;7gP05ol;7gP03o`000?oooooooooo00oooooo
00?o0000ooooooooool0D_ooool002?ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`18ooooo`03o`000?nGY=goUjCM00GoUjCM00?o0000ooooooooool05Oooool2o`0000KoUj?M00?o
0000oibTf_nLY=X00onLY=X2o`0000?ooooo00?o0000oibTf_nLY=X02?nLY=X00ol0003oUi_FoiNK
eP04oiNKeP03o`000?nGVmKo000000?oWIgC00?o0000ooooooooool03Oooool01?l0003oWIgCoifM
dol00002oj6NdP03o`000?oooooooooo00Oooooo00Go0000oj6Nd_l0003oY9oAo`000004ooooo`03
o`000?nTWm7o000000?o000000CoYJ3@o`000?l0003o00001_nWXM02o`000003ojZRcol0003o0000
00;o00001_nXVlP00ol0003o[Ik8o`000003ojfNb0Ko00000oooool3ojfNb0;o/Z;700?o0000oooo
ooooool03?ooool3ok:Qa`05o`000?nhY/Oo^:K7okRVaol000004?ooool3okRVa`04o`000?no[LSo
_jg8o`0000co_jg81?l00004okbac`04o`000?nl/Loo0000ol6hd@;o00000oo1^=42o`0001;ooooo
00?o0000ol6hdOo1^=400_o1^=400ol0003oa/7EolK1e@02olK1e@;o00002_ooool00ol0003oa/7E
olK1e@04olK1e@03o`000?o0`=[o`<3J00Ko`<3J00?o0000ol30f_o0`=X01Oo0`=X00ol0003o`/ON
ol;7gP05ol;7gP03o`000?oooooooooo01Gooooo00?o0000ol;7g_o2amh01Oo2amh00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo05;ooooo000Sooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0Aoooool00ol0003oUjCMoiNTg@05oiNTg@03o`000?oooooooooo01Oooooo00?o
0000oiNSgOnGXmd01?nGXmd2o`0000GoW:CJ00?o0000ooooool000002_nLY=X00ol0003oUi_FoiNK
eP05oiNKeP04o`000?nGVmKoUi_Fo`0000?oWIgC00?o0000ooooooooool03?ooool01ol0003oWIgC
oifMdonMWM?o0000oj6Nd_l000002_ooool2o`000003ojBOdOl0003ooooo00?ooooo0_l000000onT
Wm7o0000o`000002o`000003ojFPd?l0003o000000GoYj7@1?l00009ojRKb004o`000?nXVlSo[Ik8
ojfNb0?o00002Oooool3ojfNb003o`000?nbX/Oo000000kooooo0onbXLL01Ol0003o^:K7okRVaonh
Y/Oo0000013ooooo0onhY/L01?l0003o_jg8okn]b?l00002ooooo`?o00002ono[LP4o`000004okba
col0003o0000o`0000Oo`KSA0_l0000?ooooo`03o`000?o1^=7o`KSA00;o`KSA00?o0000olK1eOo6
`MD00_o6`MD00ol0003oooooo`00000;ooooo`03o`000?o6`MGoa/7E00Coa/7E00?o0000ol30f_o0
`=X01Oo0`=X00ol0003o`<3Jol30fP03ol30fP;o00001_o2amh2o`0001Sooooo00?o0000ol;7g_o2
amh01_o2amh00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo057ooooo000Sooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0AOooool00ol0003oUjCMoiNTg@05oiNTg@03o`00
0?oooooooooo01Wooooo0_l00006oiNSg@03o`000?nLY=[oW:CJ00?oW:CJ00?o0000oibTf_nLY=X0
2?nLY=X00ol0003oUi_FoiNKeP05oiNKeP03o`000?oooooo000000;oUi_F00Go0000oifMdonMWM?o
WIgCo`00000>ooooo`04o`000?nMWM?oWIgCo`0000;oXIkB00?o0000ooooooooool01oooool01_l0
003oXIkBo`000?nTWm7o0000ooooo`;o00000_nTWm45o`0000;oYJ3@00?o0000ojNQd?nWXM000ol0
0002ojFJb@;o00001onXVlP3o`000004ojRKb?n]W/So[Ik8o`0000_ooooo00Ko0000ojfNb?n]W/So
0000ok:Raol0000>ooooo`04o`000?nbXLOo/Z77o`0000?o^:K700?o0000ooooooooool03Oooool0
1Ol0003o^:K7okRVaonhY/Oo000000;o_jg800?o0000ooooooooool00oooool4o`0000_o_jg80_l0
000;ol6hd@;o00003?ooool00ol0003o`KSAol6hd@02ol6hd@03o`000?o6`MGoa/7E00;oa/7E00Co
0000oooooooooooo00003?ooool00ol0003oa/7EolK1e@04olK1e@03o`000?o0`=[o`<3J00?o`<3J
00?o0000ol30f_o0`=X00oo0`=X00ol0003o`/ONol;7gP05ol;7gP03o`000?oooooooooo01Wooooo
00?o0000ol;7g_o2amh01Oo2amh00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo
000Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A?ooool00ol0003oUjCMoiNT
g@05oiNTg@03o`000?oooooooooo01_ooooo00?o0000oiNSgOnGXmd01?nGXmd2o`0000?oW:CJ00?o
0000oibTf_nLY=X01onLY=X00ol0003oUi_FoiNKeP05oiNKeP05o`000?ooooooooooooooool00000
0_nGVmH01Ol0003oWIgCoifMdonMWM?o000000kooooo00Co0000oifMdonMWM?o00000_nQW]800ol0
003oooooooooo`07ooooo`05o`000?nQW];o0000ojBOdOl000001OnTWm42o`000004ojFPd?l0003o
YJ3@ojFPd0?o00001OnUV/T00ol0003oZ9_9o`000002ojRKb0Co00000_ooool2ojRKb003o`000?n]
W/So000000cooooo0_n]W/P01?l0003o/Z;7ok:Raol0000=ooooo`04o`000?nbXLOo/Z77o`0000?o
^:K700?o0000ooooooooool03Oooool01Ol0003o^:K7okRVaonhY/Oo000000;o_jg800?o0000oooo
ooooool01oooool3o`0000Ko_jg80_l000001?no[LSo0000olJfbol0000;ol6hd@03o`000?oooooo
oooo00Sooooo00?o0000ol6hdOo1^=400_o1^=400ol0003oa/7EolK1e@02olK1e@05o`000?oooooo
ooooooooool000003Oooool00ol0003oa/7EolK1e@04olK1e@03o`000?o0`=[o`<3J00;o`<3J00Co
0000ol30f_o0`=[o`<3J0_l00006ol;7gP;o00007?ooool00ol0003o`/ONol;7gP06ol;7gP03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0D?ooool002?ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`12ooooo`03o`000?nGY=goUjCM00GoUjCM00?o0000ooooooooool07Ooo
ool2o`0000KoUj?M00Go0000oibTf_nLY=[oW:CJo`000007oibTfP03o`000?nGVmKoUi_F00GoUi_F
00?o0000ooooooooool00oooool01?l0003oUi_FoiNKe_l00003oifMd`03o`000?oooooooooo00co
oooo00Co0000oifMdonMWM?o00000_nQW]800ol0003oooooooooo`06ooooo`?o000000?oY9oAo`00
0?nTWm401OnTWm400ol0003oYJ3@o`000002o`000003ojBIb_l0003oYI[900GoYI[900?o0000ojRK
bOnXVlT00_l00006ooooo`03o`000?nXVlSoZ9_800;o[Ik800?o0000ooooooooool02Oooool2ojfN
b004o`000?nbX/Oo/Z;7o`0000gooooo00Co0000ok:QaonbXLOo00000onhY/L00ol0003ooooooooo
o`0=ooooo`04o`000?nhY/Oo^:K7o`0000;o_jg800?o0000ooooooooool02oooool3o`0000;o_jg8
00?o0000okn]b?no[LP00_l00003olJfb`;o00002Oo1^=42o`0000Oooooo00?o0000ol6hdOo1^=40
0_o1^=400ol0003oa/7EolK1e@02olK1e@03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3?ooool00ol0003oa/7EolK1e@04olK1e@05o`000?o0`=[o`<3Jol30f_l000000_o0`=X00ol0003o
`/ONol;7gP05ol;7gP03o`000?oooooooooo01gooooo00?o0000ol;7g_o2amh01Oo2amh00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo04oooooo000Rooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0@Oooool00ol0003oUjCMoiNTg@05oiNTg@03o`000?oooooooooo01oooooo
00?o0000oiNSgOnGXmd01?nGXmd2o`000003oibTf_l0003oW:CJ00GoW:CJ00?o0000oiNKe_nGVmH0
1OnGVmH00ol0003oooooooooo`05ooooo`04o`000?nGVmKoUi_Fo`0000?oWIgC00?o0000oooooooo
ool03?ooool01_l0003oWIgCoifMdol0003oXIkBo`0000Kooooo0_l00002oj6NdP?o00001onTWm40
0ol0003oY9W:o`000002ojBIbP;o00001?nUV/T3o`000003ojRKbOl0003ooooo00Oooooo0_nXVlP2
ojfNb003o`000?oooooooooo00Wooooo00?o0000ojfNb?l000000_nbX/L00ol0003oooooooooo`0;
ooooo`04o`000?nbXLOo/Z77o`0000?o^:K700?o0000ooooooooool03Oooool01?l0003o^:K7okRV
aol00002okn]b003o`000?oooooooooo00kooooo0_l00003okn]b003o`000?o6]/_o000000Coa[K;
0_l00009ol6hd@;o00001?ooool00ol0003o`KSAol6hd@03ol6hd@05o`000?o6`MGoa/7EolK1eOl0
00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?o6`MGoa/7E00Coa/7E00?o0000ol30f_o0
`=X00ol00007ol;7gP03o`000?oooooooooo01kooooo00?o0000ol;7g_o2amh01Oo2amh00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04kooooo000Rooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0?oooool:o`0002;ooooo00?o0000oiNSgOnGXmd01OnGXmd00ol0003oW:CJ
o`000004oibTfP03o`000?nGVmKoUi_F00GoUi_F00?o0000ooooooooool01oooool01?l0003oUi_F
oiNKe_l00003oifMd`03o`000?oooooooooo00_ooooo00Co0000oifMdonMWM?o00000_nQW]800ol0
003oooooooooo`02ooooo`03o`000?nQW];oXIkB00?oXIkB00?o0000ojBOdOl000000_nTWm43o`00
0005oj6Hbol0003oY9W:ojBIb_l000000_nTVLX00ol0003oYI[9ojFJb@02o`000003oooooonUV/Wo
YI[900;oZ9_900?o0000ooooooooool01Oooool2ojRKb003o`000?n]W/So000000_ooooo00Ko0000
ojfNb?n]W/So0000ok:Raol0000=ooooo`04o`000?nbXLOo/Z77o`0000?o^:K700?o0000oooooooo
ool03?ooool01Ol0003o^:K7okRVaonhY/Oo000000;o_jg800?o0000ooooooooool03oooool3okn]
b004o`000?o6]/_oa[K;o`0000Koa[K;0_l00009ol6hd@;o000000?oooooo`000?o1^=401?o1^=40
1Ol0003oa/7EolK1eOo6`MGo000000Kooooo00?o0000ooooooooool03_ooool00ol0003oa/7EolK1
e@04olK1e@?o00002?o2amhSooooo`03o`000?o2amko`/ON00Go`/ON00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1>ooooo`008_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo03kooooo00Co0000oi6Th_l0003o00001_nGY=d2o`0002;ooooo1onGXmd3o`0000;oW:CJ00?o
0000oiNKe_nGVmH01OnGVmH00ol0003oooooooooo`09ooooo`04o`000?nGVmKoUi_Fo`0000?oWIgC
00?o0000ooooooooool02oooool01?l0003oWIgCoifMdol00002oj6NdP04o`000?oooooo0000o`00
00OoXIkB1?l00004oj6Hb`;o000000?oY9W:o`000?nTVLX00ol00005ooooo`04ojFJbOnXVlWoZ9_9
o`0000Oooooo00?o0000ojRKb?l000000_n]W/P00ol0003oooooooooo`08ooooo`06o`000?n]W/So
[Ik8o`000?nbX/Oo00003Oooool01?l0003o/Z77ok:Qaol00003okRVa`03o`000?oooooooooo00co
oooo00Go0000okRVaonhY/Oo^:K7o`000002okn]b003o`000?oooooooooo00kooooo00Go0000okn]
b?no[LSo_jg8o`000002olJfb`03o`000?o6]/_oa[K;00Koa[K;0_l00009ol6hd@03o`000?o1^=7o
`KSA00?o`KSA00?o0000olK1eOo6`MD00_o6`MD00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00kooooo4Ol0000Tooooo`03o`000?o2amko`/ON00Go`/ON00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1=ooooo`008_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
03gooooo0_l00002oi6ThP;o00001_nGY=d2o`00027ooooo1_l00002oiNSg@03o`000?nLY=[o0000
00OoUi_F00?o0000ooooooooool02oooool01?l0003oUi_FoiNKe_l00002oifMd`03o`000?oooooo
oooo00cooooo00Co0000oifMdonMWM?o00000_nQW]800ol0003oXIkBoj6NdP08oj6NdP03o`000?nQ
V<_oXIS;00GoXIS;00Oo0000ojBIb_l0003o0000oooooonTVL[o000000Gooooo00CoYI[9o`000?nX
VlWo00002?ooool2ojRKb003o`000?n]W/So000000[ooooo00Ko0000ojfNb?n]W/So0000ok:Raol0
000=ooooo`04o`000?nbXLOo/Z77o`0000?o^:K700?o0000ooooooooool03?ooool01Ol0003o^:K7
okRVaonhY/Oo000000;o_jg800?o0000ooooooooool03_ooool01?l0003o_jg8okn]b?l00003olJf
b`03o`000?oooooo000000Soa[K;00?o0000ol6hdOo1^=401_o1^=400ol0003o`KSAol6hd@02ol6h
d@03o`000?o6`MGoa/7E00;oa/7E00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=oooo
o`03o`000?o6`MGoa/7E00Coa/7E00?o0000ol[;fol000001oo2amh00ol0003oooooooooo`0Roooo
o`03o`000?o2amko`/ON00Ko`/ON00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=oooo
o`008_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo00?o0000oi6Th_l0
00000onAY>82o`0000KoUjCM0_l0000Oooooo`03o`000?nGY=goUjCM00?oUjCM1_l00005oiNKeP03
o`000?oooooooooo00gooooo00Co0000oiNKe_nGVmKo00000_nMWM<00ol0003oooooooooo`0<oooo
o`06o`000?nMWM?oWIgCo`000?nQW];o00001onQW]82o`000003oijFbol0003o000000KoXIS;0_l0
00001?oooooo0000ooooooooool2o`0000Cooooo00Go0000ojFJbOnXVlWoZ9_9o`000007ooooo`;o
Z9_800?o0000ojfNb?l000002oooool00ol0003o[Ik8o`000002ok:Ra`03o`000?oooooooooo00[o
oooo00Co0000ok:QaonbXLOo00000onhY/L00ol0003oooooooooo`0<ooooo`04o`000?nhY/Oo^:K7
o`0000;o_jg800?o0000ooooooooool03_ooool01Ol0003o_jg8okn]b?no[LSo000000;oa[K;00?o
0000ooooooooool00_ooool2o`0000Koa[K;0_l00006ol6hd@05o`000?o1^=7o`KSAol6hdOl00000
1?o6`MD00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000olK1eOo6`MD0
0oo6`MD2o`000003ol[;fol0003ob/_K00So`/ON00?o0000ooooooooool08Oooool4o`0000Go`/ON
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`008_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo03_ooooo00Co0000oi6Th_nAY>;o00001?nAY>82o`0000KoUjCM
0ol0000Kooooo`03o`000?nGY=goUjCM00OoUjCM00?o0000oi2Kf_l000000ol000000onGVmKo0000
ooooo`0@ooooo`?oUi_F00Co0000oifMdonMWM?o00003Oooool4o`000003oj6Nd_l0003oXIkB00Co
XIkB0_l00003oijFb`?o000000GoXIS;o`000?l0003o0000ooooo`02o`000006oooooonTVL[o0000
oooooonTVL[o00001Oooool01?nUV/Wo0000ojRKbOl00007ooooo`05o`000?nXVlSo0000ojfNb?l0
00002oooool00ol0003o[Ik8o`000002ok:Ra`03o`000?oooooooooo00[ooooo00Co0000ok:Qaonb
XLOo00000onhY/L00ol0003oooooooooo`0<ooooo`04o`000?nhY/Oo^:K7o`0000;o_jg800?o0000
ooooooooool03_ooool01Ol0003o_jg8okn]b?no[LSo000000;oa[K;00?o0000ooooooooool01?oo
ool3o`0000Goa[K;0_l00004ol6hd@04o`000?o1^=7o`KSAo`0000Coa/7E00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0;ooooo`03o`000?o6`MGoa/7E00?oa/7E00Oo0000ol[;foo:bm_o
b/_Ko`000?o:bm_o000000Oo`/ON00?o0000ooooooooool07oooool2o`0000Co`/ON1_l0000Doooo
o`03o`000?oooooooooo04_ooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0>_ooool01Ol0003oTJCRoi6Th_nAY>;o000000GoTJCR0_l00007oiNTg@;o00006Oooool00ol0
003oUjCMoiNTg@06oiNTg@05o`000?n@V][o0000oi2Kf_l000000_nGVmH2o`00017ooooo00Go0000
oiNKe_nGVmKoUi_Fo`000002oifMd`03o`000?oooooooooo00Wooooo00Co0000oifMdonMWM?oWIgC
0_l000001?nQW];o0000oj6Nd_nQW]82o`0000KoWYK;00?o0000oj:Hb_l000001Oooool2o`000003
ooooool0003ooooo00?o00001?ooool01?nUV/Wo0000ojRKbOl00007ooooo`06o`000?nXVlSoZ9_8
o`000?n]W/So00002_ooool00ol0003o[Ik8o`000002ok:Ra`03o`000?oooooooooo00[ooooo00Co
0000ok:QaonbXLOo00000onhY/L00ol0003oooooooooo`0;ooooo`05o`000?nhY/Oo^:K7okRVaol0
00000_no[LP00ol0003oooooooooo`0=ooooo`05o`000?no[LSo_jg8okn]b?l000000_o6]//00ol0
003oooooooooo`08ooooo`;o00001Oo6]//2o`0000;o`KSA00?o0000ol6hdOl000001Oo6`MD:oooo
o`03o`000?oooooooooo00Wooooo0_l00005olK1e@05o`000?o:bm_ob/_Kol[;fol000000_o:bm/0
0ol0003o`/ONol;7gP05ol;7gP03o`000?oooooooooo01cooooo0ol0000;ol;7gP;o00004oooool0
0ol0003oooooooooo`1;ooooo`008Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
03Sooooo00?o0000oi6Th_nAY>800onAY>800ol0003oTJCRoi6ThP04oi6ThP;o00001onGY=d2o`00
01Kooooo00?o0000oiNTgOnGY=d01onGY=d00ol0003oT9[Jo`000002oi2KfP05o`000?nGVmKoUi_F
oiNKe_l000004Oooool01Ol0003oUi_FoiNKe_nGVmKo000000;oWIgC00?o0000ooooooooool01_oo
ool2o`0000KoWIgC1?l00008oijFb`?o00001Oooool2o`000004ooooool0003o0000ooooo`;o0000
1Oooool01?nUV/Wo0000ojRKbOl00007ooooo`05o`000?nXVlSo0000ojfNb?l000002_ooool01_l0
003o[Ik8ojfNb?l0003o/Z;7o`0000cooooo00Co0000ok:QaonbXLOo00000onhY/L00ol0003ooooo
ooooo`0;ooooo`05o`000?nhY/Oo^:K7okRVaol000000_no[LP00ol0003oooooooooo`0=ooooo`05
o`000?no[LSo_jg8okn]b?l000000_o6]//00ol0003oooooooooo`0:ooooo`;o00001Oo6]//4o`00
0003olK1eOl0003o000000?o00002_ooool00ol0003oooooooooo`08ooooo`03o`000?o6`MGoa/7E
00?oa/7E0_l00004ol[;f`05o`000?o:bm_ob/_Kol[;fol000001oo2amh00ol0003oooooooooo`0I
ooooo`;o00002oo2amh5o`0001Cooooo00?o0000ooooooooool0B_ooool0027ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0gooooo`03o`000?nAY>;oTJCR00CoTJCR0_l00006oi6T
hP;o00001onGY=d2o`0001Cooooo00?o0000oiNTgOnGY=d01_nGY=d01?l0003oT9[Joi2Jf_l00003
oi2KfP05o`000?nGVmKoUi_FoiNKe_l000004Oooool01Ol0003oUi_FoiNKe_nGVmKo000000;oWIgC
00?o0000ooooooooool01?ooool00ol0003oWIgCoifMd`07oifMd`03o`000?nNU/_oWYK;00GoWYK;
0_l000000ooooooo0000oijFb`02o`0000Gooooo0_l000001?oooooo0000oooooonTVLX2o`0000Co
oooo00CoYI[9o`000?nXVlWo00001oooool01Ol0003oZ9_8o`000?n]W/So000000[ooooo00Ko0000
ojfNb?n]W/So0000ok:Raol0000<ooooo`04o`000?nbXLOo/Z77o`0000?o^:K700?o0000oooooooo
ool02oooool01Ol0003o^:K7okRVaonhY/Oo000000;o_jg800?o0000ooooooooool03?ooool01Ol0
003o_jg8okn]b?no[LSo000000;oa[K;00?o0000ooooooooool03Oooool2o`0000?oa[K;00?o0000
olJfbol000000_l00005olK1e@03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oa/7EolK1e@03olK1e@03o`000?o:bm_ob/_K00;ob/_K0_l00004ol[;f`03o`000?o2amko
`/ON00Go`/ON00?o0000ooooooooool05oooool2o`0000_o`/ON0_l00002ol;?i003o`000?o2cnCo
000001Gooooo00?o0000ooooooooool0BOooool0027ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0fooooo`03o`000?nAY>;oTJCR00CoTJCR00Co0000ooooool0003o00001_nAY>82
o`0000OoUjCM0_l0000Aooooo`03o`000?nGY=goUjCM00KoUjCM00?o0000oi2Jf_n@V]X00_n@V]X0
1Ol0003oT9_Joi2Kf_n@Vm[o000000?oUi_F00?o0000ooooooooool03oooool01Ol0003oUi_FoiNK
e_nGVmKo000000;oWIgC00Co0000oooooooooooooooo0_l00008oifMd`05o`000?nIU<go0000oijF
bol000001?nNU//00ol0003oooooooooo`02ooooo`?o00001Oooool2o`000004ooooool0003o0000
ooooo`;o00001Oooool00onUV/WoZ9_9o`000007ooooo`05o`000?nXVlSo0000ojfNb?l000002_oo
ool01_l0003o[Ik8ojfNb?l0003o/Z;7o`0000cooooo00Co0000ok:QaonbXLOo00000onhY/L00ol0
003oooooooooo`0;ooooo`04o`000?nhY/Oo^:K7o`0000?o_jg800?o0000ooooooooool03?ooool0
1Ol0003o_jg8okn]b?no[LSo000000;oa[K;00?o0000ooooooooool03oooool3o`0000;oa[K;00?o
0000olg1coo6`MD01_o6`MD00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l0
0004olK1e@;o00001?o:bm/00ol0003ooooool[;f`05ol[;f`03o`000?o2amko`/ON00Co`/ON00?o
0000ooooooooool05?ooool3o`0000[o`/ON0ol00003ol;?i004o`000?o2cnCo`/oTo`0001Gooooo
00?o0000ooooooooool0BOooool0027ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0eooooo`03o`000?nAY>;oTJCR00CoTJCR00Co0000oooooooooooooooo0_l00006oi6ThP;o0000
1onGY=d2o`0000kooooo00?o0000oiNTgOnGY=d01onGY=d00ol0003oT9[Joi2JfP02oi2JfP;o0000
0on@VmX2o`0000;oUi_F0_l0000@ooooo`CoUi_F00Ko0000oifMdonMWM?o0000ooooool00008oifM
d`;o00000_nIU<d2o`000003oijFbol0003oWYK;00;o00001Oooool01?l0003oWYK;o`000?l00005
ooooo`;o000000Koooooo`000?ooooooY9W:ojFJbOl00004ooooo`04ojFJbOl0003oZ9_9o`0000Ko
oooo00Ko0000ojRKb?nXVlSo0000ojfNb?l0000:ooooo`03o`000?n]W/So000000;o/Z;700?o0000
ooooooooool02Oooool01?l0003o/Z77ok:Qaol00003okRVa`03o`000?oooooooooo00[ooooo00Go
0000okRVaonhY/Oo^:K7o`000002okn]b003o`000?oooooooooo00gooooo00Co0000okn]b?no[LSo
00000_o6]//00ol0003oooooooooo`0@ooooo`Coa[K;0_l00002olg1c`03o`000?o6`MGoa/7E00Co
a/7E00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?o6`MGoa/7E00?o
a/7E00?o0000ol[;foo:bm/00oo:bm/01?l0003oooooooooooooool5ol[;f`03o`000?o2amko`/ON
00Go`/ON00?o0000ooooooooool04Oooool2o`0000[o`/ON0ol00005ol;?i005o`000?o2cnCo`/oT
ol;?i?l000005_ooool00ol0003oooooooooo`18ooooo`008Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo03Cooooo00?o0000oi6Th_nAY>801?nAY>800ol0003oooooooooo`03oooo
o`;o00001_nAY>82o`0000OoUjCM0_l0000<ooooo`03o`000?nGY=goUjCM00KoUjCM00?o0000oi2J
f_n@V]X00on@V]X00ol0003oooooo`000004oi2KfP05o`000?nGVmKoUi_FoiNKe_l000004?ooool4
oiNKeP04o`000?nMWM?oWIgCo`0000SoWIgC00?o0000oiVDcOnIU<d01?nIU<d00ol0003oWYK;o`00
0008ooooo`;o000000?oXYS:o`000?ooool00oooool2o`000004oooooonTVL[o0000ooooo`;o0000
1?ooool2o`000003ojRKbOl0003ooooo00Kooooo00Go0000ojRKb?l0003o[Ik8o`00000:ooooo`03
o`000?n]W/So000000;o/Z;700?o0000ooooooooool00oooool7o`0000;o/Z7700?o0000okRVaonh
Y/L03ol00003okRVa`04o`000?no[LSo_jg8o`0000kooooo00Go0000okn]b?no[LSo_jg8o`000002
olJfb`03o`000?oooooooooo00oooooo00Oo0000olJfboo6]/_oa[K;o`000?o=`Loo000000?ocL7?
00?o0000olK1eOo6`MD01?o6`MD00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000olK1eOo6`MD00oo6`MD00ol0003ob/_Kol[;f`02ol[;f`;o00001?ooool00ol0003ob/_K
ol[;f`02ol[;f`03o`000?o2amko`/ON00Go`/ON00?o0000ooooooooool03oooool2o`0000[o`/ON
0_l00007ol;?i003o`000?o2cnCo`/oT00;o`/oT00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`18ooooo`008?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03?ooooo00?o
0000oi6Th_nAY>801?nAY>800ol0003oooooooooo`05ooooo`?o00001OnAY>83o`0000KoUjCM0ol0
0008ooooo`03o`000?nGY=goUjCM00OoUjCM00?o0000oi2Jf_n@V]X00_n@V]X01Ol0003ooooooooo
oooooooo000000CoT9_J00Go0000oiNKe_nGVmKoUi_Fo`00000@ooooo`CoUi_F00?o0000oifMdol0
00001_nMWM<2o`0000KoVIC=0_l000000onNU/_o0000ooooo`08ooooo`?o00001Oooool2o`000003
ojBIb_l0003ooooo00;o00001Oooool00onUV/Wo0000o`000007ooooo`05o`000?nXVlSo0000ojfN
b?l000002?ooool3o`000004ojfNb?l0003o/Z;7ok:Ra`Ko00001onbXLL01Ol0003o/Z77o`000?nh
Y/Oo000000ko^:K700Ko0000okRVaonhY/Oo^:K7o`000?no[LP4o`0000cooooo00Co0000okn]b?no
[LSo00000oo6]//00ol0003oooooooooo`0>ooooo`05o`000?o6]/_oa[K;olJfbol000000_o=`Ll0
0ol0003ocL7?olg1c`02olg1c`03o`000?o6`MGoa/7E00Coa/7E00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Coa/7E0_l00004ol[;f`03o`000?oooooooooo00Gooooo00?o
0000ol[;foo:bm/00_o:bm/00ol0003o`/ONol;7gP05ol;7gP03o`000?oooooooooo00cooooo0_l0
0009ol;7gP?o00002?o2cn@00ol0003o`/oTol;?i003ol;?i003o`000?oooooooooo01Gooooo00?o
0000ooooooooool0Aoooool0023ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0b
ooooo`03o`000?nAY>;oTJCR00CoTJCR00?o0000ooooooooool02?ooool2o`0000KoTJCR0_l00007
oiNTg@;o00001_ooool00ol0003oUjCMoiNTg@06oiNTg@03o`000?n@V][oT9[J00?oT9[J00?o0000
ooooooooool00_ooool00ol0003oT9_Joi2KfP02oi2KfP04o`000?nGVmKoUi_FoiNKeP;o00003ooo
ool4oiNKeP03o`000?nMWM?o000000CoWIgC00?o0000oiVDcOnIU<d01?nIU<d01ol0003oooooo`00
0?nIU<go0000oijFbol000002?ooool2o`000003oj:Hb_l0003ooooo00?ooooo0_l000000ooooooo
0000ooooo`03o`0000Cooooo00CoYI[9o`000?nXVlWo00001_ooool00ol0003oZ9_8o`000002ojfN
b003o`000?oooooooooo00Go00000_n]W/P00ol0003o[Ik8o`000002ok:Ra`03o`000?nbXLOo/Z77
00_o/Z770ol0000@okRVa`03o`000?nhY/Oo^:K700;o00001?no[LP5o`0000Kooooo00Go0000okn]
b?no[LSo_jg8o`000002olJfb`03o`000?oooooooooo00kooooo00?o0000olJfboo6]//00_o6]//0
1?l0003ocL7?olg1col00005olg1c`03o`000?o6`MGoa/7E00Coa/7E00?o0000ooooooooool00ooo
ool01?l0003oooooo`000?l00004olK1e@03o`000?o:bm_ob/_K00?ob/_K00?o0000ooooooooool0
1_ooool00ol0003ob/_Kol[;f`02ol[;f`03o`000?o2amko`/ON00Go`/ON00?o0000ooooooooool0
2Oooool3o`0000Wo`/ON0_l00009ol;?i0;o00001_o2cn@00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo04Kooooo000Pooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oTJCRoi6ThP03oi6ThP03o`000?oooooooooo00_ooooo0_l00006oi6ThP;o00001onG
Y=d2o`0000?ooooo00?o0000oiNTgOnGY=d01_nGY=d00ol0003oT9[Joi2JfP03oi2JfP03o`000?oo
oooooooo00Cooooo0_l00003oi2KfP03o`000?nGVmKoUi_F00;oUi_F00?o0000ooooooooool03?oo
ool4o`000003oiNKe_l0003o000000;oWIgC0_l00005oiVDc@;o00000oooool01Ol0003oVIC=o`00
0?nNU/_o000000Sooooo0ol00004ooooo`Go000000?oooooo`000?l000001Oooool00ol0003oZ9_9
o`000007ooooo`04o`000?nXVlSo0000ojfNb0?o00002?n]W/P01?l0003o[Ik8o`000?l0000;ok:Q
a`Go00000_nhY/L8o`0000So^:K70ol0000:okn]b0Co00000_ooool01?l0003o_jg8okn]b?l00003
olJfb`03o`000?oooooooooo00kooooo00Go0000olJfboo6]/_oa[K;o`000003olg1c`03o`000?oo
oooocL7?00CocL7?00?o0000olK1eOo6`MD01?o6`MD00ol0003oooooooooo`02ooooo`;o00001?o6
`MD2o`0000Cob/_K0_l00009ooooo`03o`000?o:bm_ob/_K00?ob/_K00?o0000ol;7g_o2amh01?o2
amh00ol0003oooooooooo`07ooooo`;o00002Oo2amh3o`0000So`/oT0ol000000ooooooo`/oTol;?
i005ol;?i003o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool0023ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0`ooooo`03o`000?nAY>;oTJCR00?oTJCR00?o0000
ooooooooool03Oooool2o`0000KoTJCR0_l00007oiNTg@;o000000?oooooo`000?nGY=d01onGY=d0
0ol0003oT9[Joi2JfP03oi2JfP03o`000?oooooooooo00Kooooo00Co0000oi2Kf_n@Vm[oT9_J0_l0
0003oiNKeP03o`000?oooooooooo00[ooooo00?o0000oiNKe_nGVmH00_nGVmH3o`000003oifMdol0
003oVIC=00GoVIC=00?o0000ooooooooool01?ooool2o`000003oijFbol0003ooooo00Oooooo00Co
0000oijFbol0003o00001?ooool2o`000004ooooool0003oooooojBIbP;o00001?ooool00onUV/Wo
0000o`000005ooooo`?o000000CoZ9_8o`000?n]W/So00002on]W/P3o`0000;o/Z772Ol00004ok:K
`0;o00002OniXL0:o`0000oo_jg80_l00003okn]b004o`000?o6]/_oa[K;o`00013ooooo00Go0000
olJfboo6]/_oa[K;o`000003olg1c`05o`000?ooooooooooooooool000001?o=`Ll00ol0003oa/7E
olK1e@04olK1e@05o`000?ooooooooooooooool000001?o6`MD00ol0003ob/_Kol[;f`03ol[;f`03
o`000?oooooooooo00[ooooo00?o0000ol[;foo:bm/00_o:bm/00ol0003o`/ONol;7gP05ol;7gP03
o`000?oooooooooo00Cooooo0_l00009ol;7gP;o00002Oo2cn@2o`0000Cooooo1oo2cn@00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Gooooo000Pooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0;_ooool00ol0003oTJCRoi6ThP04oi6ThP03o`000?oooooooooo00oooooo
0_l00006oi6ThP;o00001onGY=d00ol0003oUjCMoiNTg@06oiNTg@03o`000?n@V][oT9[J00?oT9[J
00?o0000ooooooooool02?ooool00ol0003oT9_Joi2KfP02oi2KfP05o`000?nGVmKoUi_FoiNKe_l0
00002_ooool00ol0003oUi_FoiNKeP06oiNKeP03o`000?nIU<goVIC=00?oVIC=0_l00007ooooo`05
o`000?nIU<go0000oijFbol000002?ooool3o`0000Cooooo1Ol000000ooooooo0000o`000004oooo
o`;o000000?oZ9_9o`000?ooool00ol00003ojRKb@;o000000?o[Ik8o`000?n]W/P02?n]W/P7o`00
00co/Y_000Co0000okVQ`?niXL3o00004?niXL02o`0000;o`ZS01Ol00009okn]b005o`000?no[LSo
_jg8okn]b?l000000_o6]//00ol0003oooooooooo`0=ooooo`05o`000?o6]/_oa[K;olJfbol00000
0oo=`Ll00ol0003oooooooooo`03ooooo`03o`000?o=`LoocL7?00;ocL7?00?o0000olK1eOo6`MD0
1?o6`MD01?l0003oooooo`000?l00003olK1e@03o`000?o:bm_ob/_K00;ob/_K0_l0000=ooooo`03
o`000?o:bm_ob/_K00?ob/_K00?o0000ol;7g_o2amh01?o2amh01?l0003oooooooooooooool3o`00
00So`/ON0ol00008ol;?i0?o00001_ooool00ol0003o`/oTol;?i004ol;?i003o`000?oooooooooo
01Sooooo00?o0000ooooooooool0A?ooool0023ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0]ooooo`03o`000?nAY>;oTJCR00CoTJCR00?o0000ooooooooool04Oooool2o`0000Ko
TJCR0_l00005oiNTg@03o`000?nGY=goUjCM00KoUjCM00?o0000oi2Jf_n@V]X00_n@V]X00ol0003o
ooooooooo`0:ooooo`03o`000?n@Vm[oT9_J00;oT9_J00Co0000oiNKe_nGVmKoUi_F0_l00007oooo
o`03o`000?nGVmKoUi_F00KoUi_F00?oTY;@o`000?nIU<d00_l000000onIU<go0000ooooo`09oooo
o`;o00000_nNU//00ol0003oooooooooo`05ooooo`04o`000?nNU/_o0000o`0000Cooooo0_l00000
1_oooooo0000ooooool0003oYI[9o`0000?ooooo0_l000000onXVlWo0000o`000007ojRKb@03ojRK
b?l0003o[Ik800;o[Ik81ol00003ojbG`@03o`000?nbVl3o000000Ko/Y_01ol000001OnbVl3o0000
okVQ`?niXL3o000000?o^J701?l00007okVQ`004o`000?niXL3o0000o`0000Ko`ZS01Ol00005okn]
b004o`000?no[LSo0000olJfb`?o00003oooool01Ol0003oa[K;olJfboo6]/_o000000;ocL7?00?o
0000ooooooooool01Oooool00ol0003ocL7?olg1c`02olg1c`03o`000?o6`MGoa/7E00Coa/7E00Co
0000olK1eOl0003oa/7E0_l00004ol[;f`03o`000?oooooooooo00kooooo00?o0000ol[;foo:bm/0
0_o:bm/00ol0003o`/ONol;7gP04ol;7gP04o`000?oooooo0000o`0000Wo`/ON0_l00009ol;?i0;o
00002Oooool00ol0003o`/oTol;?i004ol;?i003o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0A?ooool0023ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0/ooooo`03o`00
0?nAY>;oTJCR00CoTJCR00?o0000ooooooooool04oooool2o`0000KoTJCR0_l00004oiNTg@03o`00
0?nGY=goUjCM00CoUjCM00?o0000oi2Jf_n@V]X00on@V]X00ol0003oooooooooo`0;ooooo`;o0000
0on@VmX00ol0003oUi_FoiNKeP02oiNKeP03o`000?oooooooooo00?ooooo00?o0000oiNKe_nGVmH0
1OnGVmH00ol0003oTY;@oi:Bd002o`0000;oVIC=00?o0000ooooooooool02Oooool01Ol0003oVIC=
o`000?nNU/_o000000Sooooo0ol00004ooooo`So000000Coooooo`000?l0003oYI[90ol00007ojRK
b@Ko00002On/Ul401_l0003o/Y_0ok:K`?nbVl3o0000ok:K`0Co00001_ooool2ok:K`004o`000?ni
XL3o^J70o`0000Oooooo1ol00002okVQ`003o`000?o2Z<3o000000[o`ZS01_l000000ono[LSo0000
o`000003olJfb`;o00003?ooool01Ol0003oa[K;olJfboo6]/_o000000?ocL7?00?o0000oooooooo
ool01_ooool00ol0003ocL7?olg1c`02olg1c`03o`000?o6`MGoa/7E00?oa/7E00Co0000olK1eOl0
003o00001Oo:bm/00ol0003oooooooooo`0?ooooo`03o`000?o:bm_ob/_K00;ob/_K00?o0000ol;7
g_o2amh01Oo2amh00ol0003o`/ONol;7gP06ol;7gP?o00002?o2cn@3o`0000_ooooo00?o0000ol;?
i?o2cn@01?o2cn@00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04?ooooo000Oooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0:oooool00ol0003oTJCRoi6ThP04oi6ThP03
o`000?oooooooooo01Gooooo0_l00006oi6ThP;o00000onGY=d00ol0003oUjCMoiNTg@03oiNTg@03
o`000?n@V][oT9[J00;oT9[J00?o0000ooooooooool03_ooool01Ol0003oT9_Joi2Kf_n@Vm[o0000
00CoUi_F00Go0000ooooooooooooooooo`000007oiNKeP03o`000?nBT]3oTY;@00;oTY;@0_l00000
0onIU<go0000ooooo`0;ooooo`05o`000?nIU<go0000oijFbol000001oooool01?l0003oWYK;o`00
0?l00004ooooo`Co000000Coooooo`000?nUV/Wo00001?nUV/T2o`0000CoZ9_90ol00002ojND`P03
ojbG`Ol0003o[9O100So[9O11?l00002ok:K`003o`000?oooooooooo00Wooooo0_nbVl001?l0003o
^J70okVQ`?l0000=ooooo`;o^J7000Co0000ol:X`?o2Z<3o00000_ooool5o`0000So`ZS00_l00007
olJfb`;o00002Oooool01Ol0003oa[K;olJfboo6]/_o000000?ocL7?00?o0000ooooooooool02?oo
ool00ol0003ocL7?olg1c`02olg1c`06o`000?o6`MGoa/7EolK1eOl0003oa/7E0_l00005ol[;f`03
o`000?oooooooooo017ooooo00?o0000ol[;foo:bm/00_o:bm/00ol0003o`/ONol;7gP04ol;7gP03
o`000?o2amko`/ON00?o`/ON0ol00009ol;?i0;o00003_ooool00ol0003o`/oTol;?i004ol;?i003
o`000?oooooooooo01Wooooo00?o0000ooooooooool0@oooool001oooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Zooooo`03o`000?nAY>;oTJCR00CoTJCR00?o0000ooooooooool0
6?ooool00ol0003oTJCRoi6ThP04oi6ThP;o00000_nGY=d01Ol0003oUjCMoiNTgOnGY=go000000Go
T9[J00?o0000ooooooooool03oooool01Ol0003oT9_Joi2Kf_n@Vm[o000000CoUi_F00?o0000oooo
ool000001onGVmH00ol0003oTY;@oi:Bd003oi:Bd005o`000?nBT]3o0000oiVDcOl000003?ooool0
1OnIU<go0000oijFbonNU/_o000000Oooooo0_l000000onRV<[o0000ooooo`02ooooo`So00001?nU
V/T2o`000004ojRKbOl0003o0000o`0000CoYiC20_l000000on/Ul7o0000ojbG`@02ojbG`@Go0000
0_ooool2ojbG`@03ok:K`?l0003o0000027o00000_o2Z<000ol0003oooooooooo`05ooooo`Go0000
0_o2Z<001Ol0003o`ZS0o`000?o;/l;o000000Ooa[K;0_l00006ooooo`03o`000?o6]/_oa[K;00;o
a[K;00Co0000olg1coo=`Loo00003?ooool00ol0003ocL7?olg1c`02olg1c`03o`000?o6`MGoa/7E
00;o000000?ob/_Ko`000?o:bm/00oo:bm/Eooooo`03o`000?o:bm_ob/_K00;ob/_K00?o0000ol;7
g_o2amh00oo2amh00ol0003o`/ONol;7gP02ol;7gP;o00002_o2cn@2o`00013ooooo00?o0000ol;?
i?o2cn@01?o2cn@00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04;ooooo000Oooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0:Oooool00ol0003oTJCRoi6ThP04oi6ThP03
o`000?oooooooooo01[ooooo00?o0000oi6Th_nAY>801?nAY>83o`0000;oUjCM00?o0000oi2Jf_n@
V]X00on@V]X00ol0003oooooooooo`0Aooooo`04o`000?n@Vm[oT9_Joi2KfP;o00000onGVmH00ol0
003oUi_FoiNKeP05oiNKeP03o`000?nBT]3oTY;@00?oTY;@0_l00002oi:Bd003o`000?nIU<go0000
00_ooooo00Go0000oiVDcOl0003oWYK;o`000008ooooo`?o00000_ooool6o`000003ojBIb_l0003o
000000CoYI[90ol00005ojND`P?o000000?oYiC2ojbG`On/Ul403Ol00006ojc0j003o`000?n/`^Wo
[<;Y013o[<;Y0_l00008ojc3jP_o00001?ooool2o`000004ol:X`?l0003obk?2o`0000;obk?20_l0
0006olJfb`;o00001?ooool01Ol0003oa[K;olJfboo6]/_o000000;ocL7?00?o0000ooooooooool0
3?ooool00ol0003ocL7?olg1c`02olg1c`03o`000?o6`MGo000000;ob/_K00Co0000ol[;foo:bm_o
b/_K5_ooool00ol0003ob/_Kol[;f`03ol[;f`05o`000?o2amko`/ONol;7g_l000000_o2amh3o`00
00Wo`/oT0ol0000Booooo`03o`000?o2cnCo`/oT00Co`/oT00?o0000ooooooooool06oooool00ol0
003oooooooooo`11ooooo`007oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02So
oooo00?o0000oi6Th_nAY>801?nAY>800ol0003oooooooooo`0Looooo`OoTJCR0_l000000onGY=go
0000oi2JfP04oi2JfP03o`000?oooooooooo01;ooooo00?o0000oi2Kf_n@VmX00_n@VmX01?l0003o
Ui_FoiNKe_l00006oiNKeP03o`000?nBT]3oTY;@00?oTY;@00Ko0000oooooooooooo0000oi:Bd?l0
0002oiVDc@03o`000?oooooooooo00Wooooo0_nIU<d00ol0003oWYK;o`000007ooooo`;o000000?o
XYS:o`000?l000000_nRV<X2o`000003ojBIb_l0003o000000;o000000GoYI[9o`000?l0003o0000
ojBB`P02o`0000;oYiC22ol0000@ojc0j0?o00004?n/`^T00ol0003o[L?Zo`00000>ojc3jP;o0000
0on/`n/5o`0000;o`ZS000?o0000ol^c`_l000001?o;/l82o`0000Koa[K;0_l000000ooooooo0000
olJfb`02olJfb`04o`000?o=`LoocL7?o`00013ooooo00?o0000olg1coo=`Ll02Ol0000Hooooo`03
o`000?o:bm_ob/_K00;ob/_K00Co0000ol;7g_o2amko00000_o2amh00ol0003o`/oTol;?i008ol;?
i0;o00005Oooool00ol0003o`/oTol;?i003ol;?i003o`000?oooooooooo01cooooo00?o0000oooo
ooooool0@Oooool001oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Wooooo`03
o`000?nAY>;oTJCR00CoTJCR00?o0000ooooooooool07_ooool?o`0001Kooooo1?n@VmX01?l0003o
Ui_FoiNKe_l00004oiNKeP03o`000?nBT]3oTY;@00?oTY;@00?o0000ooooooooool00_ooool00ol0
003oTY;@o`000002oiVDc@03o`000?oooooooooo00Wooooo00GoVIC=o`000?nNU/_oWYK;o`000006
ooooo`Co00001?nRV<X@o`0000CoZkkW00?o0000ojk1j?l000004_n/`>P01Ol0003o[L;Yo`000?n^
`^Wo000000ko[<;Y00?o0000ojg3j_n]`nX00_l0000<ojc3jP03o`000?n]a>_o000000So[<?[1ol0
0004ol^c`P?o00001Oo6]//01Ol0003oa[K;olJfboo6]/_o000000?ocL7?00?o0000ooooooooool0
3_ooool4o`000003om?>eOl0003ob/_K00;ob/_K00?o0000ol[;fol000006?ooool00ol0003ob/_K
ol[;f`02ol[;f`05o`000?o2amko0000ol;7g_l000002_o2cn@2o`0001Oooooo00?o0000ol;?i?o2
cn@00oo2cn@00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo000Oooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool09_ooool00ol0003oTJCRoi6ThP03oi6ThP03o`00
0?oooooooooo01oooooo00?o0000oi6Th_nAY>801?nAY>801?l0003oQi[Oo`000?l00004oi2JfP;o
00005Oooool4oi2KfP03o`000?nGVmKo000000?oUi_F00?o0000oi:Bd?nBT]000onBT]000ol0003o
ooooooooo`04ooooo`03o`000?nBT]3o000000;oVIC=00?o0000ooooooooool02?ooool01Ol0003o
VIC=o`000?nNU/_o000000Cooooo0_l00002oijFb`;o00000onRV<X8o`0000coZkkW0_l00002ojk1
j003o`000?n/`>So[<3X00Ko[<3X1?l00004ojc0j004o`000?n]`^Wo[L;Yo`0000;o[/;Y3?l00000
1_n/`^Wo0000ojg3j_n]`n[o0000ojk4jPOo00001On/`nX01?l0003o[LC[o`000?l00009ojc3j`;o
00001?n[a>`9o`0000?oa[K;00Go0000olJfboo6]/_oa[K;o`000002olg1c`03o`000?oooooooooo
00kooooo00Co0000olg1coo=`Loo00000_oCc]D01Ol0003ob/_Kol[;foo:bm_o000000;ob/_K00?o
0000ooooooooool05Oooool9o`0000Wo`/oT00?o0000ooooooooool05oooool00ol0003o`/oTol;?
i004ol;?i003o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool001kooooo00?o0000
ooooooooool0=oooool2o`0002Kooooo00?o0000oi6Th_nAY>800onAY>800ol0003oooooooooo`0O
ooooo`03o`000?nAY>;oTJCR00CoTJCR0_l00002ohNJg`03o`000?n@V][oT9[J00?oT9[J00?o0000
ooooooooool04oooool4oi2KfP;o00000_nGVmH00ol0003oTY;@oi:Bd003oi:Bd003o`000?oooooo
oooo00Gooooo00Co0000oi:Bd?nBT]3o00000_nIU<d00ol0003oooooooooo`08ooooo`;oVIC=00Co
0000oijFbol0003ooooo0_l00003oijFb`Ko00004on[_^L00ol0003o[;oXo`000003ojk1j0So0000
0oooool01?n/Ul7o0000ok:K`?nbVl02o`0000;o[L;Y00Co0000ojk2jOn^`^Wo00000oooool01?l0
003o/Y_0ok:K`?l00002okVQ`004o`000?ooooooooooo`0000;o[L?Z00?o0000ojk4j_l000000ooo
ool00ol0003o^J70o`000005o`0000;o[LC[1_l00004ojc3j`03o`000?n]aNco000000KoZlC/00?o
0000ojc5k?l000000_n[aN`4o`000005olJfbol0003oa[K;olJfbol000000_o=`Ll00ol0003ooooo
ooooo`0>ooooo`04o`000?o=`LoocL7?o`0000;odlkE00?o0000om?>eOl000000_o:bm/01?l0003o
b/_Kol[;fol0000Eooooo`;o00000oo:bm/2o`000004ol_EhOl0003o`/oTol;?i0?o00001?o2cn@0
0ol0003oooooooooo`0Iooooo`03o`000?o2cnCo`/oT00Co`/oT00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0oooooo`007_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
02;ooooo00?o0000oi6Th_nAY>801?nAY>800ol0003oooooooooo`0Nooooo`03o`000?nAY>;oTJCR
00GoTJCR00?o0000ohNJgol000000_n7V]l2o`0000CoT9[J0_l0000Dooooo`Oo00001OnBT]000ol0
003oooooooooo`07ooooo`06o`000?nBT]3oTY;@o`000?nIU<go00002_ooool00ol0003oVIC=o`00
0002oijFb`Ko00000_nZ_NL01?l0003o[KkWo`000?l0000Boj^ni`05o`000?n/_nSo[;oXojboj?l0
00000_n^`NP2o`0000Wooooo00Co0000ojbG`Ol0003o/Y_00_l00002ojg2j@04o`000?n^`^Wo[/;Y
o`0000?ooooo00Co0000ok:K`?nbVl3o00000_niXL001?l0003oooooooooool00002ojg3jP03o`00
0?n^a>[o000000?ooooo00?o0000okVQ`?l000000_o2Z<001ol0003oooooo`000?n]a>_o0000ojg5
jol000001?ooool4o`000003ojg5k?l0003o000000?o00000_n[a>`01?l0003o[<G/o`000?l00002
oj_5k004o`000?nZa>coZ/C/oj[4k0So00003oooool01?l0003ocL7?olg1col00003om?>e@06o`00
0?oCc]GodlkEo`000?o:bm_o00000_o:bm/00ol0003oooooooooo`0Aooooo`;o00000oo:bm/2o`00
00;obmGQ0_l00005ol;?i0;o00007_ooool00ol0003o`/oTol;?i004ol;?i003o`000?oooooooooo
01oooooo00?o0000ooooooooool0?_ooool001kooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?nAY>;oTJCR00CoTJCR00?o0000ooooooooool07_ooool00ol0003o
TJCRoi6ThP04oi6ThP05o`000?n7V]ooQi[OohNJgol000000on7V]l2o`0000CoT9[J0_l0000Boooo
o`04o`000?n@V][oT9[Joi2JfPGo00000_nBT]000ol0003oooooooooo`09ooooo`03o`000?nBT]3o
000000;oVIC=00?o0000ooooooooool02?ooool00onIU<go0000o`000002o`0000KoZ[gW00?o0000
oj^miol000000_n]_^L00ol0003oZkkWoj^ni`02oj^ni`Wo000000GoYiC2o`000?ooooooooooo`00
0003ojboj003o`000?n^`NSo[/7X00;o00002Oooool01?l0003o[9O1o`000?nbVl02o`0000;o[L;Y
00Co0000ojk2jOn^`^Wo00000oooool01?l0003o/Y_0ok:K`?l00002okVQ`004o`000?oooooooooo
o`0000;o[L?Z00?o0000ojk4j_l000000oooool00ol0003o^J70o`000002ol:X`007o`000?oooooo
0000ojg4jol0003o[LG[o`000006ooooo`;o000000Ko[LG/o`000?l0003obk?2o`000?ooool6o`00
0003oj_5k?l0003oZ/C/00GoZ/C/00Co0000oj[4kOnZa>goZ/C]1Ol0000;ooooo`04o`000?o=`Loo
cL7?o`0000?odlkE0_l00002om?>e@03o`000?o:bm_o000000?ob/_K00?o0000ooooooooool03_oo
ool2o`0000?ob/_K0_l00003ol_Eh@03o`000?o;eN7o000000Ko`/oT00?o0000ooooooooool07?oo
ool00ol0003o`/oTol;?i004ol;?i003o`000?oooooooooo023ooooo00?o0000ooooooooool0?Ooo
ool001kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Pooooo`03o`000?nAY>;o
TJCR00;oTJCR1Ol0000Nooooo`03o`000?nAY>;oTJCR00CoTJCR00?o0000ohNJgon7V]l00_n7V]l2
o`0000?oQi[O0_l00004oi2JfP;o00003oooool00ol0003oT9[Joi2JfP03oi2JfP04ohR?e?l0003o
TY;@oi:Bd0;o00003Oooool2oi:Bd004o`000?nIU<goVIC=o`0000Kooooo1?l0000:ojZmi`03o`00
0?n[_NOo000000?o[KkW1?l000001OooooooXI33o`000?nTT/;o000000?ooooo0_l000001?nWU<;o
0000ooooool00003ojboj006o`000?n^`NSo[/7Xo`000?n/Ul7o00002?ooool01?l0003o[9O1o`00
0?nbVl02o`0000;o[L;Y00Co0000ojk2jOn^`^Wo00000oooool01?l0003o/Y_0ok:K`?l00002okVQ
`004o`000?ooooooooooo`0000;o[L?Z0_l00004ooooo`03o`000?niXL3o000000;o`ZS00_l00002
ojg4j`;o00001oooool01_l0003o[LG/o`000?n]aNcobk?2o`0000?ooooo2_l00002oj[4k0;o0000
2?nZa>d5o`0000Gooooo00Co0000olg1coo=`Loo00000ooCc]D00ol0003oooooom?>e@03om?>e@03
o`000?o:bm_o000000;ob/_K00?o0000ooooooooool03?ooool2o`0000?ob/_K0_l00005ol_Eh@03
o`000?o;eN7o000000Ko`/oT00?o0000ooooooooool07?ooool00ol0003o`/oTol;?i004ol;?i003
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool001kooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`0Oooooo`03o`000?nAY>;o000000;o00001OnAY>83o`0001_ooooo
00?o0000oi6Th_nAY>801?nAY>800ol0003oQi[OohNJg`02ohNJg`04o`000?oooooo0000o`0000?o
Qi[O00?o0000oi2Jf_n@V]X00on@V]X00ol0003oooooooooo`0;ooooo`03o`000?n@V][oT9[J00?o
T9[J00Co0000ohR?e?n8SmCo00000_nBT]000ol0003oooooooooo`0;ooooo`04o`000?nBT]3oTY;@
o`0000;oVIC=1_l0000>ojZmi`03o`000?n[_NOo000000?o[KkW00?o0000ooooooooool00_l00000
1?nQT<?o0000ojBB`_l00004ooooo`05ojBB`_nWU<;o0000ooooool000000on/_nP01_l0003o[/7X
ojk1j?l0003o[9O1o`0000Sooooo00?o0000ojbG`Ol000000_nbVl001?l0003o[L;Yojg2jOl00002
ojk2j@05o`000?ooooooooooooooool000000_nbVl001_l0003o^J70okVQ`?l0003oooooo`0000?o
[L?Z0_l00003ooooo`0<o`000?niXL3o^J70o`000?o2Z<3o0000ooooool0003o[LC[o`000?n]aN_o
00001_ooool2o`000005ojg5k?l0003o0000ol^c`_l000000_ooool5o`000003ooooool0003o0000
00;ooooo00?obk?2o`000?l000000_l00009oj[4k@;o00000_nYaNh3o`000005ooooool0003ocL7?
olg1col000000ooCc]D01?l0003oooooooooooooool3om?>e@03o`000?o:bm_o000000?ob/_K00?o
0000ooooooooool02?ooool3o`0000?ob/_K0_l00006ol_Eh@04o`000?o;eN7obmGQo`0000Ko`/oT
00?o0000ooooooooool07?ooool00ol0003o`/oTol;?i004ol;?i003o`000?oooooooooo027ooooo
00?o0000ooooooooool0??ooool001kooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0Nooooo`?o00002_nAY>83o`0001Sooooo00?o0000oi6Th_nAY>801?nAY>800ol0003oQi[OohNJ
g`02ohNJg`05o`000?ooooooooooooooool000000on7V]l2o`0000CoT9[J0_l0000;ooooo`03o`00
0?n@V][oT9[J00;oT9[J00Ko0000ohR?e?n8SmCo0000ohR?e?l00002oi:Bd003o`000?oooooooooo
00_ooooo00?o0000oi:Bd?l000000ol0000BojZmi`05o`000?n[_NOoZkgWoj^miol000000on]_^L0
0ol0003oooooo`000004o`000003ojBB`_l0003ooooo00;ooooo00?oY9;2o`000?l000000_ooool0
1?l0003o[;oXojboj?l00003ojk1j0;o00002Oooool2o`0000;o/Y_000Co0000ojg2jOn]`^Wo0000
0_n^`^T01Ol0003ooooooooooooooooo000000;o/Y_000Ko0000okVQ`?niXL3o0000ooooool00002
ojg3jP03o`000?n^a>[o000000?ooooo00co0000okVQ`?niXL3o0000ol:X`?l0003oooooo`000?n]
a>_o0000ojg5jol00006ooooo`?o000000Co[LG/ol^c`_o;/l;o00000_ooool4o`000003ooooool0
003o000000;ooooo00Go0000ol^c`_o;/l;o0000oj_6k@05o`0000CoZ/C]00?o0000oj[6k_l00000
1OnYaNh4o`0000?odlkE00?o0000ooooooooool00_ooool01?l0003odlkEom?>eOoCc]D2o`0000?o
b/_K00?o0000ooooooooool01_ooool2o`0000Cob/_K0_l00006ol_Eh@;o00000oo;eN400ol0003o
`/oTol;?i004ol;?i003o`000?oooooooooo01cooooo00?o0000ol;?i?o2cn@01?o2cn@00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo03cooooo000Nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool07Oooool00ol0003oRjOWoh^Wi`03o`0000[oTJCR0ol0000Dooooo`03o`00
0?nAY>;oTJCR00GoTJCR00Go0000ohNJgon7V]ooQi[Oo`000005ooooo`;o00000on7V]l2o`0000Co
T9[J0_l00008ooooo`03o`000?n@V][oT9[J00?oT9[J00Oo0000ohR?e?n8SmCoR8oDo`000?n8SmCo
000000;oTY;@00?o0000ooooooooool02?ooool4o`0000goZ[gW1_l00002oi^=a0;o00000on[_NL0
1_l0003o[KkWojfnion]_^Oo0000ooooo`;o000000Gooooooj6@`ol0003oY9;2o`000004ooooo`05
ojBB`_nWU<;o0000ooooool000000_n/_nP01?l0003o[/7Xojk1j?n^`NP2o`0000Wooooo0_l00002
ok:K`004o`000?n]`^Wo[L;Yo`0000;o[/;Y1_l000000onbVl3o0000okVQ`004o`0000;o[L?Z00?o
0000ojk4j_l000001?l000000oniXL3o0000ol:X`003o`0000;o[LC[0_l00007ooooo`06o`000?n]
aNco0000o`000?o;/l;o00000_ooool5o`000003ooooool0003o000000;ooooo0_o;/l801?l0003o
ZlK]oj_6kOl00004omC0aPCo00000_nZa^h00ol0003oZLG^ojW5kP07ojW5kP?o00001Oooool01?l0
003odlkEom?>eOoCc]D2o`0000Cob/_K00?o0000ooooooooool00oooool2o`0000Cob/_K0_l00006
ol_Eh@;o000000?ooooool_EhOo;eN400_o;eN400ol0003o`/oTol;?i004ol;?i003o`000?oooooo
oooo01cooooo00?o0000ol;?i?o2cn@01?o2cn@00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000Mooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07?ooool01?l0
003oRjOWoh^Wiol00002oh^Wi`?o00002_nAY>83o`00017ooooo00?o0000oi6Th_nAY>801OnAY>80
1Ol0003oQi[OohNJgon7V]oo000000Oooooo0_l00003ohNJg`;o00001?n@V]X2o`0000Gooooo00?o
0000oi2Jf_n@V]X00on@V]X00ol0003oR8oDohR?e002ohR?e004o`000?n8SmCoR8oDo`0000;oTY;@
00?o0000ooooooooool01?ooool3o`0000;oZ;_W00?o0000oj^mion[_NL00ol00003ojZmi`Ko0000
0onDR/H2o`000003oi^=a?l0003o000000;ooooo00Co0000oj^mion[_NOo00000on]_^L00ol0003o
ooooooooo`06o`0000Cooooo00GoY9;2o`000?l0003oooooo`000003ojboj003o`000?n^`NSo[/7X
00;o00002Oooool2o`0000;o/Y_000Co0000ojg2jOn]`^Wo00000_n^`^T00ol0003o/Y_0ok:K`003
ok:K`0?o00000oniXL001_l0003o[L?Zojg3j_l0003o[/CZo`0000Co^J700ol00002ol:X`004o`00
0?n]a>_o0000ojg5j`Go00000_ooool2o`000005ojg5k?l0003o0000ol^c`_l000000_ooool4o`00
0003ooooool0003o[<K]00;ooooo00Co0000ol^c`_l0003o00000_n[a^d00ol0003oooooomC0aP03
omC0aP03o`000?o=`Loo000000;oZ/K^0ol0000:ojW5kP?o00000oooool00ol0003odlkEom?>e@02
o`0000Cob/_K00Co0000oooooooooooooooo0_l00005ol[;f`03o`000?o;eN7obmGQ00CobmGQ0_l0
0003ooooo`CobmGQ00?o0000ol;?i?o2cn@01?o2cn@00ol0003oooooooooo`0Looooo`03o`000?o2
cnCo`/oT00Co`/oT00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`007Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00Co0000oh^Wion;YnOo00001?n;
YnL3o`0000[oTJCR0ol0000>ooooo`03o`000?nAY>;oTJCR00GoTJCR00Go0000ohNJgon7V]ooQi[O
o`000009ooooo`;o00000on7V]l2o`0000CoT9[J00?o0000ooooooooool00_ooool00ol0003oT9[J
oi2JfP03oi2JfP07o`000?n8SmCoR8oDohR?e?l0003oooooo`000002ohR?e005o`000?nBT]3oTY;@
o`000?ooool01?l00005ojRki`;o00001?n[_NL3o`0000?oVIC=0_l00004oiB:aP;o000000?oVhg4
o`000?ooool00_ooool01Ol0003oZkgWoj^mion[_NOo000000?o[KkW00?o0000ooooool000000_l0
0002oj6@``03ojBB`_l0003ooooo00;ooooo0ol000000ooooooo0000ojboj002ojboj006o`000?n^
`NSo[/7Xo`000?n/Ul7o00001?ooool5o`000004ojbG`Ol0003o/Y_0o`0000;o[L;Y00?o0000ojk2
jOl000000onbVl05o`0000?o^J700_l00002ojg3jPWo00000oo2Z<001Ol0003o[LC[o`000?n]aN_o
000000Co`ZS01Ol000001On]aNcobk?2ol^c`_l0003ooooo00So00000_ooool00ol0003obk?2o`00
0002oj_6k@05o`000?ooooooooooooooool000000ooD`<H2o`0000;oZ/K^0_l000001?oooooo0000
o`000?l00006ojW5kP04o`000?nYa^oo0000ojO4kPCo00000ooCc]D00ol0003ob/_Kol[;f`02ol[;
f`04o`000?oooooo0000o`0000Gob/_K0_l00005ol_Eh@;o00001Oooool01Ol0003obmGQol_EhOo;
eN7o000000Ko`/oT00?o0000ooooooooool07?ooool00ol0003o`/oTol;?i004ol;?i003o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0>_ooool001gooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0Kooooo`05o`000?n;YnOoRjOWoh^Wiol000001_n;YnL3o`0000[oTJCR0ol0
000;ooooo`03o`000?nAY>;oTJCR00CoTJCR00?o0000ohNJgon7V]l00_n7V]l00ol0003ooooooooo
o`09ooooo`03o`000?n7V]ooQi[O00;oQi[O00?o0000oi2Jf_n@V]X00_n@V]X2o`000003ooooool0
003oT9[J00CoT9[J00Go0000ohR?e?n8SmCoR8oDo`000003ooooo`03o`000?n8SmCoR8oD00Co0000
2?nX^nL01?l0003oZ;_WojRkiol00003oj^mi`04o`000?nIU<go0000oiVDc@;o00001_nDR/H01Ol0
003oUH_6o`000?nKSLCo000000;ooooo00Go0000oj^mion[_NOoZkgWo`000003ojfni`03o`000?oo
oooooooo00Ko00001?ooool01?nTT/;oYiC2o`000?l00003ojboj005o`000?n^`NSo[/7Xo`000?n/
Ul401Ol00005ojbG`@Co00000_n]`^T00ol0003o[/;Yo`000003o`0000Co/IBh00?o0000okZJ]ol0
00000_njV[L00ol0003o[L?Zojg3jP02o`0000Ko^YZg00Co0000olBR]oo4X[Oo00000_n]a>/3o`00
00Ko`ZS000Ko0000ojg5k?l0003o0000ol^c`_l00002ooooo`Co000000?oooooo`000?l000000_oo
ool01_l0003obk?2o`000?l0003oZlK]o`0000Gooooo00Co0000omC0a_l0003o00000onZa^h2olg1
c`04o`000?o=`LoocL7?olg1c`?o00000_nYaNh01?l0003oZLK_o`000?l00004ojO4kP?o000000?o
dlkEo`000?o:bm/01?o:bm/00ol0003ob/_Kol[;f`03ol[;f`;o00001Oo;eN42o`0000Oooooo00Go
0000ol_EhOo;eN7obmGQo`000006ol;?i003o`000?oooooooooo01[ooooo1?l00005ol;?i003o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool001gooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?n;YnOoRjOW00;oRjOW00?o0000oh^Wion;YnL01_n;
YnL4o`0000WoTJCR0ol00008ooooo`03o`000?nAY>;oTJCR00CoTJCR00?o0000ohNJgon7V]l00_n7
V]l00ol0003oooooooooo`0:ooooo`;o00000on7V]l2o`0000CoT9[J00?o0000oi2Jf_n@V]X00on@
V]X00ol0003oR8oDohR?e002ohR?e003o`000?oooooooooo00;ooooo0ol0000;ojRki`04o`000?nX
^nOoZ;_Wo`0000CoZkgW0ol00006oiB:aP03o`000?oooooo000000;oUH_60_l00003ooooo`05o`00
0?n[_NOoZkgWoj^miol000000_n]_^L00ol0003oooooooooo`06o`0000Cooooo0ol000001Ooooooo
0000ojboj?n/_nSo000000;o[/7X00?o0000ojbG`Ol000002?n/Ul45o`0000;o[L;Y00?o0000ojk2
jOl000001_naU;P2o`0000;o^YZg00?o0000okZJ]ol000000_n]`nX2o`0000Go^YZg0ol000001oo4
X[Oo0000ojg4jol0003o[LG[o`000?o4X[L01Ol000001?o2Z<3o0000o`000?n]aN`<o`000003oooo
ool0003obk?200;o000000?oZlK]o`000?l000001_ooool00ol0003oZ/K^oj[6kP02oj[6kP?ocL7?
00?o0000olg1coo=`Ll01?oCc]D2o`000004ojW6kol0003oZLK^o`0000OoYlC^0ol00004ol[;f`04
o`000?o:bm_ob/_Kol[;f`;o00001Oo;eN42o`0000Wooooo00Go0000ol_EhOo;eN7obmGQo`000006
ol;?i003o`000?oooooooooo01Gooooo1Ol00004ol;?i0?o00000_o2cn@00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo000Mooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool06_ooool00ol0003oRjOWoh^Wi`02oh^Wi`?o00002On;YnL3o`0000WoTJCR0ol00004oooo
o`03o`000?nAY>;oTJCR00GoTJCR00Go0000ohNJgon7V]ooQi[Oo`00000?ooooo`03o`000?n7V]oo
Qi[O00;oQi[O0_l00002oi2JfP03o`000?n@V][oT9[J00?oT9[J00Ko0000ohR?e?n8SmCoR8oDo`00
0?ooool4o`0000[oZ;_W0ol000000ooooooo0000ojRki`02ojRki`04o`000?n[_NOoZkgWoj^mi`;o
00001OnDR/H00ol0003oooooooooo`02ooooo`05o`000?nERlKo0000oi^=a?l000000_ooool01Ol0
003oZkgWoj^mion[_NOo000000?o[KkW00?o0000ooooool000000_l000001?nQT<?o0000ojBB`_l0
0003ooooo`?o000000Goooooo`000?n/_nSo[;oXo`000002ojk1j003o`000?n/Ul7o000000Co[9O1
1?l00002oj^?^@;o/IBh00Go0000ojg2jOn]`^Wo0000ojk2j@07o`00000:ok6D^?l0003o^YZgokZJ
]ol0003oooooo`000?n]`n[o0000ojk4jPKo000000?o^YZgo`000?o4X[L00_l000001?n]a>_o0000
ojg5jol00006olBR]`04o`000?n]aNco0000o`0000Cobk?21?l000000ooooooo0000o`000002oooo
o`03o`000?o;/l;o000000;oZlK]00?o0000ooooooooool01Oooool2o`0000;oZ/K^00Koe<36o`00
0?o=`LoocL7?o`000?o=`Ll4om?>e@04ooooool0003oZLK_o`0000;oZLK^0_l00007ojO4kP03o`00
0?nWa>ko000000?o00000oo:bm/00ol0003obmGQol_Eh@03ol_Eh@;o00002oooool01Ol0003obmGQ
ol_EhOo;eN7o000000Ko`/oT00?o0000ooooooooool04Oooool4o`0000co`/oT0ol0000Wooooo`03
o`000?oooooooooo03Sooooo000Mooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
6Oooool00ol0003oRjOWoh^Wi`02oh^Wi`03o`000?oooooooooo00?o00002On;YnL3o`0000WoTJCR
0ol000000ooooooo0000oi6ThP06oi6ThP05o`000?n7V]ooQi[OohNJgol000004Oooool00ol0003o
Qi[OohNJg`02ohNJg`04o`000?n@V][oT9[Jo`0000?oT9[J00Co0000ohR?e?n8SmCoR8oD0ol0000;
ojRki`?o00001Oooool01?l0003oZ;_WojRkiol00004oj^mi`04o`000?nER/Ko0000oiB:aP;o0000
1Oooool00ol0003oUH_6oiF;aP02o`0000;ooooo00Go0000oj^mion[_NOoZkgWo`000003ojfni`03
o`000?oooooooooo00Ko00000oooool00ol0003oY9;2o`000002o`0000;o[;oX00?o0000ojk1j?n^
`NP00_l000000on/Ul7o0000o`000002o`0000GoZhni0_l000001onaU;So0000ojg2jOn]`^Wo0000
ojk2jOl000001Oooool2ok6D^00:o`000?njV[Oo^YZgo`000?oooooo0000ojg3j_l0003o[/CZo`00
00Cooooo0_njV[L00ol0003oa::go`000002ojg4j`03o`000?n]aN_o000000Co00000_o4X[L01Ol0
003o[LG/o`000?o?[[Wo000000;obk?22?l000000ooooooo0000ol^c`P02o`000003oj_6kOl0003o
000000Kooooo0_l00002oj[6kP03o`000?oD`<Koe<3600;o000000?ocL7?om?>eOoCc]D00_oCc]D0
1?oooooo0000ojW6kol00003ojW6kP03o`000?oooooo000000;o00001?nWa>h00ol0003oYlC^ojO4
kP02ojO4kP?o00001Oo;eN42o`0000gooooo00Go0000ol_EhOo;eN7obmGQo`000006ol;?i003o`00
0?oooooooooo00cooooo1Ol0000@ol;?i0?o0000:?ooool00ol0003oooooooooo`0gooooo`007?oo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Sooooo00?o0000oh^Wion;YnL00_n;
YnL00ol0003oooooooooo`03ooooo`Co00002?n;YnL3o`0000WoTJCR0ol00006oi6ThP05o`000?n7
V]ooQi[OohNJgol000004oooool5ohNJg`;oT9[J00?o0000oi2Jf_n@V]X01?l0000;ojRki`?o0000
0_nBT]000ol0003oooooooooo`03ooooo`;o00000_nX^nL01?l0003oZkgWoj^mion[_NL2o`000003
oiF:a_l0003ooooo00Oooooo00Go0000oiF;a_l0003oVhg4o`000002ooooo`05o`000?n[_NOoZkgW
oj^miol000000_n]_^L00ol0003oooooooooo`06o`000004ooooool0003o0000ojBB`PCo00000on/
_nP00ol0003o[/7Xo`000002o`0000OoZhni0ol000000onZSkWo/IBho`000002ojg2j@03o`000?n^
`^Wo000000Gooooo0_naU;P00ol0003o^YZgokZJ]`02o`0000;o[L?Z00?o0000ojk4j_l000001?oo
ool2okZJ]`07o`000?o4X[Oo0000ojg4jol0003o[LG[o`000005ooooo`Ko00000oo?[[T4o`000005
ol^c`_l0003o0000o`000?ooool00ol000000on[a^go0000o`000006ooooo`;o00000_nZa^h2o`00
00;oe<361_l000001?oooooo0000ojW6kol00003ojW6kP03o`000?oooooooooo00?ooooo0ol00000
0onWa>ko0000ojO4kP05ojO4kP?o00000_o;eN400ol0003oooooooooo`0=ooooo`05o`000?o;eN7o
bmGQol_EhOl000001_o2cn@00ol0003oooooooooo`08ooooo`Co00004?o2cn@6o`000003ol3EjOl0
003ooooo02Oooooo00?o0000ooooooooool0=oooool001cooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?n;YnOoRjOW00?oRjOW00?o0000ooooooooool01_ooool3
o`0000SoRjOW1?l00008oi6ThP03o`000?nAY>;oTJCR00?oTJCR00Go0000ohNJgon7V]ooQi[Oo`00
000Dooooo`03o`000?n7V]ooQi[O00;oQi[O0_l000001_n@V][o0000o`000?nV^nSo0000ojRki`;o
00001_nX^nL3o`0000?oR8oD00Co0000oi:Bd?nBT]3o00000oooool00ol0003oTY;@o`000003ojRk
i`04o`000?n[_NOoZkgWoj^mi`?o00002Oooool01?l0003oUH_6o`000?l00002ooooo`05o`000?n[
_NOoZkgWoj^miol000000on]_^L00ol0003oooooo`000002o`000004oj6@`ol0003o0000o`0000Co
Y9;20ol00003ojboj006o`000?n^`NSo[/7Xo`000?nZSkWo00000_n[SkT4o`0000;ooooo0_nZSkT0
1onaU;So0000ojg2jOn]`^Wo0000ojk2jOl000001Oooool00ol0003o/IBho`000002okZJ]`;o0000
0_n]`nX2o`0000Gooooo0_njV[L01ol0003oa::go`000?n]a>_o0000ojg5jol000001_ooool01ol0
003o[LG/o`000?l0003ocjjio`000?o?[[T02?l000000oo;/l;o0000ol^c`P02o`000003oj_6kOl0
003ooooo00Gooooo00Go0000oj[6k_nZa^koZ/K^o`000002ooooo`;o000000?oe<36o`000?oCc]D0
0_oCc]D2o`000003ojW6kol0003oZLK^00;oZLK^00?o0000ooooooooool01_ooool3o`0000?oYlC^
0ol000000onWaNoo0000ojG3k`02o`00013ooooo00Go0000ol_EhOo;eN7obmGQo`000006ol;?i003
o`000?oooooooooo00Cooooo1?l0000@ol;?i0Co00000_o0eNT2o`0000;o`=GY00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0fooooo`007?ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo01Oooooo00?o0000oh^Wion;YnL00_n;YnL00ol0003oooooooooo`09ooooo`Co0000
2?n;YnL3o`0000KoTJCR00?o0000oi6Th_nAY>800_nAY>801Ol0003oQi[OohNJgon7V]oo000001Ko
oooo1_l00003ojJkj0;o00000_nX^nL2o`000004ojRkiol0003o0000o`0000Cooooo0on8Sm@01_l0
003oTY;@oi:Bd?l0003oooooo`0000?oTY;@00Co0000ojRkionX^nOo00000on[_NL2o`000003oiF:
a_l0003ooooo00Oooooo00Co0000oiF;a_l0003o00000_ooool01Ol0003oZkgWoj^mion[_NOo0000
00?o[KkW00?o0000ooooool000001_l00004ojBB`P?o00000on/_nP01?l0003o[/7Xojk1j?l00002
ojZ?^@;o00001_ooool01?l0003oZXnio`000?l00002ojg2j@03o`000?n^`^Wo000000Gooooo00?o
0000ok6D^?l000000_njV[L2o`0000;o[L?Z0_l00005ooooo`04o`000?njV[Oo0000o`0000;o[LC[
00?o0000ojg5jol000001_ooool00ol0003o[LG/o`000002oln^^@03o`000?oooooo000000?o0000
00Gocjjio`000?l0003o0000ol^c`P03o`000003oj_6kOl0003o000000Kooooo0_l000000onZa^ko
0000ooooo`02ooooo`04o`000?oD`<Ko0000o`0000?odlkE00Co0000ojW6konYa^oo00000_nYa^h0
0ol0003oooooooooo`06ooooo`03o`000?oCc]GodlkE00Co00000_nWa^l2ojO5k`04o`000?nU`noo
YL?_ojG3k`;o00003_ooool01Ol0003obmGQol_EhOo;eN7o000000Ko`/oT00?o0000ooooool00000
1?l0000?ol;?i0Go00001Oo0eNT00ol0003o`=GYol3Ej@02ol3Ej@03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0=Oooool001cooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?n;YnOoRjOW00;oRjOW00?o0000ooooooooool03Oooool4o`0000OoRjOW0ol0
0004oi6ThP04o`000?nAY>;oTJCRo`0000?oQi[O00?o0000ooooooooool05Oooool3o`0000GoY[_X
00Co0000ojJjj?nV^^So00000onX^nL00ol0003oooooooooo`06ooooo`?oR8oD00Co0000oi:Bd?nB
T]3o00001?nBT]001Ol0003oZ;_WojRkionX^nOo000000?oZkgW0_l000000onER/Ko0000ooooo`07
ooooo`04o`000?nERlKo0000o`0000;ooooo00Go0000oj^mion[_NOoZkgWo`000002ojfni`;o0000
00CoWho3o`000?l0003oXI330ol000001_nTT/;o0000o`000?l0003oXHZkojF<^P;o00000_n/_nP0
1?l0003o[/7Xojk1j?l00002ojZ?^@03o`000?oooooooooo00Gooooo1?l00002ojg2j@03o`000?n^
`^Wo000000co00000_n]`nX;o`000004ojg4jol0003o[LG[o`0000Oooooo0ol00002oln^^@Wo0000
00Cocjjio`000?l0003o00000_n[a^d2o`0000Gooooo0_l00002oj[6kP07o`000?ooooooooooo`00
0?oD`<Ko0000omgAc@02o`000005om?>eOl0003oZLK_ojW6kol000000_nYa^h00ol0003ooooooooo
o`05ooooo`;o00000_oCc]D2o`0000CoYlK_0_nWaNl00ol0003oYL?_ojG3k`04ojG3k`;o00003?oo
ool01Ol0003obmGQol_EhOo;eN7o000000Go`/oT0ol0000@ol;?i0Co00002?o0eNT2o`0000Co`=GY
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0eooooo`007?ooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo01Gooooo00?o0000oh^Wion;YnL00on;YnL00ol0003ooooooooo
o`0@ooooo`?o00001on;YnL2o`0000?oTJCR00?o0000oi6Th_l000000on7V]l00ol0003ooooooooo
o`0Dooooo`;o00001onV^nP01Ol0003oY[[XojJjj?nV^^So000000;oZ;_W00?o0000ooooooooool0
1oooool3ohR?e003o`000?nBT]3o000000?oTY;@00?o0000ohb7b?l000000_nX^nL00ol0003oZkgW
oj^mi`02oj^mi`?o00002?ooool01?l0003oUH_6o`000?l00002ooooo`05o`000?n[_NOoZkgWoj^m
iol000000on]_^L00ol0003oWho3oin?``06o`0000CoXHZk00?o0000ojF<^_l000000_n/_nP01?l0
003o[/7Xojk1j?l00002ojZ?^@So00000on_`^P01_l0003o[L;Yojg2jOl0003o[/;Yo`0000_o[lCY
00Go0000ojg3j_l0003o[/CZo`000008ojo6j`04o`000?n]a>_o0000ojg5j`So000000?o[LG/o`00
0?l000000_l000000ooooooo0000o`000007o`000005oln^^Ol0003o0000oj_6kOl000000_oD`<H0
1?l0003oooooooooooooool2o`0000;oZ/K^00Ko0000oooooooooooo0000omC0a_l00002omgAc@03
o`000?oMdLgo000000;oZLK_00Co0000ojW6k_nYa^ko00001_ooool2o`0000;odlkE1?l00002ojO6
k`04o`000?nWaNooYlG_ojO5k`;o00001onU`nl3o`0000Wooooo00Go0000ol_EhOo;eN7obmGQo`00
0004ol;?i003o`000?o2cnCo`/oT00co`/oT1Ol00009ol3Ej@?o00001_o0eNT00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo03Cooooo000Looooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool05?ooool00ol0003oRjOWoh^Wi`03oh^Wi`03o`000?oooooooooo01?ooooo0ol00007
oh^Wi`03o`000?nAY>;oTJCR00;o000000?oQi[Oo`000?l000000_l0000Booooo`?o00002OnV^nP0
0ol0003oY[[XojJjj002ojJjj004o`000?nX^nOoZ;_Wo`0000Wooooo0on8Sm@2o`0000;oTY;@00Go
0000ohb7b?n<QlSoS8O8o`000002ojRki`04o`000?n[_NOoZkgWoj^mi`;o000000?oUH[6o`000?oo
ool01oooool2oiF;aP;o000000?oooooo`000?n[_NL00on[_NL01?l0003o[KkWojfniol00003oin?
``05o`000?nOR;_o0000oj6:^ol000000_nQR[/6o`000004ojboj?l0003o[/7Xojk1j0Co00002on_
`^P01?l0003o[L;Yo`000?l0000=ojo4j@?o00002On_a^/01?l0003o[LC[o`000?l00007ojk7k0?o
00000_n^an`5o`000004ooooool0003o[<K]o`0000;ooooo0_l000000on[a^go0000omC0aP03omC0
aP03o`000?oooooooooo00;o000000GoZ/K^o`000?ooooooooooo`000002omC0aP03o`000?oMdLgo
gM7=00;o00000_nYa^l01?l0003oZLK^ojW6k_l00006ooooo`0;o`000?oCc]GodlkEom?>eOl0003o
eMgMo`000?nWa^oo0000ojO6kol000000onWaNl2ol_EhPCo00001onU`nl2o`0000Oooooo00Go0000
ol_EhOo;eN7obmGQo`000003ol;?i003o`000?o2cnCo`/oT00Wo`/oT1?l00009ol3Ej@Go00000_oo
ool7ol3Ej@03o`000?oooooooooo02cooooo00?o0000ooooooooool0<oooool001cooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`0Dooooo`03o`000?n;YnOoRjOW00;oRjOW00?o0000
ooooooooool05oooool00ol0003oRjOWoh^Wi`04oh^Wi`Go00001?n7Vml3o`0000gooooo0_l0000:
ojJkj003o`000?mjSM[o000000GoY[[X00Co0000ojRkionX^nOo00002Oooool6o`0000?oS8O80_l0
0003ojRki`04o`000?n[_NOoZkgWoj^mi`;o000000?oUH[6o`000?ooool01oooool2oiF;aP04o`00
0?ooooooooooo`0000?oZkgW00?o0000ojfnion]_^L00ol000000onLQkco0000o`000006o`0000Go
[KoW00Go0000ojboj?l0003o[/7Xo`00000?ojo2j0?o00001_n_a>T?o`0000Go[lK[0_l00008ojk7
k0;o00001?n^an`:o`000006oj_6kOl0003oZlK]o`000?oK_[co00000ooD`<H3o`0000;oZ/K^00?o
0000ooooool000000_oD`<H00ol0003ogM7=omgAc@02o`0000;oZLK_00Go0000ojW6k_nYa^koZLK^
o`000004ooooo`;o00000_oCc]D2o`000004omGMgOl0003oYlK_ojO6k`;o00000onWaNl3ol_EhP04
o`000?ooooooooooooooo`;o00001onU`nl2o`0000Gooooo00Go0000ol_EhOo;eN7obmGQo`000002
ol;?i003o`000?o2cnCo`/oT00Go`/oT1Ol00009ol3Ej@Co00001_ooool00ol0003o`=GYol3Ej@04
ol3Ej@03o`000?oooooooooo02gooooo00?o0000ooooooooool0<oooool001_ooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`0Cooooo`03o`000?n;YnOoRjOW00?oRjOW00?o0000oooo
ooooool06Oooool4o`0000?oRjOW00?o0000ogbLi_l000000_l00004ohNKg`?o00002?ooool2o`00
00SoY[_X0ol00002ogZ=fP?o00001?nV^^P01Ol0003oZ;_WojRkionX^nOo000000Sooooo00?o0000
ohR?e?n8Sm@01?l000001On<QlSo0000oooooooooooo000000;oZ;_W00Ko0000oj^mion[_NOoZkgW
o`000?n<QlP2o`0000Sooooo0_nERlH4o`0000?oZkgW00Co0000ojfnion]_^Oo[KkW1?l0000=ojfo
i`?o00002?n_`^PAo`0000Oo/<?X0_l00006ok35jP_o00001?n^an`2o`0000?o[/O/1?l000000on_
bNgo0000o`000003ojg8k@So00000_oD`<H2o`0000;oZ/K^00Ko0000oooooooooooo0000omC0a_l0
0002omgAc@;o00000_nYa^l01?l0003oZLK^ojW6k_nYa^h2o`0000;ooooo0_l00003om?>e@04o`00
0?oEgMgoeMgMo`0000;oYlK_00Go0000ojO5kol0003oYlG_o`000004ol_EhP03o`000?oooooooooo
00?ooooo0_l00007ojG3k`;o00000_ooool3o`0000;obmGQ00?o0000ol;?i?l000001?o2cn@4o`00
00Wo`=GY1Ol0000:ooooo`03o`000?o0eNWo`=GY00Co`=GY00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0booooo`006oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01;o
oooo00?o0000oh^Wion;YnL00on;YnL00ol0003oooooooooo`0Jooooo`03o`000?n;YnOoRjOW00?o
RjOW00Go0000ogbLi_mlW>Ko0000ogfLiP02o`0000GoQi_O0_l00003ooooo`?o00001onV^nP3o`00
00;oQi[O00Go0000ogZ=f_mjSM[o0000ooooo`02o`0000CoY[[X00Go0000ojRkionX^nOoZ;_Wo`00
0006ooooo`03o`000?n8SmCoR8oD00;oR8oD00Co0000ohb7b?n<QlSo00001?ooool01?l0003oZ;_W
ojRkiol00003oj^mi`;o000000?oUH[6o`000?ooool01_ooool4o`000003oi^=a?l0003oZkgW00?o
ZkgW00Co0000ojfnion]_^Oo00004On]_nL:o`0000So/<3V0_l0000=ok33j004o`000?naaNWo0000
o`0000Wo/<GZ0_l00005ojo6j`oo00001?n]b>d00ol0003oZlK]ojc8kP04ojc8kPCo00000_nZa^h0
1_l0003oooooooooool0003oe<36o`0000;ogM7=0_l00003ojW6k`08o`000?nYa^koZLK^o`000?oC
c]Go0000ooooool00003om?>e@;o00000_oEgMd01?l0003oYlK_ojO6kol00002ojO5k`?o00001?o;
eN800ol0003oooooooooo`05ooooo`;o00001?nU`nl5o`0000?obmGQ1?l00002ol;?i0?o00002_o0
eNT3o`0000oooooo00?o0000ol3EjOo0eNT00oo0eNT00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo03;ooooo000Kooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool04_ooool0
0ol0003oRjOWoh^Wi`02oh^Wi`03o`000?oooooooooo01[ooooo00?o0000oh^Wion;YnL01?n;YnL0
1?l0003oO9cVogbLi_l00002ogfLiP;o00001On7Vml3o`0000SoY[_X0_l00004ohNJg`05o`000?mj
SM[oNXgJogZ=f_l000000_ooool2o`0000CoY[[X00Co0000ojRkionX^nOo00001Oooool00ol0003o
R8oDohR?e002ohR?e005o`000?mnP/go0000ohb7b?l000001?ooool01?l0003oZ;_WojRkiol00003
oj^mi`05o`000?n<QlSo0000oiF:a_l000001Oooool01?l0003oUH_6oiF;a_nERlH5o`0000;oZkgW
00?o0000ojfniol000002?n]_nL7o`0000?o[[gU0_l0000?ok30iP04o`000?na`^Oo0000o`0000Ko
/<?X0ol00002ok33j003o`000?naaNWo/LGY00Wo000000?o/<GZo`000?naan/00_l00006ojo6j`03
o`000?n`bNco000000Co[/O/00?o0000ojo9kOl000001Ol000000on]b>go0000o`000008ojc8kPWo
00000_oMdLd2o`0000?oZLK_00Co0000ojW6k_nYa^ko00000ooCc]D01Ol0003odlkEom?>eOoCc]Go
000000?oeMgM00Co0000ojO6konWa^oo00000onWaNl00ol0003oeMgMo`000004ol_EhP03o`000?oo
oooooooo00Oooooo1?l00002ojG5l003ojC3kol0003oXl;_00;o000000?obmGQo`000?l000000_l0
000;ol3Ej@?o00004_ooool00ol0003o`=GYol3Ej@04ol3Ej@03o`000?oooooooooo033ooooo00?o
0000ooooooooool0<Oooool001_ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0A
ooooo`03o`000?n;YnOoRjOW00;oRjOW00?o0000ooooooooool06oooool00ol0003oRjOWoh^Wi`03
oh^Wi`04o`000?mlW>KoO9cVogbLiP;o00000_mmW>H3o`000004ohNKgol0003o0000ojJkj0?o0000
0onV^nP3o`000003ooooool0003oQi[O00?oQi[O00Co0000ogZ=f_mjSM[o00001?ooool2o`0000Co
Y[[X00Co0000ojRkionX^nOo00000oooool00ol0003oR8oDohR?e002ohR?e003o`000?mnP/goOX;=
00;o000000?oS8O8o`000?ooool00oooool01?l0003oZ;_WojRkiol00003oj^mi`;o000000?oUH[6
o`000?ooool00_ooool7o`0000CoZkgW0ol000000on]_^Oo0000ojfoi`07o`0000Wo[[gU0_l00000
0onb`NGo0000ok30iP06ok30iP?o00000on``>H01Ol0003o/L;Wok72iol0003o//CW00co000000?o
/LGYo`000?nba^T00_l00006okVB[P?o000000?o/LS[o`000?l000001Ol00002ok39k0;o00000_n^
an`01?l0003o[lW]o`000?n_bNd2o`0000?o[LS]1ol00003ojc8kP?o00001_n[b>l4o`0000?oZLK_
00?o0000ojW6k_nYa^h00_l00003om?>e@04o`000?oCc]Go0000o`0000?oeMgM00Co0000ojO6konW
a^oo00000_nWaNl3o`000003omGMgOl0003obmGR00?obmGR00?o0000ooooooooool01_ooool00ol0
003oYLG`ojG5l002ojG5l003o`000?nT`noo000000CoXl;_00?o0000olSNjOo8g^T00_o0eNT3o`00
00Go`=GY0_l0000Fooooo`03o`000?o0eNWo`=GY00?o`=GY00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0`ooooo`006oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo013o
oooo00?o0000oh^Wion;YnL00on;YnL00ol0003oooooooooo`0Jooooo`03o`000?n;YnOoRjOW00?o
RjOW00Ko0000ogbLi_mlW>KoO9cVo`000?ooool2o`0000;oOIcV0_l000001?nT^nWo0000oj>jjOl0
0002ojJkj0Co00000oooool00ol0003oQi[OohNJg`02ohNJg`04o`000?mjSM[oNXgJo`0000Kooooo
00?o0000ojJjj?nV^^P00_nV^^P01?l0003oZ;_WojRkiol00002ooooo`03o`000?n8SmCoR8oD00;o
R8oD00So0000ogj2cOmnP/go0000ogj2cOl0003oS8O8o`0000?ooooo00Go0000ojRkionX^nOoZ;_W
o`000002oj^mi`04o`000?n<QlSo0000oiF:aPGo00003?n[_NL3o`00013o[[gU0_l00002ok;1i@Oo
000000?oooooo`000?l000001?l00002ok72i`03o`000?nba>Oo000000Go00000on`S;001ol0003o
^I:_o`000?naaNWo0000ok;6jOl000000_niTZh5o`000005okVB[_l0003o0000ok78jol000001Oo5
Vjd00ol0003o/<W/o`000009o`0000Co[LS]0_l00005ojc8kPKo00002On[b>l01?l0003oZLK_ojW6
kol00002ojW6kP;o000000KogM7=o`000?oCc]Go0000om?>eOl00003omGMg@;o00000_nWa^l01Ol0
003oYlG_ojO5kol0003ooooo00;o000000?oeMgMo`000?o;eN800oo;eN800ol0003oooooooooo`04
ooooo`;o00000onUaO001?l0003oY<?_ojC3konT`nl2o`0000CoXl;_0_l00005ol3Ej@03o`000?o0
eNWooooo01Wooooo00?o0000ol3EjOo0eNT01?o0eNT00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo033ooooo000Kooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool03oooool0
0ol0003oRjOWoh^Wi`03oh^Wi`03o`000?oooooooooo01[ooooo00?o0000oh^Wion;YnL00on;YnL0
1Ol0003oO9cVogbLi_mlW>Ko000000?ooooo0_l00003ojBkj@04o`000?nS^^WoXk[Yo`0000GoY[_X
0ol00005ohNJg`04o`000?mjSM[oNXgJo`0000Oooooo00Go0000ojJjj?nV^^SoY[[Xo`000003ojRk
i`;o00001?n8Sm@02_l0003oOX;=ogj2cOl0003oooooo`000?mnP/go0000ohb7b?l00003ooooo`04
o`000?nX^nOoZ;_Wo`0000?oZkgW0ol0000;oj^mi`Co00000_n/^^@2o`00013o[[gU00Go0000ojno
iOn__nGo0000ok;1i@03o`000003ojZ?^Ol0003o000000;o00001?nZSkT2o`0000;o/L;W00?o0000
ok;4iol000001On`S;04o`000005okVB[ol0003o/LGYo`000?nba^T00_l00005ooooo`;o000000?o
/LO[o`000?nab>/01Oooool01_l0003o/<W/ok39k?n`bNco0000olFL[P_o000000?o[/_^o`000?l0
00000_l00003ojc8kP03o`000?n]bo3o000000;oZLS`1?l00005oj_8k`04o`000?nYa^oo0000ojW6
kPCo000000CogM7=o`000?oCc]Go00001?oEgMd2o`000004ojO6kol0003o0000ojO5k`;o00000_oo
ool2o`000003omGMgOl0003obmGR00?obmGR00Co0000oooooooooooooooo0ol00003ojG5l0;o0000
0onT`nl01?l0003ob=kYolSNjOl00005oj?2k`;o00000oo0eNT00ol0003oooooooooo`0Iooooo`03
o`000?o0eNWo`=GY00?o`=GY00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0_ooooo`00
6_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00oooooo00?o0000oh^Wion;YnL0
0_n;YnL00ol0003oooooooooo`0Jooooo`03o`000?n;YnOoRjOW00CoRjOW00Co0000ogbLi_mlW>Ko
O9cV0ol00006ojBkj@04o`000?nS^^WoXk[Yo`0000GoY[_X0_l00004ohNJg`04o`000?mjSM[oNXgJ
o`0000Wooooo00Go0000ojJjj?nV^^SoY[[Xo`000003ojRki`05o`000?n8SmCoR8oDohR?e?l00000
0_mnP/d01?l0003oooooooooooooool2o`0000;oS8O800?o0000ooooooooool00ol000001OnX^nOo
0000oj^mion[_NOo000000SoZkgW1Ol00005ojbji0;o000000?o/;gTo`000?n^_ND00on^_ND7o`00
00;ooooo00?oXHZko`000?l000000_n__nD00ol0003o//7Uo`000002o`000003ojZ?^Ol0003oZXni
00;oZXni1?l000001_nXR;;o0000ok72iona`^Oo0000ok;4i`Ko00000_ooool3o`0000;o/LGY0_l0
0007ooooo`?o000000?o/LS[o`000?ooool01?ooool01?l0003o/<W/o`000?l00002olFL[P;o0000
00CodZR^o`000?l0003o/Lg^0ol000000oo?[[Wo0000o`000002o`000003om^n_?l0003o000000;o
00000_n]bo000ol0003oZLS`ojW8l004ojW8l0Co000000?oZlS_o`000?l000000_l00004ojW7l0Go
00000_oEgMd01?oooooo0000ojO6kol00002ojO5k`03o`000?oooooooooo00;ooooo0_l000000ooE
gMgo0000ol_EhP03ol_EhPKo00000onUaO001Ol0003oY<?_ojC3konT`noo000000Cob=kY0ol00005
oj?2k`03o`000?o0eNWo000001_ooooo00?o0000ol3EjOo0eNT01?o0eNT00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo02kooooo000Jooooo`03o`000?oooooooooo05Oooooo00?o0000oooo
ooooool03_ooool00ol0003oRjOWoh^Wi`03oh^Wi`03o`000?oooooooooo01Wooooo00?o0000oh^W
ion;YnL01?n;YnL00ol0003oO9cVogbLiP02o`0000SoY;_Y0_l00002oj>jj@03o`000?nV^nSoY[_X
00?oY[_X00?o0000ohNJgon7V]l00_n7V]l01?l0003oNXgJogZ=f_l00009ooooo`03o`000?nV^^So
Y[[X00;oY[[X00Co0000ojRkionX^nOo00000_n8Sm@01?l0003oOX;=ogj2cOl00005ooooo`03ogj2
cOl0003oS8O800?o00000onX^nL2o`0000;oZkgW00?o0000oj^mion[_NL00_n[_NL4o`0000[o[;[T
00Co0000ojfki?l0003o/;gT2_l00003ooooo`?o00000_n__nD01?l0003o//7Uo`000?nUS;X2o`00
0004ojZ?^Ol0003o0000o`0000GoZ8Rb00Ko0000ok72iona`^Oo0000ok;4iol00007ooooo`03o`00
0?n`S;3o000000;o/LGY0_l00007ooooo`?o000000?o/LS[o`000?ooool01?ooool01?l0003o/<W/
o`000?l00002olFL[PGo000000Co[l[^om:X[_oBZ:kodZR^0_l000001On^b^kocjjio`000?oK_[co
000000;ooooo00?o0000ojg;l?n/bo000ol00008ojW8l0Co00002?nYao03o`000004ooooool0003o
YlK_o`0000;oYlG_00?o0000ooooooooool00oooool2o`000003omGMgOl0003obmGR00;obmGR0_l0
00000oo;eN7o0000o`000003ojG5l0;o00000onT`nl3olSNj@?o000000?oooooolSNjOo8g^T00_l0
0004oj?2k`;o00006oooool00ol0003o`=GYol3Ej@04ol3Ej@03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0;_ooool001[ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0=
ooooo`03o`000?n;YnOoRjOW00?oRjOW00?o0000ooooooooool06_ooool00ol0003oRjOWoh^Wi`03
oh^Wi`03o`000?mlW>Ko000000SoY;_Y00?o0000ooooooooool00_l00002oj>jj@;o00001?nV^nP0
1Ol0003oQi[OohNJgon7V]oo000000;oNXgJ00?o0000ooooooooool02?ooool00ol0003oY[[XojJj
j002ojJjj006o`000?nX^nOoZ;_Wo`000?n8SmCo00000_mnP/d00ol0003oooooooooo`03ooooo`?o
00002?nX^nL2o`000003oj^miol0003o000000;o00003On/^^@01Ol0003o[K_Tojfki?l0003o/;gT
00;o00000oooool5o`0000Cooooo0_l00002ojnoi@03o`000?nb`NGo//7U00Co00001_nXR;83o`00
00;o/L;W00?o0000ok;4iol000001oooool00ol0003o/8b`o`000002ok75j@;o00001oooool00ol0
003o/LO[o`000002o`0000Cooooo00?o0000ok39k?l000000_l000000oo5W:ko0000o`000005o`00
0005ooooool0003o0000o`000?n^b^h01Ol000000ooooooo0000ojg;l002ojc;l003o`000?oooooo
000000Co00000_nYb?02o`000004oj[;lOl0003oYlSaojO8l@?o00002?nYao000ol0003oYlK_o`00
0002ojO5k`03o`000?oooooooooo00Cooooo0_l000001OoEgMgo0000ol_Eh_o;eN;o000000;obmGQ
00?o0000ojG5l?nUaO000_nUaO001_l0003oY<?_ojC3konT`noo0000olSNj@?o00000oooool01?l0
003ob=kYolSNjOo8g^T2o`0000GoXl;_0_l0000Iooooo`03o`000?o0eNWo`=GY00?o`=GY00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0]ooooo`006_ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo00cooooo00?o0000oh^Wion;YnL00on;YnL00ol0003oooooooooo`0Joooo
o`03o`000?n;YnOoRjOW00?oRjOW0_l00006ojBkj@;o00001_ooool01Ol0003oXk[Yoj>jjOnS^^Wo
000000CoY[_X00Co0000ohNJgon7V]oo00000_mjSMX00ol0003oooooooooo`09ooooo`03o`000?nV
^^SoY[[X00;oY[[X00Co0000ojRkionX^nOo00000_mnP/d01?l0003oooooooooooooool3o`0000co
Z;_W0_l0000:ojbji0Ko000000Goooooo`000?n]^nCo[K_To`000002ok2mi00;o`000?oooooooooo
oooooonLQkco0000oif7_?l0003oXHZko`000?ooool00ol000001?nUS;[o0000ojnoiOl00002ok;1
i@04o`000?nSQ;?o0000o`0000;oZ8Rb1?l00002ooooo`06o`000?na`^Oo/L;Wo`000?nba>Oo0000
1oooool01ol0003o/8b`o`000?naaNWo0000ok;6jOl000001oooool2o`000003ok78jol0003o0000
00Cooooo00?o0000ok39k?l000000_l000000oo5W:ko0000o`000004o`0000?ooooo0ol000000ooB
Z:ko0000o`000002om^n_003o`000?n]bo3o000000;o[<_`0_ooool01Ol0003ofkjlo`000?l0003o
j=C200;o00000_nZbo42o`0000GoYlSa0ol00005ojW7l0;o000000CoYlG_o`000?l0003o00001_oo
ool2o`000005omGMgOl0003obmGRo`000?o;eN400_l00003ojG5l0;o00000_nT`nl4o`0000Kooooo
00Co0000olSNjOo8g^Wo00000_o0eNT00ol0003oXl;_oj?2k`04oj?2k`03o`000?oooooooooo01Go
oooo00?o0000ol3EjOo0eNT01?o0eNT00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02go
oooo000Jooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03?ooool00ol0003oRjOW
oh^Wi`03oh^Wi`03o`000?oooooooooo01Wooooo00Co0000oh^Wion;YnOoRjOW0_l00006ojBkj@;o
00002Oooool01Ol0003oXk[Yoj>jjOnS^^Wo000000CoY[_X0_l00002ogZ=fP03o`000?oooooooooo
00_ooooo00?o0000ojJjj?nV^^P00_nV^^P00ol0003oZ;_WojRki`02o`000004ooooool0003o0000
o`0000[oZ;_W0ol00002ojRhi004o`000?n]^^?o0000o`0000?o[;[T1Ol00002ooooo`04o`000?nA
PKkoTH6noiR4_@;o00000on]^n@01?l0003o/;gTo`000?l00002ooooo`Oo00000_nQR[/3o`000008
ojnoiOl0003o//7Uok;1iOl0003oXhBco`000?nXR;82o`0000Kooooo00Co0000ok72iol0003o//CW
0_l00008ooooo`;o000000Co/LGYo`000?nba^Wo00001oooool2o`000003ok78jol0003o000000Co
oooo0ol000000ooooooo0000o`000006o`0000?ooooo00Go0000ojk:k_l0003o0000on:k[`02o`00
0003om^n_?l0003o[L_`00;o[<_`0_ooool00ol0003ofkjlom^n_002o`0000;oj=C200Co0000oj[;
lOl0003oZL[a0ol00006ojO8l@?o000000?oZLO`o`000?l000000_l00003ojK6l0?o00000_ooool6
o`000003ol_EhOl0003oYLG`00?oYLG`00Co0000ojC3konT`nooY<?_0_l00008ooooo`05o`000?o8
g^Wob=kYolSNjOl000001?o0eNT6oj?2k`;o00005Oooool00ol0003o`=GYol3Ej@03ol3Ej@03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0;?ooool001[ooooo00?o0000ooooooooool0Fooo
ool00ol0003oooooooooo`0;ooooo`03o`000?n;YnOoRjOW00;oRjOW1_l0000Gooooo`04o`000?n;
YnOo0000o`0000OoY;_Y00?o0000ooooooooool02_ooool01Ol0003oXk[Yoj>jjOnS^^Wo000000Co
Y[_X1Ol0000=ooooo`05o`000?nV^^SoY[[XojJjj?l000000onX^nL2o`0000[oZ;_W0ol00005ojRh
i0;o00000_n]^^<3o`000003oi60__l0003ooooo00Gooooo00Ko0000oi61__l0003o0000ooooool0
0002ojfki004o`000?n`_NCo0000o`0000;ooooo1?l000001?nQR[_o0000oj6:^onQR[/4o`0000;o
[koU00?o0000ok;1iOl000001?l00007ooooo`04o`000?na`^Oo0000ok;4i`;o00002?ooool2o`00
0004ok75jOl0003o//KYo`0000?ooooo1?l000001?naan_o0000o`000?o5Vjd5o`000004ok39k?l0
003o0000ooooo`Oo00000oooool3o`000007om:X[_l0003oh[^_o`000?oR^joo0000ojg;l002ojc;
l0;ooooo00?o0000om^n_?oK_[`00_l000001oooooooj=C2o`000?nZbo7o0000ojW:lOl000000_oo
ool5o`0000CoYlSa1?l00008ojK6l0;o00000_oEgMd5o`0000?oYLG`0_l00002ojC3k`;o00002_oo
ool01Ol0003ob=kYolSNjOo8g^Wo000000Co`=GY2_l0000Booooo`03o`000?o0eNWo`=GY00Co`=GY
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0[ooooo`006_ooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo00[ooooo00?o0000oh^Wion;YnL00_l00006oh^Wi`Oo00004?oo
ool2o`0000OoY;_Y0ol0000=ooooo`04o`000?nS^^WoXk[Yoj>jj@;o00000onV^nP3o`000003ogZ=
f_l0003o000000cooooo00Go0000ojJjj?nV^^SoY[[Xo`000002ojRki`03o`000?nX^nOoZ;_W00Go
Z;_W1?l00007ojRhi003o`000?nY^>Co000000;o[K[S00?o0000ohEk`?n5Nl000_l00006ooooo`04
o`000?nAPKko0000oiR4_@;o00000_n]^n@01ol0003o/;gTok2mi?l0003oooooo`000?nLQk`01ol0
0002oin2]0;o00000_n__nD02?l0003o//7Uo`000?ooooooXhBco`000?nXR;;o00001_ooool01?l0
003o/L;Wo`000?nba>L2o`0000Sooooo0_l000000onaaNWo0000ok;6j@04o`0000?o^I:^00?o0000
ok77jol000000_l00004olFL[@_o00000oooool4o`000003om:X[_l0003oh[^_00;o000000?o[L_`
ojc;l?n/bo000_l000003ooooooo0000om^n_?l0003oj=C2o`000?oooooo0000oj[;lOl0003oZL[a
omgAcOl0003oooooo`000002omgAc@04o`000?oQiMKo0000ooooo`?o000000CoY/_cojG8l_l0003o
XlKb0ol00007ojK6l0Go00001?nUaO001Ol0003oY<?_ojC3konT`noo000000cooooo00Co0000olSN
jOo8g^Wo00000oo0eNT2o`0000OoXl?`00CoXl7_oj;0k_nR`>ko00004Oooool00ol0003o`=GYol3E
j@03ol3Ej@03o`000?oooooooooo03_ooooo00?o0000ooooooooool0:oooool001Wooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`0:ooooo`;o00003on;YnL7o`0000Oooooo0_l00000
1?nT^nWo0000o`000?l00003ojBkj@;o00000_mlW>H00ol0003oooooooooo`0<ooooo`03o`000?nS
^^WoXk[Y00;oXk[Y00Oo0000ojJkj?nV^nSoY[_Xo`000?mXS>;o000000;oNXgJ0_l00009ooooo`Go
000000CoY[[Xo`000?nX^nOo00001?nX^nL3o`0000_oZ;ST00Co0000ojVhi?nY^>Co00000_n]^^<0
1?l0003oQG_0o`000?l00007ooooo`;oTH6n00?oV8Bmo`000?l000000on]^n@01?l0003o/;gTo`00
0?l00003oib7_0?o000000CoWh:do`000?nOP[CoWh:d0ol00002ojnoi@04o`000?nb`NGo0000oooo
o`;o000000?oZ8Rbo`000?ooool01Oooool01?l0003o/L;Wo`000?nba>L2o`0000Kooooo0ol00002
ok75j@;o00001?niTZh5o`000003ok78jol0003o000000CoaIb]2ol00003ooooo`Go000000?oh[^_
o`000?ooool00_l000003on/bo3o0000om^n_?oK_[co0000om^n_?l0003oj=C2o`000?oooooo0000
oj[;lOl0003oZL[ao`000002omgAc@08o`000?oMdLgogM7=o`000?oQiMKo0000ooooool00003ojK;
l`;oYLSb00?o0000oj?6l_nSa_800_nSa_82o`0000OoY/K`0_l00003ojG5l0;o00000onT`nl00ol0
003oooooooooo`0:ooooo`06o`000?o8g^Wob=kYolSNjOl0003o`=GY0_l00006oj?3l004o`000?nS
`NooXl7_o`0000?oX/3^00?o0000ooooooooool03Oooool00ol0003o`=GYol3Ej@04ol3Ej@03o`00
0?oooooooooo03cooooo00?o0000ooooooooool0:_ooool001Wooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`09ooooo`Go00004on;YnL7o`000004oj>kjol0003oXK_[o`0000;oXk_Z
1?l00003ogbLiP03o`000?oooooooooo00gooooo0_l00003oj>jj@06o`000?nV^nSoY[_XojJkj?l0
003oJ8cR0_l00002ogZ=fP;o00001Oooool3o`0000CoYK[X1?l000001?nX^nOo0000o`000?l00009
ojRhi0Co000000?oQG[0o`000?nY^>@00_nY^>@01ol0003o[K[So`000?n5Nl3o0000oi60__l00000
1_ooool2oi61_P;o000000Goooooo`000?n]^nCo[K_To`000002ok2mi0?o000000GoVWneo`000?nJ
OkGo0000oin2]003o`000003oooooonOP[Co000000;o[koU00?o0000ok;1iOl000000_ooool00onS
Q;?o0000o`000006ooooo`08o`000?na`^Oo0000ok;4iol0003o/8b`o`000?ooool4o`0000;o/8b`
00?o0000ok75jOnaaNT01_l00002okN:Y@03o`000?naan_o000000;o000000KoaI>Ro`000?o5Tj?o
aI>So`000?n`bN`9o`000003om:Y[_l0003o000000Co000000?odZR^o`000?oR^jl00ol000004?n/
bo3o0000o`000?l0003ofkjlo`000?oK_[co0000onSD`_oooooo0000oj[;lOl0003oZL[aonSD`_l0
0002omgAc@04o`000?oMdLgogM7=on7UeP;ooooo00Co0000ojK;lonVbo?o00000onUb?82o`0000Go
XlKb0_l00005ojK6l0;o00000_nUaO001?l0003oY<?_ojC3konT`nl2o`0000gooooo00Ko0000olSN
jOo8g^Wo0000ol3EjOl00006oj?3l004o`000?nS`NooXl7_oj?1k`;o00001?nR`>h00ol0003ooooo
ooooo`0<ooooo`03o`000?o0eNWo`=GY00?o`=GY00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0Yooooo`006Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00Sooooo00?o
0000ohF[k_l000000_n5Znh7o`00017oRjOW00Ko0000oj>kjonS^n_oXk_[o`000?nQ^n/2o`0000Co
Xk_Z00Co0000ogbLi_mlW>Ko00004Oooool01Ol0003oXk[Yoj>jjOnS^^Wo000000?oY[_X00?o0000
ofR<h_mXS>800_l00002ogZ=fPGo00002_nU^^P2o`0000SoZ;ST1?l00002ogj2c@;o000000?oQG[0
o`000?l000000_nY^>@01Ol0003o[K[Sojfjhol0003oQG_000;o00001_ooool01?l0003oTH6noi61
__nHQ;d2o`0000;o[K_T00Co0000ok2mi?n`_NCo00000onJOkD6o`0000?ooooo00Co0000ojnoiOn_
_nGo00000_nb`ND01_l0003ooooooj>4/ol0003oZ8Rbo`0000Gooooo00Ko0000ok72iol0003o//CW
o`000?n`S;02o`000003ok2</?l0003o000000Co00000_naaNT9o`000003ok77jol0003o0000013o
00000_oEXJ45o`000003om:X[_l0003oh[^_00;o00000_n/bo000ol0003oooooo`000003o`00000>
onSD`_l0003o0000oj[;lOl0003oZL[aooooool0003oj=C2o`000?oMdLgo0000omgAcOoQiMH2oooo
o`04o`000?nVbo?oY/_co`0000?oYLSb00?oeMgMo`000?l000000ol00004oj?6lP?o00000_nVa_04
o`0000?oY<?_00?o0000ooooooooool03?ooool01?l0003ob=kYolSNjOo8g^T2o`0000CoXl?`0_l0
0004oj?1k`?ooooo00?o0000oj;0k_nR`>h00_nR`>h2o`0000cooooo00?o0000ol3EjOo0eNT00oo0
eNT00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02Wooooo000Iooooo`03o`000?oooooo
oooo067ooooo00?o0000ooooooooool02?ooool00ol0003oQJ_^ohF[kP02o`0000KoQJ_^1ol00008
oh^Wi`;o00001?nS^n/01Ol0003oXK_[oj6kjonQ^n_o000000CoXk_Z00Co0000ogbLi_mlW>Ko0000
4Oooool01Ol0003oXk[Yoj>jjOnS^^Wo000000?oY[_X0_l00002ofR<hPCo00002_nU^^P2o`000003
ojFgiOl0003oZKST00?o00000_nX^>@3o`000003ooooool0003oOX;=00?oOX;=00Go0000ohEj_ol0
003oooooo`000003ojVhi007o`000?n]^^?o0000ohEk`?l0003oTH2no`000005ooooo`?o000000?o
V8Bmo`000?l000000on]^n@00ol0003o/;gTo`000003oiYo]@Ko00000oooool2o`000006ojnoiOl0
003o//7Uok;1iOl0003ooooo0_l000000onXR;;o0000o`000005o`000003ok72iol0003o//CW00Go
00001Onda^P01Ol0003o/LGYo`000?nba^Wo000000Ko]<WZ0ol00006ok?;k0;o00000onbc>d>o`00
0006on:k[ol0003o0000o`000?n/bo3o00000oooool5o`000003oj[;lOl0003o000000?ooooo0ol0
00000ooMdLgohNGFooooo`02o`0000;oY/_c00Co0000ojG8l_nUb?;oYLSb0_oEgMd01?l0003oeMgM
omGMgOoEgMd3o`0000GoXlKb1?l000000onT`noo0000o`000003o`0000kooooo00Co0000olSNjOl0
003o00001?nS`o02o`0000?oXl7_00?o0000ooooooooool01?ooool00ol0003oX/3^oj;0kP03oj;0
kP04o`000?ooooooooooooooo`Wo00001Oo0eNT00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo02Sooooo000Iooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool02?ooool01Ol0
003oQJ_^ohF[k_n5Znko000000coQJ_^2?l00007oj>kj`;o00000_nQ^n/2o`0000?oXk_Z0ol0000A
ooooo`;o00000onS^^T2o`0000;oY[_X1Ol00009ojFjj0;o00001?nU]nD2o`0000?oZKST0_l00003
ooooo`03o`000?mnP/goOX;=00;oOX;=1?l00002ooooo`04o`000?nY^>CoZKSTo`0000;o[K[S00Co
0000ohEk`?nAP;ko00000oooool2o`0000?oTH6n1?l00002ojfki003o`000?n`_NCo/;gT00;o0000
00?oooooo`000?nKOk@00_l000000ooooooo0000o`000002ooooo`04oin2]?l0003o[koUo`0000;o
//7U1_l00006ok?3iP?o00002onda^P3o`0000?o]<WZ4?l000000onbc>go0000o`000003o`0000Co
/Lg_0_l00004ojo>l0?o000000?o[<_`o`000?ooool00oooool2o`000003onSD`_l0003oZ/_a00;o
00001?ooool01_l0003oj=C2o`000?l0003oooooo`0000;oY/_c0_l00002ojG8lP;o00000_oEgMd0
1?l0003oeMgMomGMgOl00003om;ZiP;o00000onSa_85o`0000GoY<C`0_l0000;ooooo`?o00000onS
`o03o`0000?oXl7_00Co0000oooooooooooooooo1ol00005oj;0kP?o00002Oo0eNT2o`0000;o`=GY
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Wooooo`006Oooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo00Sooooo00Co0000ohF[k_n5ZnkoQJ_^0_l0000?ohF[kP;o0000
1onS^n/3oh^Wi`05o`000?nQ^n_oXK_[oj6kjol000001?nS^nX3o`0000oooooo00?o0000ogfLi_l0
00001?nS^^T01?l0003oY[_XojJkj?l00009ojFjj0?o00001OnU]nD01?l0003oYKKUojFfiOl00002
ojVhi005o`000?mnP/go0000ooooool000001?mnP/d01_l0003oM7;3o`000?l0003oQGZoo`0000;o
oooo00Co0000ojVhi?nY^>Co00000_n]^^<3o`000003ooooool0003o000000KoTH6n00?o0000oiEl
]Ol000000_n]^n@01?l0003o/;gTok2mi?l00003ooooo`_o000000Co[koUo`000?nb`NGo00002?nc
`nHGo`0000Co]LSX0_l00006okC;j`;o00000_ncc>d8o`000003ok7=kol0003o000000Ko[lk`2ol0
00000onZbo7o0000o`000004ooooo`03o`000?oXe<;oj=C200?o00000_nVbo<01?l0003oYLSbojG8
l_nUb?83o`000004omGMgOl0003oeMgMo`0000?od^[V0_l00002ooooo`?o000000?oX/Scoj;6l_l0
00000ol00006ojC4l0;o00002?ooool2o`0000?oXl?`0_l00003oj?1k`Oo00001oo0eNT00ol0003o
X/3^oj;0kP03oj;0kP03o`000?o0eNWo`=GY00[o`=GY00?o0000ol3EjOl00000@oooool00ol0003o
ooooooooo`0Wooooo`006?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Oooooo
00?o0000ohF[k_n5Znh00on5Znh5o`0000WoQJ_^00?o0000oj>kjonS^n/01OnS^n/00ol0003oQJ_^
o`000004o`0000?oXK_[00?o0000oj>kj_nS^nX00_nS^nX6o`0000_ooooo00Co0000ogfLi_mmW>Ko
00001?nS^^T00ol0003oY[_Xo`000006ojFjj0?o00002?nU]nD01Ol0003oYKKUojFfiOnU]^Go0000
00;oZKST00?o0000ogj2cOl000001?mnP/d02_l0003oM7;3o`000?l0003oM7;3o`000?n5N[oo0000
ooooool00002ojVhi007o`000?n]^^?o[K[So`000?n5Nl3oTH2no`000005oi61_P;o000000CoSGNf
o`000?l0003o00000on]^n@00ol0003o/;gTo`000003ooooo`Ko00001Ona_n@3o`0000;o/l?V1ol0
0004okC0h`;o00002_nea>D00ol0003o^<SWo`000007okG8j003o`000?ngc>[o000000Ko000000?o
]/o/o`000?l000000_ncc>d01?l0003o]M3^o`000?l00003ok3=k`co00001?n]c_43o`000003oj[;
lOl0003o000000;o00000_ooool01_l0003oj=C2onSD`_l0003ohNGFo`0000;oY/_c00Go0000ojG8
l_nUb?;o0000ooooo`05o`0000?od^[V00Co0000oooooooooooooooo0_l00002oj;8l`03o`000?nR
a_;o000000;o00000_nPa?82o`0000KoY<C`0_l00005ooooo`04o`000?nS`o3oXl?`oj?3l0;o0000
1?nS`Nl00ol0003o`=GYol3Ej@0=ol3Ej@03o`000?nR`>koX/3^00?oX/3^0_l00004ol3Ej@So0000
AOooool00ol0003oooooooooo`0Vooooo`006?ooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo00Oooooo00?o0000ohF[k_n5Znh00_n5Znh00ol0003oooooooooo`02ooooo`Oo000000?o
QJ_^o`000?nS^n/01_nS^n/00ol0003oQJ_^ohF[kP05ohF[kP;o00000_nQ^n/2o`0000CoXk_Z00Co
0000ogbLi_mlW>KoO9cV1?l00007ooooo`05o`000?mmW>KoOIcVogfLi_l000001?nS^^T2o`0000Co
YK[X0_l00008ojFgi@;o000000?oooooo`000?nU]^D00_nU]^D01?l0003oZKSTojVhi?nY^>@2o`00
00?oOX;=00?o0000ogAb`ol000000_ooool01?l0003oM7;3o`000?l00002ooooo`04o`000?nY^>Co
ZKSTo`0000;o[K[S00?o0000oi60__l000000_nAPKh3o`0000;oSGNf0ol000001Ooooooo0000ojfk
i?n]^nCo000000;o/;gT0ol0000<ok6oi0Co00002_nd`><2o`000003okW5i?l0003o000000Go0000
0_nea>D00ol0003o^<SWokS8i`05o`0000?ooooo0_l000000onhcN[o0000o`00000@o`000003ok?B
l?l0003o[/k`00Co[/k`0_l00003oj_?l`Go000000?o[Lkao`000?l000001?nYcO<7o`0000;oY/_c
00Oo0000ojG8l_nUb?;o0000ooooool0003ohNGF00?o00000ooBj^H3ooooo`;o00000_nRb?<01_l0
003oX/Kboj;6l_oBj^Ko0000olSNj@;o00000onPa?82o`0000KoY<C`0_l000000ooooooo0000o`00
0002oj?3l0;o00001?nS`Nl2o`0000ko`=GY1?l00006oj;0kPCo00001?nlfNl2o`000003okcIkol0
003ooooo04Cooooo00?o0000ooooooooool09_ooool001Sooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooooooo`07ooooo`03o`000?n5ZnkoQJ_^00;oQJ_^00?o0000ooooooooool01oooool2
o`0000KoXk_[0_l0000:ohF[kP05o`000?nQ^n_oXK_[oj6kjol000001?nS^nX00ol0003oO9cVogbL
iP04ogbLiP?o00001Oooool00ol0003oOIcVogfLiP05o`000003oj>jjOl0003o000000?o00001onU
]nD2o`000003ofYld_l0003ooooo00;ooooo00Go0000ojFfiOnU]^GoYKKUo`000003ojVhi006o`00
0?mnP/goOX;=o`000?mdL/?o00001?ooool2o`000004ohEj_ol0003oooooo`0000;oZKST00?o0000
ojfjhon]^^<01Ol00003oheg]P04o`000?oooooo0000oheg]PCo000000Go[K_To`000?n`_NCo/;gT
o`000005ok6oi0Ko00000onb^n02o`0000_o]<3S00Co0000okK3i?l0003o^LGT0_l000000on]Q:So
0000ooooo`04ooooo`05o`000?nhb>Oo0000okW:iol000000_nhRZD6o`000004okS=j_l0003o]H6L
okF1W0;o000000?o]/o/o`000?o4RYL00_o4RYL6o`000003omNITol0003o/m;`00Ko000000?o/=?b
o`000?l000000ol00004oj_?l`Co00001onYcO<2o`0000;oY/_c00?o0000ojG8l_nUb?800ol00000
1_oQiMKo0000omcfgOl0003od^[Vo`0000?ooooo0_l00002oj;8l`;o000000CoX/Kbo`000?oBj^Ko
00000_o8g^T3o`0000CoX<Cb0_l00006ojC4l003o`000?nS`o3oXl?`00;o00001?nS`Nl2o`0000Go
`=GY2ol00004okcIk`OoX/3^00?o0000okcIkonlfNl00ol00003okcIk`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool09Oooool001Sooooo00?o0000ooooooooool0J?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?n5ZnkoQJ_^00;oQJ_^00?o0000ooooooooool01Oooool00ol0003oXk_[
oj>kj`05oj>kj`Ko00001_n5Znh01?l0003oQJ_^o`000?l00002oj6kj`;o00000onS^nX3o`0000Ko
O9cV1?l000001?oooooo0000o`000?l00005oj>jjP?o00002?nU]nD6o`0000Cooooo00Go0000ojFf
iOnU]^GoYKKUo`000002ojVhi0?o000000?oM7;3o`000?ooool01?ooool01?l0003oM7;3o`000?l0
0002ooooo`04o`000?nY^>CoZKSTo`0000;o[K[S0_l00002oheg]P;o000000?oooooo`000?l00000
0_l00004ojjkh`Co000000?o/KoTo`000?l000000ol00008ok:kh0;o000000?o]l3Qo`000?l00000
1?l000000onUP:co0000ooooo`02ooooo`04o`000?nf`nCo0000okW5i0;o000000?o[HBXo`000?oo
ool01?ooool01?l0003o^<SWo`000?nib^L7o`000003okO<j_l0003o000000?o000000Co]H6Lo`00
0?l0003o00000_ooool01_l0003o^MG^o`000?l0003o]=7_olB;V0;o000000Co/m;`o`000?l0003o
eiVC1?l000000on_d_;o0000ooooo`03ooooo`Ko00000_nUc_D4o`0000CoZLgc00?o0000ojK;lol0
00000_nUb?82o`000005on7Ue_l0003o0000omcfgOl000000_oBj^H01?l0003oooooooooool00002
oj;8l`;o00000_nRa_801?oooooo0000om;Zi_l00002olSNj@;o000000?oooooo`000?l000001?nP
a?82o`0000CoY<C`0ol00004oj?1k`;o000000?o`=GYo`000?l000000_l0000BokcIk`OoX/3^0_l0
0005okcIk`03o`000?oooooooooo04Oooooo00?o0000ooooooooool09?ooool001Sooooo00?o0000
ooooooooool0JOooool00ol0003oooooooooo`06ooooo`03o`000?n5ZnkoQJ_^00?oQJ_^00?o0000
ooooooooool00oooool00ol0003oXk_[oj>kj`05oj>kj`03o`000?oooooooooo00Kooooo0_l00000
0on5Znko0000ohF[kP03ohF[kP05o`000?nQ^n_oXK_[oj6kjol000001?nS^nX5o`0000KoO9cV0_l0
0007oj>jjP03o`000?nR]nOo000000Co000000?oYKOUo`000?l000000_l000001_mXS>;o0000odYd
f_l0003oJWcBo`0000Cooooo00Go0000ojFfiOnU]^GoYKKUo`000002ojVhi0?o00001oooool01Omd
L/?o0000ohEj_ol0003ooooo00;o00000_nY^>@01Ol0003o[K[So`000?l0003oSGNe00Co00002_n^
^n<3o`0000co/[_P00Go0000ok>mhOl0003o]l3Qo`000002oj1m[@?o000000?oYH2/o`000?ooool0
0_ooool01_l0003o]/?To`000?niaNCo0000ojEoZ`;o00001?ooool2o`000003okS8iol0003o0000
00Co000000Ko]H6Lo`000?l0003o0000okS=j_l00002ooooo`;o000000?o]/o/o`000?ooool00_oo
ool5o`000005olB;V?l0003o0000o`000?nbdO000_l00002omNIT`;o000000?o[m;bo`000?ooool0
1?ooool3o`000004oj[Am?l0003o0000o`0000CoYLke0ol000000onYcO?o0000o`000006o`000007
omcfgOl0003o0000o`000?oBj^Ko0000ooooo`02o`0000;oX/Sc00Ko0000oj;6l_nRa_;o0000oooo
ool00002om;ZiP03o`000?o8g^Wob=kY00Ko00001OnPa?82o`000003ojC4l?l0003o000000CoXl7_
0ol000000onlfNoo0000okcIk`0?okcIk`oo00001?nlfNl00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo02Cooooo000Hooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01_oo
ool00ol0003oQJ_^ohF[kP02ohF[kP03o`000?oooooooooo00;ooooo1Ol00003oj>kj`03o`000?oo
oooooooo00[ooooo00?o0000ohF[k_n5Znh00on5Znh01?l0003oXK_[oj6kjonQ^n/2o`0000?oXk_Z
0_l00002og6PkP?o00000_mlW>H00ol0003oXk[Zoj>jjP05oj>jjP07o`000?nR]nOoX[OWoj:giol0
003oX;KWo`000002ojFgiP06o`000?ooooooooooooooool0003oJ8cR0_l000001?m:M=[o0000ofYl
d_l00004ooooo`05o`000?nU]^GoYKKUojFfiOl000000_nY^>@2o`0000Oooooo00Oo0000ogAb`on5
N[ooQGZoo`000?n5Nl3o000000;oZKST00?o0000ojfjhon]^^<00_l00008ojjkh`Co00000_n^]ml0
0ol0003o];_Oo`000003ok:kh0Ko00000_nNP[@2o`000003ok>mhOl0003o]l3Q00?o000000?ooooo
oimm[OnOOJd00_l00003ooooo`08o`000?nf`nCo0000okW5i?l0003oYGn[o`000?n]Q:P4o`000003
ojf3Z?l0003o^<SW00Co000000Co]H2Ko`000?oooooooooo0_l000000onhcN[o0000ooooo`02oooo
o`Co000000?oooooo`000?l000000_l000001_nddNooooooo`000?l0003o/m;`ok;Al0Cooooo0_l0
00001?n_d_;okJf;onRfWol00004ooooo`;o000000?oZ]7do`000?ooool00_ooool3o`0000CoYLke
1?l00004ojG;m0Go000000?od^[Vo`000?l000000_nRb?<2o`000003oj;6l_l0003ooooo00;ooooo
00?o0000om;Zi_l000000_o8g^T3o`0000Gob=kY1?nPa?8;o`0000?o_=W_00?o0000okcIkonlfNl0
1onlfNl5o`0000Cooooo0ol00006oj71k`03o`000?nQ_^go000000?o_=W_00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`0Sooooo`005oooool00ol0003oooooooooo`1/ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ohF[k_n5Znh00_n5Znh00ol0003oooooooooo`02o`000004oj2lkOl0
003o0000oj:lk0Co00003Oooool00ol0003oQJ_^ohF[kP03ohF[kP;o00000onQ^n/00ol0003oXk_Z
oj>kjP02oj>kjP03o`000?maX>koLJ3^00;oLJ3^0_l00006oj>jjP;o00001?nR]nL01?l0003oX;KW
oj2fiol00002ojFgiP07o`000?ooooooooooo`000?mXS>;o0000od]dfP03o`000003ofYld_l0003o
000000?ooooo00Co0000ojFfiOnU]^Go00000onY^>@2o`0000Oooooo0_mdL/<00on5N[oo0000ohEk
`003o`000004ojVhi?l0003o[K[So`0000Co[[_S1Ol00005ojjgg`04o`000?n_^>3o0000okBkg`Oo
000000KoW86do`000?l0003o0000oial[_l00002ok>mh@03o`000?ng`>7o000000;ooooo00Go0000
oimm[Ol0003oYH2/o`000002ooooo`04o`000?nf`nCo0000okW5i0?o000000Co[HBXo`000?n]PjSo
[H>X0ol000001onhb>Oo0000o`000?l0003oZGZPo`000?neP9/00_l000000ongc>[o0000o`000003
ooooo`go000000?o/m;`o`000?l000000_l000001?oooooo0000o`000?n_d_82o`000003onf]RooX
]Yoo000000;ooooo0_l000000onZdOCo0000o`000003ooooo`03o`000?obe;7o000000Co000000Co
Xlkgo`000?nOboOoWl_g0ol00005ojG;m0;o00000onRb?<01?l0003oX/Kbo`000?l00004ooooo`03
o`000?oBj^Ko000000;o000000?ob=kYo`000?o8g^T00_o8g^T7o`000005oik5lonN`_7oWL3aoig0
lOl000001OnR`^l00ol0003o_=W_okcIk`02okcIk`03o`000?nlfNoo_=W_00;o00002oooool2o`00
00KoXL7_00Wo0000oj6nkOnQ_^goXKk]o`000?nQ_^go0000okcIkol00000C_ooool00ol0003ooooo
ooooo`0Rooooo`005oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Kooooo00?o
0000ohF[k_n5Znh00_n5Znh2o`0000;oX[g/00?o0000oj2lkOnP_>d00_l00003oj:lk0;o00003?oo
ool00ol0003oQJ_^ohF[kP03ohF[kP;o00000onQ^n/2o`0000?oXk_Z1?l00006oj>jjP;o00001_nR
]nL2o`0000;oX;KW00Ko0000ojFgi_nU]nKo0000ooooool00002ofR<hP;o000000?oooooo`000?l0
00000_mZO=801?l0003oooooooooool00003ojFfi@06o`000?nY^>CoZKSTo`000?mdL/?o00001ooo
ool4o`0000?oZKST0ol000000on^^n?o0000o`000002o`0000Wo[[OO00Go0000ojnhh?n_^>3o0000
okBkg`02o`0000?oVWne1?l00002oial[P;o00000_nc_N400ol0003o]l3Qo`000003ooooo`04oimm
[Ol0003oYH2/o`0000;ooooo00Co0000okK3i?l0003o^LGT2Ol000001Onhb>Oo0000okW:iol0003o
oooo00;o000000Co]H2Ko`000?l0003o]lcZ1_l000000onfcnco0000o`00000:o`000004ok;Al?l0
003oeiVBomNITPKo000000?oooooonf]Rol000000ol000001?nZdOCo0000o`000?l00002ooooo`03
o`000?obe;7ol]Ba00;o00000_nTd_P2oj?>m`?o00000onOboL3o`0000?oYL_d00Ko0000oj;8lol0
003o0000oj;6l_l00004ooooo`?o000000?od^[Vo`000?o8g^T00_o8g^T3o`000004ol;Ul?l0003o
0000o`0000;oW/Gc00Co0000oik2lOnN`_7o00000onM`?400ol0003oX/;_oj;2k`03oj;2k`05o`00
0?nlfNoo_=W_okcIkol000003?ooool3o`0000GoXL7_00?o0000oj6nkOnQ_^d00onQ_^d01Ol0003o
XKk]oj6nkOnQ_^go000004oooooo00?o0000ooooooooool08_ooool001Oooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`05ooooo`03o`000?n5ZnkoQJ_^00;oQJ_^00?o0000oj:mk?nR
_N`00_nR_N`01?l0003oX;c]oj2lkOnP_>d2o`0000?oX[c/0_l0000;ooooo`03o`000?n5ZnkoQJ_^
00?oQJ_^0ol00003oj6kj`05o`000?nS^n[oXk_Zoj>kj_l000001_nS^^X2o`0000KoX[OW1Ol00002
oj2fi`03o`000?nU]nKoYKOV00;o00000_mXS>82o`0000;ooooo0_l00002ofYldP04o`000?oooooo
ooooo`0000?oYKKU00?o0000ojVhi?nY^>@00_l00005ooooo`?o00002?nY^>@2o`0000Oo[[OO1?l0
00000onEO;Go0000o`000002ojnhh003o`000?nd^moo000000?o000000?oV7R_o`000?nJNZl01?l0
00001ooooooo0000ok>mhOnc_N7o0000okO0hOl000000oooool01?l0003oWgf]o`000?l00002oooo
o`06o`000?nf`nCo0000okW5i?l0003oYGn[1?l00002ooooo`08o`000?nhb>Oo0000okW:iol0003o
ooooo`000?nYNZ04o`000003okS=j_l0003o000000_o00000_ooool00ol0003o/m;`o`00000:o`00
00;ooooo00CokJf;o`000?l0003oZ]7d0_l000001_okd9Wol]Bao`000?oooooo0000oo;D/@;o0000
00CoY=;ho`000?nSc_OoXlkg0ol000001?oLm]go0000o`000?l00003oio;m`Go000000GoX/Kbo`00
0?l0003o0000ooooo`03o`0000;od^[V0_l000001_o8g^Wo0000ol;Ul?o2iO3o0000ol;Ul0;o0000
0_nNaO<2o`0000CoW/;a0_l00003oig0l@03o`000?nR`^ooX/;_00?oX/;_0ol0000;ooooo`;o0000
1?nQ`Nl2o`0000OoXKk]00?o0000oj6nkOnQ_^d00onQ_^d00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo027ooooo000Gooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01Ooo
ool01?l0003oQJ_^ohF[k_l00006oj:mk0;o00000onP_>d2o`0000?oX[c/0_l00009ooooo`03o`00
0?n5ZnkoQJ_^00?oQJ_^00Co0000og6Pk_maX>ko00000onQ^n/01?l0003oXk_Zoj>kj_l00004oj>j
jP;o00001OnR]nL4o`0000?oJ8cR0_l00002oj2fi`03o`000?nU]nKoYKOV00;o000000?oJ8cRo`00
0?l000000oooool01?l0003oBWCJofYld_mZO=82o`000003ofYld_l0003oYKKU00;oYKKU00?o0000
ojVhi?nY^>@00_l000001?oooooo0000o`000?l00007ojVhi0;o00000_nY/ml00ol0003o[kKNo`00
0002ojjgg`Co00000_ooool01_n=MkKo0000oiEl]Ol0003oUGbeo`0000;o[kSP00?o0000okBkgol0
00000onHN:l5o`0000;ooooo00Ko0000ok>mhOnc_N7o0000okO0hOl00003ooooo`04o`000?nOOJgo
0000ojF0[0?o000000?o]/?To`000?niaN@00_l000001?nQN:Go0000ojUkXOl00002ooooo`04o`00
0?nhb>Oo0000o`0000;ooooo00Go0000ojUjX?l0003o0000okO<jP06o`000003okK?k?l0003o0000
00?o000000?oooooo`000?l000000_ooool5o`000005ooooool0003o0000ojoBl_ooool01?l00000
1?oooooo0000o`000?nZdO@2o`000005ooooool0003o0000o`000?ooool01?l00002oj?>m`;o0000
00?ok^g7o`000?l000001Oooool7o`0000CoX<Od0_l000001OoBj^Ko0000o`000?l0003oao?]00;o
00000oo2iO02o`0000;oW/Gc0_l00005oik2l@?ooooo00Go0000oig0lOnM`?7oWL3ao`000006oj;2
k`03o`000?oooooooooo00Kooooo0ol00003oj71k`?o00001onQ_^d00ol0003o_=W_o`000006oj6n
k@03o`000?oooooooooo04cooooo00?o0000ooooooooool08Oooool001Oooooo00?o0000oooooooo
ool0L?ooool2o`0000Kooooo0_l00006oj:mk0?ooooo0_l00003oj2lk@;o00000onR_>`2o`0000So
oooo00?o0000ohF[k_n5Znh00on5Znh01?l0003oLJ3^og6Pk_l00003oj6kj`?o00000onS^^X00ol0
003oX[OWoj:gi`04oj:gi`04o`000?maX>ko0000oe2=j`Co00000_mXS>801?l0003oX;KWoj2fiol0
0002ojFgiP04o`000?mXS>;o0000o`0000Gooooo00CoBWCJofYld_mZO=;o00000_mZO=801?l0003o
YKKUojFfiOl00003ojVhi0;o00001OnY^>@4o`0000CoZK?O00Co0000ojVch?l0003o[kKN0_l00005
ooooo`?o000000CoUGbeo`000?l0003o00000_n_^>001?l0003o];_Oo`000?l00002ooooo`03oiQi
[ol0003o000000;o00000oooool01Ol0003o/kgQo`000?ng`>7o000000Cooooo0_l000001onUP:co
0000ojEoZol0003o]/?To`000?niaN@00ol000001onPMjCo0000ojUkXOl0003oooooo`000?nhb>L0
2?l000001?ngc>[o0000o`000?l00002ok_Bj`03o`000?nfcnco000000;o^MC]3Ol000000on`do;o
0000o`000004o`000004onf]Rol0003o0000oj[Am0?o00000_ooool01_okd9Wo0000o`000?l0003o
Y=;ho`0000;oXlkg0_l000001?o^kLOo0000o`000?l00004ooooo`03o`000?nLc_WoW<ki00;oW<ki
00?oW<Wgo`000?nIa_L00_l00004oj37m0?o000000Coao?]o`000?o2iO3o`^G`1?l000000onNaO?o
0000o`000004oik2l@Gooooo00?o0000ol;Ul?l000000onM`?42o`0000GoX/;_00?o0000oooooooo
ool00oooool2o`0000?oXL7_0ol00006oj6nk@;o000000?oooooo`000?nlfNl00_nlfNl00ol0003o
XKk]oj6nk@04oj6nk@03o`000?oooooooooo04cooooo00?o0000ooooooooool08?ooool001Oooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`03o`000?nR_NcoX[g/00?oX[g/
00?o0000ooooooooool01?ooool2o`0000?oX;c]0_l00003oj:lk0;o00001oooool00ol0003oQJ_^
ohF[kP03ohF[kP03o`000?maX>ko000000Co000000?oXK_[o`000?l000000_l00005oj:gi`;o0000
0omaX>h01Ol0003oD8g[o`000?l0003oD8g[00;o000000GoJ8cRo`000?nP]^OoX;KWo`000002ojFg
iP;o000000?oBgCJo`000?ooool01?ooool01om:M=[oJWcBo`000?mZO=;o0000oeIVa_l000000_nU
]^D01?l0003oZKSTojVhi?l00003ojVhi0?o00002?nY/ml02?l0003oZK?Po`000?n_]]ko0000oheg
]Ol0003ooooo0ol00003ohig]P;o000000OoTgF^o`000?n_^>3o[kSPo`000?nd^moo000000?ooooo
00?oV7V_o`000?l000000ol00002ooooo`03o`000?nc_N7o000000;o]l3Q00?o0000ooooooooool0
0_l000000onOOJgo0000o`000002o`000007okK3i?l0003o^LGTo`000?oooooo0000oj1gY005o`00
0003okS8iol0003o000000Go^lkX0ol00002ok_Bj`_o00000_nge_02o`0000Co]=Ob0_l00004ok3G
m0[o000000?oooooo`000?l000000ol000002?nSc_Oo0000ooooool0003ok^g7o`000?oPo/Ko0000
0oooool2o`0000?oW<ki0_nLbOL2o`0000?oVLKg0_l00004oj37m0;o000000?o`^G`o`000?l00000
0onNaO<2o`0000?oW/;a00?o0000ooooooooool01?ooool01Ol0003o`^G`ol;Ul?o2iO3o000000Co
WL3a00?o0000oj;2konR`^l00onR`^l00ol0003oooooo`000002o`0000?oXL7_0_l00005oj6nk@?o
00000oooool00ol0003o_=W_okcIk`03okcIk`03o`000?nQ_^goXKk]00CoXKk]00?o0000oooooooo
ool0B_ooool3o`00027ooooo000Gooooo`03o`000?oooooooooo07?ooooo00Go0000oooooooooooo
ooooo`000005oj:mk0;o00002?ooool2o`0000?oX;c]0_l00003oj:lk0;o00001Oooool00ol0003o
QJ_^ohF[kP03ohF[kP;o00001OnP^n`3o`000003oj:giol0003o000000;oX[OW0_l00002ooooo`07
o`000?maX>koLJ3^o`000?m@SN_o0000ooooo`02o`000004oe2=jol0003o0000o`0000;oX;KW00Ko
0000ojFgi_nU]nKo0000od]df_l00006ooooo`03odYdf_mZO=;o000000So000000CoZKSTo`000?l0
003o00001onY/ml2o`0000;ooooo00Go0000ojVch?nY/n3o0000ojnfgP03o`0000?oSWNf0_l00000
1?n:KZgo0000o`000?nCMJh2o`0000;o[kSP00?o0000okBkgol000000_ooool00onHNJoo0000oooo
o`03o`0000;ooooo00?o0000ok>mhOl000000_ng`>43o`0000;oWgf]1Ol000000onf`nCo0000okW5
i004o`0000Co^l[U0ol00003ok_>j0So00000_nldNX2o`0000;o^]?]6?l00005ojWFm`Co00000_nS
c_L3o`000003onk]aol0003oh?k600;o00000_ooool01?l0003oW<kioic>nOnLc_T3oic9m`?od^[V
0_l00003oiW6m`03o`000?nPaoCoX<Od00?oX<Od00Co0000oik5lonNaO?oW/Gc0ol000000onN`_7o
0000o`000007ooooo`05o`000?o2iO3o`^G`ol;Ul?l000000_nlfNl4oig0l@03o`000?nR`^ooX/;_
00?oX/;_00Co0000oj71konQ`NooXL7_0ol00004oj6nk@?o00001Oooool00ol0003o_=W_okcIk`03
okcIk`03o`000?oooooo000000GoXKk]00?o0000ooooooooool0Aoooool3o`0000;ooooo00?o0000
ooooooooool07oooool001Kooooo00?o0000ooooooooool0MOooool00ol0003oooooo`000005oj:m
k004o`000?n5ZnkoQJ_^o`0000Wooooo0_l00003oj2lk@03o`000?nR_>coX[c/00;oX[c/0_l00004
ooooo`04o`000?n5ZnkoQJ_^ohF[kP;o00001_nP^n`01_l0003oWkSZo`000?nM]^[o0000oj6gj0?o
00001?ooool01_l0003oLJ3^og6Pk_l0003oD8g[o`0000;ooooo0_l000000om@SN_o0000o`000002
oj2fi`03o`000?nU]nKoYKOV00;o00001oooool4o`0000CoY;KV0ol00004ojVcg`Ko000000?oP6jf
o`000?ooool00_ooool01?l0003oZK?Po`000?n_]]h2o`0000;oSWNf0_l00002ohY^[@;o000000Co
TgF^o`000?oooooo00000_n_^>000ol0003o];_Oo`000002ooooo`;o000000Coooooo`000?l0003o
00000_ooool01Ol0003o/kgQok>mhOl0003o]l3Q00Go00001Onja>83o`0000Co^l[U2_l00003okg<
iPGo000000?o_=7Zo`000?l000002Ol000001onigO;o0000o`000?l0003o/mSco`000?ndgoD01?l0
0002ojcHm`[o00000_nYe_L00ol0003oXlkgo`000003o`000005onk]aol0003oh?k6o`000?oLm]d0
0ol000001?nLc_Wo0000oic9monLbOL2o`000003om;Zi_l0003o000000;ob??]0ol00002oiW6m`;o
00000onPao@01?l0003oW/Gco`000?l00002oik2l@03o`000?oooooooooo00Sooooo00Co0000ol;U
l?o2iO3o00001?nlfNl4oig0l@06o`000?nR`^ooX/;_oj;2kol0003oXL7_0ol00004oj6nk@?o0000
1oooool00ol0003o_=W_okcIk`03okcIk`05o`000?ooooooooooooooool000001OnQ_^d00ol0003o
ooooooooo`13ooooo`?o00001Oooool00ol0003oooooooooo`0Oooooo`005_ooool00ol0003ooooo
ooooo`1fooooo`03o`000?nR_NcoX[g/00?oX[g/00?o0000ohF[k_n5Znh00_n5Znh00ol0003ooooo
ooooo`08ooooo`;o00000_nP_>d2o`0000CoX[c/0_l00003ooooo`?o00001_nP^n`2o`0000?oWkSZ
00Co0000oiffj_l0003o00000_nQ]nP01Ol0003ooooooooooooooooo000000?oLJ3^00?o0000oe2=
jol000000oooool01?l0003oD8g[oe2=jol00002oj2fi`04o`000?nU]nKoYKOVo`0000Gooooo0ol0
0006ojBfiP03o`000?nS/N;o000000;oZK?O1?l00003ooooo`04o`000?mYHKKoP6jfo`0000?ooooo
00Go0000ojVch?nY/n3o0000ojnfgP03o`0000;oRVj]00Ko0000ooooool0003o0000oi=e[_l00002
ooooo`05o`000?n_^>3o0000okBkgol000000oooool00onHNJoo0000o`000006o`000004ok>mhOl0
003o]l3Qo`0000Oo^/CR2Ol00003okg6h@03o`000?o0c>Co000000Co00000_nmc>H00ol0003o`=?X
o`000002o`000003oji^ROoooooo000000Co000000?o`n?^o`000?l000000ol000000onigO;o0000
o`000009o`000003oj_OnOl0003oZMci00?o000000Coooooo`000?l0003oX]Oj1_l00003oj7Bn@Ko
000000CoW<kio`000?l0003oW<Wg1?l00003olSck@03o`000?oooooooooo00;ooooo00Co0000oiW6
monIa_OoVLKg1Ol000000onN`_7o0000o`000002o`0000Wooooo00Co0000ol;Ul?o2iO3o00001Onl
fNl00ol0003oWL3aoig0l@02oig0l@03o`000?nR`^oo000000;o00001?nQ_^d3o`0000Wooooo00?o
0000okcIkonlfNl00onlfNl00ol0003oooooooooo`03ooooo`03o`000?nQ_^goXKk]00?oXKk]00?o
0000ooooooooool0?oooool3o`0000Sooooo00?o0000ooooooooool07oooool001Kooooo00?o0000
ooooooooool0MOooool00ol0003oX[g/oj:mk003oj:mk0;o00001On5Znh00ol0003oooooooooo`09
ooooo`;o00000_nP_>d2o`0000CoX[c/0_l000000ooooooo0000oj2kk006oj2kk003o`000?nO^>[o
WkSZ00?oWkSZ0_l00002oiffjP03o`000?nQ]nSoXKOX00;o00000_ooool01_l0003oLJ3^og6Pk_l0
003oD8g[o`0000Kooooo00GoD8g[o`000?nP]^OoX;KWo`000002ojFgiP03o`000?oooooo000000;o
00001OnT]^H2o`0000CoXk7R0_l00002ojVcg`;o00001Oooool01?mYHKKoP6jfo`000?ooool2o`00
0007oh1_]_l0003oZK?Po`000?n_]]ko0000ohY^[@02o`0000?ooooo00Co0000oh]_[_l0003o0000
0_ooool01_l0003o[kSPojnhh?l0003o];_Oo`0000;ooooo1Ol00004okJmg`?o000000?o^/CRo`00
0?l000001Ol00002ok^og@;o000000?o`LONo`000?l000001_l000000oo0c>Co0000o`000003oooo
o`Co000000?o`MCXo`000?n^KHL00_l000000onoenco0000ojm_R007o`000004okWMl_nig?;o0000
ok]WK0So000000?oZmoio`000?nYg?T01ol00002oigMo@03oicGo?l0003o000000;oU];m1Ol00000
0onQd_Wo0000o`000002o`000005oic9mol0003o0000o`000?o7o]l00ol00008ooooo`So00001?nM
`o82o`0000Oooooo00Go0000ol;Ul?o2iO3o`^G`o`000004okcIk`So000000?oXKk]o`000?l00000
1?l0000<ooooo`03o`000?nlfNoo_=W_00;o_=W_00?o0000ooooooooool01Oooool00ol0003oXKk]
oj6nk@03oj6nk@03o`000?oooooooooo03_ooooo0ol0000;ooooo`03o`000?oooooooooo01oooooo
000Fooooo`03o`000?oooooooooo07Cooooo2?l000000ooooooo0000ohF[kP03ohF[kP03o`000?oo
oooooooo00_ooooo0_l00002oj2lk@;o00001?nR_>`00ol0003oX;_/oj2kk004oj2kk0;o00001OnO
^>X3ooooo`03o`000?nM]^[oWKKZ00;o00000_nQ]nP01?l0003oooooooooool00002og6PkP03o`00
0?m@SN_o000000Oooooo00Co0000oj2fionP]^Oo00000_nU]nH00ol0003oY;KVojBfiP03ojBfiP?o
00001_nS/N800ol0003oXk3Qo`000002ojVcg`03o`000?oooooooooo00?ooooo00Co0000oh1^]_n0
K[Ko00000on0KkH01_l0003oZK?PojVch?l0003o[kKNo`0000Gooooo00Co0000oh]_[_l0003o0000
0_ooool01Ol0003o[kSPojnhh?l0003o];_O00?o00002_nf_Ml3o`0000So^koM00Co0000okg4gol0
003o`LON1Ol000001?nLL9oo0000o`000?o0c>@2o`0000;ooooo00?o0000ojEaV?l000000ol00000
0onPJI7o0000o`000002o`000003ooooool0003o000000Go000000?o^Mgbo`000?l000002Ol00000
0on[goWo0000ojWLn@07o`0000;oWMgm00?oW=Olo`000?okd9P01?l00004oiKBo@So000000CoaokO
o`000?o8lngo00001_ooool3o`0000?oU/Si00Go0000oiK2m_l0003oU<3eo`000005oig3lP03o`00
0?oooooooooo00Cooooo00Go0000ol;Ul?o2iO3o`^G`o`000003okcIk`?o00001?nL`O801?l0003o
W;g_o`000?l00005oj6nkP03o`000?oooooooooo00Wooooo00?o0000okcIkonlfNl00onlfNl00ol0
003oooooooooo`06ooooo`03o`000?nQ_^goXKk]00?oXKk]00?o0000ooooooooool0=oooool3o`00
00oooooo00?o0000ooooooooool07_ooool001Kooooo00?o0000ooooooooool0M?ooool00ol0003o
X[k]o`000002o`0000?oXKg]0ol00004ohF[kP03o`000?oooooooooo00cooooo0_l00002oj2lk@;o
00000_nR_>`00ol0003oX;_/oj2kk003oj2kk003o`000?nO^>[oWkSZ00?oWkSZ00?o0000oooooooo
ool00oooool2o`0000;oWKKZ00?o0000oj6gj?nQ]nP00_l000001ooooooo0000og6Pk_maX>ko0000
oe2=jol000001oooool01_l0003oX;KWoj2fiol0003oYKOVo`0000?oY;KV0_l00007oj>ahP03o`00
0?oooooo000000;oXk3Q00Co0000ojVcgonY/moo00001?ooool00ol0003oJF6foh1^]P04o`000006
og]SZol0003oZK?Po`000?n_]]ko00001Oooool01?l0003oRfn^o`000?nCMJh6o`000003okBkgol0
003o][gO00Co][gO1Ol000001?ng^=[o0000o`000?nn_mX5o`000003ooooool0003oVgJX00;o0000
00Oo_LCOo`000?o1amko0000oj1gYOl0003oW72O00;o000000CoVVjNo`000?l0003o`/kS1_l00000
0oo0dnSo0000o`000003o`000003okoGk?l0003o000000[o000000_o_6M[o`000?l0003o0000oooo
ool0003o^UmQo`000?n[goWo0000ojWLn@07o`000004oigMoOl0003oW=Olooooo`Co000000?ooooo
o`000?l000001_l000000on:bOgo0000o`000005o`0000Gooooo0_l00003oiK8n@04o`000?nF`_Ko
U/;fo`0000?ooooo00?oU<3eo`000?l000000onM`o82o`0000Cooooo00Ko0000ol;Ul?o2iO3o`^G`
o`000?nlfNl3o`0000?oW<7b0_l00003oibmk`04o`000?nL_>ooW;c_o`0000GoXKk^00?o0000oooo
ooooool01oooool00ol0003o_=W_okcIk`03okcIk`03o`000?oooooooooo00Kooooo1ol000000onQ
_^go0000ooooo`0dooooo`?o00004_ooool00ol0003oooooooooo`0Nooooo`005_ooool00ol0003o
ooooooooo`1cooooo`06o`000?nR_^goX[k]oj:nkOl0003oWkg^0_l00004oj6mk@;o00000on5Znh0
0ol0003oooooooooo`0;ooooo`Co00000_nP_>d2o`000004oj:lk?l0003oX;_/oj2kk0;o00001?nO
^>X2o`000003og6Pk_l0003ooooo00Gooooo00?o0000oiffj_nM]^X00_l00002oj6gj0;o00000_ma
X>h00ol0003oD8g[o`000007ooooo`Wo00001?nS/N84o`000003oeIVaol0003ooooo00;o000000Go
Xk3Qo`000?nY/mooZK?Oo`000004ooooo`Co000000GoNf>[o`000?l0003oooooo`000002ojVch003
o`000?n_]]ko000000Gooooo1?l00004ok2hgP;o000000?o][gOo`000?l000000ol00005okNhfP05
o`000?ni^m_o0000okjof_l000001_ooool3o`000003okg4gol0003o`LON00Co000000?oooooo`00
0?nJKYh00_l000000oo2c^?o0000o`000002o`000003ooooool0003o0000017o000000?o]EEFo`00
0?l000001Ol000000on[goWo0000ojWLn@08o`000003oicGo?l0003onK9;00[o000000CoSlgmo`00
0?l0003og?KM0ol000001?n:bOgo0000o`000?nIc?T2o`000005ooooool0003o0000o`000?nFb?T0
0_l00002oiK2mP?o00001Oooool2oiC0m@;o000000?oWL?bo`000?nM`o801?l00003ol;Ul0?o0000
0_nL`O83o`0000KoW;g_00Go0000oiblkonL_>ooW;c_o`000005oj6nkP;o00001_ooool00ol0003o
_=W_okcIk`03okcIk`03o`000?oooooooooo00Cooooo0ol00007oj6nkP?o0000<?ooool4o`0001Go
oooo00?o0000ooooooooool07_ooool001Gooooo00?o0000ooooooooool0Loooool00ol0003oX[k]
oj:nk@03oj:nk@;o000000CoWkg^o`000?l0003o00000onQ_Nd3o`000003ohF[k_l0003o000000_o
00001?n5Znh6o`000003oj2kk?l0003oWkSZ00CoWkSZ0_l00003og6PkPWo00000_nM]^X01Ol0003o
XKOXoj6gj?nQ]nSo000000;oLJ3^00?o0000oe2=jol000001?ooool2o`0000CoWkKX0_l00004oj>a
hPCo00000_ooool01Ol0003oEVK7oeIVaol0003oEVG600;o000000KoXk3Qo`000?nY/mooZK?Oo`00
0?ooool2o`000005ofUQ]_mNCjSo0000og]SZol000001?ooool01Ol0003oZK?Po`000?n_]]ko0000
00;ooooo0ol00009ok2hgP;o00001?ng^=X7o`000003okVkfol0003o_[oJ00;o00001Oooool3o`00
0003okg4gol0003o`LON00;o00001?ooool00ol0003o`<cTo`000003o`0000?ooooo0ol000000ooo
oooo0000o`000009o`000003okWMl_l0003o000000Ko00000_nbiOLEo`000005ohoEool0003oSlgm
o`000?oPo/H00_l00003ooooo`;o00000_n:bOd4o`000003oiK8nOl0003o000000;oU/;f0_l00000
0oo2iO3o0000o`000007o`0000?oU<3e0_l00002oig3lP03o`000?o2iO3o`^G`00?o00000_nL`O83
o`0000OoW;g_0onlfNl01Ol0003oW;c_oiblkonL_>oo000000GoXKk^1ol00005okcIk`04o`000?oo
ooooooooooooo`Co00002OnQ_^h2o`000003oj6lk?l0003ooooo02cooooo0ol0000Iooooo`03o`00
0?oooooooooo01kooooo000Eooooo`03o`000?oooooooooo07;ooooo00?o0000oj:nkOnR_^d01?nR
_^d00ol0003oooooo`000002o`000004oinmk_l0003o0000o`0000?oXKg]0_l0000?ohF[kP03o`00
0?nN_NkoW[g^00;oW[g^1_l00002oinhjPCo000000?oLJ3^o`000?maX>h02?maX>h2o`000003oiff
j_l0003oXKOX00;oXKOX0_l000001?maX>ko0000o`000?ooool3o`0000GoWkKX00?o0000oij`iOl0
00000_nS/N82o`000003od]df_l0003oBWCJ00;o00000_ooool01_l0003oEVK7o`000?l0003o?TVe
o`0000;oXk3Q00Ko0000ojVcgonY/moo0000ofUQ]_l00002oei?Z003o`000?mkHj_o000000Cooooo
00Go0000ojVch?nY/n3o0000ojnfgP02o`0000Go/;SN1Ol000001?n`/MWo0000o`000?ni^=P3o`00
0003oiMdZ_l0003o000000?o000000Coooooo`000?ni^m_o^K_K0ol00005ooooo`?o000000Co_LCO
o`000?l0003o00001Oooool01ol0003o`<cTo`000?l0003oWfN@o`000?ooool00_l000000oo0dnSo
0000o`000003o`000003okoGk?l0003o000000Co000000Co_n;`o`000?l0003o^nCc6?l000000onF
foko0000o`000005o`000003on3na_l0003o000000Cooooo0_l000000oo8lngo0000o`000004o`00
0003oiK2m_l0003oU/;f00Go00002?o2iO02o`0000?oU<3e0_l00002oig3lP;o00000_nL`O83o`00
00GoW;g_0_l00007okcIk`05o`000?nL_>ooW;c_oiblkol000001OnQ_^h00ol0003o_=W_okcIk`03
okcIk`06o`000?nlfNoo_=W_okcIkol0003ooooo0ol00008oj6nkP;o00000onQ_>`01Ol0003oXKc/
oj6lk?nQ_>co000002Wooooo0ol0000Looooo`03o`000?oooooooooo01kooooo000Eooooo`03o`00
0?oooooooooo077ooooo00?o0000oj:nkOnR_^d01?nR_^d00ol0003oooooooooo`03ooooo`;o0000
0_nO_Nh2o`0000?oXKg]0_l0000<ohF[kP03o`000?nN_NkoW[g^00CoW[g^00?oWK[]o`000?nJ^>d0
1Ol00003ohF[kPOo00001_maX>h01?l0003oWKKZo`000?l00003oj6gj0Co00001OnO]^P2o`0000?o
W[3U0_l00003oj>ahP;o000000?oBWCJo`000?l000000oooool01?mFI/Oo0000o`000?lnBKD2o`00
0003oj>`hOl0003oZK?O00;oZK?O00Go0000oei?Z?mNCjSooooooei>Y`02o`0000?ooooo1Ol00000
0on_]]ko0000ok2hgP05o`0000Go/;7I00Co0000ok:cf_l0003o^KSH0_l000000onGM:[o0000o`00
0004o`0000;ooooo00?o0000okVkfol000000_l00003ooooo`;o000000CoVgJYo`000?l0003o_LCO
0_l00005ooooo`;o000000?o`<cTo`000?l000000_nOIi0Do`000003okSVmOl0003o000000Co0000
00?oXnkhoj;YnonG6@h01?l00003ohKTn0Go00000_mme_h9o`000003ok7d/ol0003ooooo00?ooooo
1?l00002oh?;oP04o`000?n7`__o0000ohBnnPCo00000oo2iO08o`0000?o^NSe0_nD`?D01?l0003o
U<3eo`000?nM`o84o`0000CoW;g_0ol00002okKLl`[o00000onL_>l00ol0003oXKk^oj6nkP03oj6n
kP03o`000?nlfNoo_=W_00?o_=W_1Ol00005oj6nkPCo00001_nQ_>`00ol0003oXKc/oj6lk002oj6l
k003o`000?oooooooooo02Cooooo0ol0000Oooooo`03o`000?oooooooooo01kooooo000Eooooo`03
o`000?oooooooooo077ooooo00?o0000oj:nkOnR_^d00onR_^d00ol0003oooooooooo`05ooooo`?o
00000_nO_Nh3o`0000;oXKg]3?l00005oijmkP05o`000?nM^^goWK[]oifjkOl000000_nJ^>d00ol0
003oWKW/oifik002o`0000?oPK7d0_l00003ofFWmPWo000000?oWKKZo`000?nQ]nP00_nQ]nP00ol0
003oWkKXoinfj002oinfj0?o00001OnN/>D00ol0003oW:oUo`000003oj>ahPCo00001?ooool3o`00
00;ooooo00?o0000oj>`hOl000000_nY/ml2o`0000;ooooo00?oGTjWo`000?l000000ol00005ojZc
g`?o00001On`/MT3o`0000;oTW2Y00Oo0000ok:cf_nb/m[o0000okVhf?l0003ooooo00Co000000So
ooooo`000?l0003oooooo`000?ni^m_o0000okjofPCo000000?oVgJYo`000?l000000_l000000onm
a=oo0000o`000004ooooo`Co000000Go`/kSo`000?l0003o0000olKEi@05o`0000;oa]WW2_l00000
0ooooooo0000o`000005o`000003oj?^n?nRjO_oR`@000?o00000_n6i?P9o`0000;oJ=?h2_l00002
ooooo`?o000000?oPl_no`000?l000000on7`_/2o`0000;oQ;kj1?l0000:okWXm@[o00001?nL_Nl3
o`0000oo]]cc00Go0000oiblkonL_>ooW;c_o`000005oj6nkPKo00001_nQ_^h3o`0000OoXKc/00Co
0000oooooooooooo00001OnQ_>`00ol0003oooooooooo`0Pooooo`?o00008_ooool00ol0003ooooo
ooooo`0Nooooo`005Oooool00ol0003oooooooooo`1`ooooo`03o`000?nR_^goX[k]00?oX[k]00?o
0000ooooooooool01oooool00ol0003oooooo`000002o`0000;oWkg^0_l00003oj6mk@;o00001On1
/O@00ol0003oW[g^oijmkP03oijmkP03o`000?nM^^goWK[]00?oWK[]0_l000000onJ^>go0000o`00
0002oifik0;o00000_n1/O@3o`0000[oIJOf00Ko0000oiffj_l0003o0000oj6gj?l00002oinfj0;o
00001_nN/>D2o`000004oe2=jol0003oW:oUo`0000?oXk7R0ol00004ooooo`03o`000?lnB[Ko0000
00?ooooo00?o0000oj>`hOl000000_nY/ml00ol0003oooooooooo`03o`0000GoZ[?O0_l000001?nY
[=Wo0000ok:aeol00002ok2af@Oo00000_ooool01_l0003o/[?Jo`000?ni^=So0000ooooo`;o0000
00?oooooo`000?ooool00_l000001Ooooooo0000okVkfol0003o_[oJ00;o000000SoVgJYo`000?l0
003oVG:Uo`000?oooooo0000okg4g`;o000000Coooooo`000?l0003o00000_o5cN47o`0000;oam7R
00Co0000olKIiol0003oa]WW0ol000000ooooooo0000o`00000:o`000003ooooool0003o000000ko
000000?oJ=?ho`000?l000001_l000000ooPo/Ko0000o`000005o`000003oh?;o_l0003o000000?o
Ql;k00?o0000okOflOngm_401?l00002ohBnnP03o`000?nD`oOo000000;o^NSe2Ol000001?nB`OOo
0000o`000?l00002oi>jlP03o`000?nL_O3oW;g`00?o00002?ooool<o`0000?oW;c_00?o0000oj6n
k_nQ_^h00onQ_^h2o`0000GoXKk^1?l00005oj6lk0;o00001oooool00ol0003oXKc/oj6lk002oj6l
k003o`000?oooooooooo01gooooo0ol0000Vooooo`03o`000?oooooooooo01gooooo000Eooooo`03
o`000?oooooooooo06oooooo00?o0000oj:nkOnR_^d00onR_^d00ol0003oooooooooo`09ooooo`04
o`000?ooooooooooooooo`;o00000_nO_Nh3o`0000;oXKg]0ol000000on1/OCo0000oijmkP04oijm
kP03o`000?nM^^goWK[]00?oWK[]0on1/O@2o`000003oiZhkOl0003o000000;oWKW/0_l000000on1
/OCo0000ofFWmP09o`000003ofFWm_l0003o000000Ko00001?nN/>D7o`000004oe2=jol0003oW:oU
o`0000?oXk7R00?o0000ob5@b?l000000oooool2o`000005oci:]_l0003oooooooooool000000_nS
/>400ol0003oZK?OojVcg`02o`0000CoZ[?O0ol00003ojV/f@04o`000?nZ[M[o0000ok:ae`;o0000
0_n9J:H3o`0000Cooooo00Ko0000ok:cf_l0003o^KSHo`000?ooool2o`000003ooooool0003o0000
00;o000000Goooooo`000?ni^m_o0000okjofP03o`000003oiUbYOl0003o000000?o000000Co_LCO
o`000?l0003o00001?o5cN44o`0000Goam7R1?l000001?n<AW?o0000o`000?oooolXo`0000GoEl;j
0_l000000on7`__o0000o`000003okOfl@;o000000Koooooo`000?l0003o0000okWXmOl00002ohBn
nPCo00000_ooool3o`0000;oT/7g0ol00002oi>jlP05o`000?nC^_;o0000oi>jl_l000000onL_O00
0ol0003oooooooooo`0Booooo`05o`000?nL_>ooW;c_oiblkol000000onQ_^h01?l0003oXKk^oj6n
k_nQ_^h4o`0000CoXKc/1?l0000:ooooo`03o`000?nQ_>coXKc/00?oXKc/00?o0000ooooooooool0
6?ooool4o`0002Wooooo00?o0000ooooooooool07Oooool001Gooooo00?o0000ooooooooool0K_oo
ool8o`0000cooooo00?o0000ooooooooool00_ooool2o`0000?oWkg^0ol00002oj6mk@03o`000?nN
_NkoW[g^00?oW[g^00?o0000oifjkOnM^^d00_nM^^d00ol0003oooooooooo`04ooooo`;o000000?o
V[S]o`000?l000000_nM^N`01_l0003oPK7do`000?l0003oIJOfo`0000Kooooo00?o0000oi^gk?nK
]n`00_nK]n`2o`000004oij`iOl0003oW[3Uoij`i@;o00000_leSnl3o`000003oe2=jol0003o0000
00;o000000?oW:oUo`000?nS/N800_nS/N800ol0003o8E38o`000002ooooo`04o`000?l06ZGo0000
o`0000;ooooo0_l000001OnS/>7o0000ojVcgonY/moo000000;oZ[?O0ol00006ojV/f@05o`000?nZ
[M[o0000ok:aeol000000oooool3o`0000Cooooo00?o0000ok:cf_l000000_ni^=P00ol0003ooooo
oiMeZ`03o`000007oiUfZol0003o0000o`000?ni^m_o0000okjofP06o`0000?o`LCL2?l00002olK8
f`Go000000?oS5ZAo`000?l000000_l000001?n<AW?o0000ol_RjOooool4o`000003ooooool0003o
000000Wo000000GoK=gVo`000?l0003o0000ob>^]@0=ooooo`;o000000?o08g0o`000?l000001ol0
00001Onfm_7o0000o`000?l0003oP/;l00;o00000oooool2o`0000?o^NSe0_l00003ohBnnP05o`00
0?nD`oOo0000o`000?nB`OL01?l00003oi>jlPCo000000Co]]cco`000?nC^_;o00000onL_O000ol0
003oooooooooo`0@ooooo`Oo000000?oXKk^o`000?l000000ol00004oj6lk0Co00003oooool00ol0
003oXKc/oj6lk002oj6lk003o`000?oooooooooo01Gooooo0ol0000]ooooo`03o`000?oooooooooo
01gooooo000Dooooo`03o`000?oooooooooo06oooooo00?o0000oj:ok_l000000ol00002oj6okP?o
00002_ooool00ol0003oooooooooo`03ooooo`?o00000onO_Nh2o`000003oj6mkOl0003oW[g^00;o
W[g^00?o0000oifjkOnM^^d00_nM^^d00ol0003oooooooooo`07ooooo`;o000000CoV[S]o`000?nM
^NcoWKW/0_l000001?n1/OCo0000ofFWm_l00003ooooo`;o00001OnK]n`00onI/^Wo0000oiJ`j@08
o`0000?o=Ho_0_l000001Om@SN_o0000o`000?nL[nGo000000?oXk7R00Co0000ob5@b?l0003ooooo
0_l000001Ol06ZGo0000ooooool0003o?DRe00So00001_nY[=T01?l0003oN5RQo`000?l00002ojZ]
fP03o`000?nb/MOo000000;ooooo0ol00005ooooo`07o`000?nb/m[o0000okVhf?l0003ooooooiMe
Z`06o`000003oiUfZ_l0003o^K_K00?o00001Oo1a=`5o`0000Koa/SK0ol00002oooooaKo000000?o
N>?=oh;Yi?l000005?ooool00ol0003o4iKSo`000007o`000004okKflOl0003oooooooooo`So0000
0onij?D@o`0000;o^NWe0_l00002okKLl`05o`000?nfg??o0000oi>jl_l000000onL_O000ol0003o
ooooooooo`0;ooooo`Co00001_nL_Nl3o`000003oj6lk?l0003oXKc/00;oXKc/0ol0000Cooooo`03
o`000?nQ_>coXKc/00?oXKc/00?o0000ooooooooool04Oooool3o`00033ooooo00?o0000oooooooo
ool07Oooool001Cooooo00?o0000ooooooooool0K_ooool01Ol0003oX[o^oj:ok_nR_nko000000;o
X;o_0ol00002oj6okP?o00002?ooool00ol0003oooooooooo`03ooooo`Co00000onO_Nh3o`000003
oijmk_l0003oWK[]00?oWK[]00?o0000ooooooooool02_ooool01?l0003oV[S]o`000?l00002oifi
k0?o000000CoIJOfo`000?l0003o00001?nK]n`2o`0000?oVK;Y00?o0000oiJ`jOl000000_nM/NH0
0ol0003oIJOfo`000003o`0000Go=Ho_0_l000000onL[nGo0000oj>ahP02oj>ahP03o`000?lQD<So
000000;o000000?oooooo`000?l000000_l00004oj:`hP03o`000?nY[=WoZJcI00;oZJcI0ol00000
1?mhF:7o0000o`000?ooool3o`000004ojZ]f_l0003o/[7Go`0000;ooooo0ol00005ooooo`07o`00
0?nb/m[o0000okVhf?l0003ooooooiMeZ`03o`000003oiUfZol0003o000000Go000000?o`LCLo`00
0?l000000ol00002ol:mePKo00000oooool3o`000003ooooool0003ooooo00Co000000?oOTF1o`00
0?l000003Ol000000on2jNCo0000ooooo`0Eooooo`_o00001Oooool00ol0003oHkOlo`000006o`00
0004ognonol0003o0000o`0000;oQ;Ke0ol000001?nC^o;o0000o`000?ooool2o`0000;o^NWe00?o
0000okKLlonfg?<00onfg?<01Ol0003oooooo`000?nC^_;o000000?oW;g`00?o0000ooooooooool0
1Oooool5o`0000OoW;g_0ol000000onM^Nco0000oj:lk002oj:lk0?o00005oooool00ol0003oXKc/
oj6lk003oj6lk003o`000?oooooooooo00gooooo0ol0000cooooo`03o`000?oooooooooo01gooooo
000Dooooo`03o`000?oooooooooo06gooooo00?o0000oj:ok_nR_nh00onR_nh3o`0000;oX;o_0ol0
0002oj6okP?o00001_ooool00ol0003oooooooooo`04ooooo`03o`000?n1/OCo000000So00000_nM
^^d00ol0003oooooooooo`0<ooooo`;o000000?oV[S]o`000?l000000_nM^N`2o`000003ofFWm_l0
003oVkO/00?oVkO/00?o0000oiVbjOnI/^T00onI/^T2o`000006oiJ`jOl0003oWK7Voifai_l0003o
IJOf0_l00003ooooo`04o`000?leSnoo=Ho_ocF?k`;o000000?oW:oUo`000?nS/N800_nS/N800ol0
003o8E38o`000003o`0000CoX[3R0_l000001?nQZMco0000ojV/fOnY[=T5o`0000Cooooo0ol00002
ojZ]fP05o`000?nb/MOo0000oooooon;JJL00_l00005ooooo`03o`000?nb/m[o000000;o^KSH1ol0
0002ok^kf@Go00001_o2_MH00ol0003oaL?Ho`000002o`0000;oUVRK00?o0000ooooool000001?l0
00000ooooooo0000o`00000=o`000003okWfl?l0003o000000;o00006Oooool3o`000005o`0m`Ol0
003o0000o`000?lkU?403ol00005ohBfm@Co000000?oQ;Ceo`000?nC^o800_nC^o801Ol0003o^NWe
okWYmOnijOGo000000Go]]cc0_l00002ooooo`03o`000?nC^_;o000000?oW;g`00?o0000oooooooo
ool01?l00005oibmk`Co00001?nL^N`01Ol0003oWKW/oifik?nM^Nco000000?oX[c/00?o0000oooo
ooooool05oooool00ol0003oXKc/oj6lk002oj6lk003o`000?oooooooooo00[ooooo0ol0000foooo
o`03o`000?oooooooooo01gooooo000Dooooo`03o`000?oooooooooo06gooooo00?o0000oj:ok_nR
_nh00onR_nh00ol0003oooooooooo`03o`0000;oX;o_0ol00002oj6okP;o00001Oooool00ol0003o
ooooooooo`04ooooo`;o00001?nN_^l2o`000003oiVkl?l0003o000000;o00004?ooool2o`000003
oiZhkOl0003o000000;oWKW/00?o0000oi^gk?nK]n`00_nK]n`00ol0003oVK;YoiVbj@03oiVbj@?o
oooo00?o0000oiJ`jOl000000_nM/NH01?l0003oIJOfo`000?l00005ooooo`Co000000?oW:oUo`00
0?nS/N800_nS/N82o`0000?oX[3R0ol00003oj6Yg004o`000?nPZ=co0000ojV/f@Co00001Oooool0
3?mhFJ7o0000o`000?l0003oZZgJo`000?nb/MOo0000oooooon;JJOoTg2Xo`0000;ooooo1_l00002
okVhf0;o00000_nk^mT5o`000004ok^cd_l0003o0000olFmdPCo000000Goooooo`000?l0003o0000
olG3f002o`000004ohiWXOl0003oUVRKoiIXV`Go000000Goooooo`000?l0003o0000olcJi00?o`00
01[ooooo1Ol000000ol0?L7o0000o`000002o`000003oooooolkU?7o000000Co00000omZZoL3o`00
0003oh>fm_l0003o000000Co00000oooool00ol0003oQ;Ceo`000003oi>klP?o00001_nfg?<2oooo
o`06o`000?ooooooooooo`000?nC^_;o00000onL_O02o`0000?oW;g_1Ol00006oibik004o`000?nf
g??o]]cco`0000?oWKW/00?o0000oj:lk?nR_>`00_nR_>`00ol0003oooooooooo`0Fooooo`03o`00
0?nQ_>coXKc/00?oXKc/00?o0000ooooooooool01_ooool3o`0003Wooooo00?o0000ooooooooool0
7Oooool001Cooooo00?o0000ooooooooool0K?ooool00ol0003oX[o^oj:okP03oj:okP03o`000?oo
oooooooo00Cooooo0ol00002oj2ok`?o000000CoXKo^o`000?l0003o00000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?nN_^ooW[k_00;oW[k_00Co0000oiflkonM_>oo00000_nI^o05o`0000oo
oooo0_l000001?nJ^>go0000oifik?l00002oi^gk0;o00000onI/^T00ol0003oooooooooo`04oooo
o`03o`000?nF/>Wo000000;oWK7V0_l000000omUYoKo0000o`000006ooooo`;o000000GoW:oUo`00
0?nS/N;oXk7Ro`000002oj:`hP;o00001?nQZM`3o`0000;oX:SL00?o0000ojV/fOl000000_l00005
ooooo`04ogQIXOn;J:Go0000o`0000;oZZgJ00Go0000ok:aeol0003o0000oi=`Z003o`0000;oUG:Y
2_l00005ok^cdP04o`000?nn^=Co0000olFmdP?o000000?oooooo`000?nFL:H00_l000001oo5`mSo
0000o`000?l0003oSVNQo`000?nFJ9/01?l000000ooooooo0000o`00000@o`0001_ooooo5_l00000
0onijOGo0000o`000002o`0000Co^NWe1Ol000000on4]?Go0000oi>klP02oi>klP03o`000?nfg??o
]]cc00Co]]cc1?ooool6o`000003oibml?l0003o000000Co00001?nL^N`5o`0000Go]]cc0_l00003
oifik003o`000?nR_>coX[c/00;oX[c/00?o0000ooooooooool05_ooool00ol0003oXKc/oj6lk002
oj6lk003o`000?oooooooooo00?ooooo0ol0000mooooo`03o`000?oooooooooo01cooooo000Doooo
o`03o`000?oooooooooo06cooooo00?o0000oj:ok_nR_nh00_nR_nh00ol0003oooooooooo`08oooo
o`?o00000_nP_nl3o`000006oj6ok_l0003o0000o`000?oooooo00000oooool00ol0003oW[k_oijn
k`02oijnk`03o`000?nM_>ooWKc_00;oWKc_0_l00003oiVkl0Go00003Oooool7o`0000?oVK;Y0_l0
0008ooooo`04o`000?nF/>Wo0000o`0000;oWK7V00Co0000ofFWm_l0003o00001_ooool8o`0000;o
XJWL0ol00002ooooo`?o000000CoX:SLo`000?nY[=WoZJcI0_l00002ooooo`Co000000OoRfRUo`00
0?l0003o0000ojZ]f_l0003o/[7G00;o000000?oTg2Xo`000?l000000ol00004ok>cf0;o00001?nk
/m86o`000005okjhe?l0003oaKgBo`000?nFLZP00_l000001OnFL:Ko0000o`000?l0003oaL?H00;o
000000?oooooo`000?l000003?l000001?oDhn;o0000o`000?ooool2o`000003om3m__l0003o0000
00;o00006oooool6o`000003o`05Uol0003o000000Ko000000?o]oKao`000?l000000_l00002okWY
m@Go000000?oPkKfo`000?l000001onijOD00ol0003oQ;Ceo`000003oi>klP[o000000?oT[[bo`00
0?nB^_800onB^_82o`0000GoW;W/1?l00003ooooo`03o`000?nfg??o]]cc00?o]]cc00?o0000oooo
ool000001?nM^N`01Ol0003oX[c/oj:lk?nR_>co000001Sooooo00?o0000oj6lk?nQ_>`00onQ_>`5
o`00043ooooo00?o0000ooooooooool07?ooool001?ooooo00?o0000ooooooooool0K?ooool00ol0
003oX[o^oj:okP02oj:okP03o`000?oooooooooo00cooooo0ol00002oj2ok`?o000000KoXKo^o`00
0?l0003o0000ooooool00004oijnk`03o`000?nM_>ooWKc_00?oWKc_00?o0000ooooool000000_l0
0002oiVkl0;o000000?oVk_^o`000?l000002_ooool00ol0003oV;[_oiRjk`02oiRjk`Wo00002?oo
ool01?l0003oU[3YoiJ`jOl00002oifaiP04o`000?mUYoKo0000o`0000;ooooo0ol00004oiZ`iP04
o`000?nQZMco0000oj6Yg0?o000000?o8RNMo`000?ooool01Ol000000onPZ=co0000ojV/f@04o`00
00CoNEVQ1?l00002ojZ]fP04o`000?nb/MOo0000o`0000Co/k?H0ol00002ok>[d003o`000?nm/loo
_K??00Go000000Ooooooo`000?nGM:[o0000okjhe?l0003oaKgB00Ko000000?oooooo`000?o5`mP0
0_l000001?ooooooT6bUo`000?n6H9h7o`0000;oe=OJ3?l0000Looooo`Ko000000?o4c6^o`000?l0
00003Ol00004ojkYn@;o000000?oPkKfo`000?l000002?l000000on4]?Go0000oi>klP02oi>klP?o
00001OnB^_84o`0000?oU;C]00Co0000oifik?nM^NcoWKW/0ol00005ooooo`;o00001?nfg?<2o`00
00?ooooo00Go0000oifik?nM^NcoWKW/o`000004oj:lk003o`000?oooooooooo01;ooooo2?l00000
0onQ_>co0000ooooo`13ooooo`03o`000?oooooooooo01cooooo000Cooooo`03o`000?oooooooooo
06_ooooo2?l0000@ooooo`?o00000_nP_nl3o`000003oj6ok_l0003o000000?oW[k_00?o0000oifl
konM_>l00onM_>l00ol0003oPK7do`000003ooooo`?o000000CoVK_`o`000?l0003oVk_^0ol00005
ooooo`;o00001?nH^^l01Ol0003oU[G]o`000?nA/^ko000000?oUk?[00?o0000ofFWm_l000002Ooo
ool2oiJ`j@05o`000?nM/NKoWK7Vo`000?mUYoH00ol00004oiZ`iP;o000000CoVJSQo`000?nQZMco
XJWL1_l000000ooooooo0000o`000003o`0000;oX:SL00?o0000ojV/fOl000001?l000000omfCiKo
0000o`000006o`000003ok:aeol0003o000000?o00001OncZm02o`0000;o_K??00Ko0000oiUfZ_l0
003oooooo`000?ooool3o`000003okjhe?l0003oaKgB00Go00000_ooool00ol0003oaL?Ho`000005
o`000004om3@fOl0003o0000o`0000Coe=OJ2_l000000onOl/?oooooooooo`0Kooooo`So000000?o
4c6^o`000?l000001?l000000omJSNSo0000o`00000<o`000003oh>fm_l0003o000000[o000000?o
Tk_bo`000?nB^_801Ol00005oiBdk@06o`000?nD]>goU;C]o`000?nE]Ngo00000onM^N`00ol0003o
ooooooooo`03ooooo`03o`000?nfg??o]]cc00?o]]cc00?o0000ooooooooool01?ooool01Ol0003o
WKW/oifik?nM^Nco000000?oX[c/00?o0000ooooooooool02_ooool8o`0000SoX[c/0ol00013oooo
o`03o`000?oooooooooo01cooooo000Cooooo`03o`000?oooooooooo06_ooooo00?o0000oj?1k_l0
00001?l000000onQ`Noo0000o`000002o`0000oooooo0ol00002oj2ok`Co000000?oW[k_o`000?nM
_>l01?nM_>l01Ol0003oPK7doh6am?n1/OCo000000Gooooo0_l000000onI^o3o0000o`000002oi^k
kP?o000000?oooooo`000?nH^^l01?nH^^l01?l0003oU[G]oiJekOnF]Nd4o`0000;oUk?[0ol00007
ooooo`;o00000_nF/>T01?l0003oWK7Voifai_l00004oiZ`iP?o00000onIZ>42o`0000;oXJWL1?l0
00000olR9igo0000o`000005o`000004oj2Xg?l0003oZJcIo`0000;oMTnF0oooool4o`0000CoZZgI
0_l00004ok>[d0Co000000GoUW:Wo`000?nd[M7o0000okfcc`03o`000003ooooool0003o000000Co
000000Go_[SDo`000?o5_M;o0000oiIdZP02o`0000;ooooo00?o0000olG3f?l000000_l000001Oo@
d=Wo0000o`000?l0003od<SB00_o000000?oooooo`000?l000000_l0000Looooo`Oo000000Co001a
o`000?l0003o00000_ljEL<00ol0A<Ko0000o`000004o`000003ooooool0003o000000Ko00000omV
ZOL8o`0000GoP[Ce0ol00005oiBdk@Go000000Co]]cco`000?nfg??o00000_nE]Nd01Ol0003oWKW/
oifik?nM^Nco000000?ooooo00?o0000okKLlonfg?<00onfg?<00ol0003oooooooooo`05ooooo`05
o`000?nM^NcoWKW/oifik?l000001?nR_>`00ol0003oooooooooo`02ooooo`Oo00002onR_>`4o`00
0004oj:jj_l0003oX[_Zo`0004?ooooo00?o0000ooooooooool07?ooool001?ooooo00?o0000oooo
ooooool0J_ooool00ol0003oXl7^oj?1kP02oj?1kPOo000000?oXL7_o`000?l000000_l0000>oooo
o`[o00000_nM_>l00ol0003oooooo`000003oh6am0;o00001Oooool2o`000004oiVkl?l0003o0000
o`0000;oVk_^00?o0000oiRjkonH^^l00_nH^^l2o`0000?oU[G]00Gooooooh6am?n1/OCo0000oi6b
kP02o`0000;oUk?[2?l00003ofFWmP;oU[3Y00?o0000oifai_l000000_nJ/>H2o`0000CoVJSQ00Go
0000ooooool0003oUZGPo`000002oj6Yg0?o000000So8RNMo`000?l0003ooooooe@lV?l0003oDc^G
o`0000;oX:SL00?o0000ojV/fOl000000_ooool3o`0000CoZZgI00Go0000ojVTdOnYY=7o0000okBZ
c`02o`0000Gooooo00Go0000oiIbYol0003o]:gAo`000002okfcc`03o`000?nIMJ[o000000;o0000
00Ooooooo`000?nGM:[o0000okjhe?l0003oaKgB00;o000000?oTFnXo`000?l000001ol00003om38
dP?o000000?oNE>Ho`000?l000002_l0000Kooooo`Wo000000?o7a22o`000?l000000_l000000olj
EL?o0000o`000005o`0000;ooooo0_l000001?mgX>co0000o`000?l00003ogBPk@;o000000?oRJc]
o`000?n8[>d02?n8[>d2o`0000;oUKC/1?l00004ok3Mm`Go000000Co]]cco`000?nE]Ngo00000onM
^N`4o`0000Co]]cc0_l00009ooooo`05o`000?nM^NcoWKW/oifik?l000001?nR_>`4o`0000WoX[c/
1_l00007oj:jjP05o`000?nR^n[oX[_Zoj:kj_l00000@_ooool00ol0003oooooooooo`0Looooo`00
4oooool00ol0003oooooooooo`1Zooooo`03o`000?nS`NkoXl7^00;oXl7^00?o0000ooooooooool0
2?l000001?nQ`Noo0000o`000?l0000<ooooo`03o`000?nN`?3oW/3`00;oW/3`00?o0000oifol?nI
__401Ol000000ooooooo0000o`000003oh6am003o`000?oooooooooo00Gooooo00?o0000oiVkl?nI
^o000ol00003oiRjk`06o`000?nF]NgoU[G]oiJekOl0003ooooo1_l000000onA/^ko0000oiNcj`02
oiNcj`03o`000?mUYoKoIJOf00KoIJOf1ol00002oiVXh@;o00000oleSnl3o`000004oiJUh?l0003o
XJWLoj6Yg0Co00000_ooool2o`000005od/ZQol0003o0000oj2Xg?l000000_nY[=T2o`0000;oZZgI
0ol00004ojVTd@04o`000?nZYM;o0000o`0000Kooooo1Ol00002okfcc`Wo000000?o_[SDo`000?o5
_M801Ol000001?o9`mCo0000o`000?l00003om38dQ;o00006oooool@o`0000;o>UG31Ol00003oooo
o`?o00001Oooool01?l0003oMJ7]o`000?n9[>d5o`000007ok3Mmol0003o0000ooooool0003oR:g^
o`000002oiFdk003o`000?n`gOOo/=gg00Wo/=gg0_l00002oiFek@07o`000?nM^NcoWKW/oifik?l0
003o]]cco`000003okKLl`03o`000?oooooooooo00Wooooo00?o0000oifik?nM^N`00_nM^N`01?l0
003oX[c/oj:lk?l00007oj:lk0Ko00003?nR^^X00ol0003oX[_Zoj:kjP02oj:kjP03o`000?oooooo
oooo043ooooo00?o0000ooooooooool07?ooool001?ooooo00?o0000ooooooooool0JOooool00ol0
003oXl7^oj?1kP02oj?1kP03o`000?oooooooooo00Gooooo3?l00007ooooo`03o`000?nN`?3oW/3`
00;oW/3`00Co0000oifol?nM_o3oWKo`0_l000000onI__7o0000o`000004o`0000?oPK7d00?o0000
ooooooooool01oooool4o`000003oiRjkol0003oU[G]00;oU[G]0ol00005oh6am0;o000000?oTK;^
o`000?l000000_nG/n/2o`000003ofFWm_l0003o000000?o00001?nC/N/00ol0003oVJSQo`000003
o`000003oej`nol0003o7i?[00?o000000Co=Ho_o`000?nFYN3o00000_nQZM`3o`000004ooooool0
003o0000o`0000;ooooo1?l000000onY[=Wo0000o`000002o`0000OoZJCA00Go0000ojZUd_l0003o
]:[?o`000005ooooo`Co000000Go]:gAo`000?nm/loo0000oiUfZP03o`000007oiQeZ_l0003o0000
o`000?nn^=Co0000olFmdP02o`000004olW3e?l0003o0000o`0000;obK[<0ol000000ooooooo0000
o`000006o`000003ooooool0003o000000Ko00006_ooool2o`000003og7ATol0003o000000?o0000
00?o000Vo`000?l000003_l00004ooooo`03o`000?mgX>co000000;ooooo0_l000000on^jOWo0000
ogFQk@02o`0000Co/=gg00?o0000ooooooooool00_ooool00ol0003oR:g^o`000002oiFdk003o`00
0?oooooooooo00Ko00000_n`gOL00ol0003o/=ggo`000002oiFek@09o`000?nM^NcoWKW/oifik?l0
003o]]cco`000?nfg??o000000Wooooo2Ol000000onR_>co0000oj:lk007o`0000_oX[[Z0ol00004
ooooo`03o`000?nR^n[oX[_Z00;oX[_Z00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0L
ooooo`004oooool00ol0003oooooooooo`1Yooooo`03o`000?nS`NkoXl7^00;oXl7^00?o0000oooo
ooooool02Oooool3o`000003oj71kol0003o000000Ko00000_ooool00ol0003oW/3`oik0l002oik0
l003o`000?nM_o3oWKo`00;oWKo`00Co0000ooooool0003o00000_nI__45o`0000;oPK7d0_l00006
ooooo`04o`000?nF_O;oU[gboiJmlPOo00002_n1/O@2oi6bkP06o`000?nG/n_oUk?[oiNcjol0003o
G[3k0_l00004oi>aj`05o`000?n@ZNOoRjGVoh^Ui_l000000_nGZN83o`000003oej`nol0003o0000
00;o000000Co7i?[o`000?nFYN3o00000_nQZM`8o`0000CoX:SL0_l00004ojVTd@Co000000KoSFJP
o`000?l0003oZZGBo`000?ndZ/l4o`0000;ooooo1?l000001?nd[M7o0000okfcconm/ll5o`0000?o
`;OA1_l00004olVjc0?o000000?oooooo`000?l000003ol0000Iooooo`So000000?o6015o`000?l0
00001Ol000001Om3>9oo0000o`000?l0003o[^Wi00?o000000?o[^WioeQadOmHLM401_l000000omg
X>co0000o`000002ojkYn@Co000000?oRJc]o`000?n`gOL00_l00006ooooo`;o00000_nE]>`00ol0
003oooooooooo`06ooooo`Ko00000_nE]Nd00ol0003oWKW/oifik004o`000003ooooool0003o0000
00Oo00002?nM^N`4o`0000KoX[[Z1ol0000<ooooo`03o`000?nR^n[oX[_Z00?oX[_Z00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0Kooooo`004_ooool00ol0003oooooooooo`1Yooooo`So
00003Oooool4o`000003oj71kol0003o000000Go00001?nN`?001?l0003oWKo`oifol?nM_o02o`00
00Cooooo0_l00002oiVnl@Go000000?oPK7do`000?ooool00oooool00ol0003oU[gboiJmlP02oiJm
lP03o`000?nD^O7o000000;o00000_nC]o02o`0000KoPK7d0_l000000omo^OWo0000oi6bkP02o`00
00;oUk?[00?o0000oi>ajonC/N/00_nC/N/2o`0000?oT:WW0_n;YNH01Ol0003oUjWRoiNYh_l0003o
oooo00?o000000Co7i?[o`000?l0003ooooo0_nFYN000ol0003oXJWLoj6Yg004o`0000GoX:SL00?o
0000oijOe?l000000_nYY=45o`0000?oSF6I0_l00002ojZUdP?o00000_nHLZH5o`000003oiYfZOl0
003o000000;o_K??0_l00004ol2gd@Go00000oo9^/`7o`000003ooooool0003ooooo00;o000000Go
e];Eo`000?l0003o0000on;Sd`02o`000003onG]e?oooooo000000?o00006?oooolBo`0000;o9D2g
2Ol000000om_R=_oFhoYoe^?j@04o`000003ojkYnOl0003o000000;o/=gg00Go0000ogFQkOl0003o
RJc]o`000008ooooo`03o`000?n8[Nko000000;oUKC/00?o0000ooooooooool02Oooool2o`0000;o
UKG]00Co0000oifik?nM^NcoWKW/1?l00007oifik0Oo00000_nN]^T00ol0003oWkOZo`000003oj>j
j@Ko00004oooool00ol0003oX[_Zoj:kjP02oj:kjP03o`000?oooooooooo043ooooo00?o0000oooo
ooooool06oooool001;ooooo00?o0000ooooooooool0JOooool00ol0003oXl7_o`00000:o`0000co
oooo1?l000000onQ`Noo0000o`000003o`000003oik0l?l0003oWKo`00;oWKo`00Co0000oooooooo
oooo00001_ooool01?l0003oVKkaoiVnlOnI__45o`0000;ooooo00?o0000oiJml_nF_O800_nF_O80
1?l0003oU;WaoiBilOnD^O44o`0000;oTkO`0ol00008ognin@;oTK;^0ol00002oi>aj`;o00001?n@
ZNL2ooooo`;oRjGV00Co0000oiNYh_nGZN;o00000oooool2o`000003oanCjol0003o000000;oUZGP
00Co0000oj6Yg?nQZMco00000_nPZ=`3o`0000CoWYoD0_l000001OnYY=7o0000o`000?n>HISo0000
00?ooooo00So0000oheQVOl0003o0000ojZUd_l0003o]:[?o`0000;oV72S0_l000000onHLZKo0000
o`000005o`000003ol2gdOl0003o000000?o00000_no[/T2o`000004olbib?l0003oooooooooo`;o
000000?oTgJ_o`000?l000001ol000000ooFd]Go0000o`000002o`000004on?JcOl0003o0000oooo
o`?o00005oooool7o`000003oa`07_l0003o000000?o000000?o=`MVoaP7Nol000001?l000000omC
C:co9D2go`000004o`0000;oY>Sk1?l00002ofn8f`03oe^?jOl0003oMj3/00Go000000Go/=ggo`00
0?l0003oRJc]o`000009ooooo`;o00000_nE]>`00ol0003oooooooooo`05ooooo`[o000000CoWKW/
o`000?nM^NcoWKW/2?l00009oijfj@04o`000?nO]n[oWkOZo`0000CoXk[Y0_l0000Fooooo`03o`00
0?nR^n[oX[_Z00;oX[_Z00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Kooooo`004_oo
ool00ol0003oooooooooo`1Yooooo`03o`000?nS`NooXl7_00;oXl7_3Ol0000;ooooo`Wo00000_nM
_o001Ol0003ooooooooooooooooo000000Sooooo00Co0000oiVnlOnI__7oVKka1Ol00003oiJmlP04
o`000?nD^O7oU;WaoiBil@Co000000?oS[Obo`000?l000000_nC]o02o`0000OoOkWi1ol00003oi2Y
i`?o00000oooool2oh^UiP;o000000?oUjWRo`000?ooool00oooool00ol0003oG[3koej`n`04o`00
0004oj6Yg?l0003o0000o`0000CoWYoD1?l000000onMW]Co0000ojVTd@02o`0000Kooooo0_l00000
1?nZYM;o0000okBZcol00002ooooo`03o`000?nHL:?o000000;o00000onf[M03o`0000;o_jk90ol0
00001ooooooo0000o`000?l0003oc;W8o`000?ooool00_l000000onCMZoo0000ohMYZP0;o`0000;o
hm[=1_l0000Fooooo`?o000000?o2P00o`000?l000002_l000000olH1g_o0000o`000004o`000003
oe=<[?l0003oAUo800?o00000_ooool6o`0000;oKhSK1?l00002ogNRk@Co000000?oRJc]o`000?l0
00002_l000000onE]>co0000o`000006o`0000GoU[C]00Co0000oiJdkOnF]>goU[C]1Ol00008oijf
j@Ko00000oooool01Ol0003oWkOZoingj_nO]n[o000000CoXk[Y00?o0000ooooooooool05?ooool0
0ol0003oX[_Zoj:kjP03oj:kjP03o`000?oooooooooo03oooooo00?o0000ooooooooool06oooool0
01;ooooo00?o0000ooooooooool0J?ooool00ol0003oXl7_oj?1k`03oj?1k`04o`000?oooooooooo
ooooo`go00002?ooool00ol0003oWl;aoio2l@02oio2l@03o`000?nN`O7o000000Co00000oooool0
0ol0003oooooooooo`08ooooo`CoVKka0ol000000onF_O;o0000oiBil@02oiBil@;o00001?mo^OT0
0ol0003oS[Obo`000002o`000003oi>gl?l0003o000000?o000000?oooooo`000?n<]?400on<]?42
o`000004oi2Yiol0003o0000o`0000?oG[3k0_l00002ooooo`?oRjGV00?o0000oiNYh_l000001?oo
ool2o`0000CoU:KR00Co0000oijOe?nNWmCoWYoD2?l000000onMW]Co0000ojVTd@04o`0000Cooooo
0_l00002ojZUdP;o000000Coooooo`000?l0003o00001?nf[M001?l0003o]:C7o`000?o2[LD2o`00
0003ooooool0003o000000;ooooo0_l000000oo2//_o0000o`000002o`000003oi=f[ol0003ooooo
00Oo00000_oKdLl2o`000003on?JcOl0003ooooo00Ko00004oooool5o`000003o`X00?l0003o0000
00;o000000?oT>g`o`000?l000002_l000000ooooooo0000ooooo`02o`000004ofER^_m6GlSo0000
o`0000;ooooo0ol000000onTj?_o0000o`000003o`000003ohJJh?l0003oPY[Q00;oPY[Q0ol00000
0omgX^go0000o`000006o`0000GoRJg]2_l00005oiR`i`06o`000?nH/>Oo0000oiVaj?l0003oWkKX
0_l00003oijfj@Go00002_ooool01?l0003oWkOZoingj_l00004oj>jj@03o`000?oooooooooo01Go
oooo00?o0000oj:kj_nR^nX00_nR^nX00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01_o
oooo000Booooo`03o`000?oooooooooo06Sooooo00?o0000oj?1kol000001_l00007ooooo`co0000
0_ooool00ol0003oWl;aoio2l@02oio2l@04o`000?nN`O7oW/7aoik1l@Wo00002oooool8o`000003
oiBilOl0003oOkWi00OoOkWi00?o0000ohjgl_n>]o800_l000001OnC]o3o0000o`000?oooooo0000
00CoS;Ca00?o0000ohV]kOn9[Nd00_l00002ohf[jP;o00000omN/?/2o`000008oooooon;YNKoRjGV
oh^Ui_l0003oUjWRo`000?ooool2o`0000CoU:KR00?o0000oi6Lf_l000000_nMWmD8o`000005ogA2
QOl0003oWIkDo`000?nYY=400_l000000on?HY[o0000o`000002o`000007ohiRVol0003o0000ojZU
d_l0003o]:[?o`000002okJ]d0?o00000ondY<L2o`000003ol:]aOl0003o000000;ooooo0_l00000
2Ooooooo0000o`000?o2//_o0000olbib?l0003oTgJ_o`000003ooooo`?o00000_oKdLl:o`000003
ooooool0003o000001;ooooo2Ol00002ooooo`[o000000?oERn5o`000?l000000ol000001Ooooooo
0000o`000?ooooooIF:j00So00000on[g?T2o`000004ohJJh?l0003oZ]cioj[Ln@?o000000CoPY[Q
o`000?l0003o00002on?Y^D01?l0003oVZoVo`000?l0000<oiR`i`04o`000?nI/NSoVK7Xo`0000?o
WkKX0ol0000<ooooo`Co00000_nO]nX00ol0003oXk[Yoj>jj@02oj>jj@03o`000?oooooooooo01Go
oooo00?o0000oj:kj_nR^nX00_nR^nX00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01_o
oooo000Booooo`03o`000?oooooooooo06Oooooo00?o0000oj?2konS`^l00_nS`^l;o`0000Kooooo
2_l00004oio2l@05o`000?nN`O7oW/7aoik1lOl000000_ooool:o`0000Oooooo00?o0000oiK0m?nF
`?@00_nF`?@6o`0000CoOkWi1?l000001?oooooo0000ohjgl_n>]o82o`000003oi>gl?l0003oS;Ca
00;oS;Ca00Co0000ohV]kOn9[NgoRJg]0_ooool3o`000003ohf[j_l0003o000000;o00000_mN/?/2
o`0000?oRjGV00?o0000oiNYh_l000000_nDY^83o`0000?oTIcJ0_l000000onMWmGo0000o`000008
o`000004oifNe?l0003oZJCAojVTd@;o000000?oT5nDo`000?n?HYX01_l000001?ndZ/oo0000o`00
0?l00004okBTa`;ooooo00Go0000okJVb?l0003o`Zg5o`000002ooooo`04oi]j[_l0003ooooooooo
o`?o000000?oc;W8o`000?l000000oooool8o`000004ogE>U_l0003o0000oe8WOPOo00004?ooool2
o`000003oekD__l0003o000000[o000000OoA@1>o`000?l0003o0000ooooool0003oD2In00[o0000
0_ooool8o`0000?oZmci00Co0000og:<gOl0003o00000_ooool3oj[Ln@?o000000?oTZKTo`000?l0
00001_l00002ohnVi@03o`000?n@ZNOo000000;oVZoV1_l00002ok3Mm`;o00000_ooool2o`0000;o
VK7X00Co0000oinfj?nO]^So00002_ooool4o`0000?ooooo00Go0000oingj_nO]n[oWkOZo`000004
oj>jj@03o`000?oooooooooo01Cooooo00?o0000oj:kj_nR^nX00onR^nX00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo01_ooooo000Aooooo`03o`000?oooooooooo06Sooooo5Ol00007oooo
o`Oo000000GoWl;ao`000?nN`O7oW/7ao`000007ooooo`[o00000_ooool00ol0003oU/3doiK0m002
oiK0m003o`000?nE_O?oUKgc00;o000000?oS[ceo`000?l000000ol00007ooooo`?oS[Ob0_l00000
0on<]?7o0000o`000002ohV]k@03o`000?oooooooooo00?ooooo00?oPJS]o`000?n=ZnX00_l00000
0omo^OWo0000o`000002oej`n`04o`000?n;YNKoRjGVoh^UiPCo00001?nAW=X01_l0003oG[3ko`00
0?n>VM[o0000oifOe@Wo00000_nMW]@00ol0003oZJCAo`000002ooooo`?o00001OnZY=400ol0003o
]:C7okBTa`04o`0000?ooooo00Co0000okJVb?l0003o`Zg50_l000000oooooooVgZ^o`000002oooo
o`?o000000?oc;W8o`000?ooool02Ol00002og5KZ@_o00003OoooolBo`000003odD0C_l0003o0000
00Co000000Ooooooo`000?mR?i7o0000odm5Y_l0003oWNKl00go000000CoZmcio`000?l0003ooooo
0ol00005ooooo`03oj[LnOl0003oPigS00?o00001On`g?L4o`000004oi2Yiol0003oVZoVoiZ_iP;o
00001?n`gOL2o`0000Gooooo0_l000001OnI/NSo0000oinfj?nO]^So000000Oooooo0ol00008oooo
o`04o`000?nO]n[oWkOZo`0000CoXk[Y00?o0000ooooooooool05Oooool00ol0003oX[_Zoj:kjP02
oj:kjP03o`000?oooooooooo03oooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000oooo
ooooool0J?ooool00ol0003oY<;_o`00000Ho`0000?ooooo00Co0000oio3lOnO`o7oWl?a2?l00009
ooooo`Wo00000onF`?@01?l0003oUKgcoiFmlonE_O<4o`000003ohjlmOl0003o000000?o00001_oo
ool7o`000003ohV]kOl0003ooooo00Kooooo0ol000001?n=Zn[o0000ogninOmo^OT2o`000003oej`
nol0003o000000?o00000_nAW=X2o`0000CoG[3k0ol000000onMWmGo0000o`000008o`0000;oWIkD
00Co0000ojVTdOl0003o00000onZY=43o`000004ojRKb?l0003o0000okJSa@Go00000oooool01?l0
003o]ZK8o`000?o2[LD2o`0000;ooooo1Ol000000oo2//_o0000o`000007o`000003omo4__l0003o
IeFY00co00003?ooool2o`000003o`400?l0003o000000;o000000?o:000o`000?l000001_l00000
0om304co0000o`00000>o`000003ooooool0003o000000Oo00000_mfMlH5o`000005ooooool0003o
0000ohJJh?l000001Oooool01?l0003oPigSo`000?nBY^@4o`0000Go/=cg0ol00003oiZ_iP05o`00
0?n`gOOo/=ggok3Mmol000001oooool2o`000003oiVaj?l0003oWkKX00;oWkKX00Co0000oooooooo
oooooooo0ol0000;ooooo`04o`000?nO]n[oWkOZo`0000CoXk[Y00?o0000ooooooooool03oooool9
o`0000;oX[_Z00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0
003oooooooooo`1Xooooo`03o`000?nT`^ooY<;_00;oY<;_00Co0000oj;3l?nR`o3oX/?`5Ol00005
oio3l@03o`000?nO`_7oWl;a00So00001_ooool01?l0003oooooooooooooool5o`000003oiK0m?l0
003oUKgc00;oUKgc1?l000001Omo^OWo0000o`000?l0003oS[ce00Go00000_ooool01_l0003oR;Wf
ohRim_n8^OKo0000ohFcl`Co00002Oooool01On1Z>go0000ohf[j_l0003oOkWi00?o00000_n7YnT0
1Ol0003oQ9cRo`000?n?WMgo000000GoG[3k0ol000000on>VM[o0000oifOe@0<o`000003ojVTdOl0
003o000000;o00000onXVlP01_l0003oooooo`000?nYVlSo0000okJSa@[o00000_o2[LD;o`000005
olnf`Ol0003o0000o`000?n<M;<00_l000001OoOa;ko0000ofMEZOl0003ooooo00Go000000?olMVh
o`000?l000000_l00007ooooo`Wo000000?o9`00o`000?l000001?l000000onChogo0000oaT06P0B
o`000003of5J/ol0003o000000?o000000?oY]_jo`000?l000000_nZg?T3o`000004oh>8d?l0003o
N8kLogR>g0?o000000?oQY[Po`000?ooool01Oooool2o`000003oi:Vi?l0003o000000;oZ]ci0ol0
0003ok3Lm`03o`000?n@ZNOo000000;oVZoV00Co0000ok3Mmol0003o00002Oooool2o`000004oiVa
j?l0003oWkKXoinfj0Co00003_ooool01Ol0003oWkOZoingj_nO]n[o000000CoXk[Y00?o0000oooo
ooooool00oooool;o`0000WoXk_Z1?l00010ooooo`03o`000?oooooooooo01[ooooo000Aooooo`03
o`000?oooooooooo06Oooooo00?o0000ojC2konT`^l00onT`^l01Ol0003ooooooooooooooooo0000
00GoX/?`5?l00003oio2l@03o`000?oooooooooo00[o00000_ooool01Ol0003ooooooooooooooooo
000000;oUl;e2?l00002ooooo`;o000000CoOkWio`000?l0003o00000_n>_?D4o`0000?oR;Wf00Ko
0000ohFclon5/o?oQK?co`000?mj[_@3o`0000Sooooo00CoPJS]o`000?l0003o00000on7YnT01?l0
003oQ9cRohBLh_n4W>82o`000004ohnMgOl0003oG[3koej`n`Go00000_n>VMX01Ol0003oWIoEo`00
0?ma;fgoL3Eg00Co00001?nLW]D2o`000003ojRKb?l0003o000000Ko000000?oZI_8o`000?nfXlD0
1_l00002oj1lZ`;o00000_o2[LD7o`000003ol>X__l0003o000000;o00000_ooool02Ol0003oS7Bc
o`000?l0003oglBno`000?mWEJWo0000ooooo`09o`0000Gooooo5ol000000ooooooo0000o`00000;
o`000005oigVo?l0003oMU^VogIKY_mQF[<00ol000000onVfo[o0000ofUX_P02o`000003ojKKn_l0
003o000000Co000000?oPhS@o`000?mhS]`01ol00002ooooo`;o000000?oTZKTo`000?ooool00_oo
ool00ol0003oZ]cioj[Ln@04o`000004oi2Yiol0003oVZoVoiZ_iP;o00002oooool01?l0003oVK7X
o`000?l00002oinfj003o`000?oooooooooo013ooooo00Co0000oingj_nO]n[o00000onS^^T7o`00
01OoXk_Z00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003o
ooooooooo`1Wooooo`Wo00001oooool2o`0000?oX/?`5Ol00004ooooo`[o000000?oooooo`000?nG
`_D00onG`_D00ol0003oU/7eoiK1m@07o`000003ooooool0003o000000;oOkWi0_l00002ohjlm@?o
000000?oR;Wfo`000?n5/o<00_n5/o<3ooooo`03o`000?mj[_Co000000;o00001_ooool4o`000003
ohNWjOl0003o000000;oQ9cR00?o0000ogninOl000000_l000000on?WMgo0000o`000002oenko@?o
000000?ooKa^ohjIf_n>VMX01Ol00005oibNe@06o`000?nJTlco0000ojVJaol0003oTEb?2Ol00000
0onfXlGo0000oiidY003o`000003oj1n[_l0003o000000Oo00000_o3Z;h3o`000004olF/`?l0003o
0000o`0000;ooooo1?l000000ooOa;ko0000ofMEZ@06o`000003ooooool0003o000001Co000000?o
:000o`000?li02801_l00002oooooa3o00000_mfFjH2o`000003og9^_ol0003o000000;o00000_oo
ool01?nVfo[o0000o`000?l00002oj[Ln@04o`000?n3R=3oPhS@oh>8d0Co00000_n7W^84o`0000;o
TZKT00?o0000ooooooooool00_ooool3o`000005oj[LnOl0003o0000oi2Yiol000000_nJ[nH00ol0
003oooooooooo`09ooooo`04o`000?nI/NSoVK7Xo`0000?oWkKX00?o0000ooooooooool01_ooool;
o`000005oingj_l0003oXk[Yoj>jjOl000003_nS^nX;o`000006ojBij?l0003o0000o`000?nT^^Wo
0000@?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`1Wooooo`;oYL?_
0ol00004oj?3l0Ko00001_ooool4o`0000;oX/?`2_l000000onMa??o0000o`000008o`0000?ooooo
2Ol000001OnG`_Go0000oiK1mOnF`OGo000000?ooooo00?oSl3go`000?l000001_l00002ognin@Ko
000000CoQK?co`000?l0003o00001Oooool01?l0003oNZkdo`000?l00004ooooo`03o`000?mjZ_7o
NZ[a00;oNZ[a00Co0000ohBLh_n4W>;o00000_mo^OT5o`000003ohnMgOl0003o000000Go00000_n>
VMX00ol0003oWIoEo`000003oibNe@;o00000onJTl`00ol0003oVI;;o`000006o`000009oj5dWol0
003oWgFRo`000?nYVlSo0000okJSaOl0003oYWjX00?o00001?nhYLH2o`0000;o`jRn1?l000000ooo
oooo0000olF/`002o`000006oiAk]?l0003oooooohad/ol0003ooooo1Ol000000ooUcl3o0000o`00
000Bo`000003ocT00?n;gogo000000;o000000Go:000o`000?l0003o0000ooooo`09o`0000;ooooo
3?l00002ojCKn`05o`000?n1K;;oPFbbo`000?mbK[l00ol00003ooooo`Go00000_nZg?T3o`0000?o
SYSH0ol00002ohNNhQ3o00000_nJ[nH@o`0000;oWkKX2_l0000;oj2gj@Co00001?nS^nX;o`0000_o
Y;WX00?o0000ojBjjOnT^^T00_nT^^T00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01[o
oooo000Aooooo`03o`000?oooooooooo06Oooooo00?o0000ojG3konU`nl00_nU`nl00ol0003oXl?`
oj?3l003oj?3l004o`000?nS`o3oXl?`oj?3l0Go00001ooooolKo`000003ooooool0003o000000Wo
00001Oooool2oho0m`Ko000000GoOkWio`000?n7_OWoQkgio`000002ohFjm`Go00001Oooool01_mj
[_Co0000o`000?l0003oooooo`0000?oNZ[a00Co0000ogJPk?l0003oJIOZ0_l00004ognin@05oh72
o?l0003oOIOQo`000?n?WMd01?l000000olJ03So0000o`000007o`0000?oVY?<00KoUEJ2oi5IRol0
003oVI;;o`000?nYV/L7o`000005oj5dWol0003oZI_8o`000?nfXlD00_l00003okRUaP;o00000_nf
Vkd01ol0003oa:Jko`000?l0003o?`00o`000?nSQkL00ol000000oo5[<3o0000o`000002oiAk]0Oo
000000?oiLo0o`000?l000001?l000000ol/6XOo0000o`000002o`000003oc800?l0003o000000ko
000000?oC@0Wo`000?l000000_l000001OmG1dOo0000o`000?l0003o@`1;00?o000000?oooooo`00
0?l000001?l000001OmV@iCo0000o`000?l0003oY=_k00?o000000?oY=_ko`000?l000000on1K;84
o`0000;ooooo1?l000001?nVfo[o0000o`000?nZg?T7o`0000?oSYSH1ol00008oi>Yi@03o`000?nJ
[nKo000000ooV[7W0ol0000;oj2gj@;o00002_nP]nT6o`0000SoY;WX2?l00006ooooo`03o`000?nT
^^WoY;[Y00;oY;[Y00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Jooooo`004?ooool0
0ol0003oooooooooo`1Xooooo`03o`000?nU`nooYL?_00;oYL?_00?o0000ooooooooool00_ooool0
0ol0003oXl?`oj?3l005oj?3l003o`000?nS`o3o000000Go00000oooool00ol0003oXLCboj74lP02
oj74lP03o`000?nQa?;oXLCb00;o00000_nJaOH00ol0003oVLGfo`000003o`000003oiW5m_l0003o
000000Oo000000CoV<Cfo`000?nHa?Ko00000_nHa?H8o`0000?ooooo0_n?`?L5o`000005ohNmnOl0
003oQK[gohFjmol000000_ooool00omg]?Wo0000o`000003o`0000?ooooo00Go0000ogZ^m?l0003o
0000ogZZl@02o`0000?oMZ3/0_l000001?mYUn[o0000o`000?l00004oh72o004o`000?mmUn7o0000
ohnMg@Go00001?n<V]`00ol0003oVY?<o`000003o`000009ooooool0003oUEJ2o`000?nIT/_o0000
ojVJaol0003o]THf00Co000000?oXg>No`000?l000000_l000000onfXlGo0000o`000002o`0000Co
]Y^m0_l000000oo4Y[_o0000o`000002o`000003oj>7]ol0003o000000;o000000CoaJc0o`000?l0
003oU7^d3Ol000000ol/6XOo0000o`00000Ao`000003odX09?oooooo000000?o000000OoE`M7o`00
0?ooooooooooo`000?mK34co@`1;00Wo000000GoN4B5o`000?m/BYWo0000oj7Jn`02o`000003ojCK
nol0003o000000;o000000?ooooooh5//_n1K;800ol000000on0P<Wo0000o`000003o`0000;ooooo
00?o0000ojKKn_l000000ol000001?nZg?Wo0000o`000?ooool5o`0000;oVZCL00?o0000oiNTg_nG
Y=h00onGY=h4o`0000;oTjWU3ol00003oiZai`go00002OnQ]>H2o`000003oj:fiol0003oYKWW00;o
YKWW1ol0000Aooooo`03o`000?nT^^WoY;[Y00;oY;[Y00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0Iooooo`004?ooool00ol0003oooooooooo`1Wooooo`03o`000?nU`nooYL?_00?oYL?_
00?o0000ooooooooool02_ooool2o`0000CoXl?`2?l000000onQa?;o0000oj74lP02oj74lP05o`00
0?ooooooooooooooool000000_nMa?<2o`000003oi[5m_nIaOKo000000?o000000?oVLGfo`000?l0
00001Ol000001?nHa?Ko0000oiS4m_l00002ooooo`[o000000?ooooooho0mol000002Ol00002oooo
o`?o000000?oO[Kgo`000?l000000_ooool4o`0000?oMZ3/00Ko0000ogninOmo^OWoOkWio`000?mY
UnX2o`0000GoPL;l00Go0000ogfGhOl0003oSigMo`000003ohbJg0Go000000?oVIC=o`000?n?Cgd0
1ol000000onIT/_o0000o`000002o`000003oejkoOl0003o000000;o00000onYVlP2o`0000?o]Y^m
0_l00002ofK7o@03o`000?ngW[oo000000Wo000000?oaJc0o`000?l000002ol000000omOC:Co0000
o`000007o`000004oe/03Ol0003o0000ooooo`;o000000?o>`00o`000?l000001?l000000on;gogo
0000odd09`03o`0000?ooooo2ol000001_nQf__o0000o`000?mmCHco0000ogEGXPCo000000Cooooo
o`000?l0003o00000_ooool01?l0003oQG>go`000?n:O;h2o`000004oh20bOl0003o0000o`0000?o
oooo1Ol00003oj[Ln@;o000000Coooooo`000?l0003o00000_nJY=`00ol0003oZ]cioj[Ln@02o`00
0003ooooool0003o000000;oUjCN00?o0000oiRWhOl000000_nO[N46o`0000OoWJgS00Co0000oif`
iOl0003oXkCU2_l00009oj6diP05o`000?nR]^OoX[KWoj:fiol000001?nU^NL00ol0003ooooooooo
o`0Dooooo`03o`000?nT^^WoY;[Y00;oY;[Y00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0Iooooo`004?ooool00ol0003oooooooooo`1Wooooo`03o`000?nU`nooYL?_00;oYL?_00?o0000
ooooooooool04_ooool4o`0000;oXl?`2ol00005ooooo`;o000000CoWLCco`000?l0003oVLGf1?l0
00000onIaOKo0000o`000002oi?6n@Go00001?ooool7o`0000;oQl;j00?o0000ohK0n_n6`?X01ol0
0003ooooo`Go00000_m^[oP00ol0003oJjKdof^Vm003o`000006ogninOl0003o0000oh72o?l0003o
JIOZ0_l00003oh72o0;ooooo1ol000002On8S];o0000o`000?l0003oQH[Ao`000?nIU<go0000ohm?
O@06o`000003oiVBbol0003oZI[700Co00001?nYVlP01?nWTKko0000o`000?ngV[/3o`000003ojN5
/?l0003o000000;o000000?o]ijoo`000?o4Y[/01?l000000onSQkOo0000o`00000=o`0000?oGdbT
0ol000001Oolgj;o0000o`000?l0003ooooo00?o000000?oooooo`000?l000000ol000001OmD02Ko
0000o`000?l0003oP=[n00Go000000?oooooo`000?l000000ol000000om`:6?o0000oedOJ00:o`00
0003ohAGU?l0003oMENR00;o000000?oXM[ko`000?l000002?l00002ohYl_PKo00000oooool5o`00
00?oZ]ci00Co0000oj[LnOl0003o00000_nJY=`3o`0000Oooooo00?o0000oiRWhOl000000_nO[N40
0ol0003oooooooooo`0:ooooo`07o`000?nM/>Go0000oj>diOl0003oXkCUo`00000@ooooo`05o`00
0?nR]^OoX[KWoj:fiol000001?nU^NL00ol0003oooooooooo`0Dooooo`03o`000?nT^^WoY;[Y00;o
Y;[Y00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Iooooo`004?ooool00ol0003ooooo
ooooo`1Wooooo`co00004Oooool00ol0003oXLGboj75lP02oj75lP?oX/Gb00?o0000oik5m?l00000
0onNa_@9o`0000;ooooo1?l000000onIaOKo0000o`00000>o`000003ooooool0003o000000?o0000
00CoQ/3jo`000?n6`?[o00000_ooool7o`0000;ooooo0ol000001?m^[oSo0000of^Vm?m[Y_@2ogni
n@Co00001?n1`_`01?mYUn[o0000o`000?ooool3o`0000?oMiSU00?o0000ohR>d_n8S]801ol00000
1?nIU<go0000oiI<L_n?Cgd2o`000007ojE]TOl0003o0000oiVBbol0003oZI[7o`000002ojVKb003
o`000?nWTKkoYi6n00;oYi6n00Co0000ojNB_ol0003o]iZk0ol000000onWQJoo0000o`000004o`00
0003olBV^ol0003o000000?o00000_o7Z[d4o`000003omB`]?l0003o000000_o000000?oo=nRo`00
0?l000003?l000000ooooooo0000o`000003o`000003oel8@Ol0003oEPA400Go000000OoW=Slo`00
0?m`:6?oL2QSoedOJ?l0003oW=Sl00;o000000GoW=Slo`000?l0003o0000ooooo`02o`000004ohAG
U?l0003oPFN]oh5W[@Co00000_ooool4o`000004ooooool0003oRWbnohYl_P?o00000_n<T=85o`00
0003oi>Ie_l0003oY]_j00;o000000?oZ]cio`000?nZg?T00_l00002oiZTg003o`000?oooooooooo
00Gooooo0ol000001OnHYn7o0000oin]hOnO[N7o000000cooooo00?o0000oif`iOl000000_nS]>D2
o`00013ooooo00Go0000oj:fionR]^OoX[KWo`000004ojFii`03o`000?oooooooooo01Cooooo00?o
0000ojBjjOnT^^T00_nT^^T00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Wooooo000@
ooooo`03o`000?oooooooooo06Oooooo0_nVa>l3o`0000;oY<C`00?o0000ojC4l?nTa?000_nTa?0;
o`0000Gooooo00?o0000oj75l_nQaO800onQaO801?l0003oX/Gboj;5l_l00005ooooo`03o`000?nN
aOCoW/Gd00;oW/Gd0ol000000onNa_Co0000o`000004o`000006oi[6m_l0003oV/Ofoi[7m_l0003o
RLSl2?l000000onBaOWo0000o`000003o`0000;oRLGk00?o0000ohS4nol000001?l00002ooooo`So
00000_mX]O`4o`0000;oOkWi1Ol00002oh72o0;o000000?oJIOZo`000?l000000omgV>D2o`000003
og>:fol0003oQXoD00Oo000000?oQH[Ao`000?nIU<d00ol000000onUKI7o0000omF6N005o`0000?o
Yi6n1Ol00002ojNB_`;o000000KoX38do`000?l0003oYhF_o`000?nWQK03o`000003olBV^ol0003o
000000;oajZm2Ol00002ogimb0oo000000?oF`0=o`000?l000001_l000000ooooooo0000o`000002
o`0000;oG`Q10_l000000omF14Co0000o`000002o`0000;oW=Sl1?l000000om^=W_o0000o`000004
o`000005oj7Jnol0003oREbGooooool000000_n<IJ02oh5W[@Go000000Coooooo`000?l0003o0000
0_ooool2o`000003ohj3`ol0003oTh_800?o00000_n<T=82o`000003oi>Ie_l0003o000000Ko0000
00CoT9cKo`000?nJY=co00001?ooool3o`0000;ooooo00?o0000oiRWhOl000000_nO[N400ol0003o
ooooooooo`0:ooooo`03o`000?nM/>Go000000?oXkCU00?o0000ooooooooool03_ooool01Ol0003o
X[KWoj:fionR]^Oo000000CoYKWW00?o0000ooooooooool05Oooool00ol0003oY;[YojBjj@02ojBj
j@03o`000?oooooooooo03kooooo00?o0000ooooooooool06Oooool0013ooooo00?o0000oooooooo
ool0Ioooool00ol0003oY/C_ojK4k`02ojK4k`03o`000?nTa?3oY<C`00[oY<C`1?l000000onTa?3o
0000o`000007o`000003oj75l_l0003oX/Gb00;oX/Gb00?o0000ooooooooool03?ooool3o`000003
oik5m?l0003o000000So000000CooooooiC7nOnDaoWoRLSl1ol000001?nBaOWo0000o`000?n8a?/?
o`000004ofReo?l0003oI:ojofB_nPGo00000on1`_`01?mEV_;o0000o`000?l00002ooooo`?o0000
00?oMiSUo`000?l000000_mcR]/5o`000008oi0fE?n8=f3oR3MPo`000?ooooooQH[Ao`000?nIU<d6
o`000005oiRCc?l0003oUHO2o`000?nWT;h00ol000002OnVLYSo0000ok66Y_l0003o[XR]o`000?nW
T[oo0000okNJ^`0Ao`000003oi=l]ol0003o000000;o000000?oooooo`000?l000001ol000000oo/
b:oo0000o`000007o`000003ooooool0003o000000Go000000?oEP0Wo`000?l000000_mO24401?nF
eOgo0000o`000?mF14@3o`0000;oW=Sl00?o0000ofhTG_l000000_l000000om^=W_o0000ooooo`03
o`000005oicHo?l0003oREbGo`000?ooool00_l00002ohaUX003oh5W[Ol0003o000000Wo000000?o
ooooo`000?n>Pl<01_l000000on<T=;o0000o`000009o`000003oi2Lfol0003oVZCL00Go00001Ooo
ool00ol0003oV:OQo`000002oin]h@03o`000?oooooooooo00[ooooo00?o0000oif`iOl000000onS
]>D2o`0000oooooo00Go0000oj:fionR]^OoX[KWo`000005ojFii`03o`000?oooooooooo01Cooooo
00?o0000ojBjjOnT^^T00_nT^^T00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01Wooooo
000?ooooo`03o`000?oooooooooo06Sooooo00?o0000ojK4konVa>l00_nVa>l00ol0003ooooooooo
o`04ooooo`So00002OnTa?0=o`0000gooooo1?nLb?H2oig9mP03o`000?nFbOWo000000;oU/Wi1ol0
00000oooooooRLSlo`000006o`000003oek0oOmN_ogoG[om00Wo00000_mV^od00ol0003oI:ojo`00
0008o`0000;oPL;l1Ol00003oebGk`05o`000?mcR]_o0000o`000?ooool00_l000001OmZP]Wo0000
o`000?l0003oT3ID00;oR3MP0_l000000on5R]7o0000oiVDc@05o`0000;oUHO200?o0000oiB6`Ol0
00000_l000000onVLYSo0000ok66YP04o`000005ojNB_ol0003o]iZko`000?nYQk400ol00002okRM
_@Ko00000_nUQk@:o`000003ofihc?l0003o000001Co000000CoEP0Wo`000?l0003o00001?nFeOd0
1?mT3TGo0000o`000?l00002oicHo0Co000000Goooooo`000?l0003o0000ogQ4Q@04o`000003oicH
o?l0003oW=Sl00;o000000?oTV^Qo`000?ooool00_n<IJ02o`000003ohah^?l0003o000000?o0000
0_ooool4o`000003oiV>a_l0003o000000Wo00000onEWMT3o`000004oi2Lfol0003oVZCLo`0000Wo
oooo00Ko0000oiRWhOnHYn7o0000oin]hOl0000<ooooo`04o`000?nM/>GoWK3Uo`0000?oXkCU0_l0
000?ooooo`05o`000?nR]^OoX[KWoj:fiol000001?nU^NL00ol0003oooooooooo`0Dooooo`03o`00
0?nT^^WoY;[Y00;oY;[Y00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Iooooo`003ooo
ool00ol0003oooooooooo`1Xooooo`03o`000?nVa>ooY/C_00;oY/C_00?o0000ooooooooool03ooo
ool8o`0000;oXlKa0_nTao401?l0003oXLOcoj77lol00003oj37m0Wo00000oooool00ol0003oW<Sf
oic8mP02oic8mP03o`000?nMbOKo000000Cooooo1?nFbOT2o`000003oiK9nOl0003o000000;o0000
0_n<bO`2ohg9o0Co00000omN`?d8o`000003ofBho?l0003o000000Go000000?oPL;lo`000?l00000
0_l000001Ooooooo0000o`000?l0003oG9O_00;o000000?oEhWVo`000?m]S=l01Ol000000ooooooo
0000ohJ?e008o`000003oiVDcOl0003o000000?oUHO20ol000000onDQ/7o0000ojN@_P02o`000003
ok66Y_l0003o000000?o00000_nWT[l;o`000003olJN/?l0003oXI_?00;o000000?oYHNdo`000?l0
00005ol000000onFeOgo0000o`000008o`0000?oU]Gm0ol000001?mZ7e_o0000o`000?nLf?`2o`00
0003og/gK_oooooooooo00Oo000000Coooooo`000?l0003oW=Sl0_l000001?nBJj7o0000oooooooo
ool5o`000003ohah^?l0003o000000?o00000_ooool2o`000003oiV>a_l0003o000000?o000000Ko
Y]_jo`000?l0003oWi[?o`000?nIVM84o`0000;oUIgI2Ol00004ooooo`06o`000?nHYn7oV:OQo`00
0?nO[N7o00003?ooool01?l0003oWK3Uoif`iOl00003oj>di@;o00003oooool01Ol0003oX[KWoj:f
ionR]^Oo000000CoYKWW00?o0000ooooooooool05?ooool00ol0003oY;[YojBjj@02ojBjj@03o`00
0?oooooooooo03kooooo00?o0000ooooooooool06Oooool000oooooo00?o0000ooooooooool0Iooo
ool00ol0003oY/C_ojK4k`02ojK4k`03o`000?oooooooooo01Gooooo1OnSa_401?l0003oY<OaojC7
lOl0000:oj77l`?o000000?oX<Odo`000?l000001?l000000onLb?Ko0000oig9mP09o`0000Cooooo
0_l000000onFbOWo0000o`000007o`0000;oO/Sn1Ol000001?mN`?go0000o`000?mV__h>o`0000?o
?YOb00?o0000oeN9i_l000000ol000001?m]S=oo0000ogP35?m`12<5o`000004ohTQ=ol0003o0000
o`0000?oPh_C00Go0000oiF7`_l0003o0000ojIXR@05o`000003oiB6`Ol0003o000000co000000Go
]Y>co`000?l0003o0000ojJ7/`02o`000003okNF]?l0003o000000;o000000?oXI_?o`000?l00000
2_l000000ooGZJSo0000o`000002o`000003ofl==_l0003o000000_o000000?oH`Tmo`000?l00000
2Ol00002ofXOF`Co00000_ooool00ol0003oooooo`000003o`0000;oQ5FB00?o0000ooooooooool0
0_l000000onBJj7o0000oj7Jn`04o`000004ooooool0003oTg>/oi=c[0Oo000000CoSX?3o`000?l0
003o00000_nTfo/5o`000005oinJcol0003oooooooooool000000onIVM87o`0000?oW:SO1_l00000
0onHYn7o0000oin]h@08o`0000Gooooo00Co0000oif`iOnM/>Go00000onS]>D00ol0003oooooo`00
000>ooooo`05o`000?nR]^OoX[KWoj:fiol000001?nU^NL00ol0003oooooooooo`09ooooo`go0000
0onT^^T00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Sooooo000?ooooo`03o`000?oo
oooooooo06Oooooo00?o0000ojK4konVa>l00_nVa>l00ol0003oooooooooo`0Eooooo`03o`000?nS
a_7oXlKa00;oXlKa00Co0000ojC7lOnTao7o00002Oooool2o`0000OoXLOc1Ol00009oiW<n@Oo0000
0_n@c?`2oi7>o003o`000?oooooooooo00?ooooo00?oPLcoo`000?l000000ol000000omnb?ko0000
o`000006o`000003od6`m_l0003o000000Co00000_lSU^d2o`000003ocV9kOl0003o000000Go0000
00?oKHcOo`000?l000000_l000001?n98COo0000ohJ?e?l00003oh>;d`;o000000?oOWg8o`000?nE
Ql<00ol000000onVJ8Wo0000o`000002o`000004oiB6`Ol0003o0000ok^7WPCo00000_nXTKh2ojF7
]@03o`000?nfT[;o000000Co000000CoYXNco`000?l0003o]iJd3_l000000ooGZJSo0000o`000003
o`000003ofI/a?l0003o000000go00000_ooool6o`000006ofdKDOoooooo0000ogDUF?l0003oJQmK
0ol000001?nLf?co0000o`000?ooool4o`0000;oSe:400Co0000ohaQVol0003ooooo0ol000000onL
f?co0000oj7Jn`02o`0000Cooooo0_l000000onJP[So0000o`000003o`000004ohj3`ol0003o0000
oj?Kn`;o00000oooool2o`000004oinJcol0003o0000o`0000?ooooo0_l000001?nKW]Ko0000oj>T
eol00002oijTfPGo00001?nLZ=l3o`0000SoX;3S1ol000001?nM/>Go0000oj>diOnS]>DDo`0000;o
X[KW00Co0000ojFiionU^NOoYKWW3Ol0000=ojFjj0Co0000@Oooool00ol0003oooooooooo`0Hoooo
o`003oooool00ol0003oooooooooo`1Wooooo`03o`000?nVa>ooY/C_00oo00002_ooool00ol0003o
XlKaoj?6l@02oj?6l@05o`000?nTao7oY<OaojC7lOl000004Oooool4oio:mP;oXLcf00?o0000oooo
ooooool01OoooolGo`0000;oL/co0_med?l3o`000003o`22^ol0003o000000?o000000?o@K3fo`00
0?l000000_l00002oan=j`[o000000?oKHcOo`000?l000001ol00002ogimb0Co000000?oUHO3o`00
0?l000000_l000001_ndOi[o0000o`000?nDQ/7o0000ojN@_PCo00001?nUQkD2o`000003okJB/_l0
003o000000;o[HN^1_l000000oo6W[3o0000o`000002o`0000;ob::b1ol000000om^N<co0000o`00
0009o`000003oofoN?l0003o000000Ko000000?oooooo`000?l000001?l00003ooooo`Ko000000?o
U]Gmo`000?l000001Ol00002ooooo`;o000000?oUEf=ohaQVol000000_l000000ooooooo0000oicH
o004o`0000;ooooo0_l000000onQQ[Oo0000o`000002oiZ2^003oiF6`_l0003o000000Co00000ooo
ool01Ol0003oUI7=o`000?nOV/oo000000Kooooo00Go0000oi^Ne_l0003oXjCGo`000003ooooo`03
o`000?nNY=[oWZCJ00?oWZCJ0_l000000onLZ=oo0000o`000008o`0000OoX;3S1?l00005oj>fiP03
o`000?nS]^KoXkKV00coXkKV1_l0000=ojFjj0?o00003OnU^^P00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo01Sooooo000?ooooo`03o`000?oooooooooo06Oooooo0ol0000?ojG5l0co0000
0onSa_401Ol0003oY<OaojC7lOnTao7o0000013ooooo00?o0000oio:m_nOb_H00_nOb_H00ol0003o
XLcfo`00000:ooooo`03o`000?oooooooooo00?oU]3l0_nIdo`00ol0003oRm7noh_AoP04oh_AoPoo
00000_mA`_L6o`000003oiP?0?l0GkSo000000[o000000?oKHcOo`000?l000000omRPmd00ol0003o
OWg8o`000006o`000007oiF7`ol0003o0000o`000?nfN8ko0000omB@R@05o`0000?oYHNe0ol00000
1Oo1M7[o0000o`000?nfT[;o000000;o[HN^4Ol000001OoHYZ?o0000o`000?l0003oKWS<00[o0000
00?ooKmho`000?l000002?l000001?mV2cko0000o`000?l00003ooooo`Co000000CoQ3ISo`000?mi
=6coNCA/1ol00002ooooo`?o00000_nEGHd2o`000003oiI`Y_l0003o000000Co000000?oXM[ko`00
0?l000000_l000000onQQ[Oo0000oj7Jn`02o`0000;oVX:h0ol00002oibDb`Go000000?oWi[?o`00
0?ooool01_ooool01Ol0003oVikFo`000?nSY=Oo000000Sooooo00KoWZCJo`000?l0003oWjSMo`00
0?nU[Md3o`0000GoXZgO1_l00002oj2`haGo00001?nS]^HAo`0000coY[WW0ol000000onV^^So0000
ooooo`10ooooo`03o`000?oooooooooo01Sooooo000?ooooo`03o`000?oooooooooo06Oooooo0_nW
a>h3o`0000CoY/G_4Ol00004ojG5l0;o000000?oXlKao`000?nTao405_l000001OnOb_Ko0000oj7<
m_nQc?Ko000000_ooooo0_l00002oiK@o004o`000?nIdocoVM?lo`0000[ooooo0_moe?l2ohGJoP03
o`000?oooooooooo00ko000000?oU0d0o`000?l0GkP03Ol000000omML]3o0000oganbP03o`000004
okARKol0003o0000ogYiaP?o000000Wo^g^=o`000?l0003o0000oiB6`_l0003oT7^ho`000?nUQk@0
1Ol000001_o1M7[o0000o`000?nUR;Ko0000okJB/PGo000000?o^9Bco`000?l000002ol000000ooH
YZ?o0000o`00000Ao`000003oiKEoOl0003o000000Oo00000_ooool3o`0000;ooooo00Ko0000oh@f
Hol0003oNCA/o`000?nFeOd4o`0000;ooooo0ol00002ooooo`;o000000CoW6bJo`000?nFL:KoUW2V
0ol000001?nLf?co0000o`000?nQf_/2o`000003oj66]onQf__o000000Go00000_nOT<@3o`0000;o
W9C;0_l000000onOV/oo0000ooooo`06ooooo`05o`000?nKW]Ko0000oj>Teol000002Oooool01_l0
003oWjSMoinXgOl0003oYJgMo`0000Oooooo0ol00003oj:]g`03o`000?nS/N;o000000;oY[CR2Ol0
0009ojBdi0;o00000_nU]nH01?l0003oYkWVojNii_nW^NH;o`0000goY[WW00?o0000ojJjj?nV^^P0
0_nV^^P00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Sooooo000>ooooo`03o`000?oo
oooooooo06Sooooo00?o0000ojO4k_nWa>h00_nWa>h00ol0003oY/G_ojK5k`0BojK5k`Wo00002OnS
bO<fo`000003oh?No?oooooo000000Go000000?oooooo`000?l000001?l00002om3od@;ooooo00?o
68;Wo`000?l000000_l00002oc1gh`03o`000?mML]3oGG;@00Co000000?oO7k:o`000?nhIFd01Ol0
00000onEQl?o0000o`000002o`0000?oT7^h00Go0000oi1j]ol0003o0000ok>4XP04o`0000;o]hNS
2ol000001?nfSZco0000o`000?n7b_h4o`000003ojNSd_nSXM?ob9f[00co000000?oooooo`000?l0
00002Ol000000omZ4TGoooooooooo`07o`0000?ooooo1?l000000on4@gOo0000o`000002o`000003
oicHo?l0003o000000;o00000oooool2o`0000?oW6bJ00?oUW2Vo`000?l000001_l000000onQQ[Oo
0000o`000004ooooo`Go00000_nOT<@00ol0003oW9C;o`000005o`0000Gooooo0_l00002oj>Te`03
o`000?oooooooooo00Oooooo00Ko0000oinXgOnOZ=go0000ojF]gOl0000=ooooo`03o`000?nS/N;o
000000?oY[CR00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`05o`000?nU]nKo
YKOVojFgi_l000001?nW^NH00ol0003oooooooooo`0Dooooo`03o`000?nV^^SoY[[X00;oY[[X00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0Hooooo`003_ooool00ol0003oooooooooo`1X
ooooo`03o`000?nWa>koYlC^00;oYlC^00?o0000ooooooooool02_ooool=o`0000;oYLKa0onWb?42
o`0000[oY<Sc2?l00002oj?<m@?oYlkd00?o0000oj7>n?nQc_P01OnQc_P7o`000004oikCn_nTf?[o
Y=Sjo`0000KoV=Om1Ol000001OnBg?ko0000oi[ToOl0003ooooo00Ko000000?oW^ghojcfl?l00000
1?l000001Ooooooo0000ol?ijol0003od?oA00?ooooo1_l000000olYHmGo0000oeMce004o`000003
oe9Xbol0003o000000So00000_n@NkP5o`000003oi1j]ol0003o000000;o000000?o]hNSo`000?l0
00002_l000001_n^H7?o0000o`000?nfSZco0000olNHYP;o00000_n>d?h?o`0000;ooooo3?l00002
ooooo`Go00000oooool4o`000004ohi1JOl0003o0000ohY;O@?o000000GoW=Slo`000?l0003o0000
ooooo`03o`000003oj=aV_l0003oW=Sl00;oW6bJ0ol000000onNOk7o0000o`000003o`000004oj66
]ol0003oooooooooo`Co000000GoYY;1o`000?ooooooooooo`000003oin@a0Go000000?oXIoCo`00
0?l000000_l000000ooooooo0000o`000002oj>Te`03o`000?oooooooooo00Oooooo00Ko0000oinX
gOnOZ=go0000ojF]gOl0000=ooooo`03o`000?nS/N;o000000?oY[CR00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`07ooooo`05o`000?nU]nKoYKOVojFgi_l000001?nW^NH00ol0003ooooo
ooooo`0Dooooo`03o`000?nV^^SoY[[X00;oY[[X00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0Hooooo`003_ooool00ol0003oooooooooo`1Xooooo`03o`000?nWa>koYlC^00;oYlC^00?o
0000ooooooooool05?ooool00ol0003oYLKaojG6l@02ojG6l@05o`000?nWb?7oYlSaojO8lOl00000
4?ooool4oj?<m@04o`000?nWc_CoYlkdo`0000cooooo0onNdoX00ol0003oY=Sjo`00000:ooooo`03
o`000?nBg?ko000000?o000000?oSnShojCWnol000000_ooool01_l0003oW^gho`000?l0003oX_KR
olCdk`;ooooo1Ol00002ooooo`03o`000?oUk=Co000000Go000000GoYQh0o`000?mGLmCo0000okiL
D`08o`000004ogQjb?mcK;co0000oi1k^@Oo000000?oT7Zgo`000?nUQk@01Ol000001onVR;Go0000
o`000?l0003o]HZXo`000?noW[L00ol000001On^H7?o0000o`000?l0003o]Xj/017o000000?ofZFO
o`000?l000002_l000001OnFeOgo0000o`000?l0003ooooo00Go00000oooool3o`000003ooooool0
003o000000Co00000_nCF8L5o`000004oicHo?l0003o0000o`0000?oW=Sl00?o0000oj1dXOl00000
0ol00002oiio/@Ko00000_ooool2o`000003ojJB`Ol0003ooooo00Cooooo00?o0000oj:GbOl00000
0onSW<h4o`000005oj6Odol0003o0000o`000?nSY=L01Ol00006ooooo`03o`000?nOZ=go000000;o
YJgM00?o0000ooooooooool02oooool00ol0003oXk7Ro`000003ojJdhP03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool01Ol0003oYKOVojFgi_nU]nKo000000CoYkWV00?o0000oooo
ooooool05?ooool00ol0003oY[[XojJjj002ojJjj003o`000?oooooooooo043ooooo00?o0000oooo
ooooool05oooool000kooooo00?o0000ooooooooool0J?ooool00ol0003oYlC^ojO4kP02ojO4kP03
o`000?oooooooooo01Cooooo00?o0000ojG6lOnUa_400_nUa_401Ol0003oYlSaojO8lOnWb?7o0000
013ooooo00Go0000oj?<mOnSc?GoXlceo`000002ojO>m003o`000?oooooooooo00[ooooo00Ko0000
oikCn_nNdo[o0000ojCHn_l00005ooooo`So000000?oSnShojCWnoooool01?ooool5o`0000;ooooo
0_l000001Oo=n>So0000o`000?l0003oh^WF00;o00000_oUk=@00ooMdLgogM;<o`000006o`000005
oeMce?l0003o0000o`000?mBJ</00_l000000omhN/So0000og=/_002og=/_003og1X^_l0003o0000
00Ko000000?oT7Zgo`000?l000001?l000000onSOZ_o0000o`000002o`000003okF:Z?l0003o_ijg
01;o000000?ofInIo`000?l000001?l000001OoJYIoo0000o`000?l0003ok[>?013o000000?oMR1@
o`000?ooool01?l000001?oooooo0000o`000?n?@6L3o`000003oiYAM?l0003oTeR700Co000000?o
W=Slo`000?l000001?l000001Ooooooo0000o`000?l0003ooooo00?o000000?oWWnao`000?l00000
0_l00004ooooo`?o00001_ooool00ol0003oXYO9o`000005o`0000?oXic>1_l00003ojBYfPGo0000
00Coooooo`000?nOZ=go00000_nU[Md00ol0003oooooooooo`0:ooooo`04o`000?nS/N;oXk7Ro`00
00?oY[CR00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`05o`000?nU]nKoYKOV
ojFgi_l000001?nW^NH00ol0003oooooooooo`0Dooooo`03o`000?nV^^SoY[[X00;oY[[X00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0Gooooo`003_ooool00ol0003oooooooooo`1Yoooo
o`03o`000?nWa>koYlC^00;oYlC^00?o0000ooooooooool05?ooool00ol0003oYLKaojG6l@02ojG6
l@04o`000?nWb?7oYlSao`00013ooooo00Go0000oj?<mOnSc?GoXlceo`000002ojO>m003o`000?oo
oooooooo00Cooooo2?l000000onNdo[o0000o`000006o`0000;oXMkl00Oo0000ojSJnOl0003o0000
ojKPnonaj?So000000?ooooo2?l000000ooooooo0000olghj002o`000003ooooool0003oe^KR00;o
00000_oUk=@01?oMdLgoooooo`000?oMd/`8o`000003olIK@_l0003o000000;o00000_mcK;`3o`00
0004og1X^_l0003o0000olB=V`;o000000?o`i>Uo`000?l000002ol000001OnSOjco0000okF:Z?l0
003o_ijg00Ko000000Go]XNTo`000?l0003o0000okjR_@05o`000003olRFXol0003o000000ko0000
00?o01^Xo`000?l000001?l00002ofdA@@05ooooool0003oNR9>o`000?mf85002_l00003oiKEo@?o
00000onLIi<00ol0003oV6BBo`000004ooooo`03o`000?nPM:7o000000?ooooo1_l000000onTSKco
0000o`000002o`000003oif:__l0003o000000Kooooo0_l000000onXWL_o0000ooooo`04ooooo`;o
000000CoXic>o`000?l0003o00000_nUYmL5o`0000?oY:WJ0_l000000onOZ=go0000ojF]g@05o`00
00Wooooo00Co0000oj>ah_nS/N;o00000onV]>800ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ojFgi_nU]nKoYKOVo`000003ojNiiP03o`000?oooooooooo01Cooooo00?o
0000ojJjj?nV^^P00_nV^^P00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Oooooo000>
ooooo`03o`000?oooooooooo06Wooooo00?o0000ojO4k_nWa>h00_nWa>h00ol0003oooooooooo`0D
ooooo`03o`000?nUa_7oYLKa00;oYLKa00Co0000ojO8lOnWb?7o00002?ooool;o`000003oj?<mOl0
003oYlkd00So00000_nVd_L8o`0000;oXMkl00?o0000ojSJnOl000000_l00005ooooo`;oY^3k00?o
0000ok7Xn?l000000_l000002on_koOo0000okcUlol0003ooooookg[lol0003oc?;[o`000?o=n>So
000000Cooooo0ol000000ooUk=CogM7=ooooo`02ooooo`co000000Co@eFoo`000?l0003obgE[1Ol0
00000on@NkWo0000o`000003o`000003ohmj^?l0003oRVj]00[o000000?o]HZXo`000?l000001Ol0
00000on7b_ko0000okJ7Y002o`000003ohk@o_l0003o_Z:m00go000000CofYnGo`000?l0003o0000
0_ooool00oo][HSo0000o`000005o`0000;oU]Gm2?l000000onFeOgo0000o`00000=o`000004oiaW
Tol0003o0000o`0000Cooooo1_l00002ooooo`?o000000GoYhVeo`000?l0003o0000ojB=_006o`00
00?ooooo00Go0000oj:GbOl0003oZ9g;o`000008ooooo`;o000000?oZJODo`000?l000001?l00000
1?nUYmOo0000o`000?l00002ojBYfP?o00001OnU/N07o`0000;ooooo00Co0000oj>ah_nS/N;o0000
0onV]>800ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00Go0000ojFgi_nU]nKo
YKOVo`000003ojNiiP03o`000?oooooooooo01Cooooo00?o0000ojJjj?nV^^P00_nV^^P00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01Oooooo000=ooooo`03o`000?oooooooooo06[ooooo
00?o0000ojO4k_nWa>h00_nWa>h00ol0003oooooooooo`09ooooo`oo000000?oYLKao`000?nWb?40
2_l00003ojO;lP_o00000_nVd_L6o`0000GoZ=3e0ol000000onXe?Oo/=Wfok3ImP02o`0000Oooooo
0ol000000onVh?_o0000o`000002o`000003okcUlol0003ooooo00?ooooo00?o0000okg[lol00000
0_l00005ooooo`Co00001Oooool6o`0000;o04G600Go0000od=E_ol0003o0000ocQ9^@04o`000003
olnOY_l0003o000000So000000?oRVj]o`000?nSOJ/01Ol00002oj=nZaOo000000?of9ZAo`000?l0
00004_l00002oiKEo@Go000000?oR2e>o`000?n2;eX01_l00003ooooo`?o00000oooool:o`000003
ojUoY_l0003ooooo00?ooooo00Ko0000ojJ4[ol0003o0000ooooool00003ojN9]@Co00000_nXVLH4
o`000003oj:GbOl0003o000000Wooooo0_l000000onYYmCo0000ooooo`05ooooo`?o000000?oYJOG
o`000?l000002ol00003ojFah0Ko000000?oY[CRo`000?l000002_l000000ooooooo0000ooooo`04
ooooo`05o`000?nU]nKoYKOVojFgi_l000000onW^NH00ol0003oooooooooo`0Dooooo`03o`000?nV
^^SoY[[X00;oY[[X00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Gooooo`003Oooool0
0ol0003oooooooooo`1Zooooo`03o`000?nWa>koYlC^00ko00001?nWa^l>o`0000?oYl_b1ol0000:
ojS9l@03o`000?nXc??o[Lob00;o[Lob00Co0000ojS@mOnXd?GoZ=3e0ol00006ooooo`08o`000?nX
e?OoZ=Cgo`000?n`fOKo0000ooooool00003ooooo`?o00000_n`goL5o`0000Kooooo1?l000000ooE
hN3o0000ooooo`03ooooo`;o000000CodloFo`000?oMd<co00000oooool02Ol0003og]7<o`000?l0
003of;Zko`000?n?6@3o0000o`0[]003o`000003olVV]Ol0003oLFfn00[o000000?o_XfRo`000?o9
SYH01_l00002oj=nZ`Go000000?o]8BQo`000?l00000<Ol000001On<?6?o0000o`000?nLDgKo0000
00?ooooo0ol00004ooooo`05o`000?nWJH_o0000o`000?nYLY@00_l000001?nVN:3o0000o`000?l0
0005ooooo`;o000000?o[Hbbooooooooool00oooool00ol0003oZY6lo`000002ojZF`P?o00000_nX
VLH01?l0003oXYO9o`000?l00009ooooo`;o000000?oZJODo`000?ooool02Oooool00ol0003oYZ_J
o`000002ojZ_f`;o00001_nW[mh6o`0000;oYK7P1ol00007ojJfi0Wo00000_nU]nH00ol0003oYkWV
ojNiiP0>o`0000[ooooo00?o0000ojJjj?nV^^P00_nV^^P00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo01Oooooo000=ooooo`03o`000?oooooooooo06[ooooo0ol00004ojO6k`[o00003?nX
aNh3o`000004ojS7l?n[bNooZlW_oj_9k`;o00001?nXbO4=o`0000;oZ<cc00Co0000ojg?l_n]co;o
00003?ooool02?l0003oZ=CgojSDmonXe?Oo0000ok3Im_l0003ooooo0ol000000on`goOo0000o`00
0003o`000004okKMm?l0003o`^?_o`0000?ooooo1ol00002omGQh003o`000?oooooooooo00;o0000
00_odloFooooool0003o0000omg@c?l0003oooooo`000?oNdLco0000om>l``02o`000003omRj^ol0
003o000000_o000000CoKVVlo`000?l0003oRfn^0_l00002ooooo`03okj=X_l0003o000000So0000
00?oooooo`000?nQMj@02_l000000ondPIgo0000o`00000Po`000003ooooool0003o000000[o0000
00Coooooo`000?l0003o00001?ooool00ol0003oYfV;o`000004o`0000;oZG:D1_l00002ooooo`03
ojJ4[ol0003o000000Gooooo00?o0000ojZA_?l000001?l000000onZU/;o0000ojRIaP06o`0000Ko
oooo0_l00002ojVWe003o`000?oooooooooo00Sooooo00?o0000ojJ[f_l000000_nZ[m/00ol0003o
ooooooooo`05ooooo`;o00000onW[mh2o`000004ojNbhOl0003oZKGQo`0000CoYkGS2_l00006ojJf
i0Go00003_nW^^L<o`0000?oY[[X00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Goooo
o`003Oooool00ol0003oooooooooo`1Zooooo`;oZLG]0ol0000>ojS5kP[o00001?nXao001Ol0003o
ZlW_oj_9kon[bNoo0000013ooooo00Oo0000ojS<lonXc??oZ<cco`000?n]co;o000000gooooo00?o
0000ojSDmonXe?L01?l000001?n`goOo0000o`000?nefO82o`0000;ooooo00Go0000okKMm?nfgOCo
0000ol;Sk`03o`00000<olCYkol0003oam[Wo`000?oooooo0000olWMj?l0003oeN7Po`000?oooooo
00000_oCcmH3ooooo`;o000000KogM3<o`000?oNdLco0000om>l`ol00002ooooo`[o000000CoLFfn
o`000?l0003oJ5Z_0ol000000on;Kjko0000o`000006o`000004oj5gY?l0003oaZ>eolJS]B3o0000
00?oJWO=o`000?l000003Ol00003oooooa7o00001?ooool3o`0000Gooooo0_l000000on_PjGo0000
o`000002ojf7[@;o000000?oYXB_o`000?l000001Oooool2o`000003ojnG__l0003ooooo00?ooooo
1ol000000onZXm3o0000o`000003o`000003ooooool0003o000000;oZJOD00?o0000ooooooooool0
2?ooool00ol0003oYZ_Jo`000002ojZ_f`03o`000?oooooooooo00[ooooo00Co0000ojNbhOnW/^7o
00000_nY]N49o`0000GoYkGS00?o0000ojNehonW]N<00ol00002ojJfi17o00003?nW^^L4o`0004Co
oooo00?o0000ooooooooool05_ooool000gooooo00?o0000ooooooooool0J_ooool00ol0003oZLG]
ojW5k@02ojW5k@03o`000?nXaNkoZ<G^00;oZ<G^1ol0000;ooooo`03o`000?nXao3oZ<O`00?oZ<O`
00Co0000oj_9kon[bNoo00004?ooool01Ol0003oZ<ccojS<lonXc??o000000;o[Lob00?o0000oooo
ooooool01oooool7o`000006ok3Omol0003o0000okGIl_oooooo00001_ooool02?l0003o]]gdo`00
0?o2hnoo0000olCYkol0003oam[W1Oooool01Ol0003obMgXo`000?oEhN3o000000;odloF1Oooool4
o`000003om>l`ol0003ooooo00?ooooo2?l000000olaBkco0000o`000002o`000003olbS[_l0003o
IEJ/00Co000000GoQfFUo`000?oooooo0000ohMUY@02o`000004olnMY?l0003o0000o`0000;oXGNT
;?l000000ooooooo0000o`000003o`000004ooooool0003o0000o`0000Cooooo1Ol000000on/K8Wo
0000o`000005o`0000Gooooo00?o0000okF4X?l000000_l000000on_PjGo0000ojf7[@05o`0000?o
oooo00Go0000ojZA_?l0003o[iNno`000006ooooo`;o000000?o/:79o`000?n[XLd01?l00002ojZS
d0?o000000?oZJODo`000?l000000ol00006ooooo`04o`000?nVZm[oYZ_Jo`0000;oZZoK00?o0000
ooooooooool02_ooool00ol0003oYk;Qo`000003ojVeh@03o`000?oooooooooo00Oooooo1_l00002
ojNeh`;o00000_nW^>D00ol0003oZKWUojVii@05o`0000WoYk[V2ol00004ojNji`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool05_ooool000gooooo00?o0000ooooooooool0Joooool01Ol0
003oZLG]ojW5kOnYaNgo000001Oooooo00?o0000ojS7l?nXao000_nXao001?l0003oZlW_oj_9kol0
000Aooooo`04o`000?nXc??oZ<cco`0000;o[Lob00?o0000ooooooooool01ol000000on]doCo0000
o`000002ok3?l005o`000?nienoo^MO_okWGkol000000oooool00ol0003oooooooooo`03ooooo`Ko
00001oooool6o`0000Kooooo1Ol00004ooooo`So000000Oo<D^lobLeZol0003o0000olVV]Ol0003o
c:>^00oo000000?ocifTolJS]Ol000008Ol000000ooHTHCo0000o`00000>o`000004ooooool0003o
YTUGo`0000Kooooo0ol000001On]GgCo0000o`000?l0003o[6b900;o000000?o/GF@o`000?ooool0
0oooool2o`000003okF4X?l0003ooooo00;ooooo1_l000000on`TkWo0000o`000002o`000003ojZA
_?l0003o000000Oooooo0_l000001On`XLWo0000oooooooooooo000000CoZj7=00?o0000ojZSd?l0
00000ol00003oj^[f0Go000000Coooooo`000?nVZm[o00000_nZ[m/00ol0003oooooooooo`0;oooo
o`03o`000?nW/^7o000000?oZKGQ00?o0000ooooooooool03?ooool01?l0003oooooooooool00003
ojNhi@CoZKWU00?o0000ooooooooool02_ooool4o`0000KoYk[V0ol00002ojNki`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool05_ooool000cooooo00?o0000ooooooooool0K?ooool00ol0
003oZLG]ojW5k@02ojW5k@03o`000?oooooooooo01Cooooo00?o0000ojS7l?nXao000_nXao001Ol0
003oZlW_oj_9kon[bNoo0000013ooooo00Co0000ojS<lonXc??oZ<cc1Ol00003ojgCm003o`000?n`
co3o/<o`00;o/<o`1?l00002ok7ClP;o^MO_00?o0000ooooooooool00_ooool00ol0003oooooo`00
0004o`000004okgBj_l0003obMWUo`0000Kooooo00Oo0000ol_KiOl0003obLcMo`000?oCcmGo0000
00Gooooo00Ko0000omC?eOl0003o0000ol^mcOoC_<@4o`0000;ooooo0_l000002?o5Z[ko0000o`07
V_l0003o9cF[ooooool0003oIeba0ol000000omTF:ko0000o`000002o`000005om:JV_l0003o0000
o`000?n7IJD00_l000000onNKico0000o`00000Ao`000003ok9gTOl0003o000000So000000?oaHF>
o`000?l000001Ol00002omRAQ0Go000000?ojIQ^o`000?l000002?l000000onVBEOo0000ooooo`05
ooooo`;o000000Co/f1/o`000?oooooo00000_n]Gg@7o`0000;ooooo00?o[WfNo`000?l000001Ooo
ool01Ol0003o/Xb^o`000?l0003o/I6d00?o000000?o/9>io`000?l000001?l00004ooooo`05o`00
0?n/WLSo0000ok2QbOl000001_ooool00on[XLgo0000ojbWdP02o`0000;oZj[F1Ol00003oj^[f0;o
000000GoYZ_Jo`000?nZ[m_oZZoKo`00000<ooooo`04o`000?nW/^7oYk;Qo`0000?oZKGQ00?o0000
ooooooooool03Oooool00ol0003oooooo`000002ojNhi@03o`000?nY^NGoZKWU00;oZKWU00?o0000
ooooooooool05?ooool00ol0003oYk_WojNki`02ojNki`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool05_ooool000cooooo00?o0000ooooooooool0K?ooool00ol0003oZLG]ojW5k@02ojW5
k@03o`000?oooooooooo01Cooooo00?o0000ojS7l?nXao000_nXao001Ol0003oZlW_oj_9kon[bNoo
000000cooooo2Ol00002ojgCm0Ko/<o`1?l00003ooooo`04o`000?nado;o/M?bo`0000;o^MO_00Co
0000oooooooooooooooo1?l000002?nmd^[o0000o`000?l0003o_]G[o`000?o9fNGo00000oooool4
o`000006olW<gOl0003o0000o`000?oCcmGo00000oooool01?l0003oe<oEomC?eOo<_L`5o`0000?o
oooo0_l000000oo7Zkgo0000olFZ_P03o`0000;ooooo00CoIebao`000?l0003oGT^S0ol000000on7
IZGo0000o`000002o`000003oh=MW_l0003o000001Go000000?o/WNAo`000?l000005ol000001OoY
V6ko0000o`000?l0003okXdj00oo000000?o/f1/o`000?ooool01?ooool3o`000003okIiT?l0003o
000000Co000000?o]HBPo`000?ooool01?ooool2o`000005okNA[ol0003oooooooooool000000_na
TK@5o`000005ok6Na?l0003o0000o`000?ooool00_l000000on`XLWo0000ooooo`07ooooo`04o`00
0?n/Ym;o0000ojnZdPGo00000_n[Z]H7o`000003ojZ_fol0003o000000Oo00001Oooool01?l0003o
Yk;QojNbhOl00002ojVeh@03o`000?oooooooooo00oooooo00Go0000ojNhiOnW^>GoYkSUo`000003
ojVii@03o`000?oooooooooo01Gooooo00Go0000ojNkionW^nOoYk_Wo`000015ooooo`03o`000?oo
oooooooo01Kooooo000<ooooo`03o`000?oooooooooo06cooooo00?o0000ojW5kOnYaNd00_nYaNd0
0ol0003oooooooooo`0Eooooo`05o`000?nXao3oZ<O`ojS7l?l000000on[bNl01?l0003ooooooooo
ooooool=o`0000;o[LW^00?o0000ojg;koncc^h00_ncc^h00ol0003o/<o`o`00000;ooooo`05o`00
0?nado;o/M?bo`000?nienl01Ol000001?nmd^[o0000o`000?l00002ooooo`0;o`000?nneN_o_]G[
o`000?o9fNGo0000ooooool0003obm_Uo`000?o9c=d00_l000002?oooooo0000olW=gOl0003odloE
o`000?oooooo00000_oDcmD3o`000003ooooooo;_Lgobkg=00;o000000Goooooo`000?l0003oaj^m
o`000002ooooo`Ko000000OoGT^So`000?oNV8Go0000ok^F/OmKAj3oQfJU00ko00000_nMJYHEo`00
00KoN]?o0ol000000omjdoooKlWoofo9o`03o`0000;oKlWo5ol00004ooooo`?o00000_ooool00ol0
003o]WV@okIiT006o`0000;ooooo00Go0000ok:<[_l0003o]i6_o`000005ooooo`?o00000_nbW<47
o`000003ok2QbOl0003ooooo00Oooooo0_l00002ojnZdP03o`000?oooooooooo00?ooooo0ol00000
0on[Z]Ko0000o`000007o`0000GoZ[;N1_l00002ojNbh@04o`000?nY]N7oZKGQo`00017ooooo0_l0
00000onW^>Go0000ojVii@03ojVii@03o`000?oooooooooo01Cooooo00?o0000ojNkionW^nL00_nW
^nL00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Kooooo000<ooooo`03o`000?oooooo
oooo06gooooo00?o0000ojW5kOnYaNd00_nYaNd00ol0003oooooooooo`0@ooooo`So000000?oZ<O`
o`000?n[bNl02_l00005ojg9kPGo00000on]bnl2ok?>kP03o`000?oooooooooo00_ooooo00Go0000
ok7Cl_nado;o0000okWGk`03o`000005okgBj_l0003o0000ooooool000001?ooool00ol0003o_]G[
o`000002olWIi@?o000000?obLcMo`000?ooool00oooool01?l0003obLgMo`000?oCcmD5o`0000Co
oooo00?o0000ol^mcOl000000_l000000oo7Zkgo0000ooooo`03ooooo`So000000?oooooo`000?l0
00004_l0000Gog[Co`?o00001?mjdol5ofo9o`;o00002om_bOlBo`0000Kooooo2Ol000000onbS:ko
0000o`000006ooooo`?o00000_ooool00ol0003o/Yc1ok:L`@02ok:L`@So00000oooool00ol0003o
[:OBo`000002ojnZdP03o`000?oooooooooo00Oooooo00Go0000ojb_f_n/[m[o0000ojjafP02o`00
00;oZk7M2Ol00002ojZbgP;o000000?oZKGQo`000?l000001Ol0000=ooooo`04o`000?nW^>Go0000
o`0000CoZKWU00?o0000ooooooooool05?ooool00ol0003oYk_WojNki`02ojNki`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool05_ooool000cooooo00?o0000ooooooooool0KOooool00ol0
003oZLG]ojW5k@02ojW5k@03o`000?oooooooooo00Wooooo1ol00005oj[6kPSo00002?n]bNh5o`00
00Cooooo00Go0000ojg;kon]bnoo[L__o`000002ok?>kP03o`000?oooooooooo00Wooooo2Ol00005
ooooo`05o`000?ooooooooooooooool000000_nneN/00ol0003obMWUo`000002olW<g@03o`000?oo
oooooooo00Cooooo1?l000000ooDcmGoc;g<olbmc006ooooo`03o`000?o;_Lgo000000?o00000_oo
ool<o`0001ooN]?o2ol00006og[Co`03o`000?m_bOooKlWo00GoKlWo00?o0000ofo9oom_bOl04om_
bOl;o`0000;ooooo0ol00002ooooo`[o00000_ooool2o`000003okNL_Ol0003ooooo00Cooooo0_l0
00000oncXlSo0000o`000009o`000004ojbWd_l0003o[j[Bo`0000[ooooo00?o0000ojb_f_n/[mX0
0_n^/MX01?l0003oooooooooooooool3o`0000KoZk7M2_l00002ojVgh`Wo00000oooool00ol0003o
YkSUojNhi@02o`0000?oZKWU00?o0000ooooooooool05Oooool01Ol0003oYk_WojNkionW^nOo0000
04Oooooo00?o0000ooooooooool05Oooool000cooooo00?o0000ooooooooool0KOooool00ol0003o
ZLG]ojW5k@02ojW5k@03o`000?oooooooooo00;ooooo1ol00004oj[6kPSo00000_n[aNd00ol0003o
ZlK^ojk8k@02ojk8k@;o00000_n]bNh00ol0003oooooooooo`0<ooooo`04o`000?n]bnoo[L__o`00
00;o/lk^00?o0000ooooooooool01?ooool8o`000005okK<jol0003o0000okoAj?l000001oooool0
0ol0003oooooooooo`07o`0000Gooooo2Ol00007ooooo`Wo000000?oR]gno`000?mjdol00_mjdol5
o`00013oN]?o6_l00007og[Co`03o`000?m_bOooKlWo00GoKlWo00?o0000ooooool000002_l0000D
ofo9oaKo00001oooool01?l0003o/j?8okJUb?l00002ooooo`;o000000?o/ZK<o`000?l000000ol0
00000on_Z];o0000o`000003o`0000Kooooo00Co0000ojb_f_n/[m[o00000_n^/MX00ol0003ooooo
ooooo`08ooooo`06o`000?n[/Mgo0000o`000?n[]N3o00000_n/]^001?l0003oZ[ORojZgh_nZ]n8C
o`000003ojViiOl0003o000000Oo00004Oooool01Ol0003oYk_WojNkionW^nOo000004Oooooo00?o
0000ooooooooool05Oooool000cooooo00?o0000ooooooooool0KOooool00ol0003oZLG]ojW5k@02
ojW5k@Go00000onZa^h8o`0000WoZlG]00Co0000oj_6k_n[a^koZlK^0on^b>d00ol0003ooooooooo
o`0?ooooo`07o`000?n]bnoo[L__ojg;kol0003o/lk^o`000002ooooo`Co000000?o]=7_o`000?l0
00000_l00002okK<j`;o00000_ngc^`00ol0003o_m7Xo`000007ooooo`;o000000Go`=?Xo`000?l0
003o_lWRo`000002olW<g003o`000?oooooo000000;o00000_ooool02?l0003ob/gLo`000?o5_mCo
0000olBne?o<_/go00001?ooool5o`0000CoR]gn00Go0000oh[Mo_n:gOkoR]gno`000007og[Co`;o
00001?mjdol8o`000003oooooon]Q:Wo000000Co000000?oV5b8o`000?l000002_l000000onoKG3o
0000o`000005o`0000OoN]?o00?o0000ofo9oom_bOl01Om_bOl5o`000003ooooool0003o0000017o
00004om_bOl?o`0000;ooooo00Go0000ok>Sb?l0003o]ZG8o`000007ooooo`03ok:Vc?l0003o0000
00Co00000_n`[mL5o`000007ooooool0003o[:oJojb_f_l0003o[[7Jo`00000=ooooo`04o`000?n[
]N3oZkGPo`0000?o[;KP00?o0000ooooooooool00_ooool2o`0000SoZ[OR2ol00006ojVkiP_o0000
1Oooool00ol0003oYk_WojNki`02ojNki`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
5Oooool000_ooooo00?o0000ooooooooool0Koooool<o`0000_oZlG]1_l00004oj_6kP05o`000?n^
b>go[/S]ojk8kOl000004?ooool01Ol0003o[L__ojg;kon]bnoo000000;o/lk^0_l000000onddNoo
0000o`000002o`0000?o]/c[0ol000001Ooooooo0000okO>k?ngc^co000000;o_m7X00?o0000oooo
ooooool00_ooool2o`000004ol3Cj?l0003o0000oko9hP;o000000?o`<[Ro`000?l000000_l00003
ooooo`Co000000?oaKoDo`000?l000000_o4_]@00oo<_/go0000o`000002o`0000SoR]gn00?o0000
oh[Mo_n:gOh00on:gOh00ol0003oN]?oog[Co`05og[Co`Oo000000?oNdf?o`000?md?X400_l00000
0ooooooo0000o`00000<o`000003ooooool0003o000000;o000000CoZf9io`000?l0003ooooo1_l0
0006og[Co`03o`000?m_bOooKlWo00CoKlWo2Ol000000ooooooo0000o`000005o`0000;ooooo0_l0
00000oo:L6Go0000o`00000;o`0000OoKlWo1_l000001?m[`Oko0000of_1o_m[`Oh;o`000003ok>S
b?l0003o000000Wooooo0_l000001?nc[M;o0000o`000?n`[]H;o`000003ojjaf_l0003o000000?o
00002_ooool00ol0003oZkGPo`000003ojbfh003o`000?oooooooooo00_ooooo00?o0000ojZgh_nZ
]n800_l00002ojZii004o`000?n[^^Go0000o`0000;oZK[V2ol00006ojVkiPOo00000onW^nL00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo01Gooooo000;ooooo`03o`000?oooooooooo06oo
oooo1?l0000:oj_5k@Wo00001Oooool00ol0003oZlK^oj_6kP02oj_6kP05o`000?n^b>go[/S]ojk8
kOl000004Oooool01Ol0003o[L__ojg;kol0003o/lk^00Co00001Onfc>/2o`0000Gooooo00Co0000
okO>k?ngc^co00000_nodNP00ol0003oooooo`000004o`000004oko9h_l0003o0000ooooo`Co0000
0_o9c=`01Ol0003oooooo`000?o:cMco000000;oaKoD1_l00009oh[MoP?o00001on:gOh00ol0003o
N]?oog[Co`05og[Co`Co000000GoNdf?o`000?l0003o0000og@nP@07o`0000;oV5^700Co0000oi9=
N?l0003oZemg0ol00002ooooo`07o`000?o6aMWo0000o`000?n[HWWo0000okm]L006o`0000KoN]?o
00?o0000ofo9oom_bOl01Om_bOl00ol0003oooooo`000004o`000004onR1<_l0003o0000ooooo`Oo
00000_ooool3o`0000?ooooo00?ob7Ugo`000?l000000_l00003olEiO0So00001?m_bOl01Ol0003o
Jl7nof_1o_m[`Oko000000GoJl7n0ol000000ooooooo0000o`000009o`0000?ooooo00Go0000ok:[
d_l0003o/jgBo`000006ooooo`;o000000?o/:kFo`000?l000001Ol00003ojjdg@Oo00000_ooool0
1?l0003oZkGPoj^eh?l00003ojbfh003o`000?oooooooooo00kooooo00Go0000ojZii?nZ^NCoZ[WT
o`000002oj^ji@03o`000?n[^^Go000000Go00001_nY^^H;o`0000;oZK_V0ol00018ooooo`03o`00
0?oooooooooo01Gooooo000;ooooo`03o`000?oooooooooo06oooooo00Co0000ojc5k?n/aNco[<G/
0ol00002oj_5k@?o00004Oooool00ol0003oZlK^oj_6kP02oj_6kP05o`000?n^b>go[/S]ojk8kOl0
00003Oooool:o`0000Co]/c[0_l00009ooooo`04o`000?ngc^co]lk/o`0000;o_m7X0ol00002oko9
hPGo00000_ooool00ol0003o`<[Ro`000002olW<g0Oo00002On:gOh5o`0000;ooooo00?o0000oh[M
o_n:gOh01_n:gOh00ol0003oN]?oog[Co`05og[Co`_o000000CoV5^7o`000?nBCGSoTTeh0ol00000
0onBCGSo0000oj]OM`03o`000003ooooool0003o000000Go000000?o_fe`o`000?l000001?l00006
og[Co`03o`000?m_bOooKlWo00GoKlWo0_l00003ooooo`03o`000?oPL1ko000000_o00000_ooool3
o`0000Cooooo00?o0000olZ4QOl000000_ooool5o`0000OoKlWo00?o0000of_1o_m[`Oh00om[`Oh0
0ol0003oJl7nof_1oP05of_1oPGo000000?o^ZS8o`000?l000002Ol000000onc[M;o0000ooooo`0:
ooooo`04o`000?n`/][o0000ok6cfPSo00001?n^]=d3o`0000;oZkGP00Go0000ojbfh?n/]^3o[;KP
o`00000@ooooo`04o`000?nZ^NCoZ[WTo`0000CoZk[U0_l00006ooooo`Ko00002_nY^^H5o`0004So
oooo00?o0000ooooooooool05Oooool000_ooooo00?o0000ooooooooool0L?ooool00ol0003o[<G/
ojc5k002ojc5k003o`000?oooooooooo01Cooooo00?o0000oj_6k_n[a^h00_n[a^h01Ol0003o[/S]
ojk8kOn^b>go000000Sooooo2_l000000on`an_o0000o`000002okO;j@?o00003?ooool01Ol0003o
]lk/okO>k?l0003o_m7X00;o00000_nobN84o`0000;ooooo00Ko0000ooooooooooooooooo`000?o0
b^84o`0000WoR]gn1_l000000oo3[lKo0000ooooo`04ooooo`03o`000?n:gOkoR]gn00KoR]gn00?o
0000og[Coomjdol01Omjdol01?l0003ohjjNo`000?ooool9o`0000?ofkNd00?o0000oi9=N?l00000
4ol00006og[Co`03o`000?m_bOooKlWo00GoKlWo0_l00003ooooo`?o000000?oooooo`000?l00000
2Ol00002ooooo`03o`000?o:L6Go000000?ooooo0ol00004ooooo`;o00001_m_bOl2o`0000KoJl7n
0_l0000:of_1oPCo000000?oooooo`000?l000000_l000000onfZ/go0000o`000006o`0000Oooooo
00?o0000ok2bf_l000000_na/mX01?l0003oooooooooooooool3o`000003ojjdgOl0003o000000Co
000000Co[[CMo`000?l0003o[;KP1ol0000<ooooo`05o`000?nZ^NCoZ[WTojZii?l000001?n[^^D2
o`00017ooooo0_l00002ojVjiP?o00000_nY_>L00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo01Gooooo000;ooooo`03o`000?oooooooooo073ooooo00?o0000ojc5k?n/aN`00on/aN`00ol0
003oooooooooo`0Dooooo`03o`000?n[a^koZlK^00;oZlK^00Co0000ojk8kOn^b>go00000oooool:
o`0000?o/<O[0ol00002ok78k004o`000?ngbnWo]l_Yo`0000gooooo2_l00006ooooo`Go00002?n:
gOh5o`000003ooooool0003o000000Go00001_ooool00ol0003oR]gnoh[MoP06oh[MoP03o`000?mj
doooN]?o00CoN]?o1ol000000onBCGSo0000o`000002om^g]1;o000000?oY4iSo`000?niFUT00ol0
00000ooooooo0000og[Co`05og[Co`03o`000?m_bOooKlWo00CoKlWo0_l000000ooNNDOo0000o`00
0002ooooo`03omigAOl0003o000000;ooooo2_l000001?oooooo0000o`000?l00003ooooo`;o0000
00?obXB5o`000?ooool00_ooool00ol0003oKlWoofo9o`04ofo9o`03o`000?m[`OkoJl7n00GoJl7n
1_l0000;of_1oPCo000000Koooooo`000?l0003o]ZoBo`000?nf/=89o`0000;ooooo00?o0000ok2b
f_l000000_na/mX00ol0003oooooooooo`08ooooo`03o`000?n^]=go000000Oo00001?n/^N<9o`00
00?ooooo00Go0000ojZii?nZ^NCoZ[WTo`000004oj^ji@03o`000?oooooo000001Cooooo00Go0000
ojVlionY_>OoZKcWo`000019ooooo`03o`000?oooooooooo01Gooooo000;ooooo`03o`000?oooooo
oooo077ooooo00?o0000ojc5k?n/aN`00_n/aN`00ol0003oooooooooo`0Dooooo`03o`000?n[a^ko
ZlK^00;oZlK^00?o0000ojk8kOn^b>d01?l000000on_b^ko0000o`000002o`0000Go/<O[0ol00002
ooooo`05o`000?nab>co/LS/ok78k?l000000_ngbnT00ol0003oooooooooo`07ooooo`Ko000000Ko
^<KUo`000?l0003o0000ol39hOl00002ooooo`Go00002?n:gOh5o`0000Gooooo00Ko0000olBoeOl0
003o_k??o`000?nm//l2ol>ab003o`000?oooooooooo00?ooooo0_l00008oh[MoP03o`000?mjdooo
N]?o00CoN]?o00?o0000of/]Kol000000ol000000onBCGSo0000o`000007o`000003ohLfGol0003o
XdaO00?o000000?ob/CDo`000?n1Di400_l000001Ooooooo0000ojA>Hol0003o^EYI00Go00001_mj
dol00ol0003oKlWoofo9o`04ofo9o`[o00000_ooool;o`000003om5T??l0003o000000[o00001_m_
bOl00ol0003oJl7nof_1oP05of_1oP?o000000Goa:Rmo`000?l0003o_jS3ol:P]`04o`0000[oJl7n
0ol000001?nf[m;o][3BokJ`d_l00003ooooo`So000000Co/;;Jo`000?na/m[o00003Oooool01?l0
003o[KOPojfgh?l00002ojjhh003o`000?n/^N;o000000Oo00001On/^N<5o`0000;oZ[WT00?o0000
oj^jiOn[^^D00_n[^^D00ol0003oooooo`00000Cooooo`03o`000?nY_>OoZKcW00;oZKcW00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0Dooooo`002_ooool00ol0003oooooooooo`1boooo
o`03o`000?n/aNco[<G/00?o[<G/00?o0000ooooooooool04Oooool8o`000003ojk8kOl0003o0000
00Co00001_n`an/2o`0000Oooooo00Go0000ok78k?nab>co/LS/o`000002okO;j@03o`000?oooooo
oooo00?ooooo1_l000001?nha^Go0000o`000?l00002okS7i@Go00002On:gOh4o`000004okfofoo5
`=GoaL3Eo`0000Gooooo00?o0000olBoeOl000000_no/ll01_l0003o_K;?okfbcol0003o`k78o`00
00?ooooo00Co0000ol6`bOl0003o00001on:gOh00ol0003oN]?oog[Co`05og[Co`03o`000?oT/J3o
iKJT00Oo00000_n7=Eh3o`000003ohLfGol0003oXdaO00?o000000Cob/CDo`000?l0003o00000_oo
ool2o`000004ojA>Hol0003o^EYIo`0000;ooooo00?o0000og[Coomjdol00omjdol00ol0003oKlWo
ofo9o`05ofo9o`?o000000?odelVo`000?l000001?l00003ooooo`So000000CodEXNo`000?l0003o
hh]R0_l00004omZBPP03o`000?oBV9So000000OoKlWo00?o0000of_1o_m[`Oh01Om[`Oh00ol0003o
ooooooooo`02olBX_@;o00001?ooool00onoZ<?o0000o`000003o`0000WoJl7n1_l00006ooooo`[o
00002_ooool00ol0003o[KOPo`000003ojjhh003o`000?oooooooooo00;ooooo0ol00002ojbihPSo
00000_n/^N<2o`0000;oZk[U1ol0000Booooo`05o`000?nY_>OoZKcWojVliol00000Boooool00ol0
003oooooooooo`0Dooooo`002_ooool00ol0003oooooooooo`1cooooo`03o`000?n/aNco[<G/00;o
[<G/00?o0000ooooooooool03?ooool5o`0000Ko[<K]1_l00006ok37j`03o`000?oooooooooo00[o
oooo00Co0000ok78k?nab>co00000ongbnT00ol0003oooooo`000002o`000004okS=j_l0003o0000
okS6i@Wo00002On:gOh3o`000005okk0fol0003oooooooooool000000_nm_m/00ol0003oaL3Eo`00
0003ooooo`03o`000?o4_mGo000000;o_k??0oooool2okfbc`08o`000?o3/LSo0000ooooool0003o
`K39o`000?njY<<2o`0000OoR]gn00?o0000og[Coomjdol01Omjdol7o`0000Cooooo0ol000001On7
=Uoo0000oj=<Gol0003oiM3200;o000000?ob/CDo`000?l000002_l00006og[Co`03o`000?m_bOoo
KlWo00GoKlWo00?o0000ooooool000000_l000000ooooooo0000o`000004o`000003ooooool0003o
0000013o000000?ogiR2o`000?m_bOl01Om_bOl2o`0000OoJl7n00?o0000olRU]_l000002?l00003
ooooo`03okn^bOl0003o_Zk900Go00002Om[`Oh7o`0000;ooooo00?o0000ok:df_l000000_nc]MX;
o`0000;ooooo00Co0000ojfgh?n]]n3o00000on^^>000ol0003oooooooooo`0;ooooo`03o`000?n/
^N;o[;WR00Wo00001OnZ_>H7o`0000[ooooo00?o0000ojVlionY_>L00_nY_>L00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo01Cooooo000:ooooo`03o`000?oooooooooo07?ooooo00?o0000
ojc5k?n/aN`00on/aN`00ol0003oooooooooo`06ooooo`Go00001_n/a^d5o`000003ojg4jol0003o
000000?o/LOZ0_l000000on`an_oooooooooo`0>ooooo`05o`000?nab>co/LS/ok78k?l000000ong
bnT00ol0003o^<gZo`000009o`0000[oR]gn0_l000001?o1bN7o0000okk0fonn`=/3o`0000?ooooo
00[o0000okfofonm_m_o0000olG0eOl0003oooooo`000?o4_mGo00000_no/ll5ooooo`09o`000?nm
//oo0000ol>ab?l0003o`K39o`000?njY<?o000000;ooooo00?o0000oh[Mo_n:gOh01On:gOh00ol0
003oN]?oog[Co`04og[Co`;o000000?oF@a?o`000?n7=Eh00_l00004oooooa7o000000?oURhlo`00
0?n[>S400ol00006og[Co`03o`000?m_bOooKlWo00GoKlWo00Co0000oooooooooooobV560_l00003
oooooa3o000000?oooooo`000?l000000_ooool2o`0000KoKlWo00?o0000of_1o_m[`Oh01_m[`Oh0
0ol0003oajNholNW^004o`0000Go`jg41?l00002okj^b@03o`000?oooooooooo00;ooooo0ol0000:
of_1oPOo00000onc]MX01?l0003oooooooooooooool;o`000005ojfgh?l0003o[[SPojjhh?l00000
4Oooool01Ol0003oZk[Toj^ji?n[^^Co000000;o[;_U00?o0000ojZli_l000001_l00005ojZliPOo
00000oooool00ol0003oZKcWojVli`02ojVli`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool05?ooool000[ooooo00?o0000ooooooooool0M?ooool00ol0003o[<G/ojc5k002ojc5k004o`00
0?ooooooooooooooo`Go00001_n/a^d5o`0000Go[LC[00Co0000ojg5k?n]aNco00000onaanX00ol0
003oooooooooo`0@ooooo`06o`000?nab>co/LS/ok78k?l0003o]l_Y4ol000001?n:gOko0000ol39
hOo0bN43o`0000;o_/3K00Go0000ooooooooooooooooo`000003ooooo`08o`000?nm_m_o_KoKo`00
0?o5`=Go0000olBoeOl00002okncc`Oooooo00?o0000okfbcol000000_l000000onjY<?o0000oooo
o`03ooooo`03o`000?n:gOkoR]gn00GoR]gn00?o0000og[Coomjdol01?mjdol00ol0003oF@a?o`00
0007o`0000;oQcEN2_l000000ooSl]Oo0000omkfg00:o`0000CoN]?o00?o0000ofo9oom_bOl01?m_
bOl7o`0000?ooooo00?o0000om9M8ol000003_l000001?oooooo0000o`000?l00007ofo9o`03o`00
0?m[`OkoJl7n00GoJl7n0_l00005ooooo`03ol^`_ol0003o000000Co`jg52_l00004ooooo`?o0000
2om[`Oh9o`0000Oooooo3_l0000<ooooo`05o`000?n[^^CoZk[Toj^ji?l000001?n/^nD00ol0003o
ooooooooo`02ooooo`03o`000?nZ_>KoZ[cV00So00001?nZ_>H4o`0000?oZKcW00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`0Dooooo`002_ooool00ol0003oooooooooo`1dooooo`03o`00
0?n/aNco[<G/00;o[<G/1?l00006ojc6k@Go00001_n]a>/4o`0000Co[LG/00Go0000ok77j_naan[o
/LOZo`00000Aooooo`_o000000CoWN?mo`000?nMhogo00002on:gOh4o`0000?o_/3K1_ooool01Ol0
003ooooooooooooooooo000000;o_KoK0ol00002okncc`Wooooo1_l00004ooooo`;o00001on:gOh0
0ol0003oN]?oog[Co`04og[Co`04o`000?n7=Eko0000o`0000;oQcEN4_l0000:og[Co`Co00000om_
bOl=o`0000;ooooo00Co0000om9M8ol0003ooooo3ol00007ofo9o`03o`000?m[`OkoJl7n00GoJl7n
0ol00005ooooo`03ol^`_ol0003o000000Kooooo00Goa;G;o`000?o2//_o0000okjcc`02o`000003
okjbcol0003o000000Co000000?o^[?Co`000?l000000_l0000:of_1oPCo00000_nd]]X6o`0000?o
oooo00Co0000ojnihOn_^N7o00000_n_^N4>o`0000Cooooo00Co0000oj^ji?n[^^Co00001?n/^nD0
0ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000onZ_>H7o`000005ojZli_l0
003o0000ojVliol00000C?ooool00ol0003oooooooooo`0Dooooo`002_ooool00ol0003ooooooooo
o`1eooooo`04o`000?n/aNco[<G/o`0000Go[<K]1Ol00006ojg4j`Go00000oooool00ol0003o[LG/
ojg5k002ojg5k003o`000?naan[o/LOZ00;o/LOZ00?o0000ooooooooool02oooool<o`0000?oWN?m
00?o0000oigSoOnMhod00_nMhod2o`0000[oR]gn1?l00007ooooo`03o`000?oooooooooo00So0000
2?ooool01Ol0003o_;CAo`000?l0003o/jS=00;o^JO600Co0000oooooooooooooooo0ol00007oh[M
oP03o`000?mjdoooN]?o00?oN]?o2Ol0000Bog[Co`ko00003?m_bOlEo`0000KoKlWo0_l00007of_1
oPCo00001?ooool2o`000003olN/_ol0003ooooo00Gooooo00Coa;G;o`000?o2//_o00001?ooool0
0ol0003o_[??okjcc`0;o`0000OoJl7n0ol000000om[`Oko0000o`000005o`000003okBff_l0003o
000000Co00000on_^N400ol0003oooooooooo`02ooooo`oo000000?oZk[To`000?n/^nD00on/^nD0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_nZ_>H6o`0004gooooo00?o0000
ooooooooool05?ooool000[ooooo00?o0000ooooooooool0MOooool01?l0003o[<G/o`000?n/a^d5
o`0000Oo[LC[1?l00009ooooo`03o`000?n]aNco[LG/00;o[LG/00?o0000ok77j_naanX00_naanX0
0ol0003oooooooooo`07ooooo`Wo000000?o//CWo`000?l000001OnMhod00ol0003oWN?moigSo@05
oigSo@;o00002_n:gOh3o`0000Oooooo0_l00002okg0g004o`000?nj]mOo0000okRfe`;o_[GA00?o
0000ooooooooool01?ooool01Ol0003o_;CAo`000?ngZ/co000000;o/jS=00Go0000okVWa_l0003o
0000ooooo`09o`0000;oR]gn00?o0000og[Cool000000_l00006og[CoaGo00001_mGbo83o`000003
oeO;l_m7_O?oAkgc00?o000000?oAkcco`000?l000002?l0000=ofo9o`So00001Om_bOl00ol0003o
Jl7nof_1oP06of_1oQ3o00000_ooool2o`000003ol:bbol0003ooooo00Oooooo0_nn^MD2o`0000;o
^;OH0ol000000oni]mSo0000o`000006o`000007of_1o_l0003o0000o`000?m[^_go0000ofZjo@0A
o`0000_ooooo4?l00007ooooo`03o`000?oooooooooo00Sooooo00?o0000ojZmionZ_NL00_nZ_NL0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01?ooooo0009ooooo`03o`000?oooooooooo
07Oooooo1?l00007ojg4j`?o00003oooool00ol0003o[LG/ojg5k002ojg5k005o`000?naan[o/LOZ
ok77j_l000001_ooool9o`0000;o//CW0_l00007oigSo@03o`000?nMhogoWN?m00OoWN?m0ol00009
oh[MoP?o00001?ooool2o`000003okg0g?l0003o000000;o00000onh]]L01?l0003o_[GAo`000?l0
0003ooooo`05o`000?nl]=7o0000okNZc?l000000_ooool2ok>Xc@Go00002?n:gOh=o`0000koEl_b
3Ol00004oeO;lP03o`000?m7_O?oAkgc00;oAkgc00?o0000odNllom7_?<02?m7_?<9o`0000coKlWo
00Go0000ofo9oom_bOooKlWoo`000008of_1oP05o`000?oH[joof:n_omR_[ol000001?o@/[d3o`00
00GobKC52_l00003ooooo`05o`000?nn^MGo0000okbge?l000000oooool4o`0000KoJl7n0_l00004
of^jo@04o`000?mZ^_goJ[[mofZjo@Wo00000_nb^=h9o`0000Wooooo00Go0000ojbliOn/_>Go0000
ojfli@0?o`000003ooooool0003ooooo00Oooooo00?o0000ojZmionZ_NL00_nZ_NL00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo01?ooooo0009ooooo`03o`000?oooooooooo07Oooooo00Co
0000ojg4jon]a>_o[LC[0ol000000on]a>_o0000ooooo`0Dooooo`03o`000?n]aNco[LG/00;o[LG/
00Go0000ok77j_naan[o/LOZo`000002ooooo`Wo00000_nba>L3o`0000SoWN?m0_l0000<oigSo@;o
00002_n:gOh2o`000003ooooool0003o_L3L00;o000000?o^[OGo`000?ooool00_ooool3okRfe`;o
000000Oo_[GAo`000?oooooo0000okbddOl0003o]j[<00Ko00002On:gOh6o`0000?oL]_d0omGbo83
o`0000GoEl_b4?l000000ooooooo0000ogP00002ogP000;o00001?mGbo800ol0003oAkgcodNml`03
odNml`Go000000?o^ShJo`000?l000000_l0000:odNll`[o00000om_bOl00ol0003oKlWoo`000008
of_1oPOo00000_o@/[d5o`0000Cob;K81?l00006ol:hd0Co000000?o_[WEo`000?l000000_ooool3
o`0000KoJl7n0ol00005of^jo@03o`000?mZ^_goJ[[m00GoJ[[m0_l00002ok6kh@03o`000?na^n7o
000000oo00000oooool01?l0003o[;cUojbliOl00004ojfli@Go000000?oZkcVo`000?l000001?l0
00000on[_>Ko0000o`000005o`0000?ooooo00?o0000ojZmionZ_NL00_nZ_NL00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo01?ooooo0009ooooo`03o`000?oooooooooo07Sooooo00?o0000
ojg4jon]a>/00_n]a>/00ol0003oooooooooo`0Eooooo`03o`000?n]aNco[LG/00;o[LG/00Co0000
ok77j_naan[o/LOZ2Ol00002ok;4i`Co00002?nMhod2o`0000;o^<KU0_l0000<oigSo@?o00002On:
gOh3o`0000;o^[OG0_l00004ooooo`08o`000?nh]]Oo^;KGokRfeol0003o_[GAo`000?nl]=44o`00
00[oR]gn1?l000001?mbfoCo0000o`000?l00006og;Km003o`000?mGbo;oEl_b00?oEl_b00So0000
oe000?l0003o0000ohMd]ol0003oD000o`0000;oN0002Ol00003ooooo`03o`000?mh003oN00000;o
00001?mGbo800ol0003oAkgcodNml`02odNml`03o`000?oooooo000000;oS`P01_l000001Onj?Q[o
0000o`000?l0003o_3L000Wo00001_m7_?<@o`0000;ooooo00?og[Vco`000?l000001?ooool00ooD
_<?o0000o`000003ooooo`?o000000?obkk>o`000?l000001Oo2^M89o`0000OoJl7n0_l00007of^j
o@;o00002OmZ^_d2o`0000?o/K_Q00Co0000ojnlhon__>?o[kcS4?l000000on/_>Go0000ojfli@03
ojfli@03o`000?oooooooooo00;ooooo3Ol00002oj^liPCo00000onZ_NL00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo0009ooooo`03o`000?oooooooooo07Wooooo00?o0000ojg4
jon]a>/00_n]a>/00ol0003oooooooooo`0Eooooo`03o`000?n]aNco[LG/00;o[LG/00?o0000ok77
j_l000001_l00002ok;4i`Co00002?nMhod3o`0000;o//CX00Go0000okS6iOnha^Go0000ooooo`03
o`0000_oWN?m0_l00009oh[MoP?o00000_ooool00ol0003oooooooooo`03ooooo`Ko00002_n:gOh4
o`000003og;Km?l0003o000000?o00000_odail2o`0000GoL]_d0_l00004oeO;lP04o`000?oT`;;o
0000o`0000;oD00000Co0000ogP00?l0003o00000_ooool>o`0000CoEl_b00?o0000odNmlom7_O<0
0_m7_O<01?l0003oooooooooool00002ohl80003oiL60?l0003ooooo00Oo000000?o_3L0o`000?l0
00000_ooool=o`0000;o@k;f00?o0000od>cm_l000002?m[`Oh5o`0000Cooooo00?oe;c3o`000?l0
00001Oooool01?o;_/ko0000olJic_l00004ooooo`Oo00001om[`Oh3o`0000KoJk[m0ol00003oooo
o`03o`000?mZ^_goJ[[m00OoJ[[m0_l000000ona^n7o0000ooooo`02ooooo`Go[kcS3?l000000on]
_>Go0000o`000006o`0000Sooooo3_l000000onZ_NOo0000ooooo`1?ooooo`03o`000?oooooooooo
01?ooooo0009ooooo`03o`000?oooooooooo07[ooooo00?o0000ojg4jon]a>/00_n]a>/00ol0003o
ooooooooo`0Cooooo`_o00001?nba>L4o`0000SoWN?m0_l00002ooooo`05o`000?nba>So//CXok;4
j?l000000_nha^D00ol0003o^LKUo`000003o`0000_oWN?m0_l0000:oh[MoP;o000000?oooooo`00
0?l000001?l0000:oh[MoPGo000000?oL]_do`000?l000000_l000000onZWlco0000o`000002o`00
0003ooooool0003o000000;o00001_mbfo@00ol0003oEl_boeO;lP02oeO;lQ_o000000?oEl_bo`00
0?m7_O<01?m7_O<7o`000003oiL60?l0003ooooo00Cooooo2Ol000001?oooooo0000o`000?l00003
odNll`;o00001?m3/_H2o`0000?o@k?f1?l00007of_1oPKo00001_ooool01?o;_/ko0000olJic_l0
0005ooooo`?o00001om[`Oh3o`0000OoJk[m0_l00009ooooo`03o`000?mZ^_goJ[[m00KoJ[[m1?l0
0008ooooo`;o[kcS2?l00003ojjkh`go00001_ooool00ol0003oooooo`000007o`00057ooooo00?o
0000ooooooooool04oooool000Wooooo00?o0000ooooooooool0N_ooool00ol0003o[LC[ojg4j`03
ojg4j`03o`000?oooooooooo00kooooo1?l00002ojk4j`Oo00000_nba>L3o`000003ooooool0003o
000000SoWN?m0_l00005ooooo`06o`000?nba>So//CXok;4j?l0003o^<KU0_l00002okO0h@03o`00
0?oooooo000000;o00002_nMhod3o`0000WoR]gn0_l0000;oh[MoPCo00000_mbfo@3o`000003ok>[
d?l0003o000000Ko000000Co[ik6o`000?l0003o>P0K0ol00006og;Km003o`000?mGbo;oEl_b00go
000000?oEl_bo`000?l000007ol00005ooooo`05oiL60?l0003o0000o`000?nk=P000ol00002odNl
l`?o00001?m3/_H5o`000003oooooom3/oKo@k?f00?o@k?f0ol00008of_1oPCo00000oooool01?l0
003obkk>o`000?l00003ooooo`?o00002?m[`Oh2o`0000OoJk[m1ol00009ooooo`;o00001omZ^_d7
o`0000Sooooo00?o[[gUojnlhol000004Ol000000on/_NKo0000o`000005o`0000?ooooo00?o0000
ojZmionZ_NL00_nZ_NL00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01?ooooo0008oooo
o`03o`000?oooooooooo07cooooo00?o0000ojg4jon]a>/00_n]a>/00ol0003oooooooooo`0:oooo
o`Co00000_n^a>/7o`000005ojk2jOl0003o[/?Yojk3jOl000000_nba>L3o`0000SoWN?m0_l00007
ooooo`[o00001Oooool2o`0000_oWN?m0_l00007oh[MoP03o`000?n:gOkoR]gn00KoR]gn1?l00002
og;Km0;o00000oooool01?l0003o/j_@o`000?n_Xl`5o`000006oc/07?l0003o0000ocX06ol0003o
1`000_l000000om@003o0000og;Km002og;Km1?o00000_lDY<4Ao`0000;o0I?600?o0000odNmlom7
_O<00_m7_O<;o`0000;ooooo00CoU`H0o`000?l0003o00000om7_?<2o`0000Go@k;f1Ol000000ood
Yfko0000o`000002o`0000;ooooo1?m3/oH4o`0000SoJl7n2_l00008of_1oP?o00001_m[^_d4o`00
0004okRng_l0003o]KgPo`0000;o][gO1Ol00003ooooo`03o`000?nb_N;o000000?o00001omZ^_d2
o`000003ojnmi?l0003o000000Co00000_ooool01Ol0003o[[gUojjmiOn^_NGo000000;o[KgU0_l0
0004ojfmi@oo000000Co[;gVo`000?l0003o00001?nZ_NL00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo01;ooooo0008ooooo`03o`000?oooooooooo07gooooo00?o0000ojg4jon]a>/00_n]
a>/00ol0003oooooooooo`05ooooo`Co00000on^a>/3o`000005ojk2jOl0003o0000o`000?n^`^T0
0ol00004ojk3j@;o00002OnMhod2o`0000Kooooo0ol000001onba>Oo0000o`000?l0003o//3To`00
0?nb`>@00ong`N400ol0003oooooooooo`04ooooo`;o00002onMhod2o`0000CoR]gn00?o0000oh[M
o_n:gOh00_n:gOh5o`0000;oL]_d00Wo0000ok6^eOna[]Go/JkEo`000?ng[Loo0000ooooool00000
0_ncZm09o`000003o`L00?l0003o000000[o00001Oln`//01?l0003o5JC1oaFT`OlEY<4;o`00013o
oooo0ol1TlH3o`0000Go0I?61Ol000000om7_O?o0000o`000005o`000003odNllol0003o000000Go
@k;f2_l000000ooooooo0000o`000004o`000003onBiZOl0003o@k?f00;o@k?f1?l00009of_1oP;o
00002Om[`Oh2o`0000OoJk[m0_l00002ok[1gP04o`000?nh_]ko^;kNo`0000;ooooo0_l00002okFm
h0Oo000000?o/[gRo`000?nb_>800_nb_>82o`0000OoJ[[m0ol00002ojnmi0Ko000000?o[[gUo`00
0?n]_ND00on]_ND01?l0003oooooooooooooool2ojbmiPCo[KgU4Ol000000onZ_NOo0000ooooo`1B
ooooo`03o`000?oooooooooo01;ooooo0008ooooo`03o`000?oooooooooo07kooooo00?o0000ojg4
jon]a>/00_n]a>/00ol0003oooooooooo`04o`0000?o[/C[1?l000001On^`^Wo0000o`000?l0003o
[/;Y00?o00000oooool01?l0003o[/?Yo`000?l00008oigSo@?o00001_ooool2o`0000;o//CW0_l0
0003ok;0i005o`000?nb`>Co//3Tok;0i?l000000_ng`N400ol0003oooooooooo`05ooooo`?o0000
2_nMhod3o`000003oh[Mo_l0003o000000Go000000?oL]_do`000?ooool01?ooool00ol0003o/JkE
ok6^e@03o`0000;o/j_@00?o0000ojnSc?l000001Ol000000ol7003o0000o`00000@o`000003onO4
/ol0003o000000;o000000?oooooo`000?l000002?l0000Iooooo`03o`6Ca_l0003o000000Oo0000
00?o0I?6o`000?l000004_l000000oodYfko0000ooooo`02o`000005onfcTol0003o0000o`000?oU
a[L01Ol00003od>cmP?o00001om[`Oh00ol0003oJl7nof_1oP04of_1oP?o00001_m[^_d3o`000004
ooooool0003o^/7No`0000;o^;kN00?o0000ooooooooool01Oooool3o`0000;o]KgP3?l00006ofZj
o@;o00000_ooool3o`000003ojnmi?l0003o000000So00001_ooool2o`000004ojbmi_l0003o[KgU
ojfmi@Wo000000CoZkgWo`000?l0003o0000E?ooool00ol0003oooooooooo`0Booooo`002?ooool0
0ol0003oooooooooo`1nooooo`03o`000?n]a>_o[LC[00?o[LC[0_l00004ojk4j`?o00000_n^`^T3
o`000004ojk2jOl0003o0000o`0000Kooooo0_l00008oigSo@;o00001oooool2o`000004ok;4iol0
003o0000o`0000?o//3T0_l00005ok;0i004o`000?ng`N7o]l7Qo`0000Kooooo1Ol00006oigSo@Co
000000?oWN?mo`000?l000000_l00006og;Lm@Go00000_ooool01ol0003o/JkEok6^eOl0003o/j_@
o`000?n_Xl`03_l00002ojFHb0Go000000?oV8g6o`000?ooool00ol000001?oXa[?o0000o`000?l0
0002ooooo`03o`000?o/c[Go000000Ko00008oooool8o`0000Oo@k?f1_l000001?oooooo0000o`00
0?ob[7/5o`0000;ooooo0_l00004ooooo`;o00000_m3/oH4o`0000?oJl7n00?o0000of_1o_m[`Oh0
0_m[`Oh2o`0000OoJk[m1?l00002ooooo`05o`000?nj`Mko0000okRng_l000002oooool3o`000004
okC1hol0003o/koSo`0000Co/KkT1Ol00006ofZjo@;o00000_ooool3ojjniP03o`000?n^_^Go[[kU
00;o00001?n/_^L5o`0000Kooooo0ol000000on/_NKo0000ojfmi@07o`0005Gooooo00?o0000oooo
ooooool04_ooool000Sooooo00?o0000ooooooooool0Ooooool01Ol0003o[LC[ojg4jon]a>_o0000
00;o[/C[1?l00002ojk2j@?o000000Co[/;Yo`000?l0003o00001_ooool3o`0000SoWN?m0_l00000
0onba>Oo0000ooooo`03ooooo`?o000000?o//CWo`000?l000001?nb`>@2o`0000?ooooo1Onb`>@0
1?l0003o]l7QokO1hOl00003ooooo`Co00000_ne^]d7o`000003oigSoOl0003o000000;o00000onB
j_P3o`0000WoL]ce4Ol00002ock2b`03o`h00?l0003o000000?o000000?o3P00o`000?l000000ol0
0002ooooo`Ko00000oooool3o`000003ooC<Y_l0003o000000?o00009_ooool00ol0SMCo0000o`00
0004o`000003o`2=e?l0003o000000Go@k?f2?l000000ooooooomljRo`000003ooooo`;o00000ooo
ool3o`000003ooooool0003o000000;o000000Go@k?fo`000?l0003o0000of_1oP04o`0000KoJk[m
0ol000001?nm`]ko0000o`000?no`M/2o`000003ok[1g_l0003o000000?o00002oooool2okC1h`05
o`000?nc_n?o/koSok>ohol000001?n`_^@3ok6ni0?o00001_mZ^_d3o`000003ojjni_l0003o[[kU
00?o[[kU00Co0000oooooooooooooooo0_l00004ojbni`Go00001_ooool8o`0005Gooooo00?o0000
ooooooooool04_ooool000Sooooo00?o0000ooooooooool0P?ooool00ol0003o[LC[o`000003o`00
00?o[/;Y0ol000000on^`^Wo0000o`000008ooooo`;o00002OnMhod3o`0000?o//CW00Go0000oooo
ool0003o0000ok;4i`03o`0000Co//3T0_l00006ooooo`03o`000?nb`>Co//3T00;o//3T00So0000
okO1hOng`N7o0000ooooool0003o]l3Qo`0000;o]K[M0_l00006oigSo@;o000000?oT^[go`000?l0
00002OnBj_P4o`0000OoL]ce1?l000000ombg?Co0000o`000002o`0000;o?/;;1ol00002onk5Z0?o
000000Gok<B[o`000?nHSLKo0000ooooo`04o`000009on_5[_l0003o0000o`000?oooooo0000og5^
_ol0003om<bV00Ko0000:_ooool6o`000003ohh00?l0SMCo000000;o00000om3/oH3o`000005oo_7
S_l0003oooooooO>X_l000000oooool2o`0000;ooooo1Ol00007odBcmPgo00000oooool01?l0003o
_L;Nokg2g_nm`]h3o`0000Co^<7Q1?l00006ooooo`03o`000?nd`N?o000000Co/koS00Co0000oooo
oooooooooooo1On`_^@00ol0003o/KkTo`000002o`0000KoJ[[m0_l00003ojjni@03o`000?oooooo
oooo00Oooooo1?l00002ojbni`Go00000_ooool00ol0003oZkkXoj^nj002oj^nj0;o0000EOooool0
0ol0003oooooooooo`0Booooo`002?ooool00ol0003oooooooooo`21ooooo`Co000000Co[/;Yo`00
0?l0003o00000_n^`^T00ol0003oooooooooo`07ooooo`;o00002OnMhod2o`0000?o[/?Y00Ko0000
ok;4ionba>Oo//CWo`000?nba>L2o`0000Go//3T0_l0000:ooooo`05o`000?nb`>Co//3Tok;0i?l0
00000_ng`N46o`0000KoWN?m0_l000001OnBj_Oo0000o`000?oooooo000000;o/kWM0ol00008oi;Z
n0Go00000_mbg?D6o`000004ock2bol0003o0000oco2b`Co000000GoYYg=o`000?l0003o0000ong7
[@02o`000003onk5Z?l0003ok<B[00?o000000Goooooo`000?l0003o0000ohn<c002o`000003on_7
[ol0003o000000[o0000;Oooool8o`000004o`2=e?l0003o0000o`0000;o@k?f0ol000001?ogcZ;o
0000ooooooooool5o`0000OoA;?f1Ol00002odN/n003o`000?m7[?So000000SoJ[[m0ol00003oooo
o`;o_LOR00Go0000ok[3hOl0003o]l;So`000005okS1h@?o00000_ooool01?l0003o]<7SokC1hol0
0003ok>oh`03o`000?oooooooooo00Oooooo0_l000000on`_^Co0000o`000006o`0000;oJ[[m0_l0
00000on^_^Go0000ooooo`0=ooooo`Go000000Co[;kWo`000?l0003o00001?n[_^P2o`0005Gooooo
00?o0000ooooooooool04_ooool000Oooooo00?o0000ooooooooool0Poooool7o`0000[ooooo0_l0
0009oigSo@;o000000?oooooo`000?n^`nT00on^`nT00ol0003o//CWo`000002o`0000Go//3T00?o
0000ooooooooool03?ooool01_l0003o//3Tok;0i?nb`>Co0000okO1h@?o00001_nMhod3o`000003
oi;Zmol0003o000000?ooooo1?l000001?na]Mco0000ojncg?nd/]L4o`0000OoT^[h1?l000000olo
`/_o0000o`000002ogOTgPKo000000?oYYg=o`000?ooool00ol00002ong7[@Co00000_nJU<`4o`00
0003ohn<c?l0003ok<N]00go0000<?ooool8o`000003o`2=e?l0003o000000;o000000?o@k?fo`00
0?l000000_l00007odBcmPGo00001?m7[?P4o`0000CoAjch0_l00007ofZjo@?o000000Go_LORo`00
0?nj`n7o^/?Qo`000002ooooo`;o00000_ng`^<3o`000006okS1hOl0003o0000o`000?nd`N?o0000
0onc_n<00ol0003oooooooooo`06ooooo`Go00002?mZ^_d3o`000004ofZjoOl0003o0000o`0001;o
oooo1_l000001On[_^So0000oooooooooooo000005Cooooo00?o0000ooooooooool04_ooool000Oo
oooo00?o0000ooooooooool0POooool4o`0000Go[/;Y00?o0000ooooooooool01?ooool3o`0000[o
WN?m1?ooool:o`0000?o//3T00?o0000ooooooooool03_ooool7o`0000KoWN?m0_l00002oi;Zm`03
o`000?oooooooooo00?ooooo00Ko0000ok>jgonc^]oo0000ok6eg?l00003ojncg003o`000?nd/]Oo
];;G00Wo00000_mgi=h8o`000003ookLVOl0003o000000;o00000_ooool01_l0003ok/R/o`000?oo
oooo0000ong7[@;o000000?ojlB]o`000?nJU<`00ol000001On?S<co0000o`000?l0003ok<N]00?o
000000?ok/JYo`000?l000001_l0000eooooo`03o`f<h_l0003o000000Co000000?o08gDo`000?l0
00000_l00003odBcmPGo00000_m7[?P7o`0000?oc<cI0ol00004odN/n0?o00001_mZ^_d3o`000003
ok[3hOl0003ooooo00Kooooo0ol00002okO2h`Wo00000_ooool5o`0000WoJ[[m1Ol00002offen`03
o`000?m]]O_oKKGk00Go00003oooool4ojboj0;o00000oooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo017ooooo0007ooooo`03o`000?oooooooooo07kooooo0ol00004ooooo`03o`00
0?n^`^Wo[/;Y00?o[/;Y00Co0000oooooooooooooooo0_l00004oigSo@go00000_n^`^T3o`000003
ojk0iol0003o[/3W00;o//7U0ol0000?ooooo`;o00000_na`>D3o`0000KoWN?m0_l00002oi;Zm`03
o`000?oooooooooo00Cooooo00Go0000ok>jgol0003o0000ok6eg002o`0000Co[k?L0ol00002oi;Z
m`;o000000KoMnCNo`000?l0003o[Z_Do`000?ooool3o`000005ooooool0003o0000o`000?oii:`0
1Ol00002ooooo`;o00000_ooool2o`000004onk9[_l0003o0000on_4[@Ko00000_ooool=o`0003Ko
oooo0_l000001Ol=S>;o0000o`000?l0003ooLV700ko00000ooEeMP00ol0003obLoOolW?g`03olW?
g`Oo00001?m7[?P2o`0000OoJ[[m0_l0000:ooooo`?o000000Go]/GVo`000?l0003o/L7Vok;1i@05
o`0000WoJ[[m1Ol00006offen`03o`000?m]]O_oKKGk00;oKKGk0_l00002ojfoi`Co00002_ooool0
0ol0003o[;oXojboj002ojboj003o`000?oooooooooo00?ooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`0Aooooo`001oooool00ol0003oooooooooo`1kooooo`?o00002?ooool00ol0
003o[/;Yojk2j@03ojk2j@Wo00002_nMhod6o`0000;o[/3W00Go0000ojk0ion^`>Oo[/3Wo`000003
ok;1i@03o`000?oooooooooo00_ooooo00Co0000ok70iOna`>Go/L3U0_l00005oigSo@?o00000_nB
j_L00ol0003oooooooooo`04ooooo`;o000000Go/k[Oo`000?na]Mco/KGLo`000003ooooo`03ojnc
g?l0003o000000?oT^[g0ol00002ok6`f003o`000?n^ZmCo000000Go000000Koooooo`000?l0003o
ooooo`000?oii:`3o`000003ojJSd_l0003o000000;o000000?oooooo`000?nPW]800ol000000ooZ
aJoo0000o`000005o`0000;ooooo0ol000000oo^aZWo0000o`000002o`000003ooooool0003o0000
00;o0000=oooool3o`000003o`f<h_l0003o000000Go000000?olNC0o`000?m7[?P01?m7[?P5o`00
0003olkBg?l0003obLoO00;obLoO0ol000001?o9enCo0000oko;honobn<4o`0000?oAjch0ol00006
ofZjo@;o00002?ooool00ol0003o]/GVokK5iP05o`0000WoJ[[m1Ol00008offen`?o00001om]]O/3
o`0000?o[KoW0ol00006ooooo`03o`000?n/_nSo[;oX00;o[;oX00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo017ooooo0007ooooo`03o`000?oooooooooo
07Sooooo0ol0000<ooooo`03o`000?n^`^Wo[/;Y00;o[/;Y00?o0000ojgUnOl000000on]iOT2o`00
017oWN?m1_l000000on^`>Oo0000ok;1i@02ok;1i@03o`000?oooooooooo00Sooooo0_l000001?na
`>Go0000o`000?l00005oigSo@;o00000onBj_L00ol0003o];_OokBkg`02o`0000?ooooo00Co0000
ok>jgonc^]oo00000_na]M`00ol0003oooooooooo`03o`0000;oT^[g1?l000000ond/]Oo0000ok6`
f007o`000003ok?SP_l0003o000000;o000000KoooooojV[f?l0003o0000oo;E/oofdJL5o`000003
ooooool0003o000000Co000000?oj/F_o`000?oZa:h00ol000001?n?TM7o0000oooooon3Qll7o`00
0003ooooool0003o000000?o0000=_ooool00ol0003oQ@D0o`000002o`000005o`f<h_l0003o0000
o`000?oai<000ol000000ooooooo0000o`000004odN/n0?o000000?oc];Lo`000?ooool01?ooool0
1?o9enCo0000olC=hOl00005oko;h`?o00000om7[?P2o`0000KoJ[[m0ol00003ooooo`Go00002OmZ
^_d5o`0000SoKKGk1Ol00002ojnoiP03o`000?ooooooKKGk00OoKKGk00?o0000ojfoion]_nL00_n]
_nL00ol0003o[KoWo`000003o`0000;ooooo00Go0000ojboj?n/_nSo[;oXo`000009ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool04Oooool000Oooooo00?o0000ooooooooool0MOoo
ool3o`00013ooooo00Co0000ojk2jOn^`^Wo00000on]iOT00ol0003o[NGiojgUn@06ojgUn@Ko0000
3OnMhod8o`0000Kooooo0_l000000ona`>Go0000o`000006oigSo@;o00000onBj_L00ol0003o/;_R
o`000004okBkg`03o`000?oooooo000000;o/k[O00Go0000ok6eg?l0003o0000ooooo`02o`0000?o
T^[g0_l000001?mgi=ko0000ojncg?n_/m`9o`000003ok?SP_l0003o000000;o000000?oooooo`00
0?l000000_l00002oo;E/`0:o`000?ofdJOo0000o`000?nVXm;o0000oj2Nd_l0003ok/V^o`0000;o
oooo0ol000001OoZa:ko0000o`000?l0003oSi7A00oo0000=oooool9o`000004ooooool0003ooooo
ooooo`Go00000om7[?P3o`0000Cooooo0_l00002olC=h@03o`000?oooooooooo00;ooooo0_l00002
oko;h`;o00000om7[?P3o`0000KoJ[[m0ol00009ofZjo@Go00002?m]]O/5o`000003ojo1iol0003o
[koV00?o[koV00?o0000ooooooooool00_ooool7offen`Co00001?n]_nL6o`000003ojboj?l0003o
oooo00Wooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Aooooo`001_ooool00ol0
003oooooooooo`1cooooo`?o00005?ooool2o`0000Go[NGi00?o0000ojgUnOn]iOT02on]iOT7o`00
00coWN?m1_l000000ooooooo0000ok70i@02o`0000GoWN?m0ol00003oi;Zm`03ooooool0003o/;_R
00;o/;_R0_l00003okBkg`07o`000?nc^]oo0000o`000?na]Mco0000ooooo`02o`0000;oT^[g0ol0
00001?mgi=koooooooooooooool:o`000003ok?SP_l0003o000000So000000?ooooooo;E/oobeK<0
2Ol00002ooooo`Co000000?oj/>]o`000?n<TM<00_l000000oo/aJco0000o`000009o`000003ooRZ
Aol0003ooooo03Kooooo1_l000000ookijKo0000o`000004o`000003onKWdOl0003o000000;ooooo
0ol00003odN/n0;o000000Koooooo`000?o9enCo0000olC=hOl00008ooooo`;o_]3W1?l00003odN/
n0;o00001?mZ^_d00ol0003oJ[[mofZjo@04ofZjo@Go00002?m]]O/9o`000003ojo1iol0003o[koV
00?o[koV00?o0000ooooooooool01?ooool2o`0000KoKKGk00?o0000ooooool000000ol00005ojfo
i`;o00003?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo017ooooo0006ooooo`03
o`000?oooooooooo073ooooo0ol0000Gooooo`03o`000?n]iOWo[NGi00Co[NGi00?o0000ojgUnOn]
iOT04_n]iOT6o`0000coWN?m0ol00005oigSo@;o00001?nBj_L5ooooo`05o`000?n`^n;o/;_Rok2k
h_l000000_nd^ml2o`0000;o/KGL0ol00002oi;Zm`;o000000?oMnCNo`000?l000001?l000000omf
hmko0000o`000002o`000003oiC_aol0003o[ZkH00?o000000?oooooo`000?l000000ol000001?nW
YmKo0000o`000?l00002ooooo`04o`000?obeK?o0000ono:[@;o000000GoWZ3Fo`000?l0003o0000
ooooo`06o`000003on[3[Ol0003o000000;o000000?ojl:[o`000?l000000_l000000ooooooo0000
o`000006o`0003Oooooo1ol000000ooooooo0000o`1La00=o`0000;oAjch0ol000000oo4cN7o0000
ooooo`05ooooo`go000000?oAjcho`000?l000000_l00002ofZjo@Go00002?m]]O/5o`0000Cooooo
3Ol00007ooooo`;o00001Om]]O/2o`0000?ooooo1?l00002ojc1j@03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Aooooo`001_ooool00ol0003ooooooooo
o`1]ooooo`?o00006?ooool2o`0000Oo[NGi0_l0000IojgUn@Ko00002?nMhod01?l0003oWN?moigS
oOnMhod2o`000003oi;Zmol0003o000001?o00000onBj_L5o`0000;oM^?N0ol000002?nYmn_o0000
ojbag?n//Mco0000oiC_aol0003oZJoL0_l000000onchh;o[ZkHo`000003o`000003ojV[f?l0003o
000000;o00001?ooool3o`000003ono:[Ol0003o000000;o000000?oWZ3Fo`000?l000001?l00000
0ooY`joo0000on[3[@02o`000003on_2Zol0003o000000Co000000?om<NPo`000?l000000ol00000
0ooiZeCo0000ooooo`0fooooo`03o`000?l008?o000000Oo000000?o05c4o`000?l000000ol00002
oaf=j`So000000?oAjcho`000?l000001ol00004odN/n0co000000?oAjcho`000?l000001?l00005
offen`Go00002_ooool3ok33j004o`000?n_`NOo[l7Wo`0000Go[/7X1?l00005ooooo`03o`000?m]
]O_oKKGk00CoKKGk00Co0000oooooooooooooooo1?n/`NT00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool04?ooool000Kooooo00?o0000ooooooooool0JOoo
ool4o`0001[ooooo00?o0000ojgUnOn]iOT01_n]iOT2o`000003ojk2jOl0003o000000;o[/3W1_l0
000EojgUn@Ko00000_nMhod7o`0001CoT^[g1Ol00002ogKSgP04o`000?nYmn_oZOO[ojWgj`;o0000
00?oZ?O[o`000?n//M`00_l000001?nDklOo0000o`000?nY[m`4o`000003ojj^f?l0003o000000Ko
00001?ooool2o`000003onc=]?l0003oklZ]00[o00000_oY`jl9o`000003ooC7X?l0003o000000Ko
0000>?ooool7o`000005o`1Udol0003o0000o`000?l0G<@02_l000000olMSN_o0000o`00000>o`00
00coCZSh00?o0000odjXn?m>Z?P01?m]]O/6o`0000gooooo00Co0000ok33j?n``nSo00001?n_`NL0
1Ol0003o[L7Xojg1j?n]`NSo000000Co[/7X1?l00002ooooo`;o00001Om]]O/3o`0000?o[<7Y00?o
0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo0006
ooooo`03o`000?oooooooooo06Kooooo0ol0000Mooooo`03o`000?n]iOWo[NGi00Ko[NGi1?l00005
ojk0i`;o00001?ooool8o`0001;o[NGi1?l00005oi;ZmaOo00000onYmn/3o`000003ooooool0003o
Z?O[00Co000000?oU>o7o`000?l000000_ooool3o`0000;oZJoL00Go0000oo?X_Ol0003o0000oo[T
[002o`000003oo?F/_l0003ooooo00;ooooo1?l000001?o/cKCo0000o`000?l00002oiZQf@Go0000
00?oooooo`000?oY`jl00ol000000ooooooo0000o`000004o`000003onjiVOl0003o000000Ko0000
=oooool00ol005go0000o`0U/@05o`000007o`1Udol0003o06GDo`000?l0G<Co0000oab=jP02o`00
00CoamkY1?l00002oaf=jP;oCZSh5_l00004odjXn0;o00001_m]]O/4o`0000Wooooo00Co0000ok33
j?n``nSo00001?n_`NL01?l0003oooooooooooooool5ojg1j0;o00000on^`NP3o`000003ooooool0
003o000000GoKKGk0_l000000on/`NWo0000ooooo`0Aooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool04?ooool000Kooooo00?o0000ooooooooool0Hoooool3o`0001oooooo00?o0000
ojgUnOn]iOT01_n]iOT9o`0000oooooo1ol00006ojgUn@Ko000000?o[^ogo`000?n^koL05?n^koL6
o`000004ojWgjol0003o/KONok6ggP;o00000_ooool00ol0003oZ?O[o`000002o`000006oiC_aol0
003o0000ol_ng?l0003ooooo1ol000000oocj;go0000oo?X_P03o`000003oo?F/_oooooooooo00;o
oooo0ol000001onQYMWo0000onc=]?l0003ojlJ_o`000?ooool01_l000000ooooooo0000onW2[P08
o`000003onjiVOl0003o000000Go000000?onJ]Do`000?ooool0=_ooool3o`000003o`0U/Ol0003o
000000co00000_ooool3o`000003ol7Gj_l0003o_MC[00;o7HgZ00?o0000odjXn?m>Z?P00_m>Z?P0
0ol0003o_]3Wo`000002ok[8i@03o`000?oooooooooo00Sooooo00?o0000okK:jOnfb^T01Om>Z?P2
o`0000GoKKGk0_l000001?nba>Oo0000o`000?l00005ooooo`04o`000?n``nSo/<?Xo`0000Co[l7W
00?o0000ooooooooool01Oooool2o`0000Co[L7X0ol000000on^`NSo0000o`000002o`0000KoKKGk
0_l0000Cooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04?ooool000Kooooo00?o
0000ooooooooool0H?ooool3o`00027ooooo00?o0000ojgUnOn]iOT01On]iOT2o`0000?ooooo1_n^
`>L00ol0003oooooooooo`0Booooo`Oo00001?n]iOT00ol0003o[^ogojk_m`02o`0000Ko[^og3_l0
0002ojk_m`;o00000on/^>42o`0000?o/KON0_l000001?nXmn_o0000o`000?nDklL3o`00000;ol_n
g?l0003oooooo`000?o7o;_o0000onkh/ol0003oooooo`000?ocj;d02?l00002ooooo`Go000000Co
ooooo`000?l0003ojLRd1ol000000onGWm[o0000o`000005o`000003ohFGg_l0003o000000;o0000
00?oLXkOo`000?l000001ol0000gooooo`?o000000?o02Fao`000?l000002?l000000ol0IMCo0000
oab=jP04o`0000;o`MOZ0oooool01?l0003o7HgZoaf=j_l00003odjXn0Ko00002?ooool00ol0003o
]/[YokK:j@03o`0000GoCZSh00?o0000offenom]]O/01?m]]O/2o`0000;o//CW0ol000001Ooooooo
0000ok33j?n``nSo000000Co[l7W00?o0000ooooooooool02_ooool3o`0000;o[L7X2Ol00003offe
n`;o00004oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo013ooooo0005ooooo`03
o`000?oooooooooo05kooooo0ol0000Rooooo`;o00001on]iOT00ol0003oooooooooo`04ooooo`03
o`000?n^`>Oo[/3W00?o[/3W00?o0000ooooooooool03oooool2o`0000;o[/3W00?o0000ojgUnOn]
iOT01On]iOT01?l0003o[^ogojk_mol00002ok2mh`;o00002Oooool01?l0003o[kcSojnlhon__><2
o`0000?o[^og0ol000000ooooooo0000o`000003ojbhh@?o00000_nXmn/5o`000003ooooooo;o]co
bokL00;o000000?oaobkoooooooWnLd01ol000000onT[=go0000o`000002oo?G/PKo000000?oXJGI
o`000?ooool00_l00002onW8]003o`000?oZaJoo000000?o000000?oU9oLo`000?oY`Zh00ol00000
0oo[_jSo0000o`000004o`0000;oLXkO2Ol0000fooooo`;o000000?o0022o`000?l09K402_l00000
0ooooooo0000o`000002o`000003oab<j_l0003o000000?o00000oooool00olMSN[o0000o`000003
odjXn0;o00000_nic>P5o`0000;ooooo00Co0000okK:jOnfb^Wo00000oncaNL3o`0000?oCZSh0_l0
0006offen`?o00000_nba>L01?l0003o/<?Xok33j?l00004ojo1i`03o`000?oooooooooo00Wooooo
2?l00008offen`Co000000?oKKGko`000?ooool04_ooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo013ooooo0005ooooo`03o`000?oooooooooo05_ooooo0ol0000Tooooo`03o`000?n]
iOWo[NGi00Ko[NGi00?o0000ooooooooool01_ooool00ol0003o[/3Wojk0i`03ojk0i`03o`000?oo
oooooooo00cooooo0_l00003ojk0i`03o`000?n]iOWo[NGi00Co[NGi0_l00002ojk_m`03o`000?n]
_NKo000000?o/;gS00?o0000ooooooooool01?ooool2o`0000;o[kcS0ol00003ojk_m`03o`000?nY
mn_o000000Cooooo0_l00002ojbhh@05o`000?nXmn_o0000o`000?nDklL00ol000000ooooooo0000
ol_ng002o`000004olOl^oooooooooooonOic@Go000000?oYjoMo`000?ooool00_l000000oo]f[ko
lmNboo?G/P04o`000003oj6UfOl0003ooooo00Co000000CojLRdo`000?l0003ojLB_0_l000001Ooo
oooo0000o`000?l0003oi[n]00_o000000?olkZ?o`000?l000001?l000000ooRM1Go0000o`00000e
ooooo`;o000000Ko001lo`000?l0003o02Fao`000?ooool:o`000003ob^=k_l0003o000000Co0000
00?o78cZo`000?l000000ol000000olMSN[o0000odjXn002odjXn0;o000000Co]Lg/o`000?l0003o
00000_nic>P2o`0000;o]/[Y00Go0000ok?5ioncaNOo/lGWo`000003ooooo`03o`000?m>Z?SoCZSh
00;oCZSh00?o0000offenom]]O/01?m]]O/5o`000003ok33j?l0003o[l7W00?o[l7W00Co0000oooo
oooooooooooo2Ol0000@offen`So00004Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo013ooooo0005ooooo`03o`000?oooooooooo05Sooooo0ol0000Vooooo`03o`000?n]iOWo[NGi
00Ko[NGi00?o0000ooooooooool02?ooool2o`0000Co[/3W0_l0000:ooooo`;o00001?n^`>L00ol0
003o[NGiojgUn@04ojgUn@05o`000?n^koOo[^ogojk_mol000000on]_NH2o`0000;o/;gS0_l00003
ooooo`07o`000?n__>?o[kcSojnlhol0003o[[WQo`000003ojk_m`03o`000?nYmn_o000000Oooooo
0_l000001OnXmn_o0000oiC_aol0003obokL00?o000000Goooooo`000?l0003o0000olOl^`03oooo
o`Go000000?oYjoMo`000?ooool00ol00002ongJ_P03o`000?ocek;o000000Co000000?oooooo`00
0?l000000_ooool5o`0000;ooooo0_l000000ooV_jgoT9oNo`000005o`000005onRgX_n0V>7o0000
o`000?ooool01_l000001?o^TeGo0000o`000?l0000eooooo`Ko000000Co02Fao`000?l0003o04[9
2_l00002ob^=kPSo000000?o78cZo`000?lMSNX00_l00003odjXn004o`000?necNco]Lg/okG=k0Co
000000?o]/[Yo`000?ncaNL00oncaNL5ooooo`;o00000om>Z?P2o`0000KoKKGk0_l000000onaaNSo
0000o`000008o`0000goKKGk3?l00002og2bn@?o00000om`/_T00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool03oooool000Gooooo00?o0000ooooooooool0
EOooool3o`0002Sooooo00?o0000ojgUnOn]iOT01On]iOT2o`0000gooooo00?o0000ojk0ion^`>L0
0on^`>L00ol0003oooooooooo`05ooooo`;o00001?n^`>L2o`0000Ko[NGi00Co0000ojk_mon^koOo
[^og0_l00005ojfmiP07o`000?n`_N?o/;gSok2mhol0003oooooo`000003ojnlh`03o`000?n^^N7o
000000;o[^og0_l000000onYmn_o0000ooooo`06ooooo`;o000000KoZ?O[o`000?l0003obokLo`00
0?nY]N43ojbdgP04o`000?o;o]co0000olOl^`Cooooo1?l000000onW[mgo0000ooooo`02o`000003
onkJ__l0003o000000;okMZn0ol000000onOZmoo0000oj6[g@03o`000003ooooool0003o000000?o
000000?oj<:^o`000?l000003Ol000000ooY^:7o0000o`000004o`000004onfMKol0003o0000ocf5
j@;o0000=?ooool6o`000003omOfh_l0003o000000?o000000?o04;2o`000?l000000_l000001?l0
JM[o0000o`000?l00002ob^=kP03o`000?oooooooooo00So000000Co7HgZo`000?m>Z?SoCZSh3_l0
0007ooooo`03o`000?m>Z?SoCZSh00;oCZSh0_l00004offen`Go00002_m]]O/;o`0000SoL;;i1_l0
0007og2bn@03o`000?oooooooooo00oooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0?ooooo`001Oooool00ol0003oooooooooo`1Booooo`?o0000:_ooool00ol0003o[NGiojgUn@05
ojgUn@03o`000?oooooooooo00kooooo00?o0000ojk0ion^`>L00on^`>L00ol0003oooooooooo`02
ooooo`;o00001On^`>L00ol0003o[NGiojgUn@05ojgUn@05o`000?n^koOo[^ogojk_mol000000_oo
ool2o`0000Co[KgV00Go0000ok2mhon`_N?o/;gSo`000002ojnlh`;o000000Go[[WQo`000?n^koOo
[^ogo`000002ojWgj`03o`000?oooooooooo00?ooooo1ol00002oj^ghP06o`000?nY]N7oZKGQojVe
hOl0003obokL0ol00004ooooo`?o000000CoYjoMo`000?oooooooooo0ol00002ooooo`06o`000?o]
f[ko0000o`000?o]c[Co00000_nOZml2o`000003oj6[gOl0003o000000Go000000Goj<:^o`000?l0
003o0000ooooo`0=o`000003oo>jSol0003o000000?o000000?ok9ANo`000?l000000_l0000coooo
o`05o`000?l007Wo0000o`000?l0=kX01_l000000onkjoCo0000o`000005o`0000;o06WJ00?o0000
ob^=k_l[SNh00ol00003okS?j`?ooooo8?l000000om>Z?So0000offen`02o`0000?oKKGk3?l00008
og2bn@co00001_ooool7og2bn@03o`000?oooooooooo00oooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0?ooooo`001Oooool00ol0003oooooooooo`1?ooooo`?o0000:oooool2o`00
00Oo[NGi00?o0000ooooooooool04?ooool00ol0003o[/3Wojk0i`03ojk0i`04o`000?oooooo0000
o`0000Go[/3W0_l00007ojgUn@05o`000?n^koOo[^ogojk_mol000001Oooool2o`0000?o[KgV0_l0
00001?n`_N?o0000ojnlhol00002ojjih@04o`000?n^koOo[^ogo`0000;oZOO[00Co0000oooooooo
oooooooo1_l00002olKgk003ol_ng?l0003oZkOR00;o00000onY]N400ol0003obokLo`000002ojbd
gP;o000000Koooooo`000?l0003o0000oo?Y_Ol00002ooooo`?o00000oooool2o`000006ongJ__l0
003okLjdong>]?l0003oWj_O2Ol000001OoU`kCo0000o`000?l0003ooooo00So000000CoQZ7Uo`00
0?l0003oPZ7W1?l000001?oXXhCo0000o`000?o[WG@3o`000003ooooool0003o000003;ooooo1Ol0
00001_l0=k[o0000ooooool09K3o0000o`YCc`So000000?o2FcMo`000?l000001_l000000onhcn_o
ooooooooo`05ooooo`;o:Xg]0_mDYOLQo`0000WoL;;i2ol00005ooooo`03o`000?n/`^[o[<;Z00;o
[<;Z00?o0000ooooooooool01_ooool00ol0003oL;;iog2bn@04og2bn@;o00003oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00oooooo0004ooooo`03o`000?oooooooooo04gooooo
0ol0000]ooooo`03o`000?n]iOWo[NGi00Ko[NGi00?o0000ooooooooool04_ooool2o`0000Co[/3W
00?o0000ojk0ion^`>L00on^`>L3o`0000Ko[NGi0_l00003ojk_m`Wooooo00?o0000ojfmi_n]_NH0
0_n]_NH6o`0000;o[^og00Go0000ojWgjonYmn_o0000ooooo`06o`0000;oa_O/00Ko0000olKgk?l0
003o0000oj^gh_l00003ooooo`Oo00000_n/]=h01_l0003oioW=on[YcOoZjLgolnVmo`0000;ooooo
0_l00003ooooo`06o`000?nT/>3o0000o`000?oXd;go00000_o]c[@01?l0003ojLRdo`000?nOZml7
o`000003onG3]?l0003oi[f/00[o00000_n6XND3o`000003oo2iU_l0003o000000[o0000<?ooool3
o`000005o`00NOl0003o0000o`000?l0=kX03_l000001?l0JM[o0000o`1Yf_leSNh7o`0000Gooooo
00?o0000obZ=kOl000001?mDYOL2o`0000?ooooo00Co0000ok38k?n`b>co/<S/3Ol00003oeBUm`Co
L;;i2Ol00003ojg3jP?o00001?n^`^T3o`0000;ooooo00?o0000ojc2j_n/`^X00_n/`^X00ol0003o
ooooooooo`08ooooo`03o`000?m`/_WoL;;i00GoL;;i00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo00oooooo0004ooooo`03o`000?oooooooooo04[ooooo
0ol0000_ooooo`03o`000?n]iOWo[NGi00Ko[NGi00?o0000ooooooooool05Oooool01Ol0003o[/3W
ojk0ion^`>Oo000000?o[/3W0_l000000on]_^Ko0000ojgUn@05ojgUn@03o`000?n^koOo[^og00;o
[^og2_ooool8o`000003ojjjhol0003o[^og00;o00000_nYmn/5o`0000?oa_O/0ol00002olKgk003
ol_ng?l0003o000000;ooooo1?l000000ooMm=goioW=o`000002ojVeh@;o000000CoioW=on[YcOl0
003oj^W=0_l000001?oooooo0000o`000?l00002ooooo`05o`000?nT/>3o0000ongJ__l000000_oX
d;d00ol0003okLjdo`000008o`000003oibZh?l0003o000000;o000000?oi[f/o`000?l000000_l0
00001?oX_Z_o0000o`000?oT]jP2o`000003oooooon6XNGo000000;o000000?oiJF>o`000?l00000
1Ol000000oo[QCCo0000onZ9B@04o`0002cooooo2Ol000001ol0=k[o0000o`0U/?l0003o^=kco`00
0?l0BLT00_l000000olSL^7o0000o`000007o`0000;o=Hg^1ol00002ooooo`;o000000?o:Xg]o`00
0?l000000omDYOL00ol0003oooooooooo`04ooooo`04o`000?n`b>co/<S/ok38k0;o000000So//OZ
o`000?l0003o0000ooooool0003o/<K[o`0000CoE:Gg00?o0000og2bnOm`/_T01Om`/_T00ol0003o
ooooooooo`03ooooo`;o00000_n]`nX3o`0000Co[/;Y0_l00004ojc2jP03o`000?oooooooooo00[o
oooo00?o0000og2bnOm`/_T01Om`/_T00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool03oooool000Cooooo00?o0000ooooooooool0Aoooool3o`00037ooooo
00?o0000ojgUnOn]iOT01On]iOT2o`0001Wooooo00Go0000ojk0ion^`>Oo0000ojk0i`02o`000003
ojfni_l0003o000000Ko[NGi00?o0000ojk_mon^koL00_n^koL9ooooo`;o00001?n/_^H01ol0003o
[;cUo`000?n[^nGo0000ojk_mol000000_nYmn/4o`0000;oa_O/1?l00002ojbih`;oa_O/0ol00002
ooooo`03o`000?o;o]co000000?ogOCM00_oioW=o`000?nY]N7oZKGQo`000?oWnLgoj^W=o`000?nX
/n3o0000on[Yc@02o`000003oo?X__l0003ooooo00;ooooo0_l000002_o]f[ko0000o`000?oooooo
0000onS@_Ol0003ojLRdo`000?nP[n85o`0000;oVj_R0ol000000ooS_[;o0000onJm[004o`000003
on>fZOn>YnKo000000;o000000?oooooohRWjOn:ZNX03Ol000000ooEIcKo0000o`000002o`0002[o
oooo2_l00002o`0g^P?o000000?oooooo`000?l:Dll00_l000001_lSL^7o0000o`000?l0003o/]?a
oa=^ga7o00000_lZSNd01Ol0003oE:GgoeBUmomDYOOo000000Oooooo0_l00002ok38k0;o00000_nb
anX00ol0003o/<K[ok36j`02o`0000CoE:Gg00?o0000og2bnOm`/_T01Om`/_T00ol0003ooooooooo
o`05ooooo`;o00000_n]`nX3o`0000;o[/;Y00Go0000ojc2j_n/`^[o[<;Zo`00000>ooooo`03o`00
0?m`/_WoL;;i00GoL;;i0_l0000>ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
3oooool000Cooooo00?o0000ooooooooool0A?ooool3o`0003?ooooo00?o0000ojgUnOn]iOT01_n]
iOTLooooo`Oo00001on]iOT00ol0003o[^ogojk_m`02ojk_m`Wooooo00?o0000ojbni_n/_^H00_n/
_^H6o`000003ojk_mol0003o000000;o00001?o6mn`2o`0000;ooooo00Co0000ojbihon/^N?o0000
0_o6mn`2o`000003ooooool0003o000000;o000000CoooooomgdgOoMm=gogOCM1?l000001?oWnLgo
j^W=o`000?nU/n82o`000003on[YcOl0003o000000?o000000?oooooo`000?nT/>000ol00003oooo
o`?o000000?ojLRdo`000?l000001Ol000000onM[nCo0000o`000002o`000003on>n/_l0003oi[f/
00;o000000CohkJYo`000?l0003ooooo5?l000000ooCJdCo0000o`000002o`0002Oooooo1?l00000
0ol004go0000o`000005o`0000;o03Nj0_l00003ooooo`03o`YCcol0003o000000;o000000Go8W7Q
o`000?l0003o0000oa=^g`03o`000003oc^=k_l0003o000000go00000omDYOL00ol0003ooooooooo
o`06ooooo`?o000000Ko/<S/o`000?l0003o0000ok36jol00002ojo3j@03o`000?mDYOOoE:Gg00;o
E:Gg0_l00006og2bn@03o`000?oooooooooo00Oooooo0ol000000on]`n[o0000o`000002o`000003
ojc2j_l0003ooooo00oooooo00?o0000og2bnOm`/_T01_m`/_T00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool03oooool000Cooooo00?o0000ooooooooool0
@Oooool3o`0003Cooooo0_l00008ojgUnAkooooo0ol000000on]_^Ko0000ojgUn@05ojgUn@;o0000
1?n^koL8ooooo`So00000_n^koL5o`0000Coa_O/0_l000001On^^^?o0000o`000?oooooo000000;o
[;WS00?o0000olKgk?o6mn`01?l000000oo;o]co0000omgdg@02ooooo`03o`000?oMm=gogOCM00?o
000000CoioW=on[YcOl0003o00000_nU/n800ol0003oj^W=o`000002o`0000;oZ;?P00Go0000ojB`
h?l0003okMZno`000004ooooo`;o000000?oiL^lo`000?l000000_l000001?oooooo0000oooooonM
[n@2o`000005on:n/_nHZn?o0000o`000?oS_[801_l00002ooooo`09o`000?oX]Z3o0000o`000?oP
YiWo0000on2WVOl0003ooooo00[o000000?oGZWhom=[A?l000001?l0000Sooooo`Ko000000?o001/
o`000?l000000ol000000ol0=KWo0000o`000002o`0g^P?o000000Goooooo`000?l:Dloo0000ob=b
h@02o`000003oooooolRLN7o4fkO00ko00000_nbbN/?o`0000?ooooo1?l000000on`b>co0000o`00
0004o`0000GoE:Gg00?o0000og2bnOm`/_T01?m`/_T00ol0003oooooooooo`08ooooo`Oo00004_oo
ool00ol0003oL;;iog2bn@06og2bn@03o`000?oooooooooo00_ooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0>ooooo`001?ooool00ol0003oooooooooo`0nooooo`?o0000=_ooool0
0ol0003o[NGiojgUn@07ojgUnB7ooooo00?o[KkVo`000?n]iOT01On]iOT00ol0003o[^ogojk_m`03
ojk_m`;ooooo1ol00004ojk_m`Ko000000?o_ncbo`000?nokO800_o6mn`2o`0000;oZk_U00?o0000
ojjjhon^^^<00_n^^^<00ol0003o[;WSojbih`02o`000007olKgk?l0003obokLo`000?o;o]co0000
omgdg@04ooooo`06o`000?oMm=go0000onOicOl0003oioW=0_oZjLd00onX]N?o0000ooooo`03o`00
0003on[YcOl0003ok]Zn00Oo00000oooool4o`000003onG;_?l0003oilJd01Co000000?oooooo`00
0?l000000_l000001Ooooooo0000o`000?l0003oPJ[_00_o000000?odf]4o`000?m3W?@01Ol0000M
ooooo`Wo000000?o001/o`000?l000000_l000001Ol009;o0000o`000?l0003oYMok00;o000000Go
;Ec?o`UBc_l0003o0000ok;Cl@03o`0000Cooooo00?o8W7Qoa=^gol000000_l00002od6=kPco0000
0_ldSNh00ol0003oFZ?foeZSmP0Bo`0000?o[/C[00?o0000oeBUmomDYOL00omDYOL00ol0003oL;;i
og2bn@04og2bn@03o`000?oooooooooo00Kooooo00?o0000ojc4jon/a>/00_n/a>/00ol0003ooooo
ooooo`02oooooaOo00000om`/_T00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool03_ooool000?ooooo00?o0000ooooooooool0??ooool3o`0003Sooooo00?o
0000ojgUnOn]iOT01?n]iOTWo`0000Go[NGi00Co0000ojk_mon^koOo[^og1Ol00006ojk_m`Co0000
1_nok?82o`000005oko]l_l0003oa_O/olKgk?l000001?n[^nD2o`0000;o[[[S00Co0000ojbihol0
003o00000_o6mn`2o`000003ol_ng?l0003ogOCM00Gooooo00Go0000omgdgOl0003oioW=o`000002
on[Yc@03ojRehol0003ooooo00?ooooo0_l000000ooVflWo0000onkJ_P03o`000003ongJ__l0003o
Y;;R00;o000000Goooooo`000?l0003o0000oj2_hP03o`000004onO5]?l0003ooooooif_i0?o0000
00?oooooo`000?l000000_l000001?oS_[;o0000o`000?l00004oi2]j@Go00000_ooool2o`000003
oh6Zkon4[_3o000000Co000000?oN:Sao`000?mhZ?400ol000000ooCJdCo0000olaF8`07o`0001So
oooo3ol00002ooooo`;o00000_ooool3o`000003obeLcol9D/ko000000Ko00000oooool00ol0003o
8W7Qoa=^g`02o`0000;o@Hg^00?o0000od6=k_l000002Ol00002ocB=kP05o`000?mJXoKoFZ?foeZS
m_l000001?oooolDo`000003oeBUmol0003oL;;i00;oL;;i5Ol00002og2bnA[o00003Oooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo00kooooo0003ooooo`03o`000?oooooooooo03Wo
oooo0ol0000jooooo`04o`000?n]iOWo[NGiojgUn@Co00009on]iOT01_l0003o[NGiojgUnOn]iOWo
0000ojk_m`?o00001_n^koL3o`0000_o_ncb00Co0000oko]l_nokO;o_ngb0_o6mn`00ol0003ooooo
o`000005oj^ki@Ko000000Coa_O/o`000?l0003obokL0_oMm=d6ooooo`04o`000?oMm=go0000o`00
00;oj^W=00?oZ;GSo`000?ooool00oooool3o`0000;oi]_900Co0000onkJ__l0003okMZn0_l00003
ojBbhP03o`000?oUbkco000000Ko000000?oiL:do`000?l000000_l000000ooooooo0000o`000002
o`000003on>n/_l0003o000000?o00000_nB[NP2o`000003onBfY_l0003o000000;o00000_ooool2
o`000004ohB^l?l0003o0000omN=O`Ko000000?oL[3ho`000?l000001?l000001On^=Ago0000o`00
0?l0003oP00000Go00003oooool@o`000003ob4HRol0003o000000;ooooo00?o;dNjo`000?l00000
0_l000002?l0=[Wo0000o`000?l]G<oo2E;>o`000?naeO?o2e;>0_l000000olgMN3o0000o`000002
ooooo`05o`000?lRLN7o8W7Qoa=^gol000000_m1SNh01?l0003o[/c_o`000?m1SNh9o`000003ocB=
k_l0003oFZ?f00;oFZ?f00Co0000oooooooooooo00000on_bNd00ol0003o[/G[ojk5j`02ojk5j`05
o`000?oooooooooooooooon/aN`0>Ol00003og:`m`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`0>ooooo`000oooool00ol0003oooooooooo`0fooooo`?o
0000??ooool5o`0002co[NGi00?o0000ojgUnOl000000_l00004ojk_m`;o00003?nok?85o`0000?o
_ngb00?o0000olKgk?l000000oooool2o`0000?oZk_U00?o0000oj^kiOl000000_l00002olKgk003
o`000?oMm=gogOCM00Sooooo1Ol000000onX]N?o0000ooooo`03ooooo`;o000000[oi]_9o`000?oV
flWoi]_9o`000?o^f[ko0000ongJ__l0003oX[;T3Ol000001OoU`[Co0000o`000?l0003ooooo00Go
000000?og[J`o`000?oN]jl00_l000001_oooooo0000o`000?oT]ZKo0000om^YXPSo000000Goi:J?
o`000?l0003o0000ooooo`02o`000006ogR_mOl0003o0000og:`n?l0003oeWAD1_l000000on^=Ago
0000o`00000Jo`000003odT0;_l0003o000000Wo000000Coooooo`000?l0003o;dNj0ol000001_l0
=[Wo0000o`000?nXdoOo;Ec?o`UBcP?o000000?o=WGPo`000?l000000ol00002ojoCl`So00000_oo
ool00ol0003o@Hg^o`00000Ao`0000?o[/G[0_l00006ooooo`05o`000?n/aNco[<G/ojc5k?l00000
0omJXoH00ol0003oL[3gog:`m`02og:`maGo00004_ooool00ol0003oL[3gog:`m`05og:`m`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0>ooooo`000ooo
ool00ol0003oooooooooo`0booooo`Co0000?_ooool2o`0000Ko[NGi;?l00002ojk_m`co_ncb1ol0
0004ooooo`Co_ngb00?o0000olKgk?l000001?ooool5o`000003ojZjiOl0003o000000Go000000Co
ZkWSo`000?l0003o00001?ooool2o`000003omoVf?l0003oj^W=00?o00000oooool2o`000004onKK
bOl0003oooooo`0000;oi]_90ol00004oj:bi0Wo00000_oQa;/8o`000003on>n/_l0003og[J`00;o
000000Sog[N_o`000?l0003oooooo`000?oT]ZKo0000om^YXPWo00000_oFTHP2o`000006ooooool0
003o0000ognemol0003ooooo1?l000000omb/?So0000o`00000<o`000003ofP00?l0003o000001Wo
000000Co8AR;o`000?l0003oY=ok0_l000000ol_Ak[o0000o`000003o`000004ooooool0003o;Ec?
o`UBcP;o000000Ko=WGPo`000?naeO?o0000ocMeh?lSL^42o`000004ojk<kol0003o8W7Qo`0000;o
BHg/1Ol000001?oooooo0000o`000?m1SNh4o`000003oc^=k_l0003oGJ;e00;oGJ;e3Ol00006oooo
o`;o000000?o[<G/o`000?mJXoH00_mJXoH00ol0003oL[3gog:`m`05og:`m`05o`000?n/a>_o[<C[
ojc4jol000007oooool00ol0003oL[3gog:`m`05og:`m`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0>ooooo`000oooool00ol0003oooooooooo`0_oooo
o`?o0000@_ooool2okSSm003o`000?nhhoCo^>?d02[o^>?d0ol000000onhhoCo_ncboko/lP02o`00
00Ko_ncb1_l00003ojbli@03o`000?oooooooooo00?ooooo00Oo0000oko]l_nokO;o_ngbo`000?o6
mnco000000Cooooo00Co0000ojZli_nZ_>KoZ[cV0ol000001?o6mnco0000o`000?oBkNL2omgdg@03
o`000?n[^N?oZkWS00;oZkWS0_l000001_oooooo0000o`000?oOi]So0000omoVf0;oj^W=0_l00002
ooooo`;o000000Coi]_9o`000?oooooooooo0_l000001?oVflWo0000o`000?oXd;d6o`000004oj:b
i?l0003o0000oj6bi@Co000000?ohLBko`000?l000000_oR_K85o`000006omjf/?l0003o0000oiR`
j?l0003og[N_0_l000001OoT]ZKo0000om^YX_l0003ooooo00Co000000?oSjo/o`000?l000002ol0
00000ooHPfco0000o`000004o`0000;o_EQ>0_l000000onfA37o0000o`000003o`000003oi<O9?l0
003o000000So000000?oA;k^o`000?m/01/00_l000000on?f?oo0000o`00000Bo`000003obm7^_l0
003o000000;o00000oooool01Ol]G<oo2E;>o`000?l0003o=WGP00Co000000?o=gGPo`000?l00000
0_l000001_lRLN7o0000odV=k?m9SNco0000odV=k0So000000?o@Hg^o`000?l000006Ol000000ooo
oooo0000o`000003oeZSmP03o`000?mb/?OoL[3g00GoL[3g00?o0000ojc4jol000008Oooool00ol0
003oL[3gog:`m`05og:`m`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0>ooooo`000oooool00ol0003oooooooooo`0/ooooo`?o0000A?ooool01?l0003o
^>?dokSSm?nhho@2o`0002Oo^>?d0ol00003okSSm003o`000?nok?;o_ncb00;o_ncb00Co0000oko/
l_l0003o00000_n]_^H00ol0003o[;kVojbniP02o`0000;o[;cU0_l00005ooooo`03o`000?nokO;o
_ngb00;o_ngb00?o0000olKgk?l000000oooool00ol0003oZ[cVo`000002o`000003olKgk?l0003o
000000;o00000_oBkNL2omgdg@?o00001?n[^N<4o`0000;ognKH00Oo0000on[YcOl0003o0000oooo
ool0003oj^W=00;o00000_ooool01_l0003oYKKTo`000?l0003oi]_:o`0000;oj=2m00Ko0000oooo
ool0003oiL^lo`000?nS]^H8o`000003on74^ol0003o000000;oh[fb0ol000000ooN][3o0000o`00
0002o`000005ooooool0003og[N_o`000?oT]ZH00ol00003ooooo`Co000000Goh:NHo`000?l0003o
0000omJBR@03o`000004ogR_mOl0003o0000omN9N@?o000000?oooooo`000?l000002ol000000oma
`Oko0000ohC<o`02o`000003ofP04ol0003oNl_o01co00000_ooool01Ol_Ak[o0000o`000?l/G<oo
000000?ooooo00Co;Ec?o`000?l0003o=WGP1_l000001OlgMN3o0000o`000?lRLN7o000000;oBHg/
00Go0000oooooooooooo0000odV=k006o`000003ojg;kol0003o0000013o000000?oGJ;eo`000?l0
00002ol000000omJXoKo0000og:`m`06og:`m`03o`000?oooooooooo027ooooo00?o0000og:`momb
/?L01Omb/?L00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool03Oooool000?ooooo00?o0000ooooooooool0:Oooool3o`0004Oooooo00?o0000okSSm?nhho@0
0onhho@00ol0003o^>?dokSSm00@okSSm1Co00001_nhho@5oko/lP04o`000?oooooo0000o`0000;o
[KkV0ol00003ojbli@03o`000?oooooooooo00Gooooo00Oo0000oko]l_nokO;o_ngbo`000?o6mnco
000000?ooooo0ol00002olKgk0;o000000?od^gWo`000?l000000ooBkNL2omgdg@03o`000?nX^NGo
Z;WU00Ko000000KoZKOSo`000?oOi]SognKHo`000?oZjLd3o`000003on[YcOl0003o000000;ooooo
00Co0000ojFfi?l0003oYKGT0_l000002?oRd/Oo0000onS@_OoXd;go0000onG;_?l0003oXkKV1Ol0
0002oinbi@Co000000Cog[nio`000?oR_K;oh[fb0ol000001?oooooo0000o`000?l00002ooooo`Go
00001Oooool4o`000003om>ET_l0003o000000;o00000_n</_0:o`0000;o`VUV0_l000000onoH5So
0000o`000003o`000003oj=2Col0003o000000Ko00000on194P00ol0003oPbM;o`00000;o`000003
odlWP?l0003o000000So00000oooool01Ol_Ak[o0000o`000?l0003ooooo00?o000000?o;Ec?o`00
0?lfMN000_l000001OnXc?;o[Lc`ojg<l?n]c?3o000000;o=gGP0ol00002odV=k003o`000?oooooo
oooo00;ooooo00?o0000odV=k?m9SN`01Ol00002od6=kP03o`000?mPXO?o000000Oo00000_mMX_D9
o`0000;oGJ;e2?l00004og:`mbgo00000_mb/?L00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool03Oooool000;ooooo00?o0000ooooooooool09oooool3o`00
04Wooooo00?o0000okSSm?nhho@01Onhho@00ol0003o^>?dokSSm003okSSm0co00004_ooool7okSS
m003o`000?nok?;o_ncb00;o_ncb00?o0000ooooooooool00_ooool3o`000003ojbliOl0003o0000
00?o00001_ooool01ol0003o_ngboko]l_nokO;o0000olKgk?l000000_ooool3o`0000;oa_O/0_l0
00001?oBkNOo0000o`000?ooool4om;]i`;ogOCM00Oo0000ojRiiOnX^NGoZ;WUo`000?oMm=gognKH
00Go00000_oOi]P01_l0003oj^W=o`000?oZjLgo0000onKKb@;ooooo00Co0000ojFfi?l0003oYKGT
0ol00002on;Ba`03o`000?oXd;go000000Wo000000?oXKKWo`000?l000000ol000001OoN_kWo0000
on:m/_l0003og[J`00?o000000SoV;3Xo`000?ooooooooooo`000?oN]Zoo0000omN[Z`;o00001?oo
ool00onA]>ko0000o`000002o`0000?ooooo0ol000000on=^??o0000omJ?Q00Ao`000003ooooool0
003oLL7n00;o000000CoPB=6o`000?oooooooooo4?l000002OnLd?[oCbN0o`000?l0003oooooo`00
0?m2?:CoWM7jod4kY004o`0000?ooooo1ol000000onXc?;o0000o`000003o`000003ojS<l_l0003o
[Lc`00;o[Lc`00Co0000ocMeh?lSL^7o00000_m9SN`00ol0003oooooooooo`04ooooo`;o00000_m9
SN`3o`0000;o@Hg^00Co0000of2QlomPXO?oH:7c3Ol00003oefRm@So000000?oGJ;eo`000?l00000
=?l0000<ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03Oooool000;ooooo00?o
0000ooooooooool09?ooool3o`0004_ooooo00?o0000okSSm?nhho@01_nhho@00ol0003ooooooooo
o`0Pooooo`03o`000?nhhoCo^>?d00Co^>?d00?o0000oko/l_nok?800_nok?800ol0003ooooooooo
o`04ooooo`?o00001On[_NH2o`0000?ooooo00?o0000oko]l_nokO800_nokO800ol0003oa_O/o`00
0002o`0000?oa_O/0_l000000ooBkNOo0000o`000003ooooo`04o`000?oBkNOod^gWom;]i`;o0000
00Goooooo`000?l0003o0000omgdg@02o`000005ojRiiOl0003o0000ojRhi?l000000_oOi]P01Ol0
003oj^W=o`000?oZjLgoi]_900;ooooo00Co0000ojFfi?l0003oYKGT0ol000000ooooooo0000on;B
a`02o`0000?oiL^l1Ol000001?ooooooXKKWo`000?oQa;/2o`000004oijciol0003o0000omjo^@[o
000000Gog[J_o`000?l0003o0000omN[Z`02o`0000?ooooo00CoTKC^o`000?l0003od9ZM0_l00003
ooooo`oo000000?o`Ve/o`000?l000004?l000000on;>F3o0000o`000009o`0000;ooooo0_l00000
1olV7Hoo0000o`000?l0003oooooo`000?l58:800_l000000onWe?Oo0000ooooo`02o`0000;oCFG:
00Co;5c?o`000?nXc?;oZ<cb1ol00002ojS<lP04o`000?n]c?3o[Lc`ojg<l0Oo00000_ooool2o`00
00?o[<_`0_l00002odV=k0Co00000omPXO<00ol0003o[LK/ojg6k007o`000003of2QlomMX_Go0000
00Oo00000_mMX_D4o`000003oefRmOl0003o000000;o00000omd[oHDo`00013ooooo00?o0000og>_
momc[oL01?mc[oL00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool03Oooool000;ooooo00?o0000ooooooooool08Oooool3o`0004kooooo00?o0000okSSm?nh
ho@01Onhho@00ol0003oooooooooo`0Pooooo`03o`000?nhhoCo^>?d00Go^>?d00?o0000oko/l_no
k?800_nok?800ol0003oooooooooo`06ooooo`03o`000?n[_NKoZkgV00GoZkgV0_l000000ooooooo
0000oko]lP02oko]lP03o`000?o6mnco000000Coa_O/00Ko0000om;]iooBkNOo0000ojZjiOl00004
ooooo`09o`000?oBkNOod^gWo`000?oMm=go0000ooooool0003ogOCM00?o000000?oZ;_Vo`000?l0
00000_nV^>H00ol0003ognKHomoVf002o`000005on[YcOl0003o0000ooooool000000_nU]^@4o`00
00?ooooo00Co0000on;Baol0003o00000_oUbk`00ol0003oooooo`000003o`000005oj6fiol0003o
0000o`000?ooool01Ol000001?oI^;Oo0000omjf[ol00004oiZdj`;o000000Goej^[o`000?l0003o
0000omN[Z`02o`000005ooooool0003o0000o`000?o@VYd01?l00003ooooo`05o`000?oCUI?o0000
o`000?o4OH@04Ol000000onYDfGo0000o`000002o`000003oh/iGol0003o000000ko00000_ooool3
o`000003obHMSol0003o000000?ooooo1?l000000onWe?Oo0000o`000002o`0000;oCFG:00Co;5c?
o`000?l0003ooooo0_l000000om=N=co0000odehg003o`0000;oZ<cb00Ko0000ojg<l?l0003o=gGP
o`000?mGSNT6o`000004ojc;l?l0003o0000o`0000CoZlO^2Ol00003ojg6k0;o00001Oooool3o`00
00?oH:7c0_mMX_D8o`0000CoM:of1ol00002ogB^mR;o00000omc[oL00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool03Oooool000;ooooo00?o0000oooooooo
ool07_ooool3o`00053ooooo00?o0000okSSm?nhho@01Onhho@00ol0003oooooooooo`0Qooooo`03
o`000?nhhoCo^>?d00Co^>?d00?o0000oko/l_nok?800_nok?800ol0003oooooooooo`09ooooo`;o
00001_n[_NH00ol0003o_ngboko]lP02oko]lP;o00000oo6mn`01Ol0003od^gWom;]iol0003oZ[[U
00;o00001Oooool01Ol0003od^gWom;]iol0003ogOCM00;o000000?ogOCMo`000?l000000_nX^nH2
o`0000CoY[SV00So0000omoVf?l0003o0000onKKb_l0003oZ;STo`0000;oYKKT0ol000000ooRd/Oo
ooooooooo`02ooooo`;o00000_oOc<D4o`000004ooooool0003ooooooj6fi`?o00000_ooool02onN
/nOo0000o`000?l0003ofKNgo`000?oI^;Oo0000omjf[ol0003oVkCY00;o000000?og[J_o`000?oG
Zj/01?l000000ooGZj_o0000o`000003o`000003om2JWOl0003ooooo00Co000000?oooooohfhlol0
00001?l000000ooooooo0000o`00000No`000005oi?<nol0003o0000o`000?nMd?X01?l000001?mN
?I;o9Qf?o`000?l00002ooooo`?o000000?o;dNjo`000?l000001Ol00002odeUbP07obaLcol0003o
ooooo`000?l]G<oo0000odehg006o`000009ojS<l_l0003o0000o`000?lgMN3o0000oeN=jOl0003o
EXcY00Ko00000on[anh2o`000008ooooool0003oBXg/odZ=k?l0003oIYoao`000?mUWo45o`000003
ojg6k?l0003ooooo00Sooooo00Co0000ojc5kOn/aNgo00000_mPXO<Vo`0000KoM:kf2ol000000omc
[oOo0000ooooo`0<ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool03Oooool000;o
oooo00?o0000ooooooooool06oooool3o`0005?ooooo00?o0000okSSm?nhho@01Onhho@00ol0003o
ooooooooo`0Pooooo`03o`000?nhhoCo^>?d00Go^>?d00Go0000oko/l_nok?;o_ncbo`00000>oooo
o`;o000000?oZkgVo`000?l000000_l00003oko]lP;o00000_o6mn`01?l0003od^gWom;]iol00002
ojZji@03o`000?oooooooooo00Cooooo00Wo0000om;]iooBkNOod^gWo`000?oMm=go0000omgdgOoO
i]P00onX^nH00ol0003oZ;[Vo`000003ojJhiP?o000000Cog]_Co`000?oVfl[oi]_:0_l000001OnU
]^Co0000o`000?l0003oh];700Cooooo1?l000001ooOc<Go0000o`000?l0003ohLBko`000?ooool0
1Ol000000ooooooo0000o`000003o`000008omVg]ol0003ofKRgomVh]ol0003og[J_o`000?nK]>T2
o`000003omN[Zol0003oUkO^00?oUkO^00Go0000omN[Zol0003o0000ombYXP04o`0000;ooooo1Ol0
00000ooCUYCo0000o`00000Po`000003ooooool0003o000000?o000000?oWM3jo`000?l000000_oo
ool00omN?I;o0000o`000004o`000008od4lY?l0003o0000obm7^_l0003oX/_eo`000?l_AkX2o`00
0006oooooom=IL[oCFG:obaLcol0003ooooo0_l000002?m=N=co0000ooooool0003oCGSLo`000?lg
M=oo00000_nXc?800ol0003o=gGPo`000002oeN=j@;o00000_mFS>T2o`000004odV=k?l0003o0000
o`0000Cooooo00Co0000odZ=k?m:SNco00000_mVWo42o`0000?oIIoa1_l00003ooooo`;o00000on/
aNd2o`000003ooooool0003oH:7c00?oH:7c00?o0000ogF]mOme[OD00ome[OD3o`0000GoMJge1_l0
0008ogB^mQKo00000_md[_H00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool03Oooool000;ooooo00?o0000ooooooooool06?ooool3o`0005Gooooo00?o0000
okSSm?nhho@01Onhho@00ol0003oooooooooo`0Qooooo`03o`000?nhhoCo^>?d00Co^>?d00Go0000
oko/l_nok?;o_ncbo`00000?ooooo`?o00001?nokO82o`000003oko]l_l0003oa_O/00?od^gW00Go
0000ojZjiOnZ^^GoZ[[Uo`000007ooooo`08o`000?oBkNOod^gWom;]iol0003ogOCMo`000?oOi]P3
ojRkiP03o`000?nX^^Ko000000?ooooo00[o0000omoVf?l0003og]_Co`000?oMfm?o0000onKKb_l0
003oY[SV0ol000001OoRd/Oo0000o`000?l0003ooooo00Co000000?oXkKVo`000?oOc<D00ol00000
0ooQa;_o0000oj6fi`03o`000003ooooool0003o000000?o00000_oI]kL2o`0000;ofKRg00Co0000
omjf[ol0003og[J_0ol00005oiVfk005o`000?oGZj_o0000o`000?o@VYd00_l000000onD^_7o0000
o`000004o`000005om>FU?l0003o`hB>o`000?ooool07Ol000002?oooooo0000o`000?l0003oODV7
o`000?mlB8KoDBZ20_l000000onMd?[o0000o`000005o`000005oj;:m?l0003o0000o`000?mHEkH0
0_l000001?nRboGo0000o`000?m=ILX2o`000004oooooom=IL[oCFG:obaLc`?o000000?oCGSLo`00
0?ooool00_ooool00ol0003oCGSLo`000003o`000006ocMeh?l0003oEhgYoeN=jOl0003oZlO^0ol0
00000omFS>Wo0000o`000002odV=k0?o00000_ooool00ol0003oBXg/o`000004ofJOl@Co00001?mU
Wo400omPXO?o0000o`000004o`000003ojc5kOl0003ooooo00?ooooo00?o0000of2QlomPXO<00_mP
XO<00ol0003oMJgeogF]m@05ogF]m@03o`000?oooooooooo00Oooooo1Ol0000AogF]m@;o00001omd
[_H4o`0000cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0<ooooo`0000?ooooo
o`000?ooool05oooool3o`0005Sooooo00?o0000okSSm?nhho@01Onhho@00ol0003oooooooooo`0P
ooooo`03o`000?nhhoCo^>?d00Co^>?d00?o0000oko/l_nok?800_nok?800ol0003oooooooooo`09
ooooo`Co00001onokO86o`000003ojZli_l0003oZ[[U00;oZ[[U00?o0000ooooooooool01_ooool0
1?l0003od^gWom;]iooBkNL3o`0000?oZ;_V00?o0000ojRji_l000000oooool00ol0003ognKHo`00
0002o`0000;ogM_C00Ko0000onKKb_l0003oY[[Wo`000?oVflX2on;Ba`?oYKSV00Go0000on;Baol0
003o0000oj>fiP07o`000003on74^ol0003ohLBk00;o000000?oooooo`000?l000000ol00002omVg
]`03oooooonN]nWo000000;ofKRg0ol000001?oGZj_o0000oifhjol00005oiVfk0Go000000?oV;S^
o`000?l000001Ol000000ooCUYCo0000o`000008o`000006ol>0R?l0003o0000o`000?n_K8Co0000
0_n_IWd<o`000003oiMGPOl0003o000000;o000000?oODV7o`000?l000001?l000000onMd?[o0000
o`000008o`000004oeUH]_oooooo0000oeQG]PCo000000GoCFG:o`000?nXc??o0000ooooo`02odeU
bP05obaLcol0003o0000odehg?l000001Oooool01?l0003oCGSLo`000?l00002ocMeh004o`000?mG
SNWoEhgYo`0000?oZlO^0ol000000omFS>Wo0000o`000002odV=k0?o00000_m:SN`01Ol0003oIYoa
ofJOlOmVWo7o000000?oZlK^1_l00003ofFOl@;oH:7c1_l000000ooooooo0000of2Ql`03of2Ql`03
o`000?me[OGoMJge00GoMJge00?o0000ooooooooool06Oooool00ol0003oMJgeogF]m@05ogF]m@Co
00000ome[OD00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool03?ooool00003ooooool0003ooooo01Cooooo0ol0001Jooooo`03o`000?nhhoCo^>?d00Go^>?d
00?o0000ooooooooool08?ooool00ol0003o^>?dokSSm005okSSm005o`000?nok?;o_ncboko/l_l0
00002?ooool4o`0000Oo_ngb1?l00002olSUk0?od^gW0_l00003ojZji@03o`000?oooooooooo00Ko
oooo1_l000001ooOi]So0000ojRki_nX^nKo0000ojRji_l000000oooool4o`000003ooooool0003o
gM_C00;ogM_C00Co0000onKKb_l0003oi]_:0_oRd/L2ojBhi`;o000000?oh];7o`000?l000000_nS
]^H5o`0000;og<K31?l000000ooooooo0000o`000003o`0000;ofKNg00Koooooo`000?l0003oW[OY
o`000?oI^;L5o`000003oifhjol0003ooooo00;ooooo0ol000000ooGZj_o0000olfNY`03o`0000Co
V;S^5_l000000on_K8Co0000o`000002o`000003oiMGP?l0003o000000Oo000000?oUlcjo`000?l0
00003Ol000001?oooooo0000o`000?l00002ooooo`03o`000?mHEkKo;dNj00Co00000_nXc?<01?l0
003oooooodeUb_m=ILX2o`0000;oCGSL00?o0000ooooooooool01?l00002odehg0?o00000_mGSNT4
o`0000?ooooo0_l00002oeJ<j@04o`000?m9SNcoBHg/odV=k0?o00001?mVWo42o`0000?oZlK^0_l0
00000on]a^co0000o`000003o`0000CoIIoa0omPXO<5o`000003of2Qlol0003oMJge00KoMJge00?o
0000ooooooooool08Oooool00ol0003oMJgeogF]m@05ogF]m@03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0<ooooo`0000?oooooo`000?ooool04Oooool3
o`0005cooooo00?o0000okSSm?nhho@01Onhho@00ol0003oooooooooo`0Qooooo`03o`000?nhhoCo
^>?d00Co^>?d00Go0000oko/l_nok?;o_ncbo`000006ooooo`?o00001onokO84o`0000;ob>G/00Co
0000olSUk?o8iNcob>G/0ooBkNL00ol0003oZ[[Uo`000003o`0000Kooooo0_l00002om;]i`;o0000
00SoeN;QomoVf?oOi]So0000ojRki_l0003oZ;[Vo`0000;ooooo0ol000000ooNfm?o0000ooooo`02
ooooo`05o`000?oMfm?ogM_Co`000?oVflX00ol00004ojBhi`Co000000GoXkKVo`000?l0003o0000
omg7a002o`0000?og<K30_l000000ooN_[Wo0000o`000003o`0000;ofKNg0_ooool3o`000008oooo
ool0003ofKNgo`000?oC[[?o0000omN[Zol00005ooooo`04o`000?oGZj_o0000olfNY`Wo000000?o
d9ZMo`000?o2RYT01Ol000000onG_?7o0000o`000002o`000003ok1bSOl0003o/7>=00co000000Go
UeN0o`000?l0003o0000oi]QS006o`000005ohAGU?l0003oQ5NDo`000?mP@9@01Ol000000ooooooo
K5:Rod8lY@03o`0000Cooooo0_mHEkH3o`000006oj;;mOl0003oZ<ccojS<lol0003ooooo0_m=ILX2
o`000005odehg?l0003o0000o`000?nWc?<00ol000000onXanoo0000odehg002o`0000;oEhgY00Go
0000oj_7k_n[ankoZlO^o`000005ooooo`04o`000?mFS>WoEXcYo`0000?oBHg/0_l00004ofJOl@?o
00000on[a^h4o`0000Cooooo0ol00004ofFOl@?oH:7c0ol00004ogF]m@[o00007Oooool00ol0003o
MJgeogF]m@05ogF]m@03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0<ooooo`0000?oooooo`000?ooool03_ooool3o`0005oooooo00?o0000okSSm?nhho@0
1Onhho@00ol0003oooooooooo`0Pooooo`03o`000?nhhoCo^>?d00Go^>?d00Go0000oko/l_nok?;o
_ncbo`000002ooooo`Co00001_nokO84o`0000?ob>G/0_l00005olSUk003o`000?oBkNOod^gW00;o
00001?nY_>H3o`000003ooooool0003o000000;od^gW0ol00002omGRh@06o`000?oOi]SognKHo`00
0?nX^^Ko00000_ooool01Ol0003ognKHo`000?oNfm?o000000Gooooo00?o0000omgKdol000000_l0
00001OoRd/Oo0000o`000?l0003oY;SW00?o00000_nT^>L00ol0003oglc5o`000002o`000004omc5
`ol0003o0000omc6``;o000000?ofL72o`000?oN_[T01?l000002?oI]kOo0000oooooooooooo0000
oijgjOl0003ooooo0_l000000ooB[[Co0000om>^/`04o`0000;ooooo00Go0000omN[ZooGZj_o0000
olfNY`03o`000005olfNYol0003o0000o`000?ooool00_l00002ol::V@So000000Ko`hFAo`000?n`
LXgo0000oic1l_l00002oiS1m003o`000?n`Lhgo000000Co000000OoVV2;o`000?nH`OCo0000oik6
m?l0003oVf6<00Co00000_n4Ei@01Ooooooo0000ohAGU?n4EiCoH42D00?o00000_nSb_@6o`0000Go
oooo1?l00002oj;;m@05o`000?nXc??oZ<cco`000?ooool02?l00005ojS7k`So00000_n[anh00ol0
003oooooooooo`05ooooo`06o`000?mFS>WoEXcYo`000?m9SNco00001?mVWo400ol0003oooooo`00
0006o`0000_ooooo00?o0000ofFOlOl000003?l00006ogF]m@go00004Oooool00ol0003oMJgeogF]
m@04ogF]m@03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`0<ooooo`0000?oooooo`000?ooool02oooool3o`00067ooooo00?o0000okSSm?nhho@01Onhho@0
0ol0003oooooooooo`0Qooooo`03o`000?nhhoCo^>?d00Co^>?d00Co0000oko/l_nok?;o_ncb1?l0
0006oko]lPCo00001?o8iN`2o`0000;ooooo1Oo8iN`01?l0003od^gWom;]iooBkNL3o`0000GoZKcV
0_l00002om;]i`;o000000?oeN;Qo`000?oEh^400ooEh^401?l0003ognKHo`000?l00002ooooo`05
o`000?oOi]So0000omkKdol000001Oooool5o`0000?oh];700Go0000ooooool0003oh];7omo<a@03
o`000003omo<aOl0003o000000;o000000?og<G3oj>hiol000000_l00003omW1`P06o`000?oN_[Wo
0000o`000?oI]kOo00000_ooool3o`000005ooooool0003ofKNgo`000?oB[[@00_l00002om>^/`08
o`000?oGZj_o0000ooooool0003oej^[o`000?o=WZL2o`0000;ooooo1Ol000001_o@VYgo0000ol::
VOl0003oVkg`o`0000?ooooo2_l00002oiS1m0;o000000?o/7>>o`000?l000003?l00004ooooo`;o
Q5ND00CoH42Do`000?l0003o00000onSb_@4o`0000Kooooo00?o0000oeQG]_l000000_l00002oj;;
m@03o`000?nXc??oZ<cc00;o000000KoCFG:o`000?mSNmGo0000odehg?l00003ojS7k`?o000000Go
ooooo`000?m=N=co0000ofB<i005o`000003oj_7k_l0003o000000Sooooo3_l0000?ooooo`03o`00
0?mUWo7oIIoa00;oIIoa00?o0000ogR/lomh[?<00ol00002ogR/l`go00001_me[OD=o`0000Cooooo
00?o0000ogF]mOme[OD01Ome[OD00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool03?ooool00003ooooool0003ooooo00Sooooo0ol0001Tooooo`03o`000?nh
hoCo^>?d00Go^>?d00?o0000ooooooooool08?ooool00ol0003o^>?dokSSm005okSSm003o`000?no
k?;o000000;o00001_nokO83o`0000Gob>G/0_l00005ooooo`03o`000?o8iNcob>G/00;ob>G/00Co
0000om;]iooBkNOo00000oooool5o`0000;od^gW0_l000001?oEh^7o0000o`000?l00004omGRh@03
o`000?oOi]So000000;ooooo00Co0000omoVf?l0003og]_C1_ooool2o`000005omgKe?l0003ofm;@
om_Bd?l000000ooRd/L01?l0003oh];7o`000?l00002ojFjj0Go000000?og<G3oj>hj?l000001?l0
0003omW1`PKo000000Goooooo`000?nN]nWo0000ooooo`02o`0000;odZjd0ol00002om>^/`?o0000
00Koej^[o`000?o=WZOo0000oibjk_l00004ooooo`09o`000?o=WZOo0000om2JWOl0003o`XZIo`00
0?nK_O3o000000Gooooo4_l00004oi]PR`?o00001Oooool6o`000005oig7m_l0003oXl[do`000?m/
Dj<00ol00005ooooo`03o`000?mHEkKoF5Nf00Oo000000CoZ<cco`000?l0003oCFG:0_l000000omS
NmGo0000o`000003o`0000Cooooo00?o0000odehg?l000000_mTS>@00ol0003oIHgTo`000003o`00
0003oj_7k_l0003ooooo00Kooooo00Go0000oeJ=jOmFSNWo0000ofbMkP06o`000003ofJOlOl0003o
000000?o00003Oooool00ol0003oIIoaofFOl@02ofFOl@03o`000?mh[??oN:cc00CoN:cc1ol00006
ogR/l`_o00002?me[OD8o`0000CoMJge00?o0000ooooooooool03?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00cooooo00000ooooooo0000ooooo`05ooooo`?o0000I_ooool00ol0
003o^>?dokSSm005okSSm003o`000?oooooooooo01gooooo1Ol00006okSSm003o`000?nok?;o0000
00Go_ngb1?l00005olSUk003o`000?oooooooooo00Oooooo00?o0000olSUk?o8iN`00_o8iN`01?l0
003od^gWom;]iol00004ooooo`;o00000_oBkNL2o`000003omGRhOl0003oZKcV00;oZKcV00?o0000
omGRhOoEh^400_oEh^400ol0003ognKHomoVf002o`000003omoVf?l0003og]_C00Kooooo0_l00002
omgKe005om_Bd?l0003ofm;@om_Bd?l000000_oRd/L2o`000003oooooonU^^SoYK[X00Go000000?o
g<G3o`000?nS^>P00_l000001?oI`<;o0000oj:hj?l00003omW1`P;o00000_oI]kL6o`000006omVg
]ol0003odZjdom:^]?l0003oWKS[0ol00002om>^/`07o`000?oGZj_o0000olfNYol0003oW;[^o`00
0005ooooo`So00001Oooool00ol0003o`X^Jo`000002o`0000?o/GZG2_l00003oiiZUP04o`000?nN
JYKo0000o`0000?ooooo0_l00002ohAGU0?o000000Ooooooo`000?nMaoKo0000ofaCXol0003oNFJa
00?o00001?ooool01Ol0003oF5Nfo`000?l0003oJVg300;o000000?oXl[do`000?l000000_l00000
0om=IL[o0000of=ke@02o`0000;oHg_E00?o0000odehg?l000001?ooool00ol0003oCGSLo`000003
ofB<i0;o000000?oIHgTo`000?l000001?l00005ooooo`05o`000?mFSNWoEXgYoeJ=jOl000000_m/
WNh2o`0000;oK9g^1?l00002ofJOl@Go00002Oooool01Ol0003oIIoaofFOlOmUWo7o000000OoN:cc
00?o0000ooooooooool01?ooool9o`0000[oN:cc1_l00007ogF]m@Ko00003_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00cooooo00000ol0003oooooooooo`02ooooo`?o0000J?oo
ool00ol0003o^>?dokSSm005okSSm003o`000?oooooooooo01Oooooo1ol00005okSSm0;o00000onh
ho@3o`0000?o_ngb0ol00006olSUk003o`000?oooooooooo00[ooooo00?o0000olSUk?o8iN`00_o8
iN`01?l0003od^gWom;]iol00002ooooo`;o00000_oBkNL2o`0000;oeN;Q00?o0000ojVli_nY_>H0
0_nY_>H2o`0000?oeN;Q00Go0000omoVf?oOi]So0000omoVf002omkKd`Kooooo0_l00002omgKe003
om_Bd?l0003o000000?ofm;@0_l000001ooRd/Ooglc6o`000?nU^^So0000omo<aOoNblD00ol00002
ooooo`?o000000?ofL32oj:hj?nR^>P00_l000001OoI`L;o0000o`000?oD^Koo000000;ofKNg0_l0
00001?nO^N_o0000omVg]ol00002om:^]0;o000000KoWKS[o`000?ooooooooooo`000?oC[[<5o`00
0003oibjk_l0003ooooo00Cooooo00Co0000olfNYol0003o`I2S1ol000001_oooooo0000ol:;V_l0
003o/GZGo`0000;oV;oc00Go0000oic1l_l0003o0000ok5jU`02o`000003oiiZU_l0003o000000;o
000000Ooooooo`000?nJ`oCo0000oiiZU_l0003oQ5ND00?o000000CoQ5NDoh]UX_n;IJ;o00000_n;
IJ402ol0003oooooo`000?l0003oK5>So`000?miI[7oXl[do`000?mhIK7oFERf00Co000000CoF5Nf
o`000?m[KL?o00000_mZKL<2o`0000;oYLKa0_l000000om=IL[o0000of=ke@03o`0000;oHg_E0ol0
0003ooooo`03o`000?m=N=co000000?oI8cT0ol00002ofF=i0Go00001?ooool2o`0000;oEXgY00?o
0000ofbMk_m/WNh00_m/WNh4o`0000;oK9g^1?l00003ofJOl@Go00001?ooool00ol0003oIIoaofFO
l@02ofFOl@03o`000?mh[??oN:cc00GoN:cc00?o0000ooooooooool04?ooool5o`0000koN:cc0_l0
00000ome[OGo0000o`000002o`0000gooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0;ooooo`0000?o0000ooooool000000_l0001[ooooo`03o`000?nhhoCo^>?d00Go^>?d00?o0000
ooooooooool04Oooool6o`0000ko^>?d0_l000001?nhhoCo0000oko]l_nokO82o`0000Oob>G/00?o
0000ooooooooool03Oooool00ol0003ob>G/olSUk002olSUk003o`000?oBkNOod^gW00?o00000_oB
kNL2o`0000;oeN;Q00?o0000ooooool000000_l00002ojVliP;o00000ooEh^401?l0003ognKHomoV
f?l00002omkKd`Oooooo00Go0000omgKe?oMfmCofm;@o`000002ooooo`05o`000?oKd]3ofm;@om_B
d?l000000ooOc<H00ol0003oglc5o`000004o`0000;ooooo0_l000000ooI`<;oooooooooo`02o`00
0004oj2gj?l0003o0000o`0000;oe;Vo00Go0000omVg]ooI]kOo0000oinij`02o`0000;odZjd2Ol0
00000ooC[K?o0000olZR/004o`0000Gooooo00Ko0000olfNYol0003o`I2So`000?nK_O04o`000004
ol:;V_l0003o0000ol:;VP;o000000Koooooo`000?nH_o?o0000oic1l_l00002ooooo`;o000000?o
WVZFo`000?ooool01?ooool00ol0003oV/?do`000004o`0000;oRfFR00?o0000ooooool000000_n;
IJ401om^E:Co0000o`000?m/Dj?o0000ogUV/Ol000000_nSb_@00omhIK7o0000o`000002oj?:m0;o
00000_m[KL<2o`0000;oJVg30ol000001onUa_7o0000odeUb_l0003oHg_Eo`000?nXao000ol00002
of=ke@?o000000Coooooo`000?m=N=co00000omTS>@01Ol0003oooooo`000?nXanoo000000?oIHgT
00?o0000oeJ=jOl000000ol000001OnZa^ko0000oeJ=jOmFSNWo000000CoK9g^00Co0000oooooooo
oooooooo1Ol00002ofbMkP?o00001?mVWo46o`0000CoIIoa00?o0000ogR/lomh[?<01?mh[?<00ol0
003oooooooooo`0Mooooo`03o`000?mh[??oN:cc00;oN:cc1?l00003ogR/l`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0;ooooo`000_l0001]ooooo`03
o`000?nhhoCo^>?d00Go^>?d00?o0000ooooooooool02oooool7o`0001;o^>?d2?l00006olSUk1;o
oooo00?o0000olSUk?o8iN`00oo8iN`01?l0003od^gWom;]iol00002om;]i`;o00000_oEh^400ol0
003oooooooooo`04ooooo`Co00001?oEh^44o`0000Oooooo00Co0000omgKe?oMfmCofm;@0_l00003
ooooo`03o`000?oKd]3o000000;o00000_oOc<H6o`0000;ooooo0_l000001OoI`<;o0000oooooooo
ooooXk[Y00?o000000?oe;Voo`000?l000000_oD^Kl01ol0003ofKNgomVg]ol0003ofKNgo`000?oB
[[@00ol00006oijkk@;o000000CobZ:`o`000?o:X[3obZ:`1ol000000oo=WZOo0000ol6@X`02o`00
0004oi^ml?l0003oooooooooo`Co000000?o`X^Jo`000?l000001?l000002?nL`O;o0000ooooool0
003o/G^Ho`000?nNJYKo00000oooool7o`000003oh]UX_l0003o000000Cooooo00Go0000oh]UXOl0
003o0000ofaCX`05o`000004oj?:m?l0003oN6FaoeUH]PCo000000?oJfg3o`000?l000000_l00002
ofY]``03odeUb_l0003o000000;oCFG:00?o0000of=keOl000000_nXao001ol0003oooooo`000?l0
003oHg_Eo`000?m=N=`00_l00002odehg004o`000?mTS>CoI8cTo`0000;ooooo0_l000000onXanoo
0000ofF=i002ofF=i0Ko00000omFSNT00ol0003oK9g^ofbMkP02ofbMkP03o`000?oooooooooo00Go
oooo0ol00003ofbMkP;o00001_mVWo43o`0000;oIIoa00?o0000ogR/lomh[?<01Omh[?<00ol0003o
ooooooooo`0Qooooo`03o`000?mh[??oN:cc00GoN:cc00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00_ooooo0002ooooo`03o`000?oooooooooo06[ooooo
00?o0000okSSm?nhho@01Onhho@00ol0003oooooooooo`05ooooo`Ko00004Onhho@8o`000004okkM
kol0003o0000okkNk`Cob>G/0_l000000oo8iNcoooooooooo`0Cooooo`03o`000?o8iNcob>G/00?o
b>G/00?o0000om;]iol000000_oBkNL01?l0003oeN;QomGRhOoEh^4:ooooo`04o`000?nX^nOo0000
omGRh@Co000000?og]_Do`000?l000001Oooool01Ol0003ogM_DomgKe?oKd]3oY[WW00;o00000ooo
ool3o`0000;ofLg>1_l000000ooLaL?oooooooooo`02o`000004omW0`_l0003oooooooooo`Go0000
00Coe;Voo`000?oooooo00000_oD^Kl01?l0003ofKNgo`000?l00002om:^]0?o00000onO^^`3o`00
0003om>]/ol0003obZ:`00;o00000oo:X[000ol0003ocIjWo`000002o`000003olfNYol0003o`I2S
00;o000000?oVkg`o`000?ooool00ooooolDo`000003oiiZU_l0003oX7BQ00;oX7BQ00?o0000oh]U
X_l000001ol00002oh]UX@Wo000000?oN6Fao`000?mIF;H00_l000000om[KL?o0000o`000003oooo
o`05o`000?mZKL?oJVg3odeUb_l000000_m=ILX3o`0000?oZ<O`00Co0000oooooooooooo00000_mS
NmD01Om=N=co0000odehg?m=N=co000000;oI8cT00?o0000ooooooooool00_ooool01?l0003oZ<O_
ojS7kol00004ofF=i0Co00000_mFSNT00ol0003oK9g^ofbMkP02ofbMkP03o`000?oooooooooo00[o
oooo0_l00004ofbMkP03o`000?mVWo7oIYoa00?oIYoa0_l000000omUWo7o0000ogR/l`05ogR/l`03
o`000?oooooooooo02;ooooo00?o0000ogR/lomh[?<01?mh[?<00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool02oooool000?ooooo00?o0000ooooooooool0
J?ooool00ol0003o^>?dokSSm005okSSm003o`000?oooooo000000Ko00003onhho@8o`0000Ko_]g_
0ol00003okkNk`Gob>G/00?o0000ooooooooool05?ooool00ol0003ob>G/olSUk002olSUk005o`00
0?oBkNOo0000om;]iol000000ooEh^4=ooooo`Co000000?oe=WLo`000?oNfm@00_oNfm@4o`000009
ooooool0003ogM_DomgKe?oKd]3oY[WWo`000?oooooo000000;ooooo00Co0000om_Bd?l0003o0000
0ooIcLh00ol0003ogLW4o`000002o`0000?ooooo00?o0000omW0`_l000000oooool01?nS^^Wo0000
o`000?l00002omBi_`?ooooo00?o0000omBi_ooD^Kl01ol000000onQ^n_o0000oinjk003oinjk0;o
00000_o:X[04o`0000;obZ:`0_l000001Oo=WZOo0000olfNYol0003o`I2S00Wo000000?o`I2To`00
0?nbPZ400_l00003ok62XPSo00001onPM:42o`000003oh]UX_l0003oWlOd00;oWlOd2Ol00003oj73
l@;o000000CoYLK`ogQU/OmhIK7oFERf0_l000000om[KL?o0000ooooo`04ooooo`0:o`000?mZKL?o
JVg3o`000?m=IL[o0000of=keOl0003oYLKao`0000?oZ<O`00Co0000oooooooooooo00000_mSNmD2
o`000005odehg?l0003oI8cTofB<i?l000000oooool7o`0000CoIHgT0ol000000omFSNWo0000ofbM
kP03ofbMkP03o`000?oooooooooo00oooooo00?o0000ofbMk_m/WNh00_m/WNh01?l0003oIYoaofJO
lOmVWo42o`0000CoN:cc2?l0000Oooooo`03o`000?mh[??oN:cc00GoN:cc00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00_ooooo0004ooooo`;o0000J?oo
ool00ol0003o^>?dokSSm003okSSm0Co00003_nhho@8o`0000co_]g_0_l00006okkNk`03o`000?o8
iNcob>G/00;ob>G/00?o0000ooooooooool05?ooool00ol0003ob>G/olSUk002olSUk0?o00000ooE
h^400ol0003oooooooooo`0;ooooo`08o`000?oEh^7o0000o`000?oDfMco0000omCIg?l00003omkK
e004o`000?nX^nOoZ;_Wo`0000;ogM_D00?ofm;@ojJiiol000000_ooool00ol0003oooooo`000002
om_Bd004ooooool0003o0000omW=cP?o000000GogLW4o`000?oLaL?o0000ooooo`02o`000004omW0
`_l0003oooooooooo`;o000000Goooooo`000?oD^Kooe;Voo`000002ooooo`04o`000?nR^n[o0000
omBi_`?o00000ooB[K<3o`0000?oWk[/00?o0000om>]/ol000000_o:X[001?l0003oXKg]o`000?nN
_>d2o`0000;obZ:`3_l000001?o1T:Co0000ok:2XOl00003oic0l@08oiRolol0003o0000ok62X_l0
003o/X>Ro`000?nQM:4:o`000003oh]UX_l0003o000000Go00000_n;IJ87o`0000;oX/Ca1ol00007
ooooo`?oJVg30_l000001OmSNmGo0000ojG6lOnUa_7o000000?oZ<O`00Co0000oooooooooooooooo
0omSNmD2o`0000;oI8cT1?l00003ojO7l0?o00000_ooool5ofF=i0Co00001?m/WNh00ol0003ooooo
ooooo`0Cooooo`03ofbMk_l0003o000000;o000000?oIYoao`000?l000000ol00007ogR/l`So0000
6?ooool00ol0003oN:ccogR/l`04ogR/l`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0;ooooo`001_ooool00ol0003oooooooooo`1Tooooo`04o`000?nh
hoCo^>?dokSSm0?o00002onhho@7o`0000oo_]g_1Ol00007okkNk`03o`000?o8iNcob>G/00?ob>G/
00?o0000ooooooooool04oooool;o`0000gooooo0_l000001OoEh^7o0000omCIg?oDfMco000000;o
e=WL00Co0000omkKe?oNfmCog]_D0ol00002omgKe003om_Bd?l0003o000000;o000000?oooooo`00
0?l000000_oKd]02ooooo`03o`000?nU^^So000000Go00000_oLaL<2o`000003omW0`_l0003ooooo
00;ooooo00KoXk[Yo`000?l0003o0000omBi_ol00003ooooo`Co000000?oe;Voo`000?o>/;`00_l0
0003om:]/`04o`000?ooooooooooooooo`;o00000_o:X[001Ol0003oX;c]oj6mkOnQ_Ngo000000;o
W[c]0_l000000oo:X[3o0000o`000002o`000004ol6@Y?l0003o0000o`0000?oW[k_00Go0000ol6@
Y?o1T:Co0000ok:2X@09o`000003ok:3X_l0003oXGBQ00;o00001_nO`O001?l0003oXGFQo`000?n;
IJ83o`0000;oRfFR00?o0000oi1b[Ol000000_n@LZd01OmiI[7o0000oooooooooooo000000;oX/Ca
00Oo0000ogQU/OmhIK7oPWJmo`000?m[KL?o000000Sooooo1ol00002ojG6l@05o`000?nXao3oZ<O`
ojS7l?l000000oooool8o`0000;oYlO`0ol00007ooooo`CoIHgT2_l0000Dooooo`03o`000?m]WNko
KIg^00;oKIg^00Go0000ogbYl?l0003o0000ogfYl008o`0000OoN:cc2?l0000@ooooo`03o`000?mh
[??oN:cc00GoN:cc00?o0000ooooooooool03Oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00_ooooo0007ooooo`03o`000?oooooooooo06;ooooo00?o0000okSSm?nhho@00_l00006
okSSm0So00003onngNl7o`0000Cooooo2?nng^l00ol0003ob>G/olSUk002olSUk003o`000?oooooo
oooo017ooooo0ol00002olSUk0?o000000?obmgVomGRhOoEh^400_oEh^400ol0003oooooooooo`09
ooooo`;o000000CoeN;Qo`000?l0003oe=WL0_l00004omCIg005o`000?oNfmCog]_DomkKe?l00000
0_oMfm@00ooKd]3oY[_XojJkj003ojJkj0;o00000_oKd]02ooooo`03o`000?nU^^So000000Go0000
00?oe/O;o`000?oLaL<01?l00002ooooo`Co000000?oe;Voo`000?l000000oooool00onR^n[o0000
o`000002o`000005olj`_?l0003oc[2lolj`_?l000000ooB[K<2o`000007ooooool0003o0000olZR
/?l0003oX;c]o`000002oj6mk@03o`000?oooooooooo00;ooooo00?o0000olZR/?l000000_noUZd3
o`000003ol6@Y?l0003o000000;o000000Co`I2To`000?nbPZ7o00001?nN_^l00ol0003oXL7_oj71
k`02o`000004ok:3X_l0003oXGBQo`0000;oWl7`1Ol00002oj5eX@05o`000?n;IJ;o0000oh]UX_l0
00000on@LZd01?oooooo0000oi1b[On@LZd2o`0000?ooooo0_l00002ogQU/@;oPWJm0_l000000om[
KL?o0000ooooo`06ooooo`08o`000?mZKL?oJVg3o`000?mhOlko0000of=keOl00002ojG6l@05o`00
0?nXao3oZ<O`ojS7l?l000000_ooool01Ol0003oHg_Eof=keOl0003oLhcM00;o000000?oI8cTo`00
0?l000003?ooool2o`0000;oIHcT00?o0000ogJKj?mfVnP00ol00002ofbMkP?o00004Oooool00ol0
003oKIg^offMkP02offMkP03o`000?mlZO3oO:W`00;oO:W`0ol00005ogfYl0So00001omh[?<7o`00
00[ooooo00?o0000ogR/lomh[?<01?mh[?<00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool02_ooool000Sooooo0_l0001Rooooo`?o00000onhho@5o`0000oo
_]g_2?l0000;ooooo`03o`000?nng^oo_]k_00Go_]k_00?o0000olSUk?o8iN`00_o8iN`00ol0003o
ooooooooo`0>ooooo`?o00000_o8iN`3o`000005ol_Mi_l0003obmgVol_Mi_l000000ooEh^400ol0
003oooooooooo`08ooooo`04o`000?oEh^7oeN;Qo`0000;oe=WL00?o0000ooooool000001?oDfM`0
1ol0003og]_DomkKe?oNfmCo0000omgKe?oKd]000_ooool3o`000005ojJkj?l0003ofm;@om_Bd?nV
^nP00_l000000onU^^So0000omW=cP04o`0000?oe/O;0_l00003omW0`@Ko000000?oe;Voo`000?oo
ool00_ooool5o`0000;oc[2l0_l00002olj`_0;o00000ooB[K<01ol0003odjfco`000?o:X[3o0000
oj2lkOl000000_nQ_Nd00ol0003oooooooooo`02ooooo`;o000000Co_iJ]o`000?l0003o00000_no
UZd3o`000005ol6@Y?l0003o`I2To`000?nbPZ401Ol000002?nO`?3o0000oj71konQ`Noo0000ok:3
X_l0003oXGBQ0_l00002ooooo`Ko000000?oRfFRo`000?l000000_n@LZd5ooooo`05o`000?n@LZgo
0000ogUV/Ol000000_ooool00ol0003oN6Fao`000003oh9f_@05o`000?n2M[go0000of]]`ol00000
1Oooool02_l0003oJVg3ofY]`ol0003oN7o>o`000?mhOlko0000of=keOl00002ojG6l@04o`000?nX
ao3oZ<O`ojS7l0?o00000_mSNmD2o`0000;oLhcM00?o0000ofB<i?mTS>@00_l0000:ooooo`05o`00
0?mUS>CoIHcTofF<i?l000000_mfVnP00ol0003oMY_XogJKj003o`0000;oK9g^0ol0000?ooooo`03
o`000?m]WNkoKIg^00;oKIg^00?o0000ogbYl?mlZO001?mlZO05o`0000SoOJW`2?l00006ogR/l`So
00000_ooool00ol0003oN:ccogR/l`05ogR/l`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0:ooooo`002_ooool00ol0003oooooooooo`1Nooooo`04o`00
0?nhhoCo0000o`00017o_]g_1_l0000Cooooo`03o`000?nng^oo_]k_00Go_]k_00?o0000olSUk?o8
iN`00_o8iN`00ol0003oooooooooo`0;ooooo`?o00000_o8iN`3o`0000?obmgV00?o0000ol_Mi_o;
gNH00_o;gNH01Ol0003oeN;QomGRhOoEh^7o000000Oooooo0_l000001?oEh^7o0000o`000?oDfM`2
o`0000?ooooo00?o0000omCIg?oDfM`00_oDfM`01Ol0003og]_Do`000?oMfmCo000000Kooooo00?o
0000om_Bd?oKd]000onV^nP2o`000003omW=c_l0003o000000Co000000Goe/O;o`000?l0003odl;9
o`000003omW0`@Co000000?oe;Voo`000?l000000oooool3o`000006omBi_ol0003oc[2lolj`_?l0
003ooooo0_l00002olj`_0;o000000?odZfco`000?l000000_o:X[000ol0003oX;c]o`000002oj6m
k@09o`000?ooooooooooooooool0003obZ:`o`000?noUZgo000000;oWkk^0ol00002oknF[@co0000
0_nQ`Nl01?l0003o/X>Ro`000?nQM:44o`0000KoXGBQ0ol00002oj?3l003o`000?oooooooooo00;o
oooo00Wo0000oi1b[On@LZgoNFJao`000?oooooo0000ogQU/Ol000000on2M[d2o`0000;oPWJm00?o
0000of]]`ol000000oooool01?l0003oJVg3ofY]`ol00002ogQocP;o000000CoN7o>o`000?mSNmGo
00000_nUa_400ol0003oZ<O`ojS7l002o`0000;oHg_E00Co0000og><gOmcS=go00000_mcS=d2o`00
00;oI8cT0_l00008ooooo`05o`000?mUS>CoIHcTofF<i?l000000omfVnP00ol0003oMY_XogJKj002
ogJKj0?o00000_m/WNh3o`0000cooooo00?o0000offMk_m]WNh00_m]WNh00ol0003oO:W`ogbYl004
ogbYl003o`000?oooooooooo00;ooooo2?l00008ogfYl0Ko00002?mh[?<6o`0000CoN:cc00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00[ooooo000;oooo
o`03o`000?oooooooooo05gooooo0onngNl4o`0000Wo_]g_0ol0000Kooooo`03o`000?nng^oo_]k_
00Go_]k_00?o0000olSUk?o8iN`00_o8iN`00ol0003oooooooooo`08ooooo`?o00000oo8iN`2o`00
00CobmgV0_l00005ol_MiP05o`000?oEh^7oeN;QomGRhOl000001_ooool01Ol0003oeN;QomGRhOl0
003oe=WL00;o00001_ooool02Ol0003oe=WLomCIg?oDfMco0000omkKe?l0003ofm;@o`000005oooo
o`03o`000?oKd]3ofm;@00Go000000CofLg>ojFkjOl0003oYK_Y1ol00002om?2b@04o`000?oI`<7o
fL31omW0`@;o000000Coe;Voo`000?l0003o00000oooool01?nR^n[o0000o`000?l00003olj`_005
ooooool0003o0000oj6kjol000000oo>/;`6o`000004oj2lkOl0003oXKg]o`0000Cooooo00Go0000
olZR/?l0003o_iJ]o`000002oinnkP03o`000?nQ_^koXKk^00?o000000?o_iJ]o`000?l000003_l0
00000onQM:7o0000o`000004o`0000?oXgj/00?o0000oi1c[_l000000_nS`o000ol0003ooooooooo
o`03ooooo`07o`000?n@LZgoNFJaogUV/Ol0003oN6Fao`000002oh9f_@03o`000?nRa?7oX/Ca00;o
00000_n2M[d2o`0000?ooooo00Co0000ofY]`omZKL?o00000_mhOlh01?l0003oooooo`000?mhOlh9
o`0000;oHg_E00Co0000og><gOmcS=goLhcM0_l00002og><g@;o00000_mTS>@2o`0000Kooooo00Go
0000ofF<i?mUS>CoIHcTo`000004ogJKj0?o00001?mfVnP4o`000004ofbMk_l0003o0000o`0000Wo
oooo00?o0000offMk_m]WNh00_m]WNh00ol0003oO:W`ogbYl005ogbYl003o`000?oooooooooo00Wo
oooo1_l00009ogfYl0Go00002?mh[?<3o`0000;oN:cc00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo000<ooooo`;o0000GOooool00ol0003o_]g_
okkMk`04okkMk`;o00000_nngNl00ol0003oooooooooo`0Pooooo`03o`000?nng^oo_]k_00Co_]k_
00?o0000olSUk?o8iN`00oo8iN`00ol0003oooooooooo`06ooooo`;o00000oo8iN`3o`0000?obmgV
0ol000000ooooooo0000ol_MiP04ol_MiP05o`000?oEh^7oeN;QomGRhOl000001?ooool2o`000005
omGRhOl0003oe=WLomCIg?l000002?ooool00ol0003oe=WLomCIg003o`0000?ofm;@00Go0000oooo
ooooooooooooo`000002om_Bd009ooooool0003oooooooooool0003ofLg>ojFkjOl0003oYK_Y00;o
00000onU^nT2o`0000Codl;900?o0000omW0`OoI`<400_l000000ooD^Koo0000o`000003ooooo`?o
000000Coe;Voo`000?o>/;coc[2l0_ooool2o`000005oj6kjol0003o0000o`000?o>/;`00ol00003
olZR/0;o000000?oXKg]o`000?ooool00_ooool02Ol0003obZ:`o`000?noUZgo0000ooooool0003o
Wkk^o`000002oj6nkP07o`000?ooooooooooo`000?noUZgo0000ok::[002o`0000Co/XZ/2?l00008
oj=n[0;o000000GoT7>^o`000?nS`o3oXl?`o`000005ooooo`04o`000?n@LZgoNFJaogUV/@;o0000
00CoPWJmo`000?oooooo00000_nRa?402Ol0003oYLK`o`000?n2M[go0000of]]`ol0003oooooo`00
0002ofY]``03o`000?mhOlkoN7o>00Go00000_mhOlh00ol0003oHg_Eo`000002o`000005ooooool0
003oHg_Eof=keOl000000omcS=d01?l0003oooooo`000?l00002og><g@;o00000_mTS>@00ol0003o
ooooooooo`03ooooo`05o`000?mUS>CoIHcTofF<i?l000001?mfVnP00ol0003oooooooooo`03o`00
00GoMY_X0ol000001?m/WNko0000o`000?l00006ooooo`03o`000?m]WNkoKIg^00;oKIg^00?o0000
ogbYl?mlZO001OmlZO000ol0003oooooooooo`0Aooooo`Co00002ommZO03o`0000GoN:cc0ol0000A
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02_ooool000kooooo00?o0000oooo
ooooool0F_ooool00ol0003o_]g_okkMk`05okkMk`03o`000?oooooooooo02?ooooo00?o0000okkN
konng^l01?nng^l00ol0003ob>G/olSUk003olSUk003o`000?oooooooooo00?ooooo0ol00002olSU
k0?o00000oo;gNH3o`0000Cooooo00?o0000ol_Mi_o;gNH00oo;gNH01Ol0003oeN;QomGRhOoEh^7o
000000;ooooo0_l00002omGRh@04o`000?oDfMco0000o`0000Wooooo1?l000000ooCd]So0000o`00
0003om_Bd003o`000?oooooo000000;ofm;@0_ooool01ol0003oooooo`000?oIcLkoooooo`000?oo
ool01_l000000ooC`/Wo0000o`000004om?2b@Oo00000oooool2o`000005omBi_ol0003oc[2lolj`
_?l000000_ooool01?nQ^n_o0000oj6kjol00002ooooo`04o`000?o>/;co0000olNW^@?o00000_o:
X[02o`0000?ooooo00Wo0000olZR/?l0003o_iJ]o`000?oooooo0000oinnk_l000000_nQ_^h02?l0
003oooooooooool0003o_iJ]o`000?nbRZco00001?ooool02?nO`?3o0000ok::[?nbRZco0000ok:;
[?l0003oXgj/1Ol00004ooooo`05o`000?nSOjco0000oi1c[_l000000_nS`o000ol0003ooooooooo
o`02ooooo`Go000000?oPWJmo`000?ooool00_ooool01Ol0003oX/Caoj;4lOl0003oYLK`00;oPWJm
00?o0000of]]`ol000000_mZKL<01?l0003oN7o>ogQoc_l00005ojG6l@06o`000?mhOlkoN7o>o`00
0?mSNmGo00000_ooool00ol0003oHg_Eo`000004og><g@05o`000?ooooooooooooooool000000omc
S=d00ol0003oI8cTofB<i002o`0000Cooooo00Co0000ofF<i?mUS>Co00001?mfVnP00ol0003ooooo
ooooo`03ooooo`?o00001OmfVnP3o`000004ofbMk_l0003o0000o`0000?ooooo00?o0000offMk_m]
WNh00om]WNh00ol0003oO:W`ogbYl004ogbYl003o`000?oooooooooo01Sooooo0ol0000<ogfYl0;o
00000_mh[?<00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool02_ooool000oooooo00?o0000ooooooooool0FOooool00ol0003o_]g_okkMk`05okkMk`03o`00
0?oooooooooo02;ooooo00?o0000okkNkonng^l01Onng^l00ol0003ob>G/olSUk002olSUk004o`00
0?ooooooooooooooo`?o00000_o8iN`3o`0000?obmgV0ol00008ooooo`03o`000?o;gNKobmgV00?o
bmgV00Co0000omGRhOoEh^7oeN;Q0_l00002omGRh@04o`000?oDfMcoe=WLo`0000[ooooo00Ko0000
omCIfooDfM_o0000om?Bf?l00002om;Af005o`000?oKd]3ofm;@om_Bd?l000000_oKd]03ooooo`;o
000000CofLg>ooooool0003ooooo0_l00003ooooo`06o`000?oC`/Wodl;9o`000?nT^nWo00000ooC
`/T3o`0000?oe;Vo0_l00002ooooo`?o00000_o>/;`01Ol0003ooooooooooooooooo000000;oXK_[
00?o0000ooooooooool00_l000000oo7YkWo0000o`000002olNW^@;o00000_o:X[02o`000003oooo
ool0003o000000;o_iJ]00Go0000ooooool0003oWkk^o`000002oj6nkP03o`000?oooooooooo00;o
00000_nbRZ`00ol0003oooooooooo`02ooooo`09o`000?nO`?3o0000oj71kol0003o/X^/o`000?nS
OZco000000Sooooo00Go0000oj=o[?l0003oT7>^o`000002oj?3l003o`000?oooooooooo00;o0000
0on@LZh3o`0000Cooooo00Co0000oj;4lOnRa?7oX/Ca0_l00002oh9f_@;o00000_mZKL<01?l0003o
N7o>o`000?nUa_45o`000006ooooool0003oN7o>ogQoc_l0003oHg_E0_l00002of=ke@05o`000?mc
S=goLhcMog><gOl000001Oooool2o`0000?oLhcM00?o0000ofB<i?mTS>@00_l00002ooooo`04o`00
0?mUS>CoIHcTo`0000CoMY_X00?o0000ooooooooool01_ooool3o`0000GoMY_X0_l00002ofbMkP?o
000000?oooooo`000?m]WNh00om]WNh00ol0003oO:W`ogbYl005ogbYl003o`000?oooooooooo01oo
oooo00?o0000ogfYl?mmZO001?l00004ogfYl003o`000?oooooooooo00oooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0:ooooo`004?ooool2o`0005Wooooo00?o0000okkMkonngNl0
1OnngNl00ol0003oooooooooo`0Rooooo`03o`000?nng^oo_]k_00Go_]k_00?o0000olSUk?o8iN`0
0_o8iN`4o`0000?ob>G/0_l00004ol_MiP;o00002oooool00ol0003obmgVol_MiP03ol_MiP05o`00
0?oEh^7oeN;QomGRhOl000000_oEh^401?l0003oe=WLomCIg?l0000:ooooo`03o`000?oDfM_o0000
00?o00001?oBdMP01_l0003ofm;@om_Bd?l0003ofm;@o`0000?ooooo00Go0000omW=c_oooooo0000
ooooo`02o`0000?ooooo0_l000000ooC`/Wo0000ooooo`02ooooo`07o`000?oC`/Wo0000om?2bOl0
003ockc7o`000004omBi_`?o000000?oe;Voo`000?o>/;`00_l00002ooooo`;o000000[oXK_[o`00
0?ooooooooooo`000?o>/;co0000olNW^Ol0003ooooo0_l00002olNW^@;o00000_o:X[001Ol0003o
bZ:`o`000?noUZgo000000;ooooo00?o0000oinnk_l000000_nQ_^h00ol0003oooooooooo`02o`00
00;o/XZ/00?o0000ooooooooool00_ooool02Ol0003oWl3`o`000?nQ`Noo0000ok:;[?l0003oXgj/
o`000008ooooo`04o`000?nSOjco0000oi1c[P;o00000_nS`o02o`0000?oT7:^00Go0000oiEn^?l0
003oPWJmo`000005ooooo`05o`000?nRa?7oX/Cao`000?nUa_000on2M[d00om[KL?o0000o`000002
ogQocP;o00002?ooool3ogQocP05of=keOl0003oHg_Eof=keOl000000omcS=d00ol0003ooooooooo
o`05ooooo`;o00000_mcS=d2o`0000;oI8cT0ol00002ofF<i003o`000?mfVnSoMY_X00;oMY_X00?o
0000ooooooooool02Oooool3o`0000KoMY_X00?o0000ofbMk_m/WNh00ol00003offMkP03o`000?ml
ZO3oO:W`00GoO:W`00?o0000ooooooooool08_ooool00ol0003oOJW`ogfYl005ogfYl003o`000?oo
oooooooo013ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`09ooooo`004_ooool0
0ol0003oooooooooo`1Fooooo`03o`000?nngNoo_]g_00Go_]g_00?o0000ooooooooool08_ooool0
0ol0003o_]k_okkNk`05okkNk`04o`000?o8iNcob>G/olSUk0;o00001?o8iN`00ol0003obmgVol_M
iP02ol_MiP;o00003_ooool00ol0003obmgVol_MiP03ol_MiP06o`000?oEh^7oeN;QomGRhOl0003o
eN;Q0_oDfM`00ol0003oooooooooo`08ooooo`;o000000Koe=WKo`000?oCd]So0000ooooool00005
om;Af0;o000000[ofm;@omW=c_oIcLko0000ooooool0003ofLg>ooooool0003ooooo0_l00004oooo
o`03o`000?oC`/Wo000000Gooooo00Co0000om?2bOl0003o00000_o?_<L2o`0000?oe;Vo00?o0000
omBi_ol000000_o>/;`00ol0003oXkc[o`000009o`0000;oajNi0_ooool00ol0003oX;c]o`000002
o`000005olNW^Ol0003o0000o`000?o:X[001_l000002onO_^ko0000oj6nk_nQ_^ko0000ooooool0
003o_iJ]o`000?nbRZco000000Gooooo00Wo0000oio0l?l0003oXL7_o`000?nbRjco0000oj=n[?l0
00002Oooool01?nSOjco0000oi1c[_n@Ljh3o`0000;oT7:^00[o0000oiEn^?nEO[SoUGjho`000?nE
O[So0000oh9f_Ol0003ooooo3_l000000omhOlko0000ooooo`0:ooooo`?oN7o>00Co0000of=keOmS
NmGo00000omcS=d00ol0003oooooooooo`07ooooo`05o`000?mcS=goLhcMog><gOl000000omTS>@0
1?l0003oIHcTofF<i?l00004ogJKj003o`000?oooooooooo00cooooo0_l00007ogJKj003o`000?m/
WNkoK9g^00;o000000?oKIg^o`000?mlZO001_mlZO000ol0003oooooooooo`0Rooooo`03o`000?mm
ZO3oOJW`00GoOJW`00?o0000ooooooooool04Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00Wooooo000Cooooo`03o`000?oooooooooo05Cooooo00?o0000okkMkonngNl01_nngNl0
0ol0003oooooooooo`0Rooooo`03o`000?nng^oo_]k_00Go_]k_00Co0000olSUk?o8iNco00000oo8
iN`2o`0000CobmgV0_l0000@ooooo`03o`000?o;gNKobmgV00?obmgV00?o0000omGRhOoEh^400_l0
0002omCIg0_ooooo00?o0000omCIfol000000ol00003ooooo`03o`000?oBdMSod]7H00;od]7H0_l0
0004omW=cP05o`000?oIcLko0000o`000?ooool00_l00004ooooo`03o`000?oC`/Wo000000Kooooo
0_l000000oo?^lOo0000o`000003olnla`;o000000Goe;Voo`000?oD^Koo0000olj`_002o`0000?o
Xkc[0_l00003oj:mk004o`000?o>/;co0000olNW^@;o000000Goooooo`000?nP_>go0000oj6mk@03
o`000003olNW^Ol0003o000000;o00001?noUZd5o`000006ooooool0003o_iJ]o`000?nbRZco0000
1_ooool2o`000006oj71kol0003o/X^/o`000?nSOZco00002Oooool01_nSOjco0000oi1c[_n@Ljko
0000oi1b[P;o00000onEO[P3o`000005oiEn^?l0003oPWJmoh9f_Ol000001OnSa?43o`0000?oPWJm
00CoRXC7o`000?mhOlko00003Oooool3ogQocP;o00001?mcS=d00ol0003oooooooooo`09ooooo`07
o`000?mcS=goLhcMog><gOl0003oI8cTo`000002ofF<i003o`000?mfVnSoMY_X00;oMY_X00?o0000
ooooooooool03oooool2o`0000OoMY_X00?o0000ofbMk_l000000_l00007ogbYl003o`000?oooooo
oooo027ooooo00?o0000ogfYl?mmZO001_mmZO000ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool02Oooool001Cooooo0_l0001Dooooo`03o`000?nngNoo_]g_
00Ko_]g_00?o0000ooooooooool08_ooool00ol0003o_]k_okkNk`04okkNk`04o`000?o8iNco0000
o`0000;ob>G/00?o0000ol_Mi_o;gNH00oo;gNH00ol0003oooooooooo`0Booooo`03o`000?o;gNKo
bmgV00?obmgV1Ol0000:ooooo`;o000000Coe=WKo`000?oCd]So00001_ooool00ol0003od]7Ho`00
0002o`000003om7=e_l0003ofLg>00;ofLg>00Co0000ooooool0003ooooo0_l00004ooooo`03o`00
0?oC`/Wo000000Kooooo0_l00002olnka`03o`000?oooooo000000Cockc71_l000000ooooooo0000
o`000002o`0000?oX[g/00?o0000olj`_?l000000_o7YkT00ol0003oX[g/o`000002o`000003oj6m
kOl0003o000000?o000000CoajNio`000?l0003o_Ibg1Ol00004oknF[@;o000000Co_iJ]o`000?nb
RZco00001_ooool02?l0003oWl3`o`000?l0003o/X^/o`000?nSOZco00001?ooool7o`000004oi1c
[_l0003o0000o`0000;oUGjh1?l00002oj?4l@04o`000?nEO[So0000oh9f_@Ko000000Goooooo`00
0?n2M[goPWJmo`000002ohZ4a`;o000000?oN7o>o`000?ooool03?ooool6o`000003og><gOl0003o
oooo00gooooo1?mcS=d01?mTS>Co0000ofF<i?l00004ogJKj003o`000?oooooooooo01;ooooo00?o
0000ogJKj?mfVnP01?mfVnP>o`0002;ooooo00?o0000ogfYl?mmZO001OmmZO000ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000
ooooooooool0DOooool00ol0003o_]g_okkMk`06okkMk`03o`000?oooooooooo023ooooo1ol00002
okkNk`;o00000_o8iN`5ol_MiP03o`000?oooooooooo01Cooooo2Ol00002omCHf`03o`000?oooooo
oooo00Oooooo00Ko0000omCIfooDfM_o0000om?Bf?l00007ooooo`Co00000ooAcMH01?l0003ofLg>
o`000?oGb/d4o`0000Cooooo00?o0000om?2bOl000001_ooool00ol0003odl;9o`000002olnka`?o
oooo00Co0000olnlaoo?_<Oockc70ol00003olj`_0;o00001_ooool01?l0003oc[2lo`000?o7YkT3
o`000004oj:mk?l0003o0000o`0000CoX[k]00Co0000olNW^Ol0003o_Ibg0ol00003okfL]`Oo0000
00?o/XZ/o`000?l000002_l000000onbRjco0000oj=n[005o`0000OoXgn/0ol000000onEO[So0000
o`000002oj?4l@Go000000GoUGjho`000?n2M[goPWJmo`000004ooooo`04o`000?n2M[goPWJmo`00
00?oRXC700Go0000ohZ4aol0003oN7o>o`00000<ooooo`05o`000?mhOlkoN7o>o`000?n3S]H01?l0
000>ooooo`04o`000?mcS=goLhcMog><g@?o00001?mfVnP00ol0003oooooooooo`0Eooooo`Co0000
0omfW>T00ol0003oPjO/o`000005o`0000?oOJW`1Ol0000Mooooo`03o`000?mmZO3oOJW`00GoOJW`
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Wooooo
000Gooooo`03o`000?oooooooooo053ooooo00?o0000okkMkonngNl01_nngNl00ol0003ooooooooo
o`0Looooo`Co00001onng^l9o`0001Oooooo0_l00004ol_MiPCo00001?oDf=/00ol0003ooooooooo
o`05ooooo`03o`000?oDfM_o000000;o00002?ooool01?l0003odm;Ho`000?l00004om7=eP;o0000
00?oel[=o`000?oGb/d00_l00004ooooo`04o`000?oFal_odl;9o`0000Gooooo00?o0000om?2bOl0
00000_o?^lL5ooooo`06o`000?o?_<Oo0000olnkaol0003ob[C40_l00003olj`_0;o00000oooool0
1_l0003oc[2lolj`_?l0003oajNio`0000;ooooo0ol00004oj:nk@03o`000?o7YkWo000000;o_Ibg
00?o0000oj:nkOnR_^d00ol00005okfL]`[o00001OnbRj`3o`0000;oXgn/1ol00002ojF8]P;o0000
0_nEO[P5o`0000Gooooo00Go0000oiEn^?l0003oPWJmo`000003ooooo`04o`000?n2M[go0000o`00
00CoRXC700Ko0000ohZ4aon:Q<Oo0000ogQoc_l0000:ooooo`07o`000?mhOlkoN7o>o`000?n3S]Ko
0000oh>>eP02o`000003og><gOl0003ooooo00kooooo2ol0000Gooooo`03o`000?mfW>WoMYcY00?o
MYcY00?o0000oh>Wk?n3Yn`00_l00003oh:Wk0Co00001?mmZO05o`0001Sooooo00?o0000ogfYl?mm
ZO001OmmZO000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool02Oooool001Sooooo0_l0001@ooooo`03o`000?nngNoo_]g_00Go_]g_00?o0000ooooooooool0
6Oooool4o`0000Oo_]k_1?l00002ol;HjPKobmgV00?o0000ooooooooool04oooool2o`0000CobmgV
0_l000001Oo;e^;o0000ol_Fh_o;e^;o000000Coe=SK00?o0000ooooooooool00_ooool2o`000004
omCIfol0003odm;Ho`0000Sooooo0ol00002ooooo`03o`000?oAcMKo000000;o000000Cod<[Do`00
0?oGb/go00000_oFal/01ol0003ooooooooooooooooo0000om?2bOl000001_ooool2o`0000;ock_7
1oooool01?l0003ock_7olnkaol00003olZda0;o00000oo>/;`2o`000006ooooool0003oc[2lo`00
0?o7YkWo00002_ooool00ol0003oajNio`000002okfL]`Wo00000_nmW;L2o`000003ok:B]Ol0003o
/Y:e00Go/Y:e2_l00008ojF8]P06o`000?nUR;KoYHRfo`000?nEO[So00002Oooool00ol0003oUGjh
oiEn^002oh9f_@05o`000?oooooo0000oh9f_Ol000001On:Q<L00ooooooo0000ohZ4a`02ohZ4a`03
o`000?mhOlko000000Sooooo00Co0000ogQoc_mhOlko00000_n3S]H01_l0003oPhkFoh>>e_n3S]Ko
0000og><g@;o00003Oooool01?l0003oLhcMog><gOmcS=d5o`0000;oMYcX0ol0000Dooooo`03o`00
0?mfW>WoMYcY00?oMYcY00?o0000oh>Wk?n3Yn`00_n3Yn`2o`0000GoPZO/1Ol00004ogfYl0Go0000
4oooool00ol0003oOJW`ogfYl005ogfYl003o`000?oooooooooo01Cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`09ooooo`006_ooool00ol0003oooooooooo`1=ooooo`03o`000?nn
gNoo_]g_00Go_]g_00?o0000ooooooooool05_ooool3o`0000Oo_]k_1?l00002ol;HjP;o00000_o2
f>X00ol0003obmgVol_MiP03ol_MiP03o`000?oooooooooo017ooooo0_l00003ol_MiP?o00000_o;
e^801Ol0003obmKRol_Fh_o;e^;o000000Coe=SK00Go0000ooooooooooooooooo`000002omCIf`03
o`000?oCd]So000000Sooooo0_l000001?oAcMKoooooooooooooool4o`000003om3:e?l0003od<[D
00;o00000ooFal/01Ol0003oooooo`000?oC`/Wo000000Kooooo0_l00002olnka`Sooooo00Go0000
olnkaol0003ob[C4o`000004olZda0;o00000oo>/;`01_l0003oc[2lolj`_?l0003oajNio`0000[o
oooo00Go0000olNW^Ol0003o_Ibgo`000009ooooo`;o000000Co_Ibgo`000?nbT[Go/Y:e1Ol00006
ok:B]@;o00000_nUR;H5o`0000Cooooo00Ko0000ojF8]_nUR;Ko0000oiEn^?l0000:ooooo`;oUGjh
00Ko0000oh9f_On2M[go0000oh9f_Ol00004ohZ4a`05o`000?ooooooooooooooool000000on:Q<L2
ogQocP03o`000?oooooooooo00Cooooo00Go0000ogQoc_mhOlkoN7o>o`000003oh>>eP;o00000_n3
S]H01?l0003oLhcMog><gOl0000;ooooo`03o`000?mcS=goLhcM00;oLhcM0_n0V^<00ol0003oP9[S
oh2Jh`02o`0000?oMYcX0_l0000Booooo`03o`000?mfW>WoMYcY00?oMYcY00?o0000oh>Wk?n3Yn`0
1?n3Yn`00ol0003oPZO/oh:Wk007oh:Wk0Go00001?mmZO04o`0000oooooo00?o0000ogfYl?mmZO00
1_mmZO000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
2Oooool001_ooooo00?o0000ooooooooool0C?ooool00ol0003o_]g_okkMk`05okkMk`03o`000?oo
oooooooo01;ooooo1?l00006okkNk`Co00001Oo2f>X00ol0003o`]SZol;HjP03ol;HjP03o`000?o;
gNKobmgV00?obmgV00?o0000ooooooooool03_ooool2o`0000?obmgV0_l00003ol_FhP;o00001Oo;
e^800ol0003oe=SKomCHf`02omCHf`03o`000?oooooo000000;oe=WK0_l00008ooooo`Co00000ooo
ool01ol0003odLgFo`000?l0003od<[Do`000?o@b]@00_l000000oo?b=?o0000omK7b`02omK7b`03
o`000?oC`/Wo000000Kooooo00Co0000om?2bOl0003ock_72?ooool00ol0003ock_7o`000002olZd
a0;o00001Oo:]<@2o`000004olj`_?l0003oc[2lo`0000;oajNi00?o0000ooooooooool01oooool0
0ol0003oajNio`000002okfL]`03o`000?oooooooooo00Sooooo00?o0000okfL]ol000000_nbT[D0
0ol0003oooooooooo`03ooooo`?o000000Co/Y:eo`000?nbT[Go00000_nUR;H00ol0003ooooooooo
o`07ooooo`03o`000?nUR;Ko000000;oUGjh00?o0000ooooooooool01oooool00ol0003oUGjhoiEn
^002oh9f_@;o00000_n:Q<L2o`0000Kooooo00Co0000ohZ4aon:Q<OoRXC70_mhOlh00ol0003ooooo
ooooo`03ooooo`04o`000?mhOlkoN7o>o`0000CoPhkF00?o0000ooooool000000_n3S]H2o`000003
og><gOl0003o000000Wooooo00Go0000og><gOmcS=goLhcMo`000003oh2Jh`04o`000?n0V^?oP9[S
oh2Jh`?o00000_mfW>P3o`0000oooooo00?o0000ogJLjOmfW>T00omfW>T00ol0003oPjO/oh>Wk005
oh>Wk0?o00002on2Yn`4o`0000CoOJW`1Ol0000:ooooo`03o`000?mmZO3oOJW`00KoOJW`00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo000Loooo
o`;o0000C?ooool00ol0003o_]g_okkMk`05okkMk`03o`000?oooooooooo00kooooo1?l00007okkN
k`?o00002?o2f>X00ol0003o`]SZol;HjP04ol;HjP03o`000?o;gNKobmgV00?obmgV00?o0000oooo
ooooool03?ooool2o`0000?obmgV0_l00003ol_FhP;o000000?oooooo`000?o;e^801Oo;e^800ol0
003oe=SKomCHf`02omCHf`05o`000?oDfM_o0000om?Bf?l000002?ooool01?l0003odm;Ho`000?l0
0003ooooo`04o`000?oAcMKo0000ooooo`;o000000?od<[Do`000?l000000oo?b=<00ol0003oe/O;
o`000003o`0000Kooooo0_l000000oo?^lOo0000ooooo`07ooooo`;o00000oo:]<@01?l0003ooooo
o`000?l00005olZda0So00002?ooool01Ol0003oajNio`000?nmW;Oo000000_ooooo00?o0000okfL
]ol000000_nbT[D00ol0003oooooooooo`07ooooo`03o`000?nbT[Go000000;oYHRf00?o0000oooo
ooooool01oooool01_l0003oYHRfojF8]_l0003oUGjho`0000Wooooo0ol000000on2M[go0000o`00
0002ohZ4a`03o`000?oooooooooo00Oooooo00Co0000ohZ4aon:Q<Oo00000_mhOlh01Ol0003ooooo
oooooooooooo000000;oN7o>00?o0000oh>>e_n3S]H00_n3S]H01Ol0003ooooooooooooooooo0000
00?oPhkF00Co0000og><gOmcS=go00002?ooool01Ol0003oLhcMog><gOmcS=go000000CoP9[S0_l0
0004oh2Jh`;o00000omfW>P2o`0000gooooo00?o0000ogJLjOmfW>T00omfW>T00ol0003oPjO/oh>W
k005oh>Wk003o`000?oooooooooo00Go00002_n2Yn`5o`0000CoOJW`1Ol00006ooooo`03o`000?mm
ZO3oOJW`00GoOJW`00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo04Wooooo00?o0000okkMkonngNl01OnngNl0
0ol0003oooooooooo`0:ooooo`Co00001onng^l4o`0000So`]SZ0ol00007ol;HjP03o`000?o;gNKo
bmgV00?obmgV00?o0000ooooooooool02_ooool2o`0000?obmgV0_l00003ol_FhP;o00001?ooool0
0ol0003obmKRol_FhP03ol_FhP03o`000?oDf=_oe=SK00;oe=SK0_l000000ooCd]Soooooooooo`07
ooooo`03o`000?oCd]So000000Cooooo00Ko0000om7=e_l0003oooooo`000?ooool2o`000003olo8
dol0003oclSC00?oclSC0_l00003om?2b@;o00000oooool2o`000003olnkaol0003ooooo00Oooooo
00?o0000olnkaol000000oo:]<@4ooooo`;o00001?o:]<@3o`0000CoajNi0ol00005ooooo`05o`00
0?o7YkWo0000okfL]ol000002oooool01Ol0003o_Ibgo`000?nbT[Go000000[ooooo00?o0000ok:B
]Ol000000_nUR;H00ol0003oooooooooo`07ooooo`06o`000?nUR;KoYHRfo`000?nEO[So00001_oo
ool3o`0000CoUGjh1?l0000;ooooo`04o`000?n:Q<OoRXC7o`0000;oN7o>00?o0000ooooool00000
0omhOlh01Ol0003oPhkFoh>>e_n3S]Ko000000Gooooo00Co0000oh>>e_n3S]KoPhkF0_l000000omc
S=go0000o`000005ooooo`05o`000?mcS=goLhcMog><gOl000001On0V^<00ol0003oooooo`000002
o`0000?oP9[S0ol00002ogJLj0?o00002_ooool00ol0003oMYcYogJLj@03ogJLj@03o`000?n3Ynco
PjO/00GoPjO/00?o0000ooooooooool01Oooool5o`0000[oPZO/0ol00006ogfYl0Go000000?ooooo
o`000?mmZO001_mmZO000ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool02?ooool001oooooo00?o0000ooooooooool0B?ooool00ol0003o_]g_okkMk`05okkM
k`03o`000?oooooooooo00Kooooo1?l00007okkNk`Co00002?o2f>X4o`0000;ooooo00?o0000ol;H
j_o2f>X01Oo2f>X00ol0003obmgVol_MiP04ol_MiP03o`000?oooooooooo00Oooooo0_l00003ol_M
iP;o00000_o;e^83o`0000Kooooo00?o0000ol_Fh_o;e^801?o;e^800ol0003oe=SKomCHf`03o`00
00Wooooo00?o0000om?Bf?oAcMH01?ooool3o`000004ooooool0003oooooo`0000;oclSC0_l00003
olo8d`;o000000?ocLCAo`000?oC`/T00ooC`/T01_l0003oooooo`000?l0003ock_7o`0000Sooooo
00?o0000olnkaol000000oo:]<@7ooooo`;o000000Gob[C4o`000?o:]<Co0000ol>[`P03o`0000Co
ajNi0ol000001?oooooo0000olNW^Ol00002okfL]`03o`000?oooooooooo00Wooooo00Go0000okfL
]ol0003o/Y:eo`00000:ooooo`03o`000?nbT[Go000000;oYHRf00?o0000ooooooooool02?ooool0
1Ol0003oYHRfo`000?nEO[So000000Cooooo0_l00005oiEn^003o`000?nIR/;o000000;oRXC700?o
0000ooooooooool02_ooool01?l0003oRXC7ohZ4aol00002ogQocP05o`000?mhOlkoN7o>ogQoc_l0
00000on3S]H00ol0003oooooooooo`05ooooo`;o00000on3S]H01?l0003oLhcMog><gOl00004oooo
o`05o`000?mcS=goLhcMog><gOl000001?n0V^<00ol0003oooooooooo`03ooooo`;o00001?n0V^<2
o`0000?oMYcX0_l00008ooooo`03o`000?mfW>WoMYcY00?oMYcY00?o0000oh>Wk?n3Yn`01On3Yn`0
0ol0003oooooooooo`0:ooooo`Go00002On2Yn`3o`0000OoOJW`0ol00006ogfYl003o`000?oooooo
oooo01Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`08ooooo`008?ooool2o`00
04Sooooo00?o0000okkMkonngNl01OnngNl00ol0003oooooooooo`03ooooo`?o00001onng^l4o`00
00So`]SZ1?l00006ooooo`03o`000?o2f>[o`]SZ00Ko`]SZ00?o0000ol_Mi_o;gNH00oo;gNH00ol0
003oooooooooo`05ooooo`;o00000_o;gNH3o`0000;obmKR0_l0000:ooooo`03o`000?o;e^;obmKR
00?obmKR00Ko0000omCHfol0003o0000om?Bf?l00007ooooo`?o000000?odLgFooooooooool00_oo
ool2o`000005om3:e?oooooo0000ooooool000000_o?b=<3ooooo`04o`000?o?b=?o0000o`0000?o
cLCA0_l00003om?2b@04o`000?oC`/Wo0000o`0000Wooooo00?o0000olnkaol000000_o:]<@:oooo
o`05o`000?o:]<Cob[C4ol>[`_l000000oo3Zl83o`0000CoajNi0_l000001?o7YkWo0000okfL]ol0
000;ooooo`03o`000?nmW;Oo000000;o/Y:e00?o0000ooooooooool02?ooool00ol0003o/Y:eo`00
0002ojF8]P03o`000?oooooooooo00Sooooo00Go0000ojF8]_nUR;Ko0000oiEn^004o`0000?oUGjh
0_l00003oiV:`P03o`000?nIR/;o000000;oRXC700?o0000ooooooooool02_ooool3ohZ4a`;oN7o>
00Co0000ogQoc_mhOlko00001?n3S]H00ol0003oooooooooo`07ooooo`05o`000?n3S]KoPhkFoh>>
e_l000000_mcS=d2o`0000;ooooo00Co0000og><gOmcS=go00001On0V^<00ol0003oooooooooo`05
ooooo`?o00000on0V^<3o`0000;oMYcX0ol00005ooooo`03o`000?mfW>WoMYcY00;oMYcY00?o0000
oh>Wk?n3Yn`01_n3Yn`00ol0003oooooooooo`0?ooooo`Co00002_n2Yn`2o`0000KoOJW`0_l00004
ogfYl003o`000?oooooooooo01Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`08
ooooo`008_ooool00ol0003oooooooooo`15ooooo`03o`000?nngNoo_]g_00Go_]g_00?o0000oooo
ool000000ol00006okkNk`Co00002Oo2f>X3o`0000_ooooo00?o0000ol;Hj_o2f>X01Oo2f>X00ol0
003obmgVol_MiP03ol_MiP03o`000?oooooooooo00?ooooo0_l00002ol_MiP;o00000oo;e^82o`00
00cooooo00Co0000ol_Fh_o;e^;obmKR1?l00004om?Bf003o`000?oooooooooo00?ooooo00Co0000
om?Bf?l0003o00001?ooool2o`000005om3:e?oooooo0000ooooool000000_o?b=<4ooooo`;o0000
00?ocLCAo`000?o=a=401?o=a=400ol0003odl;9om?2b@04o`0000Sooooo00?o0000olnkaol00000
0_o:]<@00ol0003oooooooooo`08ooooo`04o`000?o:]<Co0000ol>[`P;o00001Oo3Zl83o`0000;o
ajNi00?o0000olNW^Ol000001?l00009ooooo`03o`000?nmW;Oo000000;o/Y:e00?o0000oooooooo
ool02Oooool2ok:B]@03o`000?nUR;Ko000000[ooooo00Ko0000ojF8]_nUR;Ko0000oiEn^?l00004
oiEn^0;o00001OnIR/801?l0003oVH[2oiV:`_l00002ohZ4a`03o`000?oooooooooo00[ooooo0on:
Q<L01OmhOlko0000ogQoc_mhOlko000000?oPhkF00?o0000ooooooooool02Oooool01Ol0003oPhkF
oh>>e_n3S]Ko000000?oLhcM0_l00003og><g@03o`000?n0V^?oP9[S00?oP9[S00?o0000oooooooo
ool02?ooool2o`0000CoP9[S0_l00003ogJLj0;o00000oooool00ol0003oMYcYogJLj@02ogJLj@03
o`000?n3YncoPjO/00KoPjO/00?o0000ooooooooool04oooool5o`0000[oPZO/00?o0000ogfYl?mm
ZO000_mmZO03o`0000;oOJW`00?o0000ooooooooool05oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00Sooooo000Sooooo`03o`000?oooooooooo04?ooooo00?o0000okkMkonngNl0
1OnngNl3o`0000Ko_]k_1?l00009ol;HjPCo00003_ooool00ol0003o`]SZol;HjP05ol;HjP03o`00
0?o;gNKobmgV00?obmgV00Co0000oooooooooooooooo0_l00002ol_MiP;o00000oo;e^82o`0000ko
oooo1ol000000oo:dMko0000om?Bf003om?Bf007o`000?ooooooooooooooool0003odm;Ho`000005
ooooo`;o000000God<[Dooooool0003oooooo`000002olo8d`Cooooo0_l000000oo=a=7o0000o`00
0006olg4d@?o00000oo?^lL00ol0003oooooooooo`05ooooo`;o00000_o:]<@00ol0003ooooooooo
o`08ooooo`03o`000?o:]<Co000000;o`j_200?o0000ooooool000000_l00005ol>[`PGo00001?nm
W;L4o`0000Gooooo00?o0000okfL]ol000000_nbT[D00ol0003oooooooooo`09ooooo`;o/Y:e00?o
0000ojF8]_l000002?ooool6o`000003oiEn^?l0003oUGjh00?o00001OnIR/800ol0003oooooo`00
0002oiV:`P04o`000?n:Q<OoRXC7o`0000cooooo1?l000000omhOlko0000o`000003oh>>eP03o`00
0?oooooooooo00_ooooo00?o0000oh>>e_n3S]H00_n3S]H01?l0003oLhcMog><gOl00003og><g@03
o`000?n0V^?oP9[S00;oP9[S00?o0000ooooooooool02oooool3o`0000?oP9[S0_l00003ogJLj0Co
00001?mfW>T00ol0003oPjO/oh>Wk005oh>Wk003o`000?oooooooooo01Wooooo0ol0000;oh:Wk004
o`000?mmZO3oOJW`ogfYl0?o00006_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00Sooooo000Tooooo`;o0000@oooool00ol0003o_]g_okkMk`03okkMk`;o00001_nng^l3o`0000Wo
`]SZ1?l0000Booooo`03o`000?o2f>[o`]SZ00Ko`]SZ00?o0000ol_Mi_o;gNH00oo;gNH3o`0000;o
bmgV0_l00003ol_FhP;o00003oooool01ol0003obmKRol_Fh_o;e^;o0000ol[@g_l000000oo:dMh0
0ol0003odm;Hom?Bf002om?Bf005o`000?oooooo0000om?Bf?l000001Oooool2o`000005om3:e?oo
oooo0000ooooool000000_o?b=<4ooooo`;o000000CocLCAo`000?oooooooooo0_l00004olg4d@?o
00001?o?^lL2o`0000Cooooo00Go0000olnkaol0003ob[C4o`00000;ooooo`03o`000?o:]<Co0000
00;o`j_21Oooool2o`0000Go`j_21Ol00006okfL]`Co000000Koooooo`000?nmW;Oo0000ok:B]Ol0
000<ooooo`;o/Y:e00?o0000ojF8]_l000000_ooool6o`0000GoYHRf1?l00004oiV:`P;o00001Ooo
ool01?l0003oVH[2oiV:`_l00002ohZ4a`03o`000?oooooooooo00Sooooo00?o0000ohZ4aon:Q<L0
0_n:Q<L7o`0000oooooo1?n3S]H00ol0003oLhcMo`000002og><g@03o`000?n0V^?oP9[S00?oP9[S
00?o0000ooooooooool03_ooool2o`0000CoP9[S00?o0000ogJLj?mfW>P00_mfW>P2o`0000?oMYcY
00?o0000oh>Wk?n3Yn`01On3Yn`00ol0003oooooooooo`0Nooooo`;o00002On2Yn`3o`000003ogfY
l?l0003ooooo01[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`07ooooo`009_oo
ool00ol0003oooooooooo`10ooooo`04o`000?nngNoo_]g_okkMk`;o00001Onng^l2o`0000[o`]SZ
0ol0000Gooooo`03o`000?o2f>[o`]SZ00Go`]SZ00?o0000ol_Mi_o;gNH00_o;gNH2o`0000;obmgV
0_l00004ol_FhP03o`000?oooooooooo00gooooo0_l00002ol_FhP;o000000?ob]3No`000?o:dMh0
1?o:dMh00ol0003odm;Hom?Bf002om?Bf003o`000?oCd]SodLgF00Gooooo0_l000001Oo@b]Cooooo
o`000?oooooo000000;oclSC1?ooool2o`000003olg4dOl0003o000000Cooooo00Oo0000olg4dOl0
003o0000olg4dOl0003ob[k?00;o00001?o?^lL01_l0003oooooooooool0003ock_7o`0000;ob[C4
00?o0000ooooooooool02?ooool00ol0003ob[C4o`000002ol>[`P03o`000?oooooooooo00Gooooo
0ol000001?o3Zl;o0000ol>[`_l00003ok^R_`Ko00001?nmW;L2o`000003okfL]ol0003o/Y:e00ko
000000?o/Y:eo`000?nUR;H00ol0000<ojF8]P04o`000?nIR/;o0000oiV:`P?o00002?ooool01?l0
003oVH[2oiV:`_l00002ohZ4a`03o`000?oooooooooo00Kooooo00?o0000ohZ4aon:Q<L00on:Q<L3
oi2@d005o`000?n3S]KoPhkFoh>>e_l000003oooool5oh>>eP04og><gOl0003oLhcMo`0000GoP9[S
00?o0000ooooooooool04?ooool2o`0000CoP9[S0_l00003ogJLj004o`000?mfW>WoMYcYo`0000Oo
PjO/00?o0000ooooooooool08oooool00on2Ynco0000o`000003o`0000CoPZO/00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo000Wooooo`03o`00
0?oooooooooo03oooooo00Co0000okkMkonngNoo00001?nng^l2o`0000[o`]SZ0_l0000Kooooo`03
o`000?o2f>[o`]SZ00Go`]SZ00Go0000ol_Mi_o;gNKobmgVo`000002ol_MiP;o00001?o;e^8@oooo
o`;o00000_o;e^82o`000003ol[@g_l0003o000000Oob]7N00Co0000om?Bf?oCd]Sodm;H0_l00005
ooooo`;o000000Ood<[Dooooool0003oooooo`000?o?b=?o000000Cooooo0_l000001?o=a=7o0000
ooooool00005ooooo`03o`000?o=a=7ocLCA00;o00000oo:_/l00ol0003ock_7olnka`02olnka`07
o`000?oooooo0000olnkaol0003ob[C4o`00000;ooooo`05o`000?o:]<Co0000ol>[`_l000002ooo
ool00ol0003o`j_2ol>[`P02o`0000So^j:o1Ol000001?nmW;Oo0000o`000?l0000>ok:B]@?o0000
0_nUR;H9o`0000?oYY6o0_l00002oiV:`P03o`000?oooooooooo00Wooooo00Co0000oiV:`_nIR/;o
00000_n:Q<L00ol0003oooooooooo`04ooooo`;o00001?n:Q<L01?l0003oT93@oi2@d?l00002oi2@
d005o`000?n3S]KoPhkFoh>>e_l000003oooool5oh>>eP03o`000?mcS=go000000CoP9[S00?o0000
ooooooooool05?ooool00ol0003oP9[Soh2Jh`03oh2Jh`06o`000?mfW>SoMYcXo`000?mfW>Wo0000
1on3Yn`00ol0003oooooooooo`0Tooooo`03o`000?n2YncoPZO/00KoPZO/00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Oooooo000Xooooo`;o0000?ooo
ool3o`0000;o_]k_00?o0000ol;Hj_o2f>X02Oo2f>X00ol0003oooooooooo`0Mooooo`03o`000?o2
f>[o`]SZ00Go`]SZ00Co0000ol_Mi_o;gNKo00000_o;gNH5ol_FhQ7ooooo00?o0000ol_Fh_o;e^80
0_l000000oo:d=ko0000o`000002ooooo`03o`000?o:dMkob]7N00Gob]7N00?o0000om?Bf?l00000
0_oAcMH01Ol0003ooooooooooooooooo000000;od<[D00Goooooo`000?oooooo0000olo8d`05oooo
o`;o000000GocLCAo`000?ooooooooooo`000005ooooo`04o`000?o=a=7o0000o`0000Gob[k?0_l0
0003olnka`05o`000?o?^lOo0000olZda?l000002oooool00ol0003ob[C4o`000002ol>[`P03o`00
0?oooooooooo00Wooooo00?o0000ol>[`_l000000_nkX[l4o`0000Wo^j:o4?l00003ok:B]@Co0000
2onVTKl01_l0003oYY6oojJA_ol0003oVH[2o`0000cooooo00Co0000oiV:`_nIR/;o00000_n:Q<L0
0ol0003oooooooooo`02ooooo`03o`000?n:Q<OoRXC700;oRXC700?o0000oi2@d?n@T=000_n@T=00
1Ol0003oT93@oi2@d?n@T=3o000000?oPhkF00?o0000ooooooooool03Oooool=o`0001Oooooo00?o
0000oh2Jhon0V^<00on0V^<01?l0003oMYcXo`000?l00007oh>Wk003o`000?oooooooooo02Cooooo
00?o0000oh:Wk?n2Yn`01_n2Yn`00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool01oooool002[ooooo00?o0000ooooooooool0??ooool00ol0003o_]k_o`00
0003o`0000So`]SZ00?o0000ooooooooool08?ooool00ol0003o`]SZol;HjP06ol;HjP;o000000?o
bmgVol_Fh_l000000ol0000Aooooo`;o00000_o;e^801?l0003ob]3Nol[@g_l00005ooooo`03o`00
0?o:dMkob]7N00Gob]7N00?o0000om7=e_oAcMH00_oAcMH00ol0003oooooo`000002om3:e005oooo
ool0003oooooo`000?o?b=<01Oooool2o`000003olg4dOl0003ooooo00;ooooo00?o0000oooooooo
ool00_ooool01?l0003ocLCAo`000?o:_/l2o`0000Kob[k?0_l000001?o?^lOo0000o`000?o:]<@2
o`0000[ooooo00Ko0000olZda?o:]<Co0000ol>[`_l0000;ooooo`04o`000?o3Zl;o`j_2o`0000;o
^j:o00Co0000oooooooooooooooo1Ol00004ok^R_`03o`000?nkX[oo0000013o/IVn00?o0000ojJA
_ol000000onVTKl6o`0000?ooooo00Co0000ojJA_onVTKoo00000_nIR/800ol0003oooooooooo`09
ooooo`04o`000?nIR/;oVH[2o`0000;oRXC700Go0000ooooooooooooooooo`000003ohZ4a`;o0000
1On@T=02o`0000?oT93@00Go0000oh>>e_n3S]KoPhkFo`00000>ooooo`03o`000?n3S]KoPhkF00;o
PhkF00Co0000oh^JgOl0003o00001?n0V^<2o`0001Sooooo4Ol0000Tooooo`03o`000?n2YncoPZO/
00GoPZO/00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Oooooo000[ooooo`03o`000?oooooooooo03_ooooo1_o2f>X4o`000003ol;Hj_oooooooooo02Go
oooo00Co0000ol;Hj_o2f>[o`]SZ2?l00003ol_FhP03o`000?oooooooooo00gooooo0_l00002ol_F
hP;o000000?ob]3No`000?l000001oooool00ol0003ob]7Nol[AgP05o`0000GodLgF00So0000om3:
e?o@b]Coooooo`000?oooooo0000olo8d`Gooooo0_l000000oo=a=7o0000ooooo`03ooooo`07o`00
0?ooooooooooooooool0003ocLCAo`000002olZnc`04o`000?oooooo0000o`0000Kob[k?0ol00003
olZda0?o00001oooool01_l0003ob[C4olZda?l0003o`j_2o`0000_ooooo00Co0000ol>[`_o3Zl;o
00000_nkX[l:ooooo`?o00000_nkX[l2o`0000ko/IVn0_l00002ojJA_`?o00002_ooool00ol0003o
YY6oo`000002oiV:`P03o`000?oooooooooo00[ooooo00Co0000oiV:`_nIR/;o00000_n:Q<L00ol0
003oooooo`000002ohZ4a`;o00001_n@T=03ooooo`05o`000?n@T=3oT93@oi2@d?l000000on3S]H0
0ol0003oooooooooo`0:ooooo`03o`000?n3S]KoPhkF00;oPhkF00?o0000oh^JgOl000000_n;V]d0
0ol0003oP9[Soh2Jh`03oh2Jh`03o`000?oooooooooo01Gooooo00?o0000oh2Jhon0V^<00on0V^<0
0ol0003oRJGWohVUi`03o`0000GoPjO/0ol0000Pooooo`03o`000?n2YncoPZO/00KoPZO/00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo000/oooo
o`;o0000>oooool00ol0003o`]SZol;HjP06ol;HjP03o`000?oooooooooo02Gooooo2?l000000oo2
dnKo0000ol_FhP06ol_FhP03o`000?oooooooooo00_ooooo00?o0000ol_Fh_o;e^800_l000000oo:
d=ko0000o`000009ooooo`Ko00000_o9cM`01?l0003odLgFom7=e_oAcMH3o`000005ooooool0003o
ooooo`000?o?b=<01Oooool2o`000003olg4dOl0003ooooo00Cooooo00Ko0000oooooooooooo0000
olg4dOl00002olZnc`03o`000?oooooooooo00;ooooo00?o0000olZncoo:_/l00oo:_/l3o`0000Ko
b[C40_l00004ooooo`06o`000?o:]<Cob[C4o`000?o3Zl;o00003?ooool00ol0003o`j_2o`000002
ok^R_`03o`000?oooooooooo00[ooooo00Go0000ok^R_onkX[oo0000ok:I_P0<o`000004ok6I__l0
003o/YVno`0000;oYY6o00?o0000ooooooooool02_ooool01_l0003oYY6oojJA_ol0003oVH[2o`00
00gooooo0onIR/801?l0003oRXC7ohZ4aol00002ohZ4a`03o`000?n@T=3oT93@00?oT93@0_l00005
ooooo`05o`000?n@T=3oT93@oi2@d?l000000on3S]H00ol0003oooooooooo`08ooooo`03o`000?n3
S]KoPhkF00;oPhkF00Go0000oh^JgOn;V]goRi[Mo`000002oh^Jg@;o00001?n0V^<2o`0001Cooooo
00?o0000oh2Jhon0V^<00on0V^<01Ol0003oRJGWohVUion9YNOo000000;oRJGW0ol00005oh>Wk0?o
00007Oooool00ol0003oPZO/oh:Wk006oh:Wk003o`000?oooooooooo01kooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`07ooooo`00;_ooool00ol0003oooooooooo`0iooooo`03o`00
0?o2f>[o`]SZ00Go`]SZ00?o0000ooooooooool08_ooool3o`0000;o`]SZ0ol000000oo2dnKo0000
ol;CiP02ol;CiP03o`000?o;e^;obmKR00CobmKR00?o0000ooooooooool02Oooool2o`000004ol_F
h_l0003o0000ol[@gP;o00002_ooool01_l0003ob]3Nol[@g_l0003obLgLo`0000CobLgL00Co0000
om7=e_l0003o00000_o@b]@01?l0003oooooo`000?l00005ooooo`;o000000?ocLCAo`000?ooool0
1Oooool01Ol0003oooooo`000?o=a=7o000000;ob[k?00?o0000ooooooooool01?ooool2o`000006
olZncol0003o0000olZncol0003oa[O<0ol00005olZda0?o000000Ooooooo`000?o:]<Cob[C4o`00
0?o3Zl;o000000_ooooo00Co0000ol>[`_o3Zl;o00000_nkX[l00ol0003oooooooooo`0:ooooo`06
o`000?nkX[oo^j:oo`000?nbVKko00003?ooool00ol0003o/YVno`000002ojJA_`03o`000?oooooo
oooo00[ooooo00Co0000ojJA_onVTKoo00000_nIR/800ol0003oooooooooo`0:ooooo`?oVH[200?o
0000ohZ4aon:Q<L00ol00005oi2@d003o`000?oooooooooo00Kooooo00Go0000oi2@d?n@T=3oT93@
o`000003oh>>eP03o`000?oooooooooo00Kooooo00?o0000oh>>e_n3S]H00_n3S]H00ol0003oRi[M
oh^Jg@02oh^Jg@03o`000?n;V]goRi[M00;oRi[M0_l00004oh2Jh`;o00004_ooool00ol0003oP9[S
oh2Jh`03oh2Jh`03o`000?n9YNOoRJGW00;oRJGW00?o0000ohVUion9YNL00_n9YNL4o`0000CoPjO/
1?l0000Iooooo`03o`000?n2YncoPZO/00KoPZO/00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Kooooo000_ooooo`03o`000?oooooooooo03Sooooo00?o
0000ol;Hj_o2f>X01_o2f>X00ol0003oooooooooo`0Nooooo`?o00000_o2f>X3o`0000?o`]?V00?o
0000ol;Ci_o2dnH00_o2dnH00ol0003obmKRol_FhP05ol_FhP03o`000?oooooooooo00Kooooo0_l0
0002ol_FhP04o`000?o:d=kob]3No`0000[ooooo0_l000000oo:d=ko0000o`000002o`0000KobLgL
00Ko0000om3:e?o@b]Cod<[Do`000?o@b]@2o`0000Gooooo0_l000000oo=a=7o0000ooooo`06oooo
o`;o000000GocLCAo`000?o:_/oob[k?o`000009ooooo`05o`000?o:_/oob[k?olZncol000001?o6
]l`2o`0000Kob[C400Ko0000olZda?o:]<Co0000ol>[`_l0000<ooooo`06o`000?o3Zl;o`j_2o`00
0?nkX[oo00003Oooool00ol0003o^j:oo`000002ok:I_P03o`000?oooooooooo00[ooooo00Ko0000
ok:I__nbVKko0000ojJA_ol0000=ooooo`06o`000?nVTKooYY6oo`000?nIR/;o00003?ooool4o`00
0003ohZ4aol0003o000000GoT93@0_l0000:ooooo`04o`000?n@T=3oT93@oi2@d0;o00000_n3S]H0
0ol0003oooooooooo`04ooooo`03o`000?n3S]KoPhkF00;oPhkF00?o0000oh^JgOn;V]d01?n;V]d2
o`0000CoRi[M0_l00004oh2Jh`03o`000?oooooooooo00kooooo00?o0000oh2Jhon0V^<00on0V^<0
0ol0003oRJGWohVUi`04ohVUi`03o`000?n9YNOoRJGW00GoRJGW0ol00005oh>Wk0?o00005_ooool0
0ol0003oPZO/oh:Wk006oh:Wk003o`000?oooooooooo023ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`06ooooo`00<?ooool2o`0003Sooooo00?o0000ol;Hj_o2f>X01_o2f>X00ol0
003oooooooooo`0Kooooo`?o00000oo2f>X2o`0000Go`]?V00?o0000ol;Ci_o2dnH01?o2dnH00ol0
003obmKRol_FhP04ol_FhP03o`000?oooooooooo00Gooooo00?o0000ol_Fh_o;e^800_l000000oo:
d=ko0000ooooo`0:ooooo`08o`000?o:d=kob]3No`000?o9cMco0000ooooool00003olW=g0?o0000
00KobL_Ko`000?o@b]Co0000om3:e?l00002olo7d`04o`000?ooooooooooooooo`;o000000?ocLCA
o`000?ooool01oooool00ol0003ocLCAo`000002olZnc`03o`000?oooooooooo00Sooooo00Go0000
olZncoo:_/ooa[O<o`000006olJgc0;o00001?o:]<@01_l0003ob[C4olZda?l0003o`j_2o`0000co
oooo00?o0000ol>[`_l000000_nkX[l00ol0003oooooooooo`0:ooooo`04o`000?nkX[oo^j:oo`00
00;o/YVn00?o0000ooooooooool02_ooool01?l0003o/YVnok:I__l00002ojJA_`03o`000?oooooo
oooo00[ooooo00Ko0000ojJA_onVTKoo0000oiV:`_l00009ooooo`?o00001?nIR/85o`0000;oT93@
00?o0000ooooooooool02oooool00ol0003oT93@oi2@d002oi2@d0?oPhkF00?o0000ooooooooool0
0oooool01Ol0003oPhkFoh>>e_n3S]Ko000000OoRi[M00Co0000ooooool0003o00001?n;V]d2o`00
00?oP9[S0_l0000>ooooo`03o`000?n0V^?oP9[S00?oP9[S00?o0000ohVUion9YNL01On9YNL3o`00
00OoRJGW0ol00005oh>Wk0Co00004_ooool00ol0003oPZO/oh:Wk006oh:Wk003o`000?oooooooooo
027ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06ooooo`00<_ooool00ol0003o
ooooooooo`0fooooo`03o`000?o2f>[o`]SZ00Go`]SZ00?o0000ooooooooool06?ooool3o`0000?o
`]SZ0ol00005ol;CiP;o00002?o2dnH00ol0003obmKRol_FhP03ol_FhP03o`000?oooooooooo00?o
oooo0_l000000oo;e^;o0000o`000002ol[@gP03o`000?oooooooooo00Sooooo0_l000000oo:d=ko
0000o`000002o`0000?ooooo00?o0000olW=g?l000000_l00003olW;f`03o`000?o@b]Co000000Co
clOC00Ko0000ooooool0003o0000olg4dOl00009ooooo`;o00000_o:_/l00ol0003oooooooooo`08
ooooo`03o`000?o:_/oob[k?00;oa[O<0_l00007olJgc0?o000000?ob[C4o`000?o:]<@01Ol0000:
ooooo`04o`000?o3Zl;o`j_2o`0000;o^j:o00?o0000ooooooooool02_ooool01?l0003o^j:ook^R
_ol00002ok:I_P03o`000?oooooooooo00[ooooo00Co0000ok:I__nbVKko00000_nVTKl00ol0003o
ooooooooo`0:ooooo`04o`000?nVTKooYY6oo`0000;oVH[200?o0000ooooooooool01?ooool2o`00
00KoVH[200?o0000oibDbol000000on@T=02o`00013ooooo1?n@T=03oh>>eP05o`000?oooooooooo
ooooool000000on3S]H00ol0003oRi[Moh^Jg@05oh^Jg@03o`000?oooooooooo00;ooooo0_l00004
oh^Jg@03o`000?n0V^?oP9[S00;oP9[S0_l0000;ooooo`03o`000?n0V^?oP9[S00?oP9[S00?o0000
ohVUion9YNL01_n9YNL00ol0003oooooooooo`03o`0000OoRJGW1?l00005oh>Wk0?o00003oooool0
0ol0003oPZO/oh:Wk006oh:Wk003o`000?oooooooooo027ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`06ooooo`00<oooool00ol0003oooooooooo`0eooooo`03o`000?o2f>[o`]SZ
00Ko`]SZ00?o0000ooooooooool05?ooool3o`0000?o`]SZ0ol00005ol;CiP?o000000?oooooo`00
0?o2dnH01oo2dnH00ol0003obmKRol_FhP04ol_FhP03o`000?oooooooooo00;o00000_o;e^801?l0
003ob]3Nol[@g_l0000;ooooo`06o`000?o:d=kob]3No`000?o9cMco00001Oooool4o`0000CobL_K
0ol00005olo7d`;o000000?ocLCAo`000?ooool02?ooool01Ol0003ocLCAo`000?o:_/oo000000[o
oooo00Co0000olZncoo:_/oo00000_o6]l`00ol0003oooooo`000002o`0000Ooa[O<1?l00004ol>[
`P?o00001oooool01_l0003o`j_2ol>[`_l0003o^j:oo`0000gooooo00Co0000ok^R_onkX[oo0000
0_nbVKh00ol0003oooooooooo`0:ooooo`04o`000?nbVKko/YVno`0000;oYY6o00?o0000oooooooo
ool02oooool3ojJA_`03o`000?nIR/;o000000Cooooo0_l00004oiV:`P;o00001?nLU</2o`0000?o
T93@00?o0000ooooooooool03oooool4oi2@d0?oPhkF00?o0000ooooool000001?n3S]H00ol0003o
Ri[Moh^Jg@04oh^Jg@03o`000?oooooooooo00Gooooo00?o0000oh^JgOn;V]d00_n;V]d2o`0000Co
P9[S00?o0000ooooooooool02?ooool00ol0003oP9[Soh2Jh`03oh2Jh`03o`000?n9YNOoRJGW00Go
RJGW00?o0000ooooooooool01?ooool3o`0000SoRJGW0ol00005oh>Wk0?o00003?ooool00ol0003o
PZO/oh:Wk005oh:Wk003o`000?oooooooooo02?ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`06ooooo`00=?ooool2o`0003Gooooo00?o0000ol;Hj_o2f>X01_o2f>X00ol0003ooooo
ooooo`0Aooooo`?o00000oo2f>X3o`0000Go`]?V0ol00005ooooo`03o`000?o2dnKo`]?V00Ko`]?V
00?o0000ol_Fh_o;e^800oo;e^800ol0003oooooo`000002ol_FhP;o00000_o:d=h;ooooo`;o0000
00Gob]3No`000?l0003obLgLo`000005ooooo`Co000000SobL_Ko`000?l0003obL_Ko`000?o8b=[o
0000olS8fP;o00000oo?am<4o`0000Sooooo00?o0000olg4dOl000000_o:_/l00ol0003ooooooooo
o`07ooooo`04o`000?o:_/oob[k?o`0000?oa[O<1Oooool2o`0000Koa[O<1?l00006ol>[`P?o0000
1?ooool01_l0003o`j_2ol>[`_l0003o^j:oo`0000gooooo00Ko0000ok^R_onkX[oo0000ok:I__l0
000>ooooo`03o`000?nbVKko000000;oYY6o00?o0000ooooooooool02oooool01ol0003oYY6oojJA
_ol0003oVH[2o`000?ooool00ol00003oiV:`P?o00001OnLU</01?l0003oW9C;oibDbol00003oi2@
d003o`000?oooooooooo00oooooo1?n@T=03oh>>eP03o`000?n3S]KoPhkF00;oPhkF00?o0000oh^J
gOn;V]d01?n;V]d00ol0003oooooooooo`07ooooo`;o00001?n;V]d2o`0000?oP9[S0_l00007oooo
o`03o`000?n0V^?oP9[S00?oP9[S00?o0000ohVUion9YNL01_n9YNL00ol0003oooooooooo`07oooo
o`?o00002?n9YNL3o`0000GoPjO/1?l00007ooooo`03o`000?n2YncoPZO/00KoPZO/00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Kooooo000fooooo`03
o`000?oooooooooo03?ooooo00?o0000ol;Hj_o2f>X01Oo2f>X00ol0003oooooooooo`0?ooooo`;o
00001?o2f>X2o`0000Ko`]?V0_l00009ooooo`03o`000?o2dnKo`]?V00Go`]?V00?o0000ol_Fh_o;
e^801?o;e^801?l0003obmKRol_Fh_l00002ol[@gPcooooo00Ko0000ol[@g_o:d=ko0000olW=g?l0
0005ooooo`Co000000Soooooo`000?l0003o0000olW;fol0003ob<SJo`0000Cob<SJ00Co0000olo7
dol0003o00000oo=`m400ol0003oooooooooo`04ooooo`03o`000?o=a=7o000000;ob[k?00?o0000
ooooooooool01oooool01?l0003ob[k?olZncol00003olJgc0Sooooo0ol000001Oo6]lco0000o`00
0?o6]lco000000;o`;390ol00006ol>[`PCo00000_o3Zl801?l0003o^j:ook^R_ol0000=ooooo`06
o`000?nkX[oo^j:oo`000?nbVKko00003_ooool00ol0003o/YVno`000002ojJA_`03o`000?oooooo
oooo00_ooooo00Oo0000ojJA_onVTKooYY6oo`000?nIR/;o000000CoVH[20_l00008oibDb`05o`00
0?nLU<_oW9C;oibDbol000000on@T=000ol0003oooooooooo`0?ooooo`CoT93@0_n3S]H01Ol0003o
PhkFoh>>e_n3S]Ko000000KoRi[M00?o0000ooooooooool02_ooool2o`0000CoRi[M0_l00003oh2J
h`;o00001Oooool00ol0003oP9[Soh2Jh`03oh2Jh`03o`000?n9YNOoRJGW00KoRJGW00?o0000oooo
ooooool02_ooool3o`0000SoRJGW0ol00006oh>Wk0?o00001?ooool00ol0003oPZO/oh:Wk006oh:W
k003o`000?oooooooooo02Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06oooo
o`00=oooool00ol0003oooooooooo`0booooo`03o`000?o2f>[o`]SZ00Go`]SZ00?o0000oooooooo
ool03?ooool3o`0000?o`]SZ0ol00005ol;CiP?o00002oooool00ol0003o`]?Vol;CiP06ol;CiP03
o`000?o;e^;obmKR00;obmKR00?o0000ol_Fh_l000000_o:d=h00ol0003oooooooooo`0:ooooo`06
o`000?o:d=ko0000o`000?o9cMco00001Oooool4o`000004ooooool0003o0000ooooo`;o000000?o
b<SJo`000?o8b=X01?o8b=X3o`0000GocL?A0_l00003ooooo`03o`000?o=a=7o000000;ob[k?00?o
0000ooooooooool02?ooool00ol0003ob[k?o`000003olJgc0cooooo00Go0000olJgc?o6]lcoa[O<
o`000005ol2`b@Co00001Oo3Zl801_l0003o`j_2ol>[`_l0003o^j:oo`0000kooooo00Ko0000ok^R
_onkX[oo0000ok:I__l0000>ooooo`03o`000?nbVKko000000;oYY6o00?o0000ooooooooool02_oo
ool4o`000004ojJA_ol0003oVH[2o`0000;oVH[20_l00007oibDb`;o000000?oooooo`000?nLU</0
0onLU</01Ol0003oT93@oi2@d?n@T=3o0000017ooooo1?n@T=001On3S]Ko0000oh>>e_n3S]Ko0000
00KoRi[M00?o0000ooooooooool03Oooool2o`0000CoRi[M00?o0000oh2Jhon0V^<00_n0V^<01Ol0
003ooooooooooooooooo000000KoP9[S00?o0000ohVUion9YNL01On9YNL00ol0003oooooooooo`0>
ooooo`?o00002?n9YNL4o`0000GoPjO/0ol000000ooooooo0000oh:Wk007oh:Wk003o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`00>?ooool2o`00
03;ooooo00?o0000ol;Hj_o2f>X01_o2f>X00ol0003oooooooooo`08ooooo`?o00000oo2f>X3o`00
00Go`]?V0ol0000?ooooo`03o`000?o2dnKo`]?V00Ko`]?V00Ko0000ol_Fh_o;e^;o0000ol_Fh_o:
d=h2o`0000cooooo1?l00002olW=g0Kooooo0ol00002ooooo`;o000000Coooooo`000?o8b=[ob<SJ
0_l00003olS8fP;o000000Coa/GHo`000?o6aMSo00001_o=`m401Ol0003oooooo`000?o=a=7o0000
00;ob[k?00?o0000ooooooooool02?ooool01?l0003ob[k?olZncol00002olJgc0gooooo00Ko0000
olJgc?o6]lco0000ol2`bOl00008ol2`b@?o00000_o3Zl800ol0003o`j_2ol>[`P07o`0000Wooooo
00Oo0000ok^R_onkX[oo^j:oo`000?nbVKko000000kooooo00?o0000ok:I__l000000onVTKl00ol0
003oooooooooo`04ooooo`Go00001?nVTKl6o`0000KoW9C;0_l00005ooooo`05o`000?nLU<_oW9C;
oibDbol000000on@T=000ol0003oooooooooo`0?ooooo`Go000000?oPhkFo`000?l000001_n;V]d0
0ol0003oooooooooo`0@ooooo`;o00000on;V]d2o`0000?oP9[S0_l000000ooooooo0000oh2Jh`04
oh2Jh`03o`000?n9YNOoRJGW00KoRJGW00?o0000ooooooooool04Oooool3o`0000WoRJGW0ol00005
oh>Wk0?o00001on2Yn`00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool01Oooool003[ooooo00?o0000ooooooooool0;oooool00ol0003o`]SZol;HjP06ol;H
jP03o`000?oooooooooo00Gooooo0ol00004ol;HjP;o00001_o2dnH2o`0001;ooooo00?o0000ol;C
i_o2dnH01_o2dnH00ol0003obmKRo`000003o`000003ol[@g_l0003ooooo00[ooooo00?o0000ol[@
g_l000000_o9cM`00ol0003oooooooooo`03ooooo`Co000000Koooooo`000?l0003obL_Kooooool0
0002olS8fP?ooooo00Ko0000olS8f_l0003ob<SJolK5f?l00003olK5f003o`000?o=`m7ocL?A00Co
cL?A00?o0000olg4dOl000000_o:_/l2o`0000Wooooo00Co0000olZncoo:_/oo00000_o6]l`00ol0
003oooooooooo`0:ooooo`04o`000?o6]lcoa[O<o`0000;o`;390ol00009ol2`b@Ko00001_nkX[l7
o`0000;ooooo00Oo0000ok^R_onkX[oo^j:oo`000?nbVKko000000kooooo00?o0000ok:I__l00000
0onVTKl00ol0003oooooo`000004o`0000_oYY6o00?o0000oibDbonLU</01OnLU</2o`0000Sooooo
00Go0000oibDbonLU<_oW9C;o`000003oi2@d003o`000?oooooooooo00gooooo00?o0000oi2@d?n@
T=000on@T=05o`0000?oRi[M00?o0000ooooooooool04oooool00ol0003oRi[Moh^Jg@02oh^Jg@;o
00000on0V^<00ol0003oP9[Soh2Jh`04oh2Jh`03o`000?n9YNOoRJGW00GoRJGW00?o0000oooooooo
ool05Oooool3o`0000WoRJGW0_l00006oh>Wk003o`000?n2YncoPZO/00CoPZO/00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo000kooooo`03o`00
0?oooooooooo02oooooo00?o0000ol;Hj_o2f>X01Oo2f>X00ol0003oooooooooo`02ooooo`?o0000
1?o2f>X3o`0000Go`]?V0ol0000Eooooo`03o`000?o2dnKo`]?V00;o`]?V1_l00005ol[@gP03o`00
0?oooooooooo00Kooooo1?l00002olW=g003o`000?oooooooooo00?ooooo1?l000001?oooooo0000
o`000?ooool2o`0000;ob<SJ1?ooool2o`000003olS8f_o6aMSo000000Goa/GH0_l00004olg3d@;o
00000_o:_/l00ol0003oooooo`000008ooooo`04o`000?o:_/oob[k?o`0000;oa[O<00?o0000oooo
ooooool02_ooool01?l0003oa[O<olJgc?l00003ol2`b@03o`000?oooooooooo00Co00002?o0/<T5
o`0000_o^j:o0ol00002ok^R_`03o`000?nbVKko/YVn013o00000_nbVKh00ol0003oYY6oojJA_`02
o`0000SoYY6o1Ol00003ojNJb005o`000?nLU<_o0000o`000?nLU</00ol0000;ooooo`05o`000?nL
U<_oW9C;oibDbol000000on@T=000ol0003oooooooooo`0:ooooo`;o00001_n@T=001OnEVmOo0000
oiFKeol0003oRi[M00Co00005oooool00ol0003oRi[Moh^Jg@02oh^Jg@;o000000?oP9[So`000?n0
V^<01?n0V^<00ol0003oRJGWohVUi`06ohVUi`03o`000?oooooooooo01Sooooo0ol00009ohVUi`;o
00001?n3Yn`2o`0000CoPZO/00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00Gooooo000looooo`;o0000;oooool00ol0003o`]SZol;HjP06ol;HjPCo0000
1Oo2f>X2o`0000Ko`]?V0_l0000Hooooo`Go000000Go`]?Vo`000?l0003o`/oTo`000007ol[@gP03
o`000?oooooooooo00Cooooo00?o0000ol[@g_l000000oo9cM`5ooooo`Co00000_ooool2o`000004
ooooool0003ob<SJolS8fPGooooo00?o0000olS8f_o8b=X00_o6aMP00ol0003oa/GHolK5f005olK5
f003o`000?o=`m7ocL?A00;o000000Kob[k?o`000?l0003o0000ooooool00008ooooo`03o`000?o:
_/oo000000;oa[O<00?o0000ooooooooool02oooool01?l0003oa[O<olJgc?l00003ol2`b@Oooooo
0ol00003ol2`b@;o000000?o`;39o`000?niZ<P00_niZ<P7o`0000Oo^j:o00Go0000ok^R_ol0003o
/YVno`00000@ok:I_P05o`000?nbVKko0000ojJA_ol000001OnVTKl5o`0000OoYi[800?o0000ojNJ
b?l000000_nLU</00ol0003oooooooooo`0<ooooo`03o`000?nLU<_oW9C;00;oW9C;00Go0000oi2@
d?n@T=3oT93@o`00000:ooooo`03o`000?n@T=3oT93@00?oT93@0_l00002oiFKe`04o`000?nEVmOo
UI_Go`0000CoRi[M00?o0000ooooooooool05Oooool00ol0003oRi[Moh^Jg@03oh^Jg@03o`000?n0
V^?o000000CoP9[S00?o0000ohVUion9YNL01On9YNL00ol0003oooooooooo`0Looooo`;o00002on9
YNL01?l0003oPjO/oh>Wk?n3Yn`2o`000003oh:Wk?l0003ooooo02[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`05ooooo`00?_ooool00ol0003oooooooooo`0/ooooo`03o`000?o2
f>[o`]SZ00Go`]SZ0_l00005ol;HjP;o00001_o2dnH3o`0001Sooooo0_l00004ol;CiP?o00000oo2
cn@00ol0003ob]3Nol[@gP05ol[@gP04o`000?ooooooooooooooo`Co00000_o9cM`00ol0003ooooo
ooooo`03ooooo`05o`000?o9cMco0000o`000?ooool00_l00002ooooo`03o`000?o8b=[ob<SJ00Go
oooo00?o0000olS8f_l000000_o6aMP2o`0000Soa/GH00?o0000olg3dOl000000_l00003olZnc`;o
00001oooool01_l0003ob[k?olZncol0003oa[O<o`0000gooooo00Co0000olJgc?o6]lco00000oo0
/<T00ol0003oooooooooo`09ooooo`;o00000oo0/<T2o`0000Wo^JS81ol000001?nkX[oo0000o`00
0?l0000Bok:I_P?o000000?oYY6oo`000?l000000ol0000;ojNJb004o`000?nWV/SoYi[8o`0000;o
W9C;00?o0000ooooooooool03Oooool00ol0003oW9C;oibDb`02oibDb`05o`000?n@T=3oT93@oi2@
d?l000001oooool2o`0000GoT93@00?o0000oiFKeonEVmL00onEVmL00ol0003oUI_GoiFKe`02o`00
00?oRi[M00?o0000ooooooooool05_ooool00ol0003oRi[Moh^Jg@03oh^Jg@05oh2Jhol0003oP9[S
oh2Jhol000002?n9YNL00ol0003oooooooooo`0Oooooo`;o00002on9YNL00ol0003oPjO/oh>Wk002
o`0002cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`00?oooool00ol0
003oooooooooo`0/ooooo`03o`000?o2f>[o`]SZ00?o`]SZ00?o0000ol;Hj_o2f>X00oo2f>X00ol0
003o`]?Vol;CiP05ol;CiP;o00006Oooool2o`0000Co`]?V0_l000000oo2cnCo0000ol;?i004ol;?
i003o`000?o:d=kob]3N00Gob]3N00Go0000ooooool0003ob]3No`000003olW=g0Kooooo00?o0000
olW=g?l000000_ooool2o`000005ooooool0003o0000olS8f_l000001Oooool00ol0003ob<SJolK5
f002olK5f0?ooooo00?o0000olK5f?o6aMP01Oo6aMP3o`0000Oob[k?0_l00004ooooo`04o`000?o:
_/oob[k?o`0000;oa[O<00?o0000ooooooooool02oooool01?l0003oa[O<olJgc?l00002ol2`b@03
o`000?oooooooooo00_ooooo00Ko0000ol2`bOo0/<Wo0000okVXb?l0000@okVXb1Go00000_nbVKh3
o`0000ooYi[800?o0000ojNJb?nWV/P00_nWV/P01?l0003oW9C;oibDbol0000?ooooo`05o`000?nL
U<_oW9C;oibDbol000000on@T=000ol0003oooooooooo`04ooooo`03o`000?n@T=3oT93@00CoT93@
00?o0000oiFKeonEVmL01?nEVmL00ol0003oUI_GoiFKe`02oiFKe`04o`000?n;V]goRi[Moh^Jg@;o
00006?ooool7o`000003oh2Jhol0003oRJGW00OoRJGW00?o0000ooooooooool08_ooool00ol0003o
RJGWohVUi`06ohVUi`Ko0000;Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Go
oooo0010ooooo`;o0000;?ooool01?l0003o`]SZol;Hj_o2f>X2o`0000Co`]SZ00?o0000ol;Ci_o2
dnH01Oo2dnH00ol0003oooooooooo`0Gooooo`?o00000oo2dnH3o`0000;o`/oT00?o0000ol;?i?o2
cn@01Oo2cn@00ol0003ob]3Nol[@gP05ol[@gP?o00000_o9cM`00ol0003oooooooooo`03ooooo`Co
00000_ooool2o`000004ooooool0003ob<SJolS8fPKooooo00?o0000olS8f_o6aMP00_o6aMP5oooo
o`;o00000oo6aMP2o`000003olC0e_l0003oa<3F00;o00001oo:_/l2o`000005ooooool0003ob[k?
olZncol000000_o6]l`00ol0003oooooooooo`0;ooooo`04o`000?o6]lcoa[O<o`0000?o`;3900?o
0000ooooooooool02oooool01?l0003o`;39ol2`bOl00002okVXb0Go00002oniZ<P01?l0003o^JS8
o`000?l0000Bok6Qa`;o000000?oYi[8o`000?l000001?nWV/P7o`0000?ooooo00?o0000ojNJb?nW
V/P00_nWV/P01?l0003oW9C;oibDbol0000@ooooo`05o`000?nLU<_oW9C;oibDbol000000on@T=00
1?l0003oooooooooooooool2o`0000GoT93@0_l00007oiFKe`;o00001?nEVmL00ol0003oRi[Moh^J
g@02oh^Jg@03o`000?oooooooooo01Gooooo00?o0000oh^JgOn;V]d00_n;V]d=o`0002Oooooo1_l0
0005ohVUi`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`05ooooo`00@_ooool00ol0003oooooooooo`0Yooooo`04o`000?o2f>[o`]SZo`0000?o`]SZ00?o
0000ol;Ci_o2dnH01_o2dnH00ol0003oooooooooo`0Gooooo`;o00001?o2dnH2o`0000?o`/oT0_l0
0009ol;?i003o`000?o:d=kob]3N00?ob]3N0_l00003olW=g0Kooooo00Go0000olW=g?l0003o0000
ooooo`02o`0000;ooooo00?o0000olS8f_o8b=X01Oooool2o`000004olS8f_o6aMSoa/GHolK5f0So
oooo00Co0000olK5f?l0003oa/GH0_o4`=H01?l0003oa<3FolC0e_o4`=H2o`0000Oob[k?00Co0000
olZncoo:_/oo00000_o6]l`00ol0003oooooooooo`0;ooooo`05o`000?o6]lcoa[O<olJgc?l00000
0_o0/<T00ol0003oooooooooo`0;ooooo`05o`000?o0/<Wo`;39ol2`bOl000000_niZ<P00ol0003o
ooooooooo`02ooooo`Ko00001?niZ<P01_l0003o^JS8okVXb?l0003o/J77o`00013o/J7700?o0000
ok6Qaol000000onWV/P4o`0000_ooooo00Go0000ojNJb?nWV/SoYi[8o`000003oibDb`03o`000?oo
oooooooo00kooooo00Go0000oibDbonLU<_oW9C;o`000003oi2@d003o`000?oooooo000000KoT93@
00?o0000oiFKeonEVmL01_nEVmL3ooooo`03o`000?nEVmOoUI_G00;oUI_G0_l00003oh^Jg@03o`00
0?oooooooooo01?ooooo00?o0000oh^JgOn;V]d01On;V]d00ol0003oTJGRo`000002o`0000KoRJGW
0_l0000Vooooo`03o`000?n9YNOoRJGW00KoRJGW00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Cooooo0013ooooo`03o`000?oooooooooo02Wooooo0_l0
0002ol;HjPSo`]?V00?o0000ooooooooool06?ooool2o`0000Co`]?V0_l00003ol;?i0;o000000?o
ooooo`000?o2cn@02Oo2cn@01?l0003ob]3Nol[@g_o:d=h2o`000003olW=g?l0003o000000Gooooo
0_l000001?o9cMco0000ooooooooool2o`0000;ooooo00?o0000olS8f_ooool01Oooool00ol0003o
b<SJo`000002olK5f003o`000?oooooooooo00Oooooo0_l000001?o6aMSoa<3FolC0e_l00006olC0
eP?o00001?o:_/l01_l0003ob[k?olZncol0003oa[O<o`0000kooooo00Co0000olJgc?o6]lco0000
0oo0/<T00ol0003oooooooooo`0;ooooo`04o`000?o0/<Wo`;39o`0000?o^JS83?ooool3o`0000?o
^JS800?o0000ok6QaonaXLL03Ol00002ok6Qa`04o`000?naXLOo/J77o`0000?oYi[800?o0000oooo
ooooool03?ooool00ol0003oYi[8ojNJb002ojNJb004o`000?nLU<_oW9C;o`00013ooooo00?o0000
oibDbonLU</00_nLU</01Ol0003oT93@oi2@d?n@T=3o000000GoT93@0_l00006oiFKe`;o00001Ooo
ool00ol0003oUI_GoiFKe`03oiFKe`04o`000?n;V]goRi[Moh^Jg@;o00004_ooool00ol0003oRi[M
oh^Jg@05oh^Jg@03o`000?nAYN;o000000?oTJGR0_l00006ohVUi`?o00008_ooool00ol0003oRJGW
ohVUi`07ohVUi`03o`000?oooooooooo02kooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`04ooooo`00A?ooool2o`0002Wooooo2_l0000Kooooo`;o00001?o2dnH2o`0000?o`/oT0_l0
0004ooooo`03o`000?o2cnCo`/oT00So`/oT00?o0000ol[@g_l000000ol00002olW=g006o`000?oo
ooooooooooooool0003obLgL0_l00002ooooo`;o000000Coooooo`000?l0003ob<SJ1_ooool00ol0
003ob<SJolK5f002olK5f003o`000?oooooooooo00Oooooo00?o0000olK5f?o6aMP00oo4`=H00ol0
003oa<3FolC0eP07olC0eP;o00000_o:_/l00ol0003ob[k?o`000003o`0000gooooo00Co0000olJg
c?o6]lco00000oo0/<T00ol0003oooooooooo`0<ooooo`04o`000?o0/<Wo`;39o`0000;o^JS800?o
0000ooooooooool03?ooool01Ol0003o^JS8okVXb?niZ<So000000;o/J7700?o0000ooooooooool0
3?ooool01Ol0003o/J77ok6QaonaXLOo000000;oYi[800?o0000ooooooooool03Oooool01Ol0003o
Yi[8ojNJb?nWV/So000000;oW9C;00?o0000ooooooooool03oooool01Ol0003oW9C;oibDbonLU<_o
000000?oT93@00?o0000oi2@d?n@T=000_n@T=000ol0003oUI_GoiFKe`05oiFKe`03o`000?oooooo
oooo00Kooooo00?o0000oiFKeonEVmL00onEVmL00ol0003oRi[Moh^Jg@02oh^Jg@03o`000?oooooo
oooo00kooooo00?o0000oh^JgOn;V]d01On;V]d01Ol0003oTJGRoi6Uh_nAYN;o000000CoTJGR0_l0
0007ohVUi`;o00008?ooool00ol0003oRJGWohVUi`06ohVUi`03o`000?oooooooooo033ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`00A_ooool00ol0003oooooooooo`0V
ooooo`03o`000?o2dnKo`]?V00Ko`]?V00?o0000ooooooooool05oooool2o`0000Co`]?V0_l00003
ol;?i0;o00001oooool00ol0003o`/oTol;?i008ol;?i0;o00001_o9cM`01Ol0003oooooo`000?o9
cMco000000;ooooo0_l00002ooooo`03o`000?o8b=[o000000Kooooo00Go0000olS8f_o6aMSoa/GH
o`00000:ooooo`03o`000?o6aMSoa/GH00Coa<3F0_l0000:olC0ePGo00000oo6]l`3o`0000[ooooo
00Co0000olJgc?o6]lco00000_o0/<T00ol0003oooooooooo`0<ooooo`05o`000?o0/<Wo`;39ol2`
bOl000000_niZ<P00ol0003oooooooooo`0<ooooo`05o`000?niZ<So^JS8okVXb?l000000_naXLL0
0ol0003oooooooooo`0<ooooo`05o`000?naXLOo/J77ok6Qaol000000onWV/P00ol0003ooooooooo
o`0<ooooo`03o`000?nWV/SoYi[800;oYi[800Co0000oibDbonLU<_o00004Oooool4oibDb`04o`00
0?n@T=3oT93@o`0000?oT93@00?o0000oiFKeonEVmL01?nEVmL2o`0000[ooooo0_l00004oiFKe`;o
00000on;V]d00ol0003oooooooooo`0<ooooo`03o`000?n;V]goRi[M00GoRi[M00?o0000oi6Uh_nA
YN800onAYN800ol0003oTJGRoi6UhP03oi6UhP?o00001_n9YNL2o`0001gooooo00?o0000ohVUion9
YNL01on9YNL00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool01?ooool004Oooooo00?o0000ooooooooool09_ooool00ol0003o`]?Vol;CiP06ol;CiP03o`00
0?oooooooooo01?ooooo0ol00004ol;CiP;o00000_o2cn@3o`0000[ooooo00?o0000ol;?i?o2cn@0
0oo2cn@3o`0000?o`/cR00?o0000olW=g?o9cM`01?o9cM`00ol0003obLgLo`000002ooooo`;o0000
0_ooool00ol0003ob<SJooooo`06ooooo`;o00000_o6aMP00ol0003oooooooooo`08ooooo`03o`00
0?o6aMSoa/GH00Coa<3F0oooool2o`0000Woa<3F0ol00007olJgc0;o00001oooool01?l0003oa[O<
olJgc?l00003ol2`b@03o`000?oooooooooo00cooooo00Co0000ol2`bOo0/<Wo00000_niZ<P00ol0
003oooooooooo`0=ooooo`04o`000?niZ<So^JS8o`0000?o/J7700?o0000ooooooooool03Oooool0
1?l0003o/J77ok6Qaol00003ojNJb003o`000?oooooooooo00gooooo00Go0000ojNJb?nWV/SoYi[8
o`000002oibDb`03o`000?oooooooooo00oooooo1?l000001OnLU<_o0000oi2@d?l0003oT93@00;o
00001_nEVmL00ol0003oooooooooo`0<ooooo`03o`000?nEVmOoUI_G00?oUI_G00Co0000oh^JgOn;
V]goRi[M0_l0000;ooooo`03o`000?n;V]goRi[M00GoRi[M00?o0000oi6Uh_nAYN801OnAYN800ol0
003oTJGRoi6UhP05oi6UhP;o00001_n9YNL2o`0001_ooooo00?o0000ohVUion9YNL01_n9YNL00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool004So
oooo0_l0000Wooooo`03o`000?o2dnKo`]?V00Ko`]?V00?o0000ooooooooool04?ooool2o`0000Go
`]?V0_l00002ol;?i0;o00003_ooool00ol0003o`/oTo`000004o`0000Go`/cR00?o0000olW=g?o9
cM`00oo9cM`3o`000004ooooool0003obL_Kooooo`?o00001oooool2o`0000;oa/GH00?o0000oooo
ooooool02?ooool00ol0003oa/GHolK5f004olC0ePKooooo0_l00005olC0eP;o000000?oa<3Fo`00
0?o1^]<00ol00006olJgc0;o00001?ooool01Ol0003oa[O<olJgc?o6]lco000000;o`;3900?o0000
ooooooooool03Oooool01?l0003o`;39ol2`bOl00002okVXb003o`000?oooooooooo00gooooo00Co
0000okVXb?niZ<So00000onaXLL00ol0003oooooooooo`0=ooooo`04o`000?naXLOo/J77o`0000?o
Yi[800?o0000ooooooooool03Oooool00ol0003oYi[8ojNJb002ojNJb004o`000?nLU<_oW9C;o`00
00gooooo0ol00004oibDb`Go00001_nEVmL2o`00013ooooo00?o0000oiFKeonEVmL00onEVmL00ol0
003oRi[Moh^Jg@02oh^Jg@03o`000?oooooooooo00Sooooo00?o0000oh^JgOn;V]d01?n;V]d00ol0
003oTJGRoi6UhP07oi6UhP;o00001onAYN82o`0000KoRJGW0ol0000Gooooo`03o`000?n9YNOoRJGW
00KoRJGW00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Cooooo001:ooooo`03o`000?oooooooooo02Cooooo00?o0000ol;Ci_o2dnH01_o2dnH00ol0003o
ooooooooo`0>ooooo`;o00001?o2dnH3o`0000;o`/oT0_l0000@ooooo`;o000000Co`/oTo`000?o2
c>;o00001oo2c>801Ol0003obLgLolW=g?o9cMco000000?obL_K00Go0000oooooooooooo0000olS8
fP07ooooo`?o00000_o6aMP00ol0003oooooooooo`08ooooo`03o`000?o6aMSo000000Coa<3F2Ooo
ool2o`000003olC0e_l0003o000000;oa<3F0_l00004ol6jd`;o00001_o6]l`3o`000005ooooool0
003oa[O<olJgc?l000000oo0/<T00ol0003oooooooooo`0<ooooo`05o`000?o0/<Wo`;39ol2`bOl0
00000_niZ<P00ol0003oooooooooo`0=ooooo`04o`000?niZ<So^JS8o`0000?o/J7700?o0000oooo
ooooool03Oooool01?l0003o/J77ok6Qaol00003ojNJb003o`000?oooooooooo00kooooo00Go0000
ojNJb?nWV/SoYi[8o`000002oibDb`03o`000?oooooooooo00Sooooo0ol0000:oibDb`Co00000onE
VmL00ol0003oooooooooo`0Aooooo`;o00001?nEVmL2o`0000?oRi[M00?o0000ooooooooool01_oo
ool00ol0003oRi[Moh^Jg@04oh^Jg@03o`000?nAYN;oTJGR00OoTJGR00?o0000ooooooooool00_l0
0007oi6UhP?o00001_n9YNL2o`0001Gooooo00?o0000ohVUion9YNL01_n9YNL00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool004_ooooo00?o0000
ooooooooool09?ooool00ol0003o`]?Vol;CiP06ol;CiP03o`000?oooooooooo00_ooooo0_l00004
ol;CiP;o00000oo2cn@2o`00013ooooo0_l000001Oo2cnCo0000o`000?o2c>;o000000Wo`/cR00?o
0000olW=g?l000000oo9bm/2o`000003ooooool0003o000000Oooooo00?o0000olS8f_o6aMP00_o6
aMP00ol0003oooooooooo`08ooooo`03o`000?o6aMSo000000Coa<3F3?ooool01?l0003oa<3FolC0
e_o4`=H2o`0000Oo`K[C0ol00006olJgc005o`000?o6]lcoa[O<olJgc?l000000_o0/<T00ol0003o
ooooooooo`0=ooooo`04o`000?o0/<Wo`;39o`0000;o^JS800?o0000ooooooooool03_ooool01?l0
003o^JS8okVXb?l00003ok6Qa`03o`000?oooooooooo00gooooo00Go0000ok6QaonaXLOo/J77o`00
0002ojNJb003o`000?oooooooooo00kooooo00?o0000ojNJb?nWV/P00_nWV/P01?l0003oW9C;oibD
bol00007ooooo`;o00002_nLU</2o`000003oinNdol0003oUI_G00;oUI_G0ol0000Fooooo`03o`00
0?nEVmOoUI_G00?oUI_G00Co0000oh^JgOn;V]goRi[M0_l00005ooooo`03o`000?n;V]goRi[M00Co
Ri[M00?o0000oi6Uh_nAYN801onAYN800ol0003oooooooooo`03ooooo`?o00001onAYN82o`0000Ko
RJGW0_l0000Booooo`03o`000?n9YNOoRJGW00KoRJGW00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00?ooooo001<ooooo`;o00009?ooool00ol0003o`]?V
ol;CiP07ol;CiP03o`000?oooooooooo00Sooooo0_l00004ol;CiP;o00000oo2cn@2o`00013ooooo
0_l000001?o2cnCo0000o`000?o2c>82o`0000_o`/cR00Co0000olW;foo9bm_o00000_o9bm/4o`00
00Kooooo0_l00002olK5f0;o00002_ooool00ol0003oa/GHo`000003olC0eP03o`000?oooooooooo
00_ooooo00Ko0000olC0e_o4`=Ko0000ol6jdol0000:ol6jd`;o00001?o6]l`01?l0003oa[O<olJg
c?l00003ol2`b@03o`000?oooooooooo00gooooo00Co0000ol2`bOo0/<Wo00000_niZ<P00ol0003o
ooooooooo`0>ooooo`04o`000?niZ<So^JS8o`0000?o/J7700?o0000ooooooooool03Oooool01Ol0
003o/J77ok6QaonaXLOo000000?oYi[800?o0000ooooooooool03_ooool01Ol0003oYi[8ojNJb?nW
V/So000000;oW9C;00?o0000ooooooooool00_ooool3o`0000SoW9C;0ol00004oinNd`;o00001?nE
VmL00ol0003oooooooooo`0Eooooo`03o`000?nEVmOoUI_G00?oUI_G00?o0000oh^JgOn;V]d00_n;
V]d01Ol0003ooooooooooooooooo000000KoRi[M00?o0000oi6Uh_nAYN801onAYN800ol0003ooooo
ooooo`07ooooo`;o00001onAYN82o`0000KoRJGW0ol0000>ooooo`03o`000?n9YNOoRJGW00OoRJGW
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo
001>ooooo`03o`000?oooooooooo02;ooooo00?o0000ol;Ci_o2dnH01oo2dnH00ol0003ooooooooo
o`04ooooo`?o00001?o2dnH2o`0000?o`/oT0_l0000@ooooo`;o000000Co`/oTo`000?l0003o`/cR
0_l00003ooooo`03o`000?o2c>;o`/cR00?o`/cR0ol000001?o1b^7o0000olW;fol00002olW;f`03
o`000?o8b=[ob<SJ00;ob<SJ0_l00003ooooo`;o00000_o6aMP00ol0003oooooooooo`09ooooo`03
o`000?o6aMSo000000?oa<3F00?o0000ooooooooool02oooool01?l0003oa<3FolC0e_l00002ol6j
d`;o00002oo1^]<2o`0000;oa[O<00?o0000olJgc?l000000_o0/<T4o`0000gooooo00Go0000ol2`
bOo0/<Wo`;39o`000002okVXb003o`000?oooooooooo00gooooo00Go0000okVXb?niZ<So^JS8o`00
0002ok6Qa`03o`000?oooooooooo00oooooo00Co0000ok6QaonaXLOo00000onWV/P00ol0003ooooo
ooooo`0>ooooo`03o`000?nWV/SoYi[800;oYi[800Co0000oibDbol0003ooooo0ol00008oibDb`?o
00001_nOW]<01?l0003oWikCoinNdol00004oiFKe`03o`000?oooooooooo01Gooooo00?o0000oiFK
eonEVmL00onEVmL2o`0000?oRi[M00?o0000ooooool000001_n;V]d00ol0003oTJGRoi6UhP07oi6U
hP03o`000?oooooooooo00[ooooo0_l00007oi6UhP?o00001_n9YNL2o`0000cooooo00?o0000ohVU
ion9YNL01_n9YNL00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool00oooool004oooooo00?o0000ooooooooool08_ooool00ol0003o`]?Vol;CiP06ol;CiP03
o`000?oooooooooo00;ooooo0_l00005ol;CiP;o00000oo2cn@2o`00017ooooo00Go0000ol;?i?l0
003o0000ol;<hP02o`0000Kooooo00?o0000ol;<h_l000000ol00004ol7:h@;o000000?obL_Ko`00
0?o8b=X01_o8b=X01?l0003oooooo`000?l00002olK5f003o`000?oooooooooo00Wooooo00?o0000
olK5f?l000000oo4`=H00ol0003oooooooooo`0;ooooo`04o`000?o4`=Koa<3Fo`0000?o`K[C00?o
0000ooooool000000_l0000:ol6jd`Oo00001?o0/<T4o`0000Wooooo00Co0000ol2`bOo0/<Wo0000
0_niZ<P00ol0003oooooooooo`0>ooooo`05o`000?niZ<So^JS8okVXb?l000000_naXLL00ol0003o
ooooooooo`0?ooooo`04o`000?naXLOo/J77o`0000?oYi[800?o0000ooooooooool03oooool4ojNJ
b004o`000?nLU<_oW9C;o`0000SoW9C;0ol00009oinNd`05o`000?nOW]?oWikCoinNdol000001?nE
VmL00ol0003oooooooooo`0Eooooo`03o`000?nEVmOoUI_G00CoUI_G00Go0000oh^JgOn;V]goRi[M
o`000006oh^Jg@03o`000?nAYN;oTJGR00OoTJGR00?o0000ooooooooool03Oooool2o`0000SoTJGR
0_l00006ohVUi`;o00002Oooool00ol0003oRJGWohVUi`07ohVUi`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`00D?ooool2o`0002;ooooo00?o
0000ol;Ci_o2dnH01oo2dnH01?l0003oooooo`000?l00005ol;CiP;o00000oo2cn@2o`00017ooooo
1?l000000oo2c>;o0000o`000008ooooo`;o000000?o`/cRo`000?l000000oo1b^400ol0003o`L[Q
ol7:h@03o`0000Sob<SJ00Go0000olK5f?o6aMSoa/GHo`00000;ooooo`03o`000?o6aMSo000000?o
a<3F00?o0000ooooooooool02oooool01?l0003oa<3FolC0e_l00003ol6jd`03o`000?oooooooooo
00?ooooo0ol00009ol6jd`Co00002Oo0/<T3o`0000Kooooo00Co0000ol2`bOo0/<Wo00000_niZ<P0
0ol0003oooooooooo`0>ooooo`05o`000?niZ<So^JS8okVXb?l000000_naXLL00ol0003ooooooooo
o`0?ooooo`04o`000?naXLOo/J77o`0000?oYi[800?o0000ooooooooool03oooool01Ol0003oYi[8
ojNJb?nWV/So000000;oW9C;00?o0000oibDbonLU</00onLU</3o`0000coWikC00?o0000oinNdonO
W]<00_nOW]<00ol0003oUI_GoiFKe`02oiFKe`03o`000?oooooooooo01Kooooo1_nEVmL01?l0003o
Ri[Moh^JgOl00005oh^Jg@03o`000?nAYN;oTJGR00OoTJGR00?o0000ooooooooool04?ooool3o`00
00OoTJGR0_l00006ohVUi`;o00001oooool00ol0003oRJGWohVUi`06ohVUi`03o`000?oooooooooo
03cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`00D_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?o2dnKo`]?V00Oo`]?V00?o0000ol;Ci_o2dnH00oo2dnH2o`0000Co
`/oT00?o0000ooooooooool03oooool2o`000005ol;?i?l0003o`/cRol;<h_l000002Oooool01Ol0
003o`/cRo`000?l0003o`L[Q00Co000000Co`L[Qo`000?l0003o00000_o1b>000ol0003ob<SJolS8
fP04olS8fP05o`000?o6aMSoa/GHolK5f?l000002oooool00ol0003oa/GHo`000003olC0eP03o`00
0?oooooooooo00_ooooo00Go0000olC0e_o4`=Koa<3Fo`000002ol6jd`03o`000?oooooooooo00Oo
oooo0_l00005ol6jd`;o000000Co`K[Co`000?nl]=7o_;CA1?l00008ol2`b@Co000000?oooooo`00
0?o0/<T00_o0/<T01?l0003o^JS8okVXb?l0000@ooooo`05o`000?niZ<So^JS8okVXb?l000000_na
XLL00ol0003oooooooooo`0?ooooo`05o`000?naXLOo/J77ok6Qaol000000_nWV/P00ol0003ooooo
ooooo`0=ooooo`Go00000_nWV/P00ol0003oW9C;o`000002oibDb`?o00002onOW]<3o`000003oooo
ool0003oWikC00CoWikC00?o0000oiFKeonEVmL00_nEVmL00ol0003oooooooooo`0Fooooo`KoUI_G
0_l000000on;V]go0000oh^Jg@02oh^Jg@03o`000?nAYN;oTJGR00OoTJGR00?o0000ooooooooool0
5?ooool2o`0000OoTJGR0ol00005ohVUi`?o00000oooool00ol0003oRJGWohVUi`07ohVUi`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`00Dooo
ool00ol0003oooooooooo`0Pooooo`03o`000?o2dnKo`]?V00Go`]?V00?o0000ol;Ci_o2dnH00_o2
dnH2o`0000Co`/oT4_ooool2o`000004ol;?i?l0003o0000ol;<hP;o00002?ooool4o`000003ol;:
hOl0003o000000;o00000_o1b^400ol0003o`L[Qo`000004ol78h0;o00000oo8b=X00ol0003oa/GH
olK5f003o`0000[ooooo00?o0000olK5f?l000000oo4`=H00ol0003oooooooooo`0;ooooo`05o`00
0?o4`=Koa<3FolC0e_l000000_o1^]<00ol0003oooooooooo`0:ooooo`;o00000_o1^]<01Ol0003o
`K[Col6jdoo1^]?o000000Ko_;CA0ol00009ol2`b@;o00000_o0/<T01?l0003o^JS8okVXb?l0000A
ooooo`05o`000?niZ<So^JS8okVXb?l000000_naXLL00ol0003oooooooooo`0?ooooo`05o`000?na
XLOo/J77ok6Qaol000000onWV/P00ol0003oooooooooo`06ooooo`Ko00001OnWV/P7o`0000_oWikC
0ol00005ooooo`03o`000?nOW]?oWikC00?oWikC00?o0000oiFKeonEVmL00_nEVmL00ol0003ooooo
ooooo`0Fooooo`OoUI_G0_l00002oh^Jg@03o`000?nAYN;oTJGR00OoTJGR00?o0000ooooooooool0
5oooool2o`0000SoTJGR0_l00006ohVUi`;o000000?oooooo`000?n9YNL01on9YNL00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool005Cooooo0_l0
000Pooooo`03o`000?o2dnKo`]?V00Co`]?V00?o0000ol;Ci_o2dnH00ol00004ol;?i1;ooooo0_l0
00001?o2cnCo0000o`000?o2c>82o`0000Sooooo0_l000001_o2c>;o0000o`000?oooooo0000ol;:
h@;o000000Go`L[Qo`000?l0003o`LSPo`000007ol78h003o`000?o8b=[o000000?o00000oo6aMP0
0ol0003oooooooooo`06ooooo`03o`000?o6aMSo000000?oa<3F00?o0000ooooooooool03?ooool0
1?l0003oa<3FolC0e_l00002ol6jd`03o`000?oooooooooo00kooooo00Oo0000ol6jdoo1^]?o`K[C
o`000?nl]=7o000000So_;CA1?l00006ol2`b@05o`000?o0/<Wo`;39o`000?niZ<P01ol0000<oooo
o`05o`000?niZ<So^JS8okVXb?l000000_naXLL00ol0003oooooooooo`0@ooooo`04o`000?naXLOo
/J77o`0000?oYi[800?o0000ooooooooool01_l0000>ojNJb003o`000?nOW]?oWikC00[oWikC0_l0
0009ooooo`03o`000?nOW]?oWikC00?oWikC00?o0000oiFKeonEVmL00_nEVmL00ol0003ooooooooo
o`0Eooooo`Ko00000_nEVmL00ol0003oRi[Mo`000009oi6UhP03o`000?oooooooooo01[ooooo0ol0
0007oi6UhP;o00001_n9YNL00ol0003oRJGWohVUi`07ohVUi`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00E_ooool00ol0003oooooooooo`0N
ooooo`03o`000?o2dnKo`]?V00;o`]?V00Co0000ol;Ci_l0003o00001Oo2cn@Booooo`;o000000Co
`/oTo`000?l0003o`/cR0_l00009ooooo`05o`000?o2c>;o0000o`000?ooool01?l000001_oooooo
0000o`000?o1b^7o`LSPo`0000So`LSP0ol00007olK5f0;o00001Oooool00ol0003oa/GHo`000003
olC0eP03o`000?oooooooooo00cooooo00Co0000olC0e_o4`=Ko00000oo1^]<00ol0003ooooooooo
o`0>ooooo`04o`000?o1^]?o`K[Co`0000;o_;CA00?o0000okbddOnl]=402_nl]=44o`0000?o`;39
00Co0000ol2`bOl0003o00001oniZ<P9o`0000?ooooo00Co0000okVXb?niZ<So00000onaXLL00ol0
003oooooooooo`0@ooooo`04o`000?naXLOo/J77o`0000?oYi[80ol0000<ojNJb0Go00000onXX]40
1?l0003oWikCo`000?l00006oinNd`?o00003?ooool00ol0003oWikCoinNd`02oinNd`03o`000?nE
VmOoUI_G00?oUI_G00?o0000ooooooooool04oooool00ol0003oUI_GoiFKe`04oiFKe`Wo00001?nA
YN800ol0003oooooooooo`0Nooooo`;o00001onAYN83o`0000CoRJGW00?o0000ohVUion9YNL01On9
YNL00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_oo
ool005Oooooo00?o0000ooooooooool07Oooool01?l0003o`]?Vol;Ci_o2dnH3o`0000;o`/oT0ol0
000Booooo`;o000000Co`/oTo`000?l0003o`/cR0_l00009ooooo`Co000000?o`/[Qo`000?l00000
0ol000000ooooooo0000ol7:h@02ol78h0;o00001_o1b>02o`0000?o`<KN00?o0000olK5f?o6aMP0
1_o6aMP01ol0003ooooooooooooooooo0000olK5f?l000000oo4`=H00ol0003oooooooooo`0<oooo
o`04o`000?o4`=Koa<3Fo`0000?o`K[C00?o0000ooooooooool03_ooool01?l0003o`K[Col6jdol0
0003okbdd@?o00003_nl]=46o`00017o^JS81?l00002okVXb004o`000?naXLOo/J77ok6QaaGo0000
00?o/J77o`000?nWV/P00_nWV/P00ol0003oYi[8ojNJb007ojNJb0Go00001onXX]400ol0003oZ:;A
o`000002oinNd`;o000000CoWikCo`000?l0003o00004?ooool00ol0003oWikCoinNd`02oinNd`03
o`000?nEVmOoUI_G00?oUI_G00?o0000ooooooooool04?ooool2o`0000WoUI_G00CoVJGNo`000?nI
YMko00000onAYN85o`0002;ooooo0_l00008oi6UhP;o00000on9YNL00ol0003oRJGWohVUi`03ohVU
i`03o`000?oooooooooo04?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02oooo
o`00F?ooool2o`0001kooooo00?o0000ol;Ci_l000001Ol00003ol;?i003o`000?oooooooooo00go
oooo0_l000000oo2cnCo0000o`000002ol;<hP03o`000?oooooooooo00Oooooo0_l000002Oo2c>;o
0000o`000?oooooo0000ol;:hOl0003o`L[Qooooo`02o`0000?o`LSP0oooool00ol0003o`LSPol78
h002ol78h004o`000?o1b>3o`<KNo`0000?o`<KN0_l00007olK5f005o`000?oooooo0000olK5f?l0
00000oo4`=H00ol0003oooooooooo`0<ooooo`04o`000?o4`=Koa<3Fo`0000?o`K[C0_l0000?oooo
o`05o`000?o1^]?o`K[Col6jdol000000onl]=400ol0003oooooooooo`04o`0000go_;CA1_l0000A
okVXb004o`000?niZ<So^JS8o`0000;o/J7700?o0000ok6QaonaXLL04onaXLL01Ol0003o/J77o`00
0?nWV/So000000GoYi[81Ol0000;ojRRd@04o`000?nXX]7oZ:;Ao`0000CoWikC00?o0000oooooooo
ool04_ooool00ol0003oWikCoinNd`02oinNd`03o`000?nEVmOoUI_G00;oUI_G00?o0000oooooooo
ool03_ooool2o`0000SoUI_G0_l00002oiVUgP03o`000?nIYMkoVJGN00;o00001_nAYN800ol0003o
ooooooooo`0Qooooo`;o00002?nAYN82o`0000;oRJGW00?o0000ohVUion9YNL00_n9YNL00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool005[ooooo
00?o0000ooooooooool07?ooool2o`0000Wo`/oT00?o0000ooooooooool02_ooool2o`000003ol;?
i?l0003o000000;o`/cR00?o0000ooooooooool02?ooool01Ol0003o`/cRo`000?l0003ooooo00Co
00000_ooool01Ol0003o`L[Qol78h?o1b>3o000000Gooooo00?o0000ol78h?l000000_l000000oo0
a]ko0000ol36gP05ol36gP;o00001_o6aMP00ol0003oa/GHo`000003olC0eP03o`000?oooooooooo
00cooooo00Go0000olC0e_o4`=Koa<3Fo`000002ol6jd`03o`000?oooooo000000oooooo00Co0000
ol6jdoo1^]?o00001?nl]=47ooooo`Co00001onl]=42o`000003okbddOl0003o]jk@00?o]jk@2Ol0
0009okVXb005o`000?niZ<So0000ok6Qaol000005onaXLL3o`000003ojNJb?l0003o000000?o0000
4?nXX]401Ol0003oZ:;AojRRdOnXX]7o000000?oWikC00?o0000ooooooooool04oooool00ol0003o
WikCoinNd`02oinNd`03o`000?nEVmOoUI_G00;oUI_G00?o0000ooooooooool03?ooool00ol0003o
UI_GoiFKe`06oiFKe`;o00001OnIYMh01Ol0003oVJGNoiVUg_nIYMko000000KoTJGR0_l0000Soooo
o`03o`000?nAYN;oTJGR00OoTJGR1?l00002ohVUi`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`02ooooo`00Foooool00ol0003oooooooooo`0Looooo`03
o`000?o2cnCo`/oT00So`/oT00?o0000ooooooooool02?ooool01?l0003o`/oTol;?i?l00002ol;<
hP03o`000?oooooooooo00Sooooo1?l000000oo2b^7oooooo`000003o`000003ooooool0003o0000
00?o`LSP1oooool2o`000005ol78h?o0a]ko`<KNol36g_l000002?o0a]h00ol0003oa/GHolK5f003
olK5f0;o00000oo4`=H00ol0003oooooooooo`0<ooooo`05o`000?o4`=Koa<3FolC0e_l000000oo1
^]<00ol0003oooooo`00000>ooooo`05o`000?o1^]?o`K[Col6jdol000000onl]=400ol0003ooooo
ooooo`09ooooo`?o00000onl]=401_l0003o_;CAokbddOnl]=7o]jk@o`0000co]jk@2?l00002okVX
b0?o00003?naXLL:o`0000?o/J770ol0000DojRRd@03o`000?nXX]7oZ:;A00;oZ:;A00?o0000oinN
donOW]<00_nOW]<00ol0003oooooooooo`0Cooooo`03o`000?nOW]?oWikC00;oWikC00?o0000oiFK
eonEVmL00_nEVmL00ol0003oooooooooo`09ooooo`;o00002?nEVmL00ol0003oVJGNoiVUgP05oiVU
gP03o`000?nIYMkoVJGN00;oVJGN0_l00006oi6UhP03o`000?oooooooooo02?ooooo2_nAYN82o`00
0003ohVUiol0003ooooo04Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02oooo
o`00G?ooool2o`0001gooooo00?o0000ol;?i?o2cn@02?o2cn@00ol0003oooooooooo`05ooooo`;o
000000Go`/oTo`000?l0003o`/cRo`00000:ooooo`Go000000Goooooo`000?l0003o0000ol7:h@02
ooooo`04o`000?o1b^7o`LSPol78h0Sooooo00?o0000ol78h?l000000oo0a]h00ol0003o`<KNol36
gP08ol36gP;o00000_o6aMP2o`0000;oa<3F0ol0000>ooooo`04o`000?o4`=Koa<3Fo`0000?o`K[C
00Co0000oooooooooooo00003_ooool01?l0003o`K[Col6jdol00003okbdd@03o`000?oooooooooo
00kooooo0_l00003okbdd@04o`000?ng[]3o]jk@o`0001?o]jk@4Ol0000<ok2Wd0;o000000?oZ:;A
o`000?l000002_nXX]46o`0000?ooooo00?o0000ojRRdOnXX]400onXX]401Ol0003oWikCoinNdonO
W]?o000001Kooooo00?o0000oinNdonOW]<00_nOW]<00ol0003oUI_GoiFKe`02oiFKe`03o`000?oo
oooooooo00Oooooo00?o0000oiFKeonEVmL01_nEVmL2o`0000SoVJGN00?o0000oiVUg_nIYMh01?nI
YMh00ol0003oTJGRoi6UhP04oi6UhP;o00009?ooool<o`0004[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`00G_ooool00ol0003oooooooooo`0Kooooo`03o`000?o2cnCo
`/oT00So`/oT00?o0000ooooooooool00_ooool2o`000003ol;?i?l0003o000000;o`/cR2oooool0
1?l0003o`/cRo`000?l00002ooooo`Co000000?oooooo`000?l000000_o1b>000ol0003ooooooooo
o`05ooooo`;o000000?o`LSPol36g_o0a]h00_o0a]h2o`0000co`<KN00?o0000olK5f?l000000ol0
0003olC0eP;o00002oooool01?l0003oa<3FolC0e_l00003ol6jd`05o`000?ooooooooooooooool0
00003Oooool01?l0003o`K[Col6jdol00003okbdd@03o`000?oooooooooo013ooooo00Go0000okbd
dOnl]=7o_;CAo`000003okN^d0Go00003_ng[]02o`000003okN^d?l0003o000001Oo/:O@00?o0000
ok2Wd?l000000onXX]401?l0003oZ:;AojRRdOnXX]46o`0000[ooooo00?o0000ojRRdOnXX]400onX
X]401Ol0003oWikCoinNdonOW]?o000001Gooooo00?o0000oinNdonOW]<00onOW]<00ol0003oUI_G
oiFKe`02oiFKe`03o`000?oooooooooo00Cooooo0_l00008oiFKe`03o`000?nIYMkoVJGN00WoVJGN
00?o0000oiVUg_nIYMh01?nIYMh2o`0000KoTJGR00?o0000ooooooooool08?ooool00ol0003oTJGR
oi6UhP08oi6UhTgooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`00Gooo
ool00ol0003oooooooooo`0Kooooo`03o`000?o2cnCo`/oT00So`/oT00Go0000ooooool0003o0000
ol;?i002o`0000;o`/cR00?o0000ooooooooool02?ooool4o`000003ol;:hOoooooo000000?o0000
0_ooool01?l0003o`L[Qol78h?o1b>08ooooo`03o`000?o1b>3o`LSP00Co`<KN0oooool00ol0003o
`<KNol36gP09ol36gP?o00002?o4`=H3o`0000Oooooo00Co0000olC0e_o4`=Ko00000oo1^]<00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ol6jdoo1^]?o`K[Co`000003
okbdd@03o`000?oooooooooo00oooooo00Go0000okbddOnl]=7o_;CAo`000004okN^d003o`000?oo
oooooooo00;ooooo2?l00005okN^d007o`000?ng[]3o]jk@okN^d?l0003o/:O@o`00000Eok2Wd005
o`000?n`Ym3o/:O@ok2Wd?l000000onXX]43o`00013ooooo00?o0000ojRRdOnXX]400onXX]400ol0
003oWikCoinNd`02oinNd`03o`000?oooooooooo01?ooooo00?o0000oinNdonOW]<00onOW]<00ol0
003oUI_GoiFKe`02oiFKe`04o`000?ooooooooooooooo`;o00002?nEVmL2o`0000coVJGN0_l00007
oiVUgP03o`000?nAYN;oTJGR00CoTJGR0_l0000Oooooo`03o`000?nAYN;oTJGR00OoTJGR00?o0000
ooooooooool0COooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo001Poooo
o`;o00007?ooool00ol0003o`/oTol;?i008ol;?i004o`000?o2cnCo0000o`0000;o`/cR00?o0000
ooooooooool02Oooool4o`000007ooooool0003o0000o`000?o1b^7o0000ooooo`02o`0000;o`LSP
00?o0000ooooooooool01_ooool00ol0003o`LSPo`000004ol36gPGooooo0_l00007ol36gP;o0000
00?o_/;Lokk2gOnn`]d00_l00009olC0eP;o00001?ooool01?l0003oa<3FolC0e_l00003ol6jd`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool01?l0003o`K[Col6jdol00003okbd
d@03o`000?oooooooooo013ooooo00Go0000okbddOnl]=7o_;CAo`000004okN^d0kooooo0_l00000
0ong[]3o0000okN^d003okN^d004o`000?n`Ym3o/:O@o`0000[o/:O@1_l00003ok2Wd003o`000?n`
Ym3o/:O@00;o/:O@00Go0000ojRRdOnXX]7oZ:;Ao`00000Cooooo`03o`000?nXX]7oZ:;A00?oZ:;A
00Go0000oinNdonOW]?oWikCo`00000Fooooo`03o`000?nOW]?oWikC00;oWikC00?o0000oiFKeonE
VmL00onEVmL00ol0003oooooo`000008oiFKe`;o00003?nIYMh01Ol0003ooooooooooooooooo0000
00OoVJGN0_l00006oi6UhP03o`000?oooooooooo01_ooooo00?o0000oi6Uh_nAYN801onAYN800ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool006;o
oooo00?o0000ooooooooool06_ooool00ol0003o`/oTol;?i005ol;?i004o`000?o2cnCo0000o`00
00?o`/cR2oooool4o`0000;ooooo1?l000001_oooooo0000o`000?l0003o`LSPo`0000Sooooo0_l0
00000oo1b>3o`<KNol36gP02ol36gPWooooo0_l00004ol36gP04o`000?o0a]ko_/;Lo`0000Co_/;M
0_l00009olC0eP;o000000Goooooo`000?o4`=Koa<3Fo`000004ol6jd`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02Oooool01Ol0003o`K[Col6jdoo1^]?o000000?o_;CA00?o0000oooo
ooooool04?ooool01Ol0003o_;CAokbddOnl]=7o000000?o]jk@00?o0000ooooooooool03oooool0
0ol0003o]jk@okN^d002okN^d004o`000?n`Ym3o/:O@ok2Wd0[o00002Oooool00ol0003o/:O@ok2W
d002ok2Wd005o`000?nXX]7oZ:;AojRRdOl000005?ooool00ol0003oZ:;AojRRd@02ojRRd@03o`00
0?nOW]?oWikC00;oWikC00?o0000ooooooooool05?ooool00ol0003oWikCoinNd`02oinNd`03o`00
0?nEVmOoUI_G00?oUI_G00?o0000oiFKeonEVmL01_nEVmL00ol0003oVJGNoiVUgP0:oiVUgP03o`00
0?oooooooooo00Cooooo0_l00007oiVUgP03o`000?nAYN;oTJGR00CoTJGR0_l0000Jooooo`03o`00
0?nAYN;oTJGR00OoTJGR00?o0000ooooooooool0D?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo007ooooo001Sooooo`03o`000?oooooooooo01[ooooo00?o0000ol;?i?o2cn@00oo2
cn@01?l0003o`/oTo`000?o2c>82o`0000_ooooo1Ol000000ooooooo0000o`000002o`0000;ooooo
00Go0000ol7:hOo1b>3o`LSPo`000008ooooo`03o`000?o1b>3o000000Co`<KN3?ooool2ol36gP;o
000000Co`<KNokk2g?nn`]co00001_nn`]d2o`0000Woa<3F00Go0000olC0e_o4`=Koa<3Fo`000003
ol6jd`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool01Ol0003o`K[Col6jdoo1
^]?o000000?o_;CA00?o0000ooooooooool04?ooool01Ol0003o_;CAokbddOnl]=7o000000Co]jk@
00?o0000ooooooooool03oooool00ol0003o]jk@okN^d002okN^d005o`000?n`Ym3o/:O@ok2Wd?l0
00004_ooool00ol0003o/:O@ok2Wd002ok2Wd003o`000?nXX]7oZ:;A00;oZ:;A00?o0000oooooooo
ool04Oooool00ol0003oZ:;AojRRd@03ojRRd@05o`000?nOW]?oWikCoinNdol000005oooool00ol0
003oWikCoinNd`02oinNd`03o`000?nEVmOoUI_G00;oUI_G00?o0000oiFKeonEVmL01?nEVmL2o`00
00_oVJGN0_l00009ooooo`03o`000?nIYMkoVJGN00GoVJGN0_l00006oi6UhP;o00005oooool00ol0
003oTJGRoi6UhP07oi6UhP03o`000?oooooooooo05;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`01ooooo`00I?ooool2o`0001_ooooo00Co0000ol;?i?o2cnCo`/oT1Ol00002ol;<
hP03o`000?oooooooooo00Oooooo1?l00002ooooo`;o000000?o`L[Qo`000?ooool00_l00002ol78
h003o`000?oooooooooo00Kooooo0_l000000oo1b>3o0000ol36gP02ol36gP03o`000?oooooooooo
00_ooooo0_l000001Oo0a]ko0000okk2g?nn`]co000000Wo_/;M0_l00007olC0eP04o`000?o4`=Ko
a<3Fo`0000?o`K[C00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`04o`000?o1
^]?o`K[Co`0000?o_;CA00?o0000ooooooooool04Oooool01Ol0003o_;CAokbddOnl]=7o000000?o
]jk@00?o0000ooooooooool04?ooool00ol0003o]jk@okN^d002okN^d005o`000?n`Ym3o/:O@ok2W
d?l000004oooool01Ol0003o/:O@ok2Wd?n`Ym3o000000CoZ:;A00?o0000ooooooooool04_ooool0
0ol0003oZ:;AojRRd@02ojRRd@03o`000?nOW]?oWikC00;oWikC00?o0000ooooooooool05Oooool5
oinNd`05o`000?nEVmOoUI_GoiFKeol000001OnEVmL00ol0003oVJGNoiVUgP09oiVUgP;o00003?oo
ool2o`0000OoVJGN00?o0000oi6Uh_nAYN801OnAYN800ol0003oooooooooo`0Cooooo`03o`000?nA
YN;oTJGR00OoTJGR00?o0000ooooooooool0E?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo007ooooo001Vooooo`03o`000?oooooooooo01Wooooo00?o0000ol;?i?l000000_l00006
ol;<hP03o`000?oooooooooo00Cooooo1?l00002ooooo`Co00000_ooool01?l0003o`L[Qol78h?l0
0009ooooo`03o`000?o1b>3o000000?o`<KN00?o0000ooooooooool03?ooool01?l0003o`<KNol36
g_l00003okk2g003o`000?nn`]go_/;M00Wo_/;M0_l00005olC0eP03o`000?o4`=Ko000000;o`K[C
0ol00007ooooo`03o`000?oooooooooo00Oooooo00Go0000ol6jdoo1^]?o`K[Co`000003okbdd@03
o`000?oooooooooo017ooooo00Co0000okbddOnl]=7o00001?ng[]000ol0003oooooooooo`0@oooo
o`03o`000?ng[]3o]jk@00;o]jk@00Go0000ok2Wd?n`Ym3o/:O@o`00000Cooooo`03o`000?n`Ym3o
/:O@00;o/:O@00Go0000ojRRdOnXX]7oZ:;Ao`00000Dooooo`03o`000?nXX]7oZ:;A00?oZ:;A00Go
0000oinNdonOW]?oWikCo`00000Hooooo`GoWikC00Co0000oiFKeonEVmOo00000onEVmL2o`0000_o
VJGN00?o0000ooooooooool03_ooool2o`0000KoVJGN0_l00006oi6UhP;o00004_ooool00ol0003o
TJGRoi6UhP07oi6UhP03o`000?oooooooooo05Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`01ooooo`00Ioooool00ol0003oooooooooo`0Iooooo`03o`000?o2c>;o`/cR00So`/cR
00Co0000oooooooooooooooo1Ol00002ooooo`Co000000?oooooo`000?l000000_o1b>000ol0003o
ooooooooo`07ooooo`03o`000?o1b>3o000000?o`<KN00?o0000ooooooooool03?ooool00ol0003o
`<KNol36gP04okk2g0;o00003Onn`]d2o`0000;oa<3F00?o0000olC0e_l000000ol00003ol6jd`?o
00000oooool00ol0003oooooooooo`07ooooo`05o`000?o1^]?o`K[Col6jdol000000onl]=400ol0
003oooooooooo`0Aooooo`05o`000?nl]=7o_;CAokbddOl000001?ng[]000ol0003oooooooooo`0@
ooooo`05o`000?ng[]3o]jk@okN^d?l000001?n`Ym000ol0003oooooooooo`0Aooooo`03o`000?n`
Ym3o/:O@00;o/:O@00Go0000ojRRdOnXX]7oZ:;Ao`00000Eooooo`03o`000?nXX]7oZ:;A00;oZ:;A
00?o0000oinNdonOW]<00_nOW]<00ol0003oooooooooo`0Eooooo`Co00000_nOW]<01?l0003oUI_G
o`000?nEVmL2o`0000_oVJGN0_l0000Cooooo`03o`000?nIYMkoVJGN00GoVJGN0_l00006oi6UhP03
o`000?oooooooooo00kooooo00?o0000oi6Uh_nAYN801onAYN800ol0003oooooooooo`1Gooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool006Sooooo0_l0000Kooooo`03o`00
0?o2c>;o`/cR00Oo`/cR00?o0000ooooool000000ol00002ooooo`;o000000So`L[Qo`000?oooooo
ooooo`000?o1b^7o`LSPo`0000Wooooo0ol00003ol36gP03o`000?oooooooooo00gooooo00?o0000
ol36g_l000001?nn`]`3ooooo`;o00003Onn`]d5o`0000Wo`K[C0_l000000ooooooo0000ooooo`08
ooooo`05o`000?o1^]?o`K[Col6jdol000000onl]=400ol0003oooooooooo`0Aooooo`05o`000?nl
]=7o_;CAokbddOl000000ong[]000ol0003oooooooooo`0Aooooo`05o`000?ng[]3o]jk@okN^d?l0
00001?n`Ym000ol0003oooooooooo`0Aooooo`03o`000?n`Ym3o/:O@00;o/:O@00Go0000ojRRdOnX
X]7oZ:;Ao`00000Eooooo`03o`000?nXX]7oZ:;A00?oZ:;A00Go0000oinNdonOW]?oWikCo`00000D
ooooo`?o00001?nOW]<6o`0000_oVJGN0_l0000Fooooo`;o00001onIYMh00ol0003oTJGRoi6UhP04
oi6UhP;o00003Oooool00ol0003oTJGRoi6UhP07oi6UhP03o`000?oooooooooo05Wooooo00?o0000
ooooooooool01?ooool1o`00007ooooo0Oooool006[ooooo00?o0000ooooooooool06Oooool00ol0
003o`/cRol;<hP07ol;<hP?o00000_ooool5o`000004ooooool0003o0000ol78h0;o00002Oooool0
0ol0003o`LSPo`000003ol36gP03o`000?oooooooooo00cooooo0_l000000oo0a]ko0000okk2g003
okk2g0Kooooo0_l0000<okk2g@?o00003?o1^]<3o`0000Oooooo00Go0000ol6jdoo1^]?o`K[Co`00
0003okbdd@03o`000?oooooooooo017ooooo00Go0000okbddOnl]=7o_;CAo`000004okN^d003o`00
0?oooooooooo017ooooo00Go0000okN^d?ng[]3o]jk@o`000004ok2Wd003o`000?oooooooooo017o
oooo00?o0000ok2Wd?n`Ym000_n`Ym000ol0003oZ:;AojRRd@02ojRRd@03o`000?oooooooooo01?o
oooo00?o0000ojRRdOnXX]400_nXX]400ol0003oWikCoinNd`02oinNd`03o`000?oooooooooo00ko
oooo0ol0000:oinNd`;o000000?oVJGNo`000?nIYMh02?nIYMh00ol0003oooooooooo`0Hooooo`03
o`000?nIYMkoVJGN00GoVJGN0_l00006oi6UhP03o`000?oooooooooo00Wooooo00?o0000oi6Uh_nA
YN801onAYN800ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7o
oooo001[ooooo`03o`000?oooooooooo01Wooooo00?o0000ol;<h_o2c>801?o2c>85o`000003oooo
ool0003o000000;o00000_ooool2o`000003ol78h?l0003ooooo00Sooooo1?l00002ol36gP;o0000
3_ooool01?l0003o`<KNol36g_l00004okk2g0Wooooo0_l00008okk2g@;o000000?o_/;Lo`000?nl
_MX00ol0000<ol6jd`;o00001Oooool01?l0003o`K[Col6jdol00004okbdd@03o`000?oooooooooo
017ooooo00Go0000okbddOnl]=7o_;CAo`000004okN^d003o`000?oooooooooo017ooooo00Go0000
okN^d?ng[]3o]jk@o`000004ok2Wd003o`000?oooooooooo01;ooooo00?o0000ok2Wd?n`Ym000_n`
Ym001Ol0003oZ:;AojRRdOnXX]7o000001Gooooo00?o0000ojRRdOnXX]400onXX]400ol0003oWikC
oinNd`02oinNd`03o`000?oooooooooo00[ooooo0ol0000;oinNd`;o000000?oXJOJo`000?nQYmX0
1_l00002oiVUgP;o00007?ooool2o`0000OoVJGN00?o0000oi6Uh_nAYN801?nAYN82o`0000Sooooo
00?o0000oi6Uh_nAYN801onAYN800ol0003oooooooooo`1Looooo`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`7ooooo001/ooooo`;o00006_ooool01?l0003o`/cRol;<h_o2c>84o`0000?o`/_Q
00?o0000ol7:hOl000000_ooool2o`000003ol78h?l0003o000000Wooooo00?o0000ol78h?l00000
0oo0a]h00ol0003oooooooooo`0=ooooo`04o`000?o0a]ko0000o`0000?o_/;L00?o0000oooooooo
ool02_ooool2o`0000Go_/;M00?o0000okk2g?nn`]`00_l00004okbmfP?o00002oo1^]<3o`000003
ooooool0003o`K[C00;o`K[C00Go0000okbddOnl]=7o_;CAo`00000Dooooo`05o`000?nl]=7o_;CA
okbddOl000000ong[]000ol0003oooooooooo`0Booooo`05o`000?ng[]3o]jk@okN^d?l000001?n`
Ym000ol0003oooooooooo`0Booooo`03o`000?n`Ym3o/:O@00;o/:O@00Go0000ojRRdOnXX]7oZ:;A
o`00000Fooooo`03o`000?nXX]7oZ:;A00;oZ:;A00?o0000oinNdonOW]<00_nOW]<00ol0003ooooo
ooooo`07ooooo`?o00002_nOW]<3o`0000CoXJOJ00Co0000oj6Wf_nQYm[o00001?nIYMh2o`00023o
oooo00?o0000oiVUg_nIYMh01OnIYMh2o`0000KoTJGR00?o0000ooooooooool01?ooool00ol0003o
TJGRoi6UhP07oi6UhP03o`000?oooooooooo05kooooo00?o0000ooooooooool00_ooool1o`00007o
oooo0Oooool006kooooo00?o0000ooooooooool06?ooool01?l0003o`/cRo`000?l00004ol;;h@Go
000000?oooooo`000?l000000_l0000:ooooo`?o00000_o0a]h2o`0000oooooo00?o0000ol36g_l0
00001?nn`]`00ol0003oooooooooo`0=ooooo`03o`000?nn`]go_/;M00;o00000_nn`]`00ol0003o
_;gJo`000007okbmfP?o00002oo1^]<01Ol0003o`K[Col6jdoo1^]?o000000?o_;CA00?o0000oooo
ooooool04_ooool01Ol0003o_;CAokbddOnl]=7o000000Co]jk@00?o0000ooooooooool04_ooool0
1Ol0003o]jk@okN^d?ng[]3o000000Co/:O@00?o0000ooooooooool04_ooool00ol0003o/:O@ok2W
d002ok2Wd005o`000?nXX]7oZ:;AojRRdOl000005oooool00ol0003oZ:;AojRRd@02ojRRd@03o`00
0?nOW]?oWikC00;oWikC00?o0000ooooooooool00oooool3o`0000[oWikC0ol00007oj6WfP05o`00
0?nQYm[oXJOJoj6Wf_l000001OnIYMh00ol0003oooooooooo`0Nooooo`;o00001onIYMh00ol0003o
TJGRoi6UhP04oi6UhP;o00000oooool00ol0003oTJGRoi6UhP07oi6UhP03o`000?oooooooooo063o
oooo00Go0000ooooooooooooooooo`000002ooooo`00Koooool00ol0003oooooooooo`0Hooooo`03
o`000?o2bn7o`/_Q00;o`/_Q1?l00002ol7:h@;o000000?o`LSPo`000?ooool02Oooool3o`0000?o
`<KN00?o0000ooooooooool03Oooool2o`000003ol36g_l0003o_/;L00?o_/;L4oooool01Ol0003o
_/;Lokk2g?nn`]co000000;o_;gJ00?o0000okbmf_nl_MX02?nl_MX3o`0000So`K[C00Go0000ol6j
doo1^]?o`K[Co`000003okbdd@03o`000?oooooooooo01;ooooo00Go0000okbddOnl]=7o_;CAo`00
0004okN^d003o`000?oooooooooo017ooooo00?o0000okN^d?ng[]000_ng[]001Ol0003o/:O@ok2W
d?n`Ym3o000001Gooooo00?o0000ok2Wd?n`Ym000_n`Ym001Ol0003oZ:;AojRRdOnXX]7o000001Oo
oooo00?o0000ojRRdOnXX]400onXX]401Ol0003oWikCoinNdonOW]?o000000;ooooo0ol0000:oinN
d`?o00002OnQYmX00ol0003oXJOJoj6WfP03oj6WfP03o`000?nIYMkoVJGN00?oVJGN00?o0000oooo
ooooool07oooool00ol0003oVJGNoiVUgP05oiVUgP;o00001_nAYN800ol0003oooooo`000009oi6U
hP03o`000?oooooooooo06;ooooo00Co0000oooooooooooo00000_ooool0073ooooo0_l0000Joooo
o`03o`000?o2bn7o000000Go`L[Q00?o0000ol78h?l000000_l00009ooooo`03o`000?o1b>3o0000
00?o`<KN00?o0000ooooooooool03Oooool01?l0003o`<KNol36g_l00003okk2g003o`000?oooooo
oooo01;ooooo00Co0000okk2g?nn`]co00000onl_MX00ol0003o_;gJokbmfP0;okbmfP?o00001Oo1
^]<01?l0003o`K[Col6jdol00002okbdd@Go00004_ooool01Ol0003o_;CAokbddOnl]=7o000000?o
]jk@00?o0000ooooooooool04_ooool00ol0003o]jk@okN^d002okN^d005o`000?n`Ym3o/:O@ok2W
d?l000005Oooool00ol0003o/:O@ok2Wd002ok2Wd003o`000?nXX]7oZ:;A00;oZ:;A00?o0000oooo
ooooool05Oooool00ol0003oZ:;AojRRd@02ojRRd@03o`000?nOW]?oWikC00;oWikC0_l0000:oinN
d`?o00003?nQYmX00ol0003oXJOJoj6WfP04oj6WfP03o`000?nIYMkoVJGN00?oVJGN00?o0000oooo
ooooool07oooool2o`0000OoVJGN00?o0000oi6Uh_nAYN801?nAYN800ol0003oTJGRoi6UhP07oi6U
hP03o`000?oooooooooo06Cooooo00?o0000ooooool000000_ooool007;ooooo00?o0000oooooooo
ool06?ooool2o`0000?o`L[Q1?l00003ol78h003o`000?oooooooooo00Cooooo1?l00002ol36gP;o
00003oooool01?l0003o`<KNol36g_l00003okk2g003o`000?oooooooooo01;ooooo00Co0000okk2
g?nn`]co00001?nl_MX2o`0000oo_;gJ0ol00003ol6jd`;o000000?o_;CAo`000?l000001Onl]=45
o`0000cooooo00Go0000okbddOnl]=7o_;CAo`000004okN^d003o`000?oooooooooo01;ooooo00?o
0000okN^d?ng[]000_ng[]001Ol0003o/:O@ok2Wd?n`Ym3o000001Kooooo00?o0000ok2Wd?n`Ym00
0_n`Ym001Ol0003oZ:;AojRRdOnXX]7o000001Oooooo00?o0000ojRRdOnXX]400onXX]401Ol0003o
WikCoinNdonOW]?o000000SoWikC0ol0000?oj6WfP;o00001_nQYmX00ol0003oVJGNoiVUgP03oiVU
gP03o`000?oooooooooo023ooooo0_l00006oiVUgP;o00001?nAYN800ol0003oTJGRoi6UhP06oi6U
hP03o`000?oooooooooo06Gooooo00Co0000oooooooooooo00000Oooool007?ooooo0_l0000Joooo
o`03o`000?o1b^7o000000So`LSP0_l00003ooooo`03o`000?o1b>3o000000?o`<KN00?o0000oooo
ooooool03_ooool01?l0003o`<KNo`000?l00003okk2g003o`000?oooooooooo01;ooooo00Co0000
okk2g?nn`]co00001Onl_MX00ol0003oooooo`000002o`0000oo_;gJ1_l0000<okbdd@Go00001ooo
ool01Ol0003o_;CAokbddOnl]=7o000000Co]jk@00?o0000ooooooooool04_ooool00ol0003o]jk@
okN^d002okN^d005o`000?n`Ym3o/:O@ok2Wd?l000005_ooool00ol0003o/:O@ok2Wd002ok2Wd005
o`000?nXX]7oZ:;AojRRdOl000005_ooool4o`0000?oZ:;A00Co0000oinNdonOW]?o00001_nOW]<3
o`0000koXJOJ0ol00003ooooo`03o`000?nQYm[oXJOJ00CoXJOJ00?o0000oiVUg_nIYMh00onIYMh0
0ol0003oooooooooo`0Qooooo`03o`000?nIYMkoVJGN00GoVJGN00?o0000oi6Uh_nAYN800_nAYN80
0ol0003oTJGRoi6UhP04oi6UhP03o`000?oooooooooo06Oooooo00?o0000ooooool000000Oooool0
07Gooooo00?o0000ooooooooool06?ooool2o`0000[o`LSP00Go0000ooooool0003o`LSPo`000002
ol36gP;o00004?ooool00ol0003o`<KNo`000003okk2g0;o00005?ooool01?l0003o_/;Lokk2g?l0
0005okbmfP03o`000?oooooooooo00?ooooo0_l0000?okbmfPCo00004Onl]=45o`0000;ooooo00Co
0000okbddOnl]=7o00001?ng[]000ol0003oooooooooo`0Cooooo`03o`000?ng[]3o]jk@00;o]jk@
00Go0000ok2Wd?n`Ym3o/:O@o`00000Fooooo`03o`000?n`Ym3o/:O@00;o/:O@00Go0000ojRRdOnX
X]7oZ:;Ao`00000Aooooo`Go00001?nXX]43o`000004ojRRdOl0003oWikCo`0000?oWikC0ol0000>
oj6WfP?o00001oooool00ol0003oXJOJoj6WfP04oj6WfP03o`000?nIYMkoVJGN00?oVJGN00?o0000
ooooooooool08Oooool00ol0003oVJGNoiVUgP05oiVUgP;o00000_nAYN800ol0003oTJGRoi6UhP03
oi6UhP03o`000?oooooooooo06Wooooo0_l00001ooooo`00M_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?o1b>3o`LSP00So`LSP0ol00002ol36gP03o`000?oooooooooo00kooooo0_l000000oo0
a]ko0000okk2g002okk2g003o`000?oooooooooo01?ooooo00Co0000okk2g?nn`]co00001Onl_MX0
0ol0003oooooooooo`06ooooo`?o00002_nl_MX2o`000004okbmf_l0003o^KSIokVhf@Go00004Onl
]=42o`0000?o_;CA00?o0000okN^d?ng[]000_ng[]000ol0003oooooooooo`0Cooooo`03o`000?ng
[]3o]jk@00;o]jk@00Go0000ok2Wd?n`Ym3o/:O@o`00000Fooooo`03o`000?n`Ym3o/:O@00;o/:O@
00Go0000ojRRdOnXX]7oZ:;Ao`00000<ooooo`Go00003?nXX]42o`000003oinNdol0003o000000;o
00003onQYmX2o`0000_ooooo00?o0000oj6Wf_nQYmX01?nQYmX00ol0003oVJGNoiVUgP03oiVUgP03
o`000?oooooooooo02;ooooo2?nIYMh01?l0003oTJGRoi6Uh_l00003oi6UhP03o`000?oooooooooo
06Wooooo0ol00001ooooo`00Moooool2o`0001[ooooo00?o0000ol78h?o1b>001_o1b>02o`0000?o
`<KN00?o0000ooooooooool03_ooool01?l0003o`<KNol36g_l00003okk2g003o`000?oooooooooo
01?ooooo00Co0000okk2g?nn`]co00001Onl_MX00ol0003oooooooooo`0:ooooo`;o00001_nl_MX2
o`0000?o_;gJ00?o0000okVhfOni^=T01Oni^=T5o`0000go_;CA00Go0000okbddOnl]=7o_;CAo`00
0004okN^d003o`000?oooooooooo01?ooooo00?o0000okN^d?ng[]000_ng[]001Ol0003o/:O@ok2W
d?n`Ym3o000001Kooooo00?o0000ok2Wd?n`Ym000on`Ym001Ol0003oZ:;AojRRdOnXX]7o000000Ko
oooo1Ol0000CojRRd@;o00003onQYmX3o`0000kooooo00?o0000oj6Wf_nQYmX01?nQYmX00ol0003o
VJGNoiVUgP03oiVUgP03o`000?oooooooooo027ooooo1Ol00004oiVUgP?o00000_nAYN800ol0003o
ooooooooo`1Vooooo`Co00001?ooool007Wooooo00?o0000ooooooooool06?ooool2o`0000Go`LSP
0_l00002ol36gP?o00003oooool01?l0003o`<KNol36g_l00003okk2g003o`000?oooooooooo01?o
oooo00Co0000okk2g?nn`]co00001Onl_MX00ol0003oooooooooo`0=ooooo`;o00000_nl_MX2o`00
00Co_;gJ00?o^KSIo`000?ni^=T02oni^=T4o`0000[o_;CA00?o0000okbddOl000000ong[]08o`00
013ooooo00?o0000okN^d?ng[]000_ng[]001Ol0003o/:O@ok2Wd?n`Ym3o000001Oooooo00?o0000
ok2Wd?n`Ym000_n`Ym001_l0003oZ:;AojRRdOnXX]7o0000ooooo`Go00004?nXX]45o`0000?oZ:[H
00Co0000oj6Wf_l0003o00002onQYmX2o`0001;ooooo00?o0000oj6Wf_nQYmX01?nQYmX00ol0003o
VJGNoiVUgP03oiVUgP03o`000?oooooooooo01oooooo00?o0000oiVUg_nIYMh00onIYMh5o`000004
oiVUg_l0003oTJGRo`0006Gooooo1?l00008ooooo`00N_ooool00ol0003oooooooooo`0Iooooo`06
o`000?o1b>3o`LSPol78h?l0003o`<KN0ol00003ol36gP;o00003?ooool01?l0003o`<KNol36g_l0
0003okk2g003o`000?oooooooooo01?ooooo00Go0000okk2g?nn`]co_/;Lo`000004okbmfP03o`00
0?oooooooooo017ooooo00?o0000okbmf_nl_MX00onl_MX01?l0003o^KSIokVhfOl0000?okVhf@Go
00001Onl]=401?l0003o_;CAo`000?ng[]02o`0000So]jk@2ol00005ooooo`05o`000?ng[]3o]jk@
okN^d?l000001?n`Ym000ol0003oooooooooo`0Eooooo`03o`000?n`Ym3o/:O@00;o/:O@00Co0000
ojRRdOnXX]7oZ:;A0_l0000?ojRRd@Go00002?nXZ]P00ol0003oZ:[Ho`000002oj6WfP;o00001_nQ
YmX3o`0001Gooooo00?o0000oj6Wf_nQYmX01?nQYmX00ol0003oVJGNoiVUgP03oiVUgP03o`000?oo
oooooooo01cooooo0_l0000;oiVUgP?o0000H_ooool4o`0000cooooo001kooooo`;o00006_ooool0
0ol0003o`LSPo`000002o`0000So`<KN00?o0000ooooooooool01oooool2o`000003ol36g_l0003o
000000?o_/;L00?o0000ooooooooool04oooool01Ol0003o_/;Lokk2g?nn`]co000000Co_;gJ00?o
0000ooooooooool04_ooool00ol0003o_;gJokbmfP02okbmfP05o`000?ni^=Wo^KSIokVhfOl00000
5?ni^=T6o`000003okbddOl0003o000001Go]jk@1_l00003okN^d003o`000?n`Ym3o/:O@00;o/:O@
6_l00003ok2Wd005o`000?nXX]7oZ:;AojRRdOl000002_nXX]46o`0000goZ:[H00Co0000ojRZf?nX
Z]So00000onQYmX2o`000004oj6Wf_l0003o0000o`0001Wooooo00?o0000oj6Wf_nQYmX01?nQYmX0
0ol0003oVJGNoiVUgP03oiVUgP03o`000?oooooooooo01Wooooo0_l0000>oiVUgV3ooooo1?l0000@
ooooo`00OOooool00ol0003oooooooooo`0Hooooo`;o00002oo0a]h2o`0000Kooooo00Co0000ol36
g_o0a]ko00000onn`]`2o`0001Gooooo00Go0000okk2g?nn`]co_/;Lo`000004okbmfP03o`000?oo
oooooooo01;ooooo00?o0000okbmf_nl_MX00_nl_MX00ol0003o^KSIokVhf@02okVhf@?o00005oni
^=T6o`0001So]jk@00Go0000okN^d?ng[]3o]jk@o`000003ok2Wd003o`000?n`Ym3o/:O@01So/:O@
0_l000001On`Ym3o0000ojRRdOnXX]7o000000GoZ:;A1_l0000BojRZf005o`000?nXZ]SoZ:[HojRZ
f?l000001OnQYmX00ol0003oooooooooo`0Kooooo`03o`000?nQYm[oXJOJ00CoXJOJ00?o0000oiVU
g_nIYMh00onIYMh00ol0003oooooooooo`0Gooooo`03o`000?nIYMkoVJGN00_oVJGN00?o0000oooo
ooooool0Foooool5o`0001Cooooo001nooooo`03o`000?oooooooooo01Wooooo00?o0000ol36g_o0
a]h02_o0a]h2o`0000?ooooo00Co0000ol36g_o0a]ko00000onn`]`00ol0003oooooooooo`0Doooo
o`05o`000?nn`]co_/;Lokk2g?l000001?nl_MX00ol0003oooooooooo`0Booooo`03o`000?nl_M[o
_;gJ00?o_;gJ00?o0000okVhfOni^=T00_ni^=T00ol0003oooooooooo`04o`0001;o^KSI00?o0000
okVhfOl000001?nd/mL8o`00017o]jk@00Co0000okN^d?ng[]3o00000_n`Ym000ol0003o/:O@ok2W
d00Kok2Wd0Co000000?oZ:;Ao`000?l000000ol0000HojRZf003o`000?nXZ]SoZ:[H00;oZ:[H00?o
0000oj6Wf_nQYmX00_nQYmX00ol0003oooooooooo`0Looooo`03o`000?nQYm[oXJOJ00CoXJOJ00?o
0000oiVUg_nIYMh00onIYMh00ol0003oooooooooo`0Dooooo`;o00003?nIYMh2o`0005[ooooo1?l0
000Iooooo`00Ooooool2o`0001[ooooo0_l0000<ol36gP03o`000?oooooo000000;o`<KN00Go0000
okk2g?nn`]co_/;Lo`00000Fooooo`05o`000?nn`]co_/;Lokk2g?l000001?nl_MX00ol0003ooooo
ooooo`0Cooooo`03o`000?nl_M[o_;gJ00;o_;gJ00?o0000okVhfOni^=T00oni^=T7ooooo`Co0000
3?ni^=T2o`0000;o^KSI00?o];?Go`000?nd/mL02_nd/mL9o`0000Wo]jk@00Go0000okN^d?l0003o
/:O@o`00000Gok2Wd0Go00001?n`Ym03o`0001goZ:[H00?o0000ojRZf?nXZ]P00_nXZ]P00ol0003o
XJOJoj6WfP03oj6WfP03o`000?oooooooooo01cooooo00?o0000oj6Wf_nQYmX01?nQYmX00ol0003o
VJGNoiVUgP03oiVUgP03o`000?oooooooooo017ooooo0_l0000<oiVUgP;o0000F?ooool4o`0001go
oooo0021ooooo`03o`000?oooooooooo01Wooooo00?o0000ol36g_o0a]h02_o0a]h01?l0003o`<KN
ol36g_l00003okk2g003o`000?oooooooooo01Cooooo00Go0000okk2g?nn`]co_/;Lo`000004okbm
fP03o`000?oooooooooo01?ooooo00?o0000okbmf_nl_MX00_nl_MX00ol0003o^KSIokVhf@03okVh
f@cooooo1?l00007okVhf@05o`000?ni^=Wo^KSIokVhfOl000000_nd/mL00ol0003o];?GokBce`0A
okBce`So00000_ng[]03o`0000Oo/:O@4Ol00009ojj^e`03o`000?nXZ]So000001coZ:[H00?o0000
ojRZf?nXZ]P01?nXZ]P00ol0003oXJOJoj6WfP03oj6WfP03o`000?oooooooooo01cooooo00?o0000
oj6Wf_nQYmX01?nQYmX00ol0003oVJGNoiVUgP03oiVUgP03o`000?oooooooooo00oooooo00?o0000
oiVUg_nIYMh02_nIYMh2o`0005Kooooo1?l0000Qooooo`00P_ooool00ol0003oooooooooo`0Ioooo
o`;o00002_o0a]h3o`0000?o_/;L00?o0000ooooooooool05?ooool01Ol0003o_/;Lokk2g?nn`]co
000000Co_;gJ00?o0000ooooooooool04oooool00ol0003o_;gJokbmfP03okbmfP03o`000?ni^=Wo
^KSI00;o^KSI00?o0000ooooooooool03_ooool3o`0000?o^KSI00?o0000okVhfOni^=T00_ni^=T0
1?l0003o];?GokBceol0000KokBce`co00006On^[]L2o`0000;oZ:[H0_l0000AojRZf0Ko00000ooo
ool00ol0003oZ:[HojRZf005ojRZf003o`000?nQYm[oXJOJ00;oXJOJ00?o0000ooooooooool07Ooo
ool00ol0003oXJOJoj6WfP04oj6WfP03o`000?nIYMkoVJGN00?oVJGN00?o0000ooooooooool03?oo
ool2o`0000coVJGN00?o0000ooooooooool0D_ooool4o`0002Gooooo0023ooooo`;o00006oooool2
o`0000Oo`<KN0_l00003okk2g0?o00005Oooool01Ol0003o_/;Lokk2g?nn`]co000000Co_;gJ00?o
0000ooooooooool05?ooool00ol0003o_;gJokbmfP02okbmfP03o`000?ni^=Wo^KSI00;o^KSI00?o
0000ooooooooool04oooool2o`0000Co^KSI00?o0000okBceond/mL00_nd/mL00ol0003o];?GokBc
e`0IokBce`04o`000?nd/mOo0000o`0001oo[ZkG00Co0000ojj^eon^[]Oo00000onXZ]P00ol0003o
Z:[HojRZf008ojRZf0Ko00002_ooool00ol0003oZ:[HojRZf004ojRZf003o`000?nQYm[oXJOJ00?o
XJOJ00?o0000ooooooooool07Oooool00ol0003oXJOJoj6WfP04oj6WfP03o`000?nIYMkoVJGN00?o
VJGN00?o0000ooooooooool02Oooool2o`0000coVJGN0_l0001Aooooo`Co0000:Oooool008Gooooo
00?o0000ooooooooool06_ooool00ol0003o`<KNol36gP03ol36gP;o00000_nn`]`2o`0000?o_/;L
0_l0000Booooo`05o`000?nn`]co_/;Lokk2g?l000001?nl_MX00ol0003oooooooooo`0Dooooo`03
o`000?nl_M[o_;gJ00;o_;gJ00?o0000okVhfOni^=T00_ni^=T00ol0003oooooooooo`0Eooooo`03
o`000?ni^=Wo^KSI00;o^KSI00?o0000okBceond/mL00ond/mL5o`0001Go];?G00Ko0000okBceond
/mOo0000ojj^eol0000Mojj^e`05o`000?n^[]Oo[ZkGojj^eol000001?nXZ]P01?l0003oZ:[HojRZ
f?nXZ]P6o`00017ooooo00?o0000ojRZf?nXZ]P01?nXZ]P00ol0003oXJOJoj6WfP02oj6WfP03o`00
0?oooooooooo01kooooo00?o0000oj6Wf_nQYmX01?nQYmX00ol0003oVJGNoiVUgP03oiVUgP03o`00
0?oooooooooo00Oooooo00?o0000oiVUg_nIYMh02_nIYMh2o`0004oooooo1?l0000]ooooo`00Q_oo
ool00ol0003oooooooooo`0Jooooo`;o00000oo0a]h4o`0000Oo_/;L0_l0000?ooooo`05o`000?nn
`]co_/;Lokk2g?l000001?nl_MX00ol0003oooooooooo`0Dooooo`03o`000?nl_M[o_;gJ00?o_;gJ
00?o0000okVhfOni^=T00_ni^=T00ol0003oooooooooo`0Dooooo`03o`000?ni^=Wo^KSI00?o^KSI
00?o0000okBceond/mL00ond/mL00ol0003oooooooooo`02ooooo`So00003?nd/mL01Ol0003o];?G
okBceond/mOo000000;o[ZkG00?o0000ojj^eon^[]L06On^[]L00ol0003o[ZkGojj^e`02ojj^e`03
o`000?nXZ]SoZ:[H00?oZ:[H0ol0000Gooooo`03o`000?nXZ]SoZ:[H00CoZ:[H00?o0000oj6Wf_nQ
YmX00onQYmX00ol0003oooooooooo`0Nooooo`03o`000?nQYm[oXJOJ00CoXJOJ00?o0000oiVUg_nI
YMh00onIYMh00ol0003oooooooooo`04ooooo`;o00002onIYMh2o`0004gooooo1?l0000aooooo`00
Qoooool2o`0001cooooo00Co0000ol36g_l0003o00003?nn`]`2o`0000cooooo00Go0000okk2g?nn
`]co_/;Lo`000004okbmfP03o`000?oooooooooo01Gooooo00?o0000okbmf_nl_MX00_nl_MX00ol0
003o^KSIokVhf@02okVhf@03o`000?oooooooooo01Gooooo00?o0000okVhfOni^=T00_ni^=T00ol0
003o];?GokBce`04okBce`gooooo1ol00004okBce`03o`000?nd/mOo];?G00;o];?G00Go0000ojj^
eon^[]Oo[ZkGo`00000=ojj^e`Wo00000on^[]L00ol0003o[ZkGojj^e`03ojj^e`03o`000?nXZ]So
Z:[H00?oZ:[H00?o0000ooooooooool06?ooool00ol0003oZ:[HojRZf004ojRZf003o`000?nQYm[o
XJOJ00?oXJOJ00?o0000ooooooooool07_ooool00ol0003oXJOJoj6WfP04oj6WfP03o`000?nIYMko
VJGN00?oVJGN00Co0000oooooooooooooooo0_l0000<oiVUgP03o`000?oooooooooo04Wooooo1?l0
000eooooo`00ROooool00ol0003oooooooooo`0Jooooo`;o00003onn`]`00ol0003oooooooooo`08
ooooo`03o`000?nn`]co_/;L00;o_/;L00Go0000okbmf_nl_M[o_;gJo`00000Gooooo`03o`000?nl
_M[o_;gJ00;o_;gJ00?o0000okVhfOni^=T00_ni^=T00ol0003oooooooooo`0Fooooo`03o`000?ni
^=Wo^KSI00;o^KSI00?o0000okBceond/mL00ond/mL00ol0003oooooooooo`0Booooo`Co00001Ond
/mL00ol0003o[ZkGojj^e`02ojj^e`go00003?ooool00ol0003o[ZkGojj^e`04ojj^e`03o`000?nX
Z]SoZ:[H00;oZ:[H00?o0000ooooooooool06Oooool00ol0003oZ:[HojRZf004ojRZf003o`000?nQ
Ym[oXJOJ00;oXJOJ00?o0000ooooooooool07oooool00ol0003oXJOJoj6WfP04oj6WfP03o`000?nI
YMkoVJGN00?oVJGN00?o0000ooooool000003?nIYMh2o`0004Oooooo1Ol0000iooooo`00R_ooool0
0ol0003oooooooooo`0Kooooo`;o00003_nn`]`2o`0000Oooooo00?o0000okk2g?nn`]`00_nn`]`0
1Ol0003o_;gJokbmf_nl_M[o000001Oooooo00?o0000okbmf_nl_MX00onl_MX00ol0003o^KSIokVh
f@02okVhf@03o`000?oooooooooo01Gooooo00?o0000okVhfOni^=T00oni^=T00ol0003o];?GokBc
e`03okBce`03o`000?oooooooooo01Gooooo00?o0000okBceond/mL00ond/mL00ol0003o[ZkGojj^
e`02ojj^e`03o`000?oooooooooo01Kooooo00?o0000ojj^eon^[]L01?n^[]L00ol0003oZ:[HojRZ
f003ojRZf003o`000?oooooooooo01Sooooo00?o0000ojRZf?nXZ]P01?nXZ]P00ol0003oXJOJoj6W
fP03oj6WfP03o`000?oooooooooo01oooooo1onQYmX00ol0003oVJGNoiVUgP03oiVUgP03o`000?nI
YMkoVJGN00WoVJGN0_l00015ooooo`Co0000?_ooool008_ooooo0_l0000Mooooo`?o00003Onn`]`2
o`0000Cooooo00?o0000okk2g?nn`]`00_nn`]`01Ol0003o_;gJokbmf_nl_M[o000001Sooooo00?o
0000okbmf_nl_MX00_nl_MX00ol0003o^KSIokVhf@02okVhf@03o`000?oooooooooo01Kooooo00?o
0000okVhfOni^=T00_ni^=T00ol0003o];?GokBce`03okBce`03o`000?oooooooooo01Kooooo00?o
0000okBceond/mL00_nd/mL00ol0003o[ZkGojj^e`03ojj^e`03o`000?oooooooooo01Oooooo00?o
0000ojj^eon^[]L00on^[]L00ol0003oZ:[HojRZf003ojRZf003o`000?oooooooooo01Wooooo00?o
0000ojRZf?nXZ]P01?nXZ]P00ol0003oXJOJoj6WfP03oj6WfP03o`000?oooooooooo01oooooo1onQ
YmX00ol0003oVJGNoiVUgP02oiVUgP03o`000?nIYMkoVJGN00SoVJGN00?o0000ooooooooool0@Ooo
ool4o`0004;ooooo002=ooooo`03o`000?oooooooooo01gooooo0_l0000=okk2g0;o000000?ooooo
o`000?nn`]`00onn`]`01Ol0003o_;gJokbmf_nl_M[o000001Sooooo00?o0000okbmf_nl_MX00_nl
_MX00ol0003o^KSIokVhf@02okVhf@03o`000?oooooooooo01Oooooo00?o0000okVhfOni^=T00_ni
^=T00ol0003o];?GokBce`03okBce`03o`000?oooooooooo01Kooooo00?o0000okBceond/mL00_nd
/mL00ol0003o[ZkGojj^e`03ojj^e`03o`000?oooooooooo01Oooooo00?o0000ojj^eon^[]L00on^
[]L00ol0003oZ:[HojRZf003ojRZf003o`000?oooooooooo01[ooooo00?o0000ojRZf?nXZ]P01?nX
Z]P00ol0003oXJOJoj6WfP02oj6WfP03o`000?oooooooooo023ooooo1onQYmX01Ol0003oVJGNoiVU
g_nIYMko000000SoVJGN0_l00010ooooo`Co0000A_ooool008kooooo00?o0000ooooooooool07_oo
ool2o`0000go_/;L00?o0000okk2g?nn`]`00_nn`]`01Ol0003o_;gJokbmf_nl_M[o000001Sooooo
00?o0000okbmf_nl_MX00_nl_MX00ol0003o^KSIokVhf@03okVhf@03o`000?oooooooooo01Kooooo
00?o0000okVhfOni^=T00_ni^=T00ol0003o];?GokBce`03okBce`03o`000?oooooooooo01Oooooo
00?o0000okBceond/mL00_nd/mL00ol0003o[ZkGojj^e`03ojj^e`03o`000?oooooooooo01Oooooo
00?o0000ojj^eon^[]L01?n^[]L00ol0003oZ:[HojRZf002ojRZf003o`000?oooooooooo01[ooooo
00?o0000ojRZf?nXZ]P01?nXZ]P00ol0003oXJOJoj6WfP03oj6WfP03o`000?oooooooooo023ooooo
1onQYmX01?l0003oVJGNoiVUg_l00006oiVUgP;o0000?_ooool4o`0004[ooooo002?ooooo`;o0000
8?ooool3o`0000[o_/;L00Go0000okk2g?nn`]co_/;Lo`000003okbmfP03o`000?oooooooooo01Oo
oooo00?o0000okbmf_nl_MX00_nl_MX00ol0003o^KSIokVhf@02okVhf@03o`000?oooooooooo01Oo
oooo00?o0000okVhfOni^=T00_ni^=T00ol0003o];?GokBce`03okBce`03o`000?oooooooooo01Oo
oooo00?o0000okBceond/mL00_nd/mL00ol0003o[ZkGojj^e`03ojj^e`03o`000?oooooooooo01Oo
oooo00?o0000ojj^eon^[]L01?n^[]L00ol0003oZ:[HojRZf003ojRZf003o`000?oooooooooo01[o
oooo00?o0000ojRZf?nXZ]P01?nXZ]P00ol0003oXJOJoj6WfP02oj6WfP03o`000?oooooooooo023o
oooo1?l00004oj6WfP04o`000?nIYMkoVJGNo`0000?oVJGN0_l0000looooo`Co0000C_ooool0097o
oooo00?o0000ooooooooool08?ooool2o`0000So_/;L00Co0000okk2g?nn`]co00000_nl_MX4o`00
01Oooooo00?o0000okbmf_nl_MX00_nl_MX00ol0003o^KSIokVhf@02okVhf@03o`000?oooooooooo
01Sooooo00?o0000okVhfOni^=T00_ni^=T00ol0003o];?GokBce`03okBce`03o`000?oooooooooo
01Oooooo00?o0000okBceond/mL00_nd/mL00ol0003o[ZkGojj^e`03ojj^e`03o`000?oooooooooo
01Sooooo00?o0000ojj^eon^[]L00on^[]L00ol0003oZ:[HojRZf003ojRZf003o`000?oooooooooo
01_ooooo00?o0000ojRZf?nXZ]P00onXZ]P00ol0003oXJOJoj6WfP03oj6WfP03o`000?oooooooooo
01cooooo0ol00004oj6WfP?o00000_nQYmX00ol0003oVJGNo`000002oiVUgP03o`000?oooooooooo
03Sooooo1?l0001Booooo`00T_ooool00ol0003oooooooooo`0Qooooo`;o00001_nn`]`01?l0003o
_/;Lo`000?nl_MX2o`0000Co_;gJ0ol0000Cooooo`03o`000?nl_M[o_;gJ00;o_;gJ00?o0000okVh
fOni^=T00oni^=T00ol0003oooooooooo`0Gooooo`03o`000?ni^=Wo^KSI00;o^KSI00?o0000okBc
eond/mL00ond/mL00ol0003oooooooooo`0Gooooo`03o`000?nd/mOo];?G00?o];?G00?o0000ojj^
eon^[]L00on^[]L00ol0003oooooooooo`0Hooooo`03o`000?n^[]Oo[ZkG00?o[ZkG00?o0000ojRZ
f?nXZ]P00onXZ]P00ol0003oooooooooo`0Kooooo`03o`000?nXZ]SoZ:[H00CoZ:[H00?o0000oj6W
f_nQYmX00onQYmX00ol0003oooooooooo`0Hooooo`?o00002_nQYmX7o`0003Oooooo1?l0001Foooo
o`00Toooool2o`0002?ooooo0ol00002okk2g003o`000?nn`]co000000;o00002Onl_MX3o`00013o
oooo00?o0000okbmf_nl_MX00_nl_MX00ol0003o^KSIokVhf@02okVhf@;o00006Oooool00ol0003o
^KSIokVhf@02okVhf@03o`000?nd/mOo];?G00?o];?G00?o0000ooooooooool05oooool00ol0003o
];?GokBce`03okBce`03o`000?n^[]Oo[ZkG00?o[ZkG00?o0000ooooooooool06?ooool00ol0003o
[ZkGojj^e`04ojj^e`03o`000?nXZ]SoZ:[H00;oZ:[H00?o0000ooooooooool07?ooool00ol0003o
Z:[HojRZf004ojRZf003o`000?nQYm[oXJOJ00;oXJOJ00?o0000ooooooooool05Oooool3o`00013o
XJOJ0_l0000eooooo`Co0000F_ooool009Gooooo00?o0000ooooooooool08oooool5o`0000ko_;gJ
0ol0000<ooooo`03o`000?nl_M[o_;gJ00;o_;gJ00?o0000okVhfOni^=T00_ni^=T00ol0003ooooo
o`00000Hooooo`03o`000?ni^=Wo^KSI00?o^KSI00?o0000okBceond/mL00_nd/mL00ol0003ooooo
ooooo`0Hooooo`03o`000?nd/mOo];?G00?o];?G00?o0000ojj^eon^[]L00on^[]L00ol0003ooooo
ooooo`0Hooooo`03o`000?n^[]Oo[ZkG00Co[ZkG00?o0000ojRZf?nXZ]P00onXZ]P00ol0003ooooo
ooooo`0Kooooo`03o`000?nXZ]SoZ:[H00CoZ:[H00?o0000oj6Wf_nQYmX00onQYmX00ol0003ooooo
ooooo`0Aooooo`?o00004OnQYmX00ol0003oooooooooo`0booooo`Co0000G_ooool009Kooooo00?o
0000ooooooooool09?ooool3o`00017o_;gJ0ol00008ooooo`03o`000?nl_M[o_;gJ00;o_;gJ00?o
0000okVhfOni^=T00oni^=T00ol0003oooooo`00000Hooooo`03o`000?ni^=Wo^KSI00;o^KSI00?o
0000okBceond/mL00ond/mL00ol0003oooooooooo`0Hooooo`03o`000?nd/mOo];?G00?o];?G00?o
0000ojj^eon^[]L00on^[]L00ol0003oooooooooo`0Iooooo`03o`000?n^[]Oo[ZkG00?o[ZkG00?o
0000ojRZf?nXZ]P00onXZ]P00ol0003oooooooooo`0Looooo`03o`000?nXZ]SoZ:[H00CoZ:[H00?o
0000oj6Wf_nQYmX00onQYmX00ol0003oooooooooo`0=ooooo`?o00003onQYmX3o`0003;ooooo1Ol0
001Rooooo`00Uoooool2o`0002Oooooo0ol0000AokbmfP?o00001Oooool00ol0003o_;gJokbmfP02
okbmfP03o`000?ni^=Wo^KSI00;o^KSI00Co0000oooooooooooo00006?ooool00ol0003o^KSIokVh
f@02okVhf@03o`000?nd/mOo];?G00?o];?G00?o0000ooooooooool06?ooool00ol0003o];?GokBc
e`03okBce`03o`000?n^[]Oo[ZkG00?o[ZkG00?o0000ooooooooool06Oooool00ol0003o[ZkGojj^
e`03ojj^e`03o`000?nXZ]SoZ:[H00?oZ:[H00?o0000ooooooooool07Oooool00ol0003oZ:[HojRZ
f004ojRZf003o`000?nQYm[oXJOJ00;oXJOJ00?o0000ooooooooool02_ooool3o`0000ooXJOJ0ol0
000aooooo`Co0000Ioooool009Wooooo00?o0000ooooooooool09oooool3o`00017o_;gJ0ol00000
0ooooooo0000okbmfP03okbmfP03o`000?ni^=Wo^KSI00;o^KSI00Go0000ooooooooooooooooo`00
000Gooooo`03o`000?ni^=Wo^KSI00?o^KSI00?o0000okBceond/mL00_nd/mL00ol0003ooooooooo
o`0Iooooo`03o`000?nd/mOo];?G00?o];?G00?o0000ojj^eon^[]L00on^[]L00ol0003ooooooooo
o`0Iooooo`03o`000?n^[]Oo[ZkG00Co[ZkG00?o0000ojRZf?nXZ]P00_nXZ]P00ol0003ooooooooo
o`0Mooooo`03o`000?nXZ]SoZ:[H00CoZ:[H00?o0000oj6Wf_nQYmX00onQYmX00ol0003ooooooooo
o`06ooooo`?o00003onQYmX3o`00033ooooo1?l0001[ooooo`00V_ooool00ol0003oooooooooo`0Y
ooooo`Co00004?nl_MX00ol0003o_;gJokbmfP02okbmfP03o`000?ni^=Wo^KSI00?o^KSI00Go0000
ooooooooooooooooo`00000Gooooo`03o`000?ni^=Wo^KSI00;o^KSI00?o0000okBceond/mL00ond
/mL00ol0003oooooooooo`0Iooooo`03o`000?nd/mOo];?G00?o];?G00?o0000ojj^eon^[]L00_n^
[]L00ol0003oooooooooo`0Jooooo`03o`000?n^[]Oo[ZkG00Co[ZkG00?o0000ojRZf?nXZ]P00_nX
Z]P00ol0003oooooooooo`0Nooooo`03o`000?nXZ]SoZ:[H00CoZ:[H00?o0000oj6Wf_nQYmX00_nQ
YmX00ol0003oooooooooo`03ooooo`?o00003onQYmX3o`0002oooooo1?l0001_ooooo`00Voooool2
o`0002gooooo0ol0000=okbmfP03o`000?nl_M[o_;gJ00;o_;gJ00?o0000okVhfOni^=T00_ni^=T0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o0000okVhfOni^=T00_ni^=T0
0ol0003o];?GokBce`02okBce`03o`000?oooooooooo01[ooooo00?o0000okBceond/mL00_nd/mL0
0ol0003o[ZkGojj^e`03ojj^e`03o`000?oooooooooo01[ooooo00?o0000ojj^eon^[]L01?n^[]L0
0ol0003oZ:[HojRZf003ojRZf003o`000?oooooooooo01kooooo00?o0000ojRZf?nXZ]P00onXZ]P0
0ol0003oXJOJoj6WfP03oj6WfP03o`000?oooooo000000;o00003_nQYmX4o`0002kooooo1?l0001c
ooooo`00WOooool00ol0003oooooooooo`0]ooooo`?o00002_nl_MX01Ol0003o_;gJokbmf_nl_M[o
000000?o^KSI1?l00003ooooo`03o`000?oooooooooo01Cooooo00?o0000okVhfOni^=T00oni^=T0
0ol0003o];?GokBce`02okBce`03o`000?oooooooooo01[ooooo00?o0000okBceond/mL00_nd/mL0
0ol0003o[ZkGojj^e`03ojj^e`03o`000?oooooooooo01_ooooo00?o0000ojj^eon^[]L00on^[]L0
0ol0003oZ:[HojRZf003ojRZf003o`000?oooooooooo01kooooo00?o0000ojRZf?nXZ]P01?nXZ]P0
0ol0003oXJOJoj6WfP03oj6WfP03o`000?nQYm[oXJOJ00coXJOJ0ol0000^ooooo`Co0000Moooool0
09kooooo00?o0000ooooooooool0;oooool4o`0000Ko_;gJ00Co0000okbmf_nl_M[o00000_ni^=T2
o`0000Co^KSI1Ol0000Eooooo`03o`000?ni^=Wo^KSI00;o^KSI00?o0000okBceond/mL00ond/mL0
0ol0003oooooooooo`0Jooooo`03o`000?nd/mOo];?G00;o];?G00?o0000ojj^eon^[]L00on^[]L0
0ol0003oooooooooo`0Kooooo`03o`000?n^[]Oo[ZkG00Co[ZkG00?o0000ojRZf?nXZ]P00_nXZ]P0
0ol0003oooooooooo`0Oooooo`03o`000?nXZ]SoZ:[H00CoZ:[H00?o0000oj6Wf_nQYmX00_nQYmX0
0ol0003oXJOJoj6WfP09oj6WfP?o0000;Oooool4o`0007_ooooo002Oooooo`;o0000<oooool3o`00
00Co_;gJ00?o0000okbmf_l000000_l0000;okVhf@Co00004Oooool00ol0003o^KSIokVhf@02okVh
f@03o`000?nd/mOo];?G00;o];?G00?o0000ooooooooool06oooool00ol0003o];?GokBce`02okBc
e`03o`000?n^[]Oo[ZkG00?o[ZkG00?o0000ooooooooool06oooool00ol0003o[ZkGojj^e`04ojj^
e`03o`000?nXZ]SoZ:[H00;oZ:[H00?o0000ooooooooool07Oooool5o`0000CoZ:[H00Go0000oj6W
f_nQYm[oXJOJo`000009oj6WfP?o0000;?ooool4o`0007oooooo002Qooooo`03o`000?oooooooooo
03?ooooo0ol000001?nl_M[o0000o`000?l0000AokVhf@Go00002oooool00ol0003o^KSIokVhf@02
okVhf@03o`000?nd/mOo];?G00?o];?G00?o0000ooooooooool06oooool00ol0003o];?GokBce`02
okBce`03o`000?n^[]Oo[ZkG00?o[ZkG00?o0000ooooooooool06oooool00ol0003o[ZkGojj^e`04
ojj^e`03o`000?nXZ]SoZ:[H00?oZ:[H00?o0000ooooooooool05oooool5o`0000GoZ:[H0_l00003
ojRZf004o`000?nQYm[oXJOJo`0000KoXJOJ0ol0000[ooooo`Co0000Poooool00:;ooooo00?o0000
ooooooooool0=Oooool4o`0001Ko^KSI1?l00007ooooo`03o`000?ni^=Wo^KSI00;o^KSI00?o0000
okBceond/mL00_nd/mL00ol0003oooooooooo`0Looooo`03o`000?nd/mOo];?G00;o];?G00?o0000
ojj^eon^[]L00on^[]L00ol0003oooooooooo`0Looooo`03o`000?n^[]Oo[ZkG00?o[ZkG00?o0000
ojRZf?nXZ]P00onXZ]P00ol0003oooooooooo`0Aooooo`Ko00003?nXZ]P4o`0000;oXJOJ00Co0000
oj6Wf_nQYm[oXJOJ0ol0000Yooooo`Go0000Qoooool00:?ooooo0_l0000iooooo`Go00005Oni^=T5
o`0000;ooooo00?o0000okVhfOni^=T00_ni^=T00ol0003o];?GokBce`02okBce`03o`000?oooooo
oooo01_ooooo00?o0000okBceond/mL00ond/mL00ol0003o[ZkGojj^e`03ojj^e`03o`000?oooooo
oooo01cooooo00?o0000ojj^eon^[]L01?n^[]L00ol0003oZ:[HojRZf002ojRZf003o`000?oooooo
oooo00cooooo1Ol0000EojRZf0?o000000CoXJOJo`000?l0003o0000:?ooool4o`0008cooooo002U
ooooo`03o`000?oooooooooo03_ooooo1Ol0000EokVhf@;o00001?ni^=T00ol0003o];?GokBce`03
okBce`03o`000?oooooooooo01_ooooo00?o0000okBceond/mL00ond/mL00ol0003o[ZkGojj^e`03
ojj^e`03o`000?oooooooooo01cooooo00?o0000ojj^eon^[]L01?n^[]L00ol0003oZ:[HojRZf002
ojRZf003o`000?oooooooooo00Kooooo1_l0000LojRZf0;o00009oooool4o`00093ooooo002Voooo
o`03o`000?oooooooooo03oooooo1Ol0000AokVhf@03o`000?ni^=Wo^KSI00;o^KSI00Co0000okBc
eond/mOo];?G1ol0000Iooooo`03o`000?nd/mOo];?G00?o];?G00?o0000ojj^eon^[]L00on^[]L0
0ol0003oooooooooo`0Looooo`03o`000?n^[]Oo[ZkG00Co[ZkG00?o0000ojRZf?nXZ]P00onXZ]P0
0ol0003oooooooooo`05o`0001WoZ:[H1_l0000Xooooo`Co0000U?ooool00:Oooooo0_l00010oooo
o`04o`000?ooooooooooooooo`Co00003_ni^=T01Ol0003o^KSIokVhfOni^=Wo000000;o];?G00?o
0000okBceond/mL01Ond/mL;o`0000kooooo00?o0000okBceond/mL00ond/mL00ol0003o[ZkGojj^
e`03ojj^e`03o`000?oooooooooo01gooooo00?o0000ojj^eon^[]L00on^[]L00ol0003oZ:[HojRZ
f003ojRZf0?o00006OnXZ]P5o`0002[ooooo1?l0002Hooooo`00ZOooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo00Gooooo1Ol00009okVhf@05o`000?ni^=Wo^KSIo`000?nd/mL00_l0
000CokBce`[o00001?ooool00ol0003o];?GokBce`03okBce`03o`000?n^[]Oo[ZkG00?o[ZkG00?o
0000ooooooooool03OoooolBo`0000Go[ZkG00?o0000ojRZf?nXZ]P00_nXZ]P00ol0003oZ:[HojRZ
f00CojRZf0Ko0000:oooool4o`0009cooooo002Zooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool02_ooool5o`0000Go^KSI00Co0000okVhfOl0003o00007ond/mL5o`0000Go];?G00?o
0000ojj^eon^[]L00_n^[]LAo`0001;o[ZkG00?o0000ojj^eon^[]L00_n^[]L01Ol0003oZ:[HojRZ
f?nXZ]So0000013oZ:[H1_l0000]ooooo`Co0000X?ooool00:_ooooo0_l0000looooo`03o`000?oo
oooooooo00oooooo1_l000000oni^=Wo0000okBce`0SokBce`03o`000?nd/mOo];?G00;o];?G00?o
0000ojj^eon^[]L00_n^[]L00ol0003o[ZkGojj^e`0Rojj^e`;o00000_n^[]L01?l0003oZ:[HojRZ
f?l0000;ojRZf0Ko0000;oooool4o`000:Cooooo002]ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool05?ooool7o`00027o];?G00Go0000okBceond/mOo];?Go`000003ojj^e`03o`00
0?n^[]Oo[ZkG02Go[ZkG0ol00002ojRZf003o`000?nXZ]SoZ:[H00CoZ:[H1Ol0000aooooo`Co0000
Z?ooool00:kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Kooooo`_o00005ond
/mL01?l0003o];?GokBceol00002ojj^e`03o`000?n^[]Oo[ZkG02So[ZkG0ol000000onXZ]So0000
o`000004o`00037ooooo1Ol0002/ooooo`00[oooool2o`0003Sooooo00?o0000ooooooooool09_oo
ool;o`0000go];?G00Go0000okBceol0003o[ZkGo`00000Pojj^e`So00001?n^[]L3o`0003?ooooo
1?l0002aooooo`00/Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo037ooooo2ol0
0003okBce`?o00002_n^[]LGo`0003kooooo1?l0002eooooo`00/_ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo03gooooo4?l0001Aooooo`Co0000^Oooool00;?ooooo0_l0000coooo
o`03o`000?oooooooooo09[ooooo1?l0002mooooo`00]Oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo09Kooooo1?l00031ooooo`00]_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo09;ooooo1?l00035ooooo`00]oooool2o`0002oooooo00?o0000ooooooooool0S_oo
ool4o`000<Wooooo002iooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0R_ooool4
o`000<gooooo002jooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Q_ooool4o`00
0=7ooooo002kooooo`;o0000:oooool00ol0003oooooooooo`21ooooo`Go0000eOooool00;gooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1mooooo`Co0000f_ooool00;kooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`1iooooo`Co0000g_ooool00;oooooo0_l0000W
ooooo`03o`000?oooooooooo07Gooooo1?l0003Rooooo`00`Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo077ooooo1?l0003Vooooo`00`_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo06gooooo1?l0003Zooooo`00`oooool2o`0002?ooooo00?o0000ooooooooool0
JOooool4o`000>kooooo0035ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0IOoo
ool4o`000?;ooooo0036ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0HOooool4
o`000?Kooooo0037ooooo`;o00007oooool00ol0003oooooooooo`1Looooo`Go0000n_ooool00<Wo
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Hooooo`Co0000ooooool00<[ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`1Dooooo`Co0000ooooool4ooooo`00booo
ool2o`0001_ooooo00?o0000ooooooooool0D?ooool4o`000?oooooo2?ooool00<gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1<ooooo`Co0000ooooool<ooooo`00c_ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo1?l0003ooooooa3ooooo003?ooooo`;o
00005oooool00ol0003oooooooooo`14ooooo`Co0000oooooolDooooo`00dOooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo043ooooo1?l0003ooooooaSooooo003Booooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0??ooool4o`000?oooooo7?ooool00=?ooooo0_l0000C
ooooo`03o`000?oooooooooo03Sooooo1?l0003oooooob3ooooo003Eooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0<oooool5o`000?oooooo9?ooool00=Kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0`ooooo`Co0000oooooolYooooo`00eoooool2o`0000kooooo
00?o0000ooooooooool0;?ooool4o`000?oooooo;Oooool00=Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Xooooo`Co0000oooooolaooooo`00f_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Cooooo1?l0003oooooocGooooo003Kooooo`;o00002_ooool00ol0
003oooooooooo`0Pooooo`Co0000ooooooliooooo`00gOooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01cooooo1?l0003oooooocgooooo003Nooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool06?ooool4o`000?oooooo@Oooool00=oooooo0_l00006ooooo`03o`000?oo
oooooooo01Cooooo1?l0003oooooodGooooo003Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03oooool5o`000?ooooooBOooool00>;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0;ooooo`Co0000oooooom>ooooo`00hoooool2o`0000;ooooo00?o0000oooooooo
ool01oooool4o`000?ooooooD_ooool00>Gooooo00?o0000ooooool000001Oooool4o`000?oooooo
E_ooool00>Kooooo0_l000000ooooooo0000o`000002o`000?ooooooF_ooool00>Oooooo0_l0003o
oooooekooooo0000\
\>"],
  ImageRangeCache->{{{0, 581}, {564.062, 0}} -> {0.00641784, -4.55792*^-6, \
0.00161611, 0.00161611}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Saving to Rotater Format", "Section"],

Cell[TextData[{
  "Once saved as ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics, it can be exported to other 3D graphics formats using \
appropriate Mathematica packages, such as CAD programs or rending programs \
like DXF or POV. Here's an example of exporting it into a format used by a 3D \
dynamic viewer called Rotater."
}], "Text"],

Cell[TextData[{
  "Rotater is a 3D object viewer. It allows you to rotate graphics in real \
time, show either as dots or wireframe. Rotater is available for Mac OS 9, \
Mac OS X, and DOS (Windows).\n\nFor Macintosh version, see\n",
  ButtonBox["http://raru.adelaide.edu.au/rotater/",
    ButtonData:>{
      URL[ "http://www.silicon-alley.com/cat/rotate.html"], None},
    ButtonStyle->"Hyperlink"],
  "\n\nFor DOS versions, see\n",
  ButtonBox["http://www.silicon-alley.com/cat/rotate.html",
    ButtonData:>{
      URL[ "http://www.silicon-alley.com/cat/rotate.html"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell["Needs[\"SaveToRotaterFormat`\"]", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?SaveToRotaterFormat\)\)], "Input"],

Cell[BoxData[
    \("SaveToRotaterFormat[ \"fileName\", graphicsData, commentString, \
(options)] will convert a graphicsData to Rotater format and save the result \
as a text file named fileName. graphicsData can be any of SurfaceGraphics, \
ContourGraphics, DensityGraphics, or Graphics3D objects. commentString is a \
string inserted literally into the beginning of the file. Remember that \
comments starts with \"#\". Options include: BoxRatios, ClosePolygon, \
ColorCode, and ExportPrecision. Each is documented on-line. Type ?name for \
more information. Example: Plot3D[ Cos[x] Cos[y], {x, -Pi, Pi}, {y, -Pi, \
Pi}]; SaveToRotaterFormat[ \"myGraphics.txt\", %]"\)], "Print",
  CellTags->"Info3245785306-7430749"]
}, Open  ]],

Cell[BoxData[
    \(SaveToRotaterFormat["\<Costa.rot\>", 
      ShowSurface["\<Documents/3dxm/Costa.surf\>"], "\<#3dfs\r#tos\>"]\)], \
"Input"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1600}, {0, 1178}},
AutoGeneratedPackage->"False",
WindowSize->{904, 699},
WindowMargins->{{111, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3247255160-7945342"->{
    Cell[6330, 215, 247, 4, 39, "Print",
      CellTags->"Info3247255160-7945342"]},
  "Info3245785306-7430749"->{
    Cell[2278177, 95444, 720, 10, 119, "Print",
      CellTags->"Info3245785306-7430749"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3247255160-7945342", 2279727, 95481},
  {"Info3245785306-7430749", 2279842, 95484}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 130, 4, 136, "Title"],

Cell[CellGroupData[{
Cell[1882, 60, 48, 0, 42, "Subsubsection"],
Cell[1933, 62, 846, 25, 206, "Text"],
Cell[2782, 89, 107, 3, 38, "Text"],
Cell[2892, 94, 122, 3, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3051, 102, 39, 0, 54, "Subtitle"],
Cell[3093, 104, 226, 4, 62, "Text"],
Cell[3322, 110, 242, 5, 121, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[3589, 119, 70, 1, 53, "Subsubtitle"],
Cell[3662, 122, 987, 22, 296, "Text"],
Cell[4652, 146, 277, 6, 86, "Text"],
Cell[4932, 154, 118, 3, 49, "Input",
  Evaluatable->False],
Cell[5053, 159, 400, 12, 73, "Text"],
Cell[5456, 173, 115, 3, 38, "Text"],
Cell[5574, 178, 163, 4, 49, "Input",
  Evaluatable->False],
Cell[5740, 184, 149, 5, 38, "Text"],
Cell[5892, 191, 138, 3, 49, "Input",
  Evaluatable->False]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6079, 200, 40, 0, 65, "Subtitle"],

Cell[CellGroupData[{
Cell[6144, 204, 48, 0, 56, "Section"],

Cell[CellGroupData[{
Cell[6217, 208, 36, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[6278, 212, 49, 1, 49, "Input"],
Cell[6330, 215, 247, 4, 39, "Print",
  CellTags->"Info3247255160-7945342"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6614, 224, 74, 1, 49, "Input"],
Cell[6691, 227, 393460, 16517, 288, 286712, 15195, "GraphicsData", \
"PostScript", "Graphics"],
Cell[400154, 16746, 132, 3, 27, "Output"]
}, Open  ]],
Cell[400301, 16752, 72, 0, 38, "Text"],
Cell[400376, 16754, 89, 1, 49, "Input"],
Cell[400468, 16757, 144, 3, 62, "Text"],

Cell[CellGroupData[{
Cell[400637, 16764, 105, 2, 49, "Input"],
Cell[400745, 16768, 384907, 16674, 296, 293953, 15547, "GraphicsData", \
"PostScript", "Graphics"],
Cell[785655, 33444, 132, 3, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[785848, 33454, 38, 0, 42, "Subsubtitle"],
Cell[785889, 33456, 298, 7, 86, "Text"],
Cell[786190, 33465, 463, 12, 86, "Text"],
Cell[786656, 33479, 71, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[786752, 33483, 199, 5, 121, "Input",
  InitializationCell->True],
Cell[786954, 33490, 115, 2, 70, "Output"]
}, Open  ]],
Cell[787084, 33495, 115, 3, 38, "Text"],

Cell[CellGroupData[{
Cell[787224, 33502, 92, 2, 49, "Input",
  InitializationCell->True],
Cell[787319, 33506, 936, 15, 70, "Output"]
}, Open  ]],
Cell[788270, 33524, 189, 5, 62, "Text"],
Cell[788462, 33531, 85, 2, 49, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[788596, 33539, 37, 0, 65, "Subtitle"],
Cell[788636, 33541, 179, 4, 62, "Text"],
Cell[788818, 33547, 96, 3, 38, "Text"],
Cell[788917, 33552, 349, 6, 193, "Input"],
Cell[789269, 33560, 526, 10, 217, "Input"],
Cell[789798, 33572, 46, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[789869, 33576, 85, 1, 49, "Input"],
Cell[789957, 33579, 1486859, 61820, 574, 1069605, 56664, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2276819, 95401, 132, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2276988, 95409, 43, 0, 56, "Section"],
Cell[2277034, 95411, 358, 8, 86, "Text"],
Cell[2277395, 95421, 620, 13, 206, "Text"],
Cell[2278018, 95436, 74, 1, 49, "Input"],

Cell[CellGroupData[{
Cell[2278117, 95441, 57, 1, 49, "Input"],
Cell[2278177, 95444, 720, 10, 119, "Print",
  CellTags->"Info3245785306-7430749"]
}, Open  ]],
Cell[2278912, 95457, 143, 3, 73, "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

